@@ -36,22 +36,24 @@
 static INTBIG    cla_workingarccount = 0;
 static ARCINST **cla_workingarcs;
 
-/* prototypes for local routines */
-INTSML cla_modifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, INTSML);
-INTSML cla_modnodearcs(NODEINST*, INTSML, INTSML);
-void cla_modwithin(NODEINST*, INTSML, INTSML);
-INTSML cla_modrigid(NODEINST*, INTSML, INTSML);
-INTSML cla_modflex(NODEINST*, INTSML, INTSML);
-void cla_nonorthogfixang(ARCINST*, INTSML, INTSML, NODEINST*, INTBIG[2], INTBIG[2]);
-void cla_ensurearcinst(ARCINST*, INTSML);
-void cla_updatearc(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void cla_domovearcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void cla_adjustmatrix(NODEINST*, PORTPROTO*, XARRAY);
+/* routines referenced in "conlin.c"*/
 void cla_oldportposition(NODEINST*, PORTPROTO*, INTBIG*, INTBIG*);
-void cla_makeoldrot(NODEINST*, XARRAY);
-void cla_makeoldtrans(NODEINST*, XARRAY);
-void cla_computefacet(NODEPROTO*, INTSML);
-INTSML cla_lookdown(NODEPROTO*);
+void cla_adjustmatrix(NODEINST*, PORTPROTO*, XARRAY);
+
+/* prototypes for local routines */
+static INTSML cla_modifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, INTSML);
+static INTSML cla_modnodearcs(NODEINST*, INTSML, INTSML);
+static void cla_modwithin(NODEINST*, INTSML, INTSML);
+static INTSML cla_modrigid(NODEINST*, INTSML, INTSML);
+static INTSML cla_modflex(NODEINST*, INTSML, INTSML);
+static void cla_nonorthogfixang(ARCINST*, INTSML, INTSML, NODEINST*, INTBIG[2], INTBIG[2]);
+static void cla_ensurearcinst(ARCINST*, INTSML);
+static void cla_updatearc(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void cla_domovearcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void cla_makeoldrot(NODEINST*, XARRAY);
+static void cla_makeoldtrans(NODEINST*, XARRAY);
+static void cla_computefacet(NODEPROTO*, INTSML);
+static INTSML cla_lookdown(NODEPROTO*);
 
 #define DEBUG 1			/* comment out for normal life */
 
@@ -355,14 +357,69 @@ void cla_layconmodifynodeproto(NODEPROTO *np) {}
 void cla_layconnewlib(LIBRARY *lib) {}
 void cla_layconkilllib(LIBRARY *lib) {}
 void cla_layconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG saddr,
-	INTBIG stype, INTBIG sdes) {}
-void cla_layconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype,
-	INTBIG aindex, INTBIG oldval) {}
+	INTBIG stype, UINTBIG *olddes) {}
 void cla_layconinsertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex) {}
 void cla_laycondeletevariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex,
 	INTBIG oldval) {}
 void cla_layconsetvariable(void) {}
-void cla_layconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG olddes) {}
+
+/******************** TEXT MODIFICATION CODE *************************/
+
+/* #define TEXTPARTOFOBJECTBOUNDS 1 */
+
+void cla_layconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype,
+	INTBIG aindex, INTBIG oldval)
+{
+#ifdef TEXTPARTOFOBJECTBOUNDS
+	REGISTER char *name;
+	REGISTER PORTPROTO *pp;
+	REGISTER NODEINST *ni;
+
+	/* look for modified text descriptor on exports */
+	if (type == VPORTPROTO)
+	{
+		if ((stype&VCREF) != 0)
+		{
+			name = changedvariablename(type, key, stype);
+			if (strcmp(name, "textdescript") == 0)
+			{
+				if (aindex == 1)
+				{
+					pp = (PORTPROTO *)addr;
+					ni = pp->subnodeinst;
+					updategeom(ni->geom, ni->parent);
+				}
+			}
+		}
+	}
+#endif
+}
+
+void cla_layconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *olddes)
+{
+#ifdef TEXTPARTOFOBJECTBOUNDS
+	REGISTER NODEINST *ni;
+	REGISTER ARCINST *ai;
+	REGISTER PORTPROTO *pp;
+
+	switch (type)
+	{
+		case VNODEINST:
+			ni = (NODEINST *)addr;
+			updategeom(ni->geom, ni->parent);
+			break;
+		case VPORTPROTO:
+			pp = (PORTPROTO *)addr;
+			ni = pp->subnodeinst;
+			updategeom(ni->geom, ni->parent);
+			break;
+		case VARCINST:
+			ai = (ARCINST *)addr;
+			updategeom(ai->geom, ai->parent);
+			break;
+	}
+#endif
+}
 
 /******************** NODE MODIFICATION CODE *************************/
 
@@ -716,7 +773,6 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
  */
 INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 {
-	REGISTER PORTPROTO *opt;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai, **arclist;
 	REGISTER NODEINST *ono;
@@ -831,7 +887,6 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 		/* get other end of arcinst and its position */
 		ono = ai->end[thatend].nodeinst;
-		opt = ai->end[thatend].portarcinst->proto;
 		ax[thatend] = ai->end[thatend].xpos;
 		ay[thatend] = ai->end[thatend].ypos;
 #ifdef	DEBUG
@@ -1552,6 +1607,9 @@ INTSML cla_lookdown(NODEPROTO *start)
 			ni->userbits &= ~MARKN;
 			np = ni->proto;
 
+			/* ignore recursive references (showing icon in contents) */
+/*			if (np->cell == start->cell) continue; */
+
 			/* if this nodeinst is to change, mark the parent facet also */
 			if ((np->userbits & FACETMOD) != 0) start->userbits |= FACETMOD;
 
@@ -1577,6 +1635,7 @@ INTSML cla_lookdown(NODEPROTO *start)
 		np = ni->proto;
 		ni->userbits &= ~(MARKN|TOUCHN);
 		if (np->primindex != 0) continue;
+/*		if (np->cell == start->cell) continue; */
 		if ((np->userbits & FACETMOD) == 0) continue;
 		ni->userbits |= MARKN | TOUCHN;
 	}
