@@ -63,14 +63,14 @@ COMCOMP cli_linconp = {linconopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("linear constraint system option"), 0};
 
 /* global data in linear constraints */
-CONSTRAINT *cli_constraint;	/* the constraint object for this solver */
-INTSML       cli_manhattan;	/* nonzero to assume Manhattan constraints */
-INTBIG       cli_properties;	/* variable key for "CONLIN_properties" */
-NODEPROTO  *cli_curfacet;	/* the current facet being equated to text */
-INTSML       cli_ownchanges;	/* set if changes are internally generated */
-INTSML       cli_textlines;	/* number of declaration/connection lines */
-INTSML       cli_texton;		/* nonzero if text/graphics system is on */
-char       *cli_linconops[] = {">=", "==", "<="};
+       CONSTRAINT *cli_constraint;	/* the constraint object for this solver */
+       INTSML      cli_manhattan;	/* nonzero to assume Manhattan constraints */
+       INTBIG      cli_properties;	/* variable key for "CONLIN_properties" */
+       NODEPROTO  *cli_curfacet;	/* the current facet being equated to text */
+       INTSML      cli_ownchanges;	/* set if changes are internally generated */
+       INTSML      cli_textlines;	/* number of declaration/connection lines */
+       INTSML      cli_texton;		/* nonzero if text/graphics system is on */
+static char       *cli_linconops[] = {">=", "==", "<="};
 
 static INTSML cli_conlindebug;
 static INTSML cli_didsolve;
@@ -104,20 +104,20 @@ void cla_adjustmatrix(NODEINST*, PORTPROTO*, XARRAY);
 void cla_oldportposition(NODEINST*, PORTPROTO*, INTBIG*, INTBIG*);
 
 /* prototypes for local routines */
-CONARC *cli_allocconarc(void);
-void cli_freeconarc(CONARC*);
-CONNODE *cli_allocconnode(void);
-void cli_freeconnode(CONNODE*);
-void cli_dosolve(NODEPROTO*);
-INTSML cli_buildconstraints(NODEPROTO*, CONNODE**, INTSML, INTSML);
-void cli_addconstraint(ARCINST*, CONNODE**, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void cli_adjustconstraints(CONNODE*, INTSML);
-INTSML cli_solveconstraints(CONNODE*, INTSML);
-INTSML cli_satisfy(CONNODE*, CONARC*);
-void cli_applyconstraints(NODEPROTO*, CONNODE*, INTSML);
-void cli_deleteconstraints(CONNODE*);
-void cli_printconstraints(CONNODE*, char*, char*);
-void cli_nameallnodes(NODEPROTO*);
+static CONARC *cli_allocconarc(void);
+static void cli_freeconarc(CONARC*);
+static CONNODE *cli_allocconnode(void);
+static void cli_freeconnode(CONNODE*);
+static void cli_dosolve(NODEPROTO*);
+static INTSML cli_buildconstraints(NODEPROTO*, CONNODE**, INTSML, INTSML);
+static void cli_addconstraint(ARCINST*, CONNODE**, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void cli_adjustconstraints(CONNODE*, INTSML);
+static INTSML cli_solveconstraints(CONNODE*, INTSML);
+static INTSML cli_satisfy(CONNODE*, CONARC*);
+static void cli_applyconstraints(NODEPROTO*, CONNODE*, INTSML);
+static void cli_deleteconstraints(CONNODE*);
+static void cli_printconstraints(CONNODE*, char*, char*);
+static void cli_nameallnodes(NODEPROTO*);
 
 /****************************** ALLOCATION ******************************/
 
@@ -267,7 +267,7 @@ void cli_linconsetmode(INTSML count, char *par[])
 		}
 		if (namesamen(pp, "highlight-equivalent", l) == 0 && l >= 1)
 		{
-			geom = (GEOM *)askaid(us_aid, "get-object");
+			geom = (GEOM *)asktool(us_tool, "get-object");
 			if (geom == NOGEOM)
 			{
 				ttyputerr(M_("Find a single object first"));
@@ -467,6 +467,7 @@ void cli_linconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 	XARRAY trans;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai;
+	REGISTER CHANGE *cha;
 
 	/* if simple rotation on transposed nodeinst, reverse rotation */
 	if (ni->transpose != 0 && dtrans == 0) drot = (3600 - drot) % 3600;
@@ -496,8 +497,9 @@ void cli_linconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 		if (thisend == thatend)
 		{
 			/* arc is internal: compute old center of nodeinst */
-			ox = (((CHANGE *)ni->changeaddr)->p1 + ((CHANGE *)ni->changeaddr)->p3) / 2;
-			oy = (((CHANGE *)ni->changeaddr)->p2 + ((CHANGE *)ni->changeaddr)->p4) / 2;
+			cha = (CHANGE *)ni->changeaddr;
+			ox = (cha->p1 + cha->p3) / 2;
+			oy = (cha->p2 + cha->p4) / 2;
 
 			/* prepare transformation matrix */
 			makeangle(drot, dtrans, trans);
@@ -801,7 +803,7 @@ void cli_linconmodifyportproto(PORTPROTO *pp, NODEINST *oni, PORTPROTO *opp)
 }
 
 void cli_linconmodifynodeproto(NODEPROTO *np) {}
-void cli_linconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG descript) {}
+void cli_linconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *descript) {}
 void cli_linconnewlib(LIBRARY *lib) {}
 void cli_linconkilllib(LIBRARY *lib) {}
 
@@ -821,7 +823,7 @@ void cli_linconnewvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
 }
 
 void cli_linconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG oldaddr,
-	INTBIG oldtype, INTBIG olddescript)
+	INTBIG oldtype, UINTBIG *olddescript)
 {
 	if ((oldtype&VCREF) != 0) return;
 	if ((type&VTYPE) == VARCINST)
@@ -1570,8 +1572,7 @@ void cli_nameallnodes(NODEPROTO *np)
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)returninfstr(), VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
-			var->textdescript = (var->textdescript & ~VTSIZE) |
-				(defaulttextsize(3) << VTSIZESH);
+			defaulttextsize(3, var->textdescript);
 	}
 
 	/* free the abbreviation keys */
