@@ -30,20 +30,20 @@
 #include "global.h"
 #include "conlin.h"
 
-WINDOWPART *cli_curwindow;
+static WINDOWPART *cli_curwindow;
 
 /* prototypes for local routines */
-void cli_addequivcon(ARCINST*);
-INTBIG cli_findtextconn(ARCINST*);
-char *cli_makearcline(ARCINST*);
-char *cli_makeportline(PORTPROTO*);
-INTSML cli_uniquelayer(ARCINST*);
-INTSML cli_addcomponentinfo(NODEINST*);
-void cli_addcomponentdata(COMPONENT*);
-char *cli_componentname(NODEINST*);
-void cli_addcomponentline(char*, WINDOWPART*);
-void cli_addattr(ATTR*);
-void cli_addnodeprotoname(NODEPROTO*);
+static void cli_addequivcon(ARCINST*);
+static INTBIG cli_findtextconn(ARCINST*);
+static char *cli_makearcline(ARCINST*);
+static char *cli_makeportline(PORTPROTO*);
+static INTSML cli_uniquelayer(ARCINST*);
+static INTSML cli_addcomponentinfo(NODEINST*);
+static void cli_addcomponentdata(COMPONENT*);
+static char *cli_componentname(NODEINST*);
+static void cli_addcomponentline(char*, WINDOWPART*);
+static void cli_addattr(ATTR*);
+static void cli_addnodeprotoname(NODEPROTO*);
 
 /************************** IDENTIFY EQUIVALENT TEXT **************************/
 
@@ -68,17 +68,17 @@ void cli_highlightequivalent(GEOM *geom)
 	{
 		ai = geom->entryaddr.ai;
 		cindex = cli_findtextconn(ai);
-		if (cindex != -1) (void)askaid(us_aid, "edit-highlightline", (INTBIG)cli_curwindow, cindex);
+		if (cindex != -1) (void)asktool(us_tool, "edit-highlightline", (INTBIG)cli_curwindow, cindex);
 		return;
 	}
 
 	/* highlight the equivalent node */
 	ni = geom->entryaddr.ni;
 	compname = cli_componentname(ni);
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, 0);
@@ -92,7 +92,7 @@ void cli_highlightequivalent(GEOM *geom)
 		/* search for the changed node */
 		for(compo = dec->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
 			if (namesame(compname, compo->name) == 0) break;
-		if (compo != NOCOMPONENT) (void)askaid(us_aid, "edit-highlightline", (INTBIG)cli_curwindow, i);
+		if (compo != NOCOMPONENT) (void)asktool(us_tool, "edit-highlightline", (INTBIG)cli_curwindow, i);
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -118,7 +118,7 @@ void cli_maketextfacet(NODEPROTO *np)
 	cli_curfacet = np;
 	if (cli_texton == 0)
 	{
-		(void)askaid(us_aid, "edit-describe", (INTBIG)&name);
+		(void)asktool(us_tool, "edit-describe", (INTBIG)&name);
 		(void)initinfstr();
 		(void)addstringtoinfstr(name);
 		(void)addstringtoinfstr(M_(" Editor equivalence for facet "));
@@ -131,12 +131,12 @@ void cli_maketextfacet(NODEPROTO *np)
 	if (np == NONODEPROTO) return;
 
 	/* convert all components into declarations */
-	(void)askaid(us_aid, "edit-suspendgraphics", (INTBIG)cli_curwindow);
+	(void)asktool(us_tool, "edit-suspendgraphics", (INTBIG)cli_curwindow);
 
 	/* erase the window */
-	len = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	len = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<len; i++)
-		(void)askaid(us_aid, "edit-deleteline", (INTBIG)cli_curwindow, i);
+		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
 
 	/* load the facet */
 	trunclen = chars / 4 * 3;
@@ -145,7 +145,7 @@ void cli_maketextfacet(NODEPROTO *np)
 	(void)addstringtoinfstr("BEGINFACET ");
 	(void)addstringtoinfstr(np->cell->cellname);
 	(void)addstringtoinfstr(";");
-	(void)askaid(us_aid, "edit-addline", (INTBIG)cli_curwindow, 0, (INTBIG)returninfstr());
+	(void)asktool(us_tool, "edit-addline", (INTBIG)cli_curwindow, 0, (INTBIG)returninfstr());
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		ni->temp1 = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -205,7 +205,7 @@ void cli_maketextfacet(NODEPROTO *np)
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		cli_addequivcon(ai);
 	cli_replaceendfacet("ENDFACET;", cli_curwindow);
-	(void)askaid(us_aid, "edit-resumegraphics", (INTBIG)cli_curwindow);
+	(void)asktool(us_tool, "edit-resumegraphics", (INTBIG)cli_curwindow);
 }
 
 /***************************** GRAPHIC CHANGES *****************************/
@@ -227,10 +227,10 @@ void cli_eq_newnode(NODEINST *ni)
 	if (ni->parent != cli_curfacet) return;
 
 	/* look for a declaration of this type of node */
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, 0);
@@ -259,7 +259,7 @@ void cli_eq_newnode(NODEINST *ni)
 		/* finish the declaration and replace the line */
 		(void)addstringtoinfstr(dec->protoname);
 		(void)addtoinfstr(';');
-		(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -293,10 +293,10 @@ void cli_eq_killnode(NODEINST *ni)
 
 	/* look for a declaration of this type of node */
 	compname = cli_componentname(ni);
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, 0);
@@ -320,7 +320,7 @@ void cli_eq_killnode(NODEINST *ni)
 		if (dec->count == 1 && namesame(dec->firstcomponent->name, compname) == 0)
 		{
 			/* line had only one keyword: delete the line */
-			(void)askaid(us_aid, "edit-deleteline", (INTBIG)cli_curwindow, i);
+			(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
 			cli_textlines--;
 			cli_deletecomponentdec(dec);
 			return;
@@ -341,7 +341,7 @@ void cli_eq_killnode(NODEINST *ni)
 		(void)addtoinfstr(' ');
 		(void)addstringtoinfstr(dec->protoname);
 		(void)addtoinfstr(';');
-		(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -427,7 +427,7 @@ void cli_eq_modarc(ARCINST *ai)
 	str = cli_makearcline(ai);
 
 	/* change the line */
-	(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, cindex, (INTBIG)str);
+	(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, cindex, (INTBIG)str);
 }
 
 /* handle the creation of port "pp" */
@@ -451,11 +451,11 @@ void cli_eq_killport(PORTPROTO *pp)
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a line of text */
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
@@ -469,7 +469,7 @@ void cli_eq_killport(PORTPROTO *pp)
 		}
 
 		/* export line found: delete it */
-		(void)askaid(us_aid, "edit-deleteline", (INTBIG)cli_curwindow, i);
+		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
 		cli_textlines--;
 		cli_deleteexport(e);
 		break;
@@ -488,11 +488,11 @@ void cli_eq_modport(PORTPROTO *pp)
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a line of text */
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
@@ -506,7 +506,7 @@ void cli_eq_modport(PORTPROTO *pp)
 		}
 
 		/* export line found: rewrite it */
-		(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i,
+		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i,
 			(INTBIG)cli_makeportline(pp));
 		cli_deleteexport(e);
 		break;
@@ -617,18 +617,18 @@ void cli_addequivcon(ARCINST *ai)
 {
 	REGISTER INTBIG i, total;
 
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 
 	/* search for the last line with a valid connection declaration */
 	for(i = total-1; i >= 0; i--)
-		if (cli_linetype((char *)askaid(us_aid, "edit-getline",
+		if (cli_linetype((char *)asktool(us_tool, "edit-getline",
 			(INTBIG)cli_curwindow, i)) == LINECONN) break;
 	if (i < 0)
 	{
 		/* no "connect" lines, take last line anywhere */
 		i = total-1;
 	}
-	(void)askaid(us_aid, "edit-addline", (INTBIG)cli_curwindow, i+1, (INTBIG)cli_makearcline(ai));
+	(void)asktool(us_tool, "edit-addline", (INTBIG)cli_curwindow, i+1, (INTBIG)cli_makearcline(ai));
 	cli_textlines++;
 }
 
@@ -643,7 +643,7 @@ void cli_deleteequivcon(ARCINST *ai)
 	cindex = cli_findtextconn(ai);
 	if (cindex != -1)
 	{
-		(void)askaid(us_aid, "edit-deleteline", (INTBIG)cli_curwindow, cindex);
+		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, cindex);
 		cli_textlines--;
 	}
 }
@@ -660,10 +660,10 @@ void cli_changeequivcomp(NODEINST *ni)
 
 	/* look for a declaration of this type of node */
 	compname = cli_componentname(ni);
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, 0);
@@ -701,7 +701,7 @@ void cli_changeequivcomp(NODEINST *ni)
 		(void)addtoinfstr(' ');
 		(void)addstringtoinfstr(dec->protoname);
 		(void)addtoinfstr(';');
-		(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -725,10 +725,10 @@ void cli_replacename(char *oldname, char *newname)
 	REGISTER ATTR *a;
 
 	/* look through all statements for the old name */
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 
 		/* search declaration statement */
@@ -757,7 +757,7 @@ void cli_replacename(char *oldname, char *newname)
 			(void)addtoinfstr(' ');
 			(void)addstringtoinfstr(dcl->protoname);
 			(void)addtoinfstr(';');
-			(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 			cli_deletecomponentdec(dcl);
 			continue;
 		}
@@ -834,7 +834,7 @@ void cli_replacename(char *oldname, char *newname)
 				(void)addstringtoinfstr(e->subport);
 			}
 			(void)addtoinfstr(';');
-			(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 			cli_deleteexport(e);
 			continue;
 		}
@@ -924,7 +924,7 @@ void cli_replacename(char *oldname, char *newname)
 				(void)addstringtoinfstr(dec->port2);
 			}
 			(void)addstringtoinfstr(";");
-			(void)askaid(us_aid, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
+			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr());
 			cli_deleteconnection(dec);
 		}
 	}
@@ -942,11 +942,11 @@ INTBIG cli_findtextconn(ARCINST *ai)
 	REGISTER char *str;
 	REGISTER CONNECTION *dec;
 
-	total = askaid(us_aid, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a valid connection line */
-		str = (char *)askaid(us_aid, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINECONN) continue;
 		dec = cli_parseconn(str, 1);
@@ -1354,13 +1354,13 @@ void cli_addcomponentline(char *str, WINDOWPART *win)
 {
 	REGISTER INTBIG i, total;
 
-	total = askaid(us_aid, "edit-totallines", (INTBIG)win);
+	total = asktool(us_tool, "edit-totallines", (INTBIG)win);
 
 	/* search for the last line with a valid component declaration */
 	for(i = total-1; i >= 0; i--)
-		if (cli_linetype((char *)askaid(us_aid, "edit-getline", (INTBIG)win, i)) == LINEDECL) break;
+		if (cli_linetype((char *)asktool(us_tool, "edit-getline", (INTBIG)win, i)) == LINEDECL) break;
 	if (i < 0) i = 0;
-	(void)askaid(us_aid, "edit-addline", (INTBIG)win, i+1, (INTBIG)str);
+	(void)asktool(us_tool, "edit-addline", (INTBIG)win, i+1, (INTBIG)str);
 	cli_textlines++;
 }
 
