@@ -54,12 +54,12 @@
 #include "conlin.h"
 
 /* prototypes for local routines */
-INTSML cli_doparseexport(char*, INTSML, EXPORT*);
-INTSML cli_doparseconn(char*, INTSML, CONNECTION*);
-INTSML cli_doparsecomp(char**, char*, INTSML, COMPONENTDEC*);
-INTSML cli_parsetwovalue(INTBIG*, INTBIG*, char*, char**, INTSML);
-ATTR *cli_getattr(char*, char**, char*, INTSML);
-void cli_freeattr(ATTR*);
+static INTSML cli_doparseexport(char*, INTSML, EXPORT*);
+static INTSML cli_doparseconn(char*, INTSML, CONNECTION*);
+static INTSML cli_doparsecomp(char**, char*, INTSML, COMPONENTDEC*);
+static INTSML cli_parsetwovalue(INTBIG*, INTBIG*, char*, char**, INTSML);
+static ATTR *cli_getattr(char*, char**, char*, INTSML);
+static void cli_freeattr(ATTR*);
 
 /*
  * routine to determine the type of text in "line"
