@@ -31,28 +31,28 @@
 #include "database.h"
 #include "conlin.h"
 
-INTSML (*cli_realcharhandler)(WINDOWPART*, INTSML);
-void (*cli_oldttermhandler)(WINDOWPART*);	/* former text editor termination routine */
+static INTSML (*cli_realcharhandler)(WINDOWPART*, INTSML);
+static void (*cli_oldttermhandler)(WINDOWPART*);	/* former text editor termination routine */
 
 /* prototypes for local routines */
-INTSML cli_charhandler(WINDOWPART*, INTSML);
-void cli_termhandler(WINDOWPART*);
-void cli_changehandler(WINDOWPART*, INTSML, char*, char*, INTBIG);
-void cli_changeexport(char*, char*, INTSML, WINDOWPART*);
-void cli_changedeclaration(char*, char*, INTSML, WINDOWPART*);
-void cli_changeconnection(char*, char*, INTSML, WINDOWPART*);
-void cli_updateattrs(ATTR*, ATTR*, INTBIG, INTBIG);
-void cli_deletedeclaration(char*);
-void cli_deletewire(char*);
-void cli_deleteexportline(char*);
-INTSML cli_adddeclaration(char*, INTSML, WINDOWPART*);
-INTSML cli_addwire(char*, INTSML, WINDOWPART*);
-void cli_addexport(char*, INTSML, WINDOWPART*);
-PORTPROTO *cli_getexportsubport(EXPORT*, NODEINST*);
-void cli_getfactors(NODEINST*, NODEPROTO*, COMPONENT*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML*, INTSML*, INTBIG, INTBIG);
-void cli_killthenode(NODEINST*);
-void cli_commentline(INTSML, WINDOWPART*);
-void cli_restoreline(char*, INTSML, WINDOWPART*);
+static INTSML cli_charhandler(WINDOWPART*, INTSML);
+static void cli_termhandler(WINDOWPART*);
+static void cli_changehandler(WINDOWPART*, INTSML, char*, char*, INTBIG);
+static void cli_changeexport(char*, char*, INTSML, WINDOWPART*);
+static void cli_changedeclaration(char*, char*, INTSML, WINDOWPART*);
+static void cli_changeconnection(char*, char*, INTSML, WINDOWPART*);
+static void cli_updateattrs(ATTR*, ATTR*, INTBIG, INTBIG);
+static void cli_deletedeclaration(char*);
+static void cli_deletewire(char*);
+static void cli_deleteexportline(char*);
+static INTSML cli_adddeclaration(char*, INTSML, WINDOWPART*);
+static INTSML cli_addwire(char*, INTSML, WINDOWPART*);
+static void cli_addexport(char*, INTSML, WINDOWPART*);
+static PORTPROTO *cli_getexportsubport(EXPORT*, NODEINST*);
+static void cli_getfactors(NODEINST*, NODEPROTO*, COMPONENT*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML*, INTSML*, INTBIG, INTBIG);
+static void cli_killthenode(NODEINST*);
+static void cli_commentline(INTSML, WINDOWPART*);
+static void cli_restoreline(char*, INTSML, WINDOWPART*);
 
 /************************ EDITOR WINDOW CONTROL ************************/
 
@@ -65,9 +65,9 @@ WINDOWPART *cli_makeeditorwindow(char *header, INTSML *chars, INTSML *lines)
 {
 	REGISTER WINDOWPART *win;
 
-	win = (WINDOWPART *)askaid(us_aid, "window-new");
+	win = (WINDOWPART *)asktool(us_tool, "window-new");
 	if (win == NOWINDOWPART) return(NOWINDOWPART);
-	if (askaid(us_aid, "edit-starteditor", (INTBIG)win, (INTBIG)header,
+	if (asktool(us_tool, "edit-starteditor", (INTBIG)win, (INTBIG)header,
 		(INTBIG)chars, (INTBIG)lines) != 0) return(NOWINDOWPART);
 
 	cli_realcharhandler = win->charhandler;
@@ -105,7 +105,7 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 		ttyputmsg(M_("No valid facet to associate"));
 		return(0);
 	}
-	line = (char *)askaid(us_aid, "edit-getline", (INTBIG)win, -1);
+	line = (char *)asktool(us_tool, "edit-getline", (INTBIG)win, -1);
 	if (line == NOSTRING) type = LINEUNKN; else type = cli_linetype(line);
 
 	switch (type)
@@ -133,8 +133,8 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 				ttyputmsg(M_("Cannot find equivalent arc for this line"));
 				return(0);
 			}
-			(void)askaid(us_aid, "clear");
-			(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
+			(void)asktool(us_tool, "clear");
+			(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 			break;
 
 		case LINEDECL:
@@ -149,8 +149,8 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 			{
 				ni = cli_findnodename(compo->name);
 				if (ni == NONODEINST) continue;
-				if (count == 0) (void)askaid(us_aid, "clear");
-				(void)askaid(us_aid, "show-object", (INTBIG)ni->geom);
+				if (count == 0) (void)asktool(us_tool, "clear");
+				(void)asktool(us_tool, "show-object", (INTBIG)ni->geom);
 				count++;
 			}
 			if (count == 0)
@@ -330,7 +330,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				{
 					newpar[0] = "killfacet";
 					newpar[1] = newname;
-					(void)tellaid(us_aid, 2, newpar);
+					(void)telltool(us_tool, 2, newpar);
 				}
 
 				/* find a window in which to place the facet */
@@ -348,10 +348,10 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 					newpar[0] = "window";
 					newpar[1] = "use";
 					newpar[2] = w->location;
-					(void)tellaid(us_aid, 3, newpar);
+					(void)telltool(us_tool, 3, newpar);
 					newpar[0] = "editfacet";
 					newpar[1] = newname;
-					(void)tellaid(us_aid, 2, newpar);
+					(void)telltool(us_tool, 2, newpar);
 					cli_curfacet = getcurfacet();
 				} else cli_curfacet = newnodeproto(newname, el_curlib);
 				efree(newname);
@@ -360,8 +360,8 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 			case LINEEND:
 				/* put the line at the bottom of the file */
 				(void)initinfstr();
-				(void)addstringtoinfstr((char *)askaid(us_aid, "edit-getline", (INTBIG)win, changed));
-				(void)askaid(us_aid, "edit-deleteline", (INTBIG)win, changed);
+				(void)addstringtoinfstr((char *)asktool(us_tool, "edit-getline", (INTBIG)win, changed));
+				(void)asktool(us_tool, "edit-deleteline", (INTBIG)win, changed);
 				cli_replaceendfacet(returninfstr(), win);
 				break;
 		}
@@ -631,8 +631,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)newcomp->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 			endobjectchange((INTBIG)ni, VNODEINST);
 		}
 		cli_ownchanges = 0;
@@ -687,8 +686,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)newcomp->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 			cli_ownchanges = 0;
 			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0,0,0,0,0);
 
@@ -838,8 +836,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		var = setvalkey((INTBIG)oldend1, VNODEINST, el_node_name, (INTBIG)newcon->end1,
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
-			var->textdescript = (var->textdescript & ~VTSIZE) |
-				(defaulttextsize(3) << VTSIZESH);
+			defaulttextsize(3, var->textdescript);
 		cli_ownchanges = 0;
 		(void)db_change((INTBIG)oldend1, OBJECTEND, VNODEINST, 0,0,0,0,0);
 
@@ -862,8 +859,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		var = setvalkey((INTBIG)oldend2, VNODEINST, el_node_name, (INTBIG)newcon->end2,
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
-			var->textdescript = (var->textdescript & ~VTSIZE) |
-				(defaulttextsize(3) << VTSIZESH);
+			defaulttextsize(3, var->textdescript);
 		cli_ownchanges = 0;
 		(void)db_change((INTBIG)oldend2, OBJECTEND, VNODEINST, 0,0,0,0,0);
 
@@ -1241,8 +1237,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)compo->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 			endobjectchange((INTBIG)ni, VNODEINST);
 		}
 		cli_ownchanges = 0;
@@ -1541,8 +1536,8 @@ void cli_commentline(INTSML cindex, WINDOWPART *win)
 {
 	(void)initinfstr();
 	(void)addstringtoinfstr("; ");
-	(void)addstringtoinfstr((char *)askaid(us_aid, "edit-getline", (INTBIG)win, cindex));
-	(void)askaid(us_aid, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr());
+	(void)addstringtoinfstr((char *)asktool(us_tool, "edit-getline", (INTBIG)win, cindex));
+	(void)asktool(us_tool, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr());
 }
 
 /*
@@ -1552,33 +1547,33 @@ void cli_commentline(INTSML cindex, WINDOWPART *win)
 void cli_restoreline(char *str, INTSML cindex, WINDOWPART *win)
 {
 	/* first insert this old line */
-	(void)askaid(us_aid, "edit-addline", (INTBIG)win, cindex+1, (INTBIG)str);
+	(void)asktool(us_tool, "edit-addline", (INTBIG)win, cindex+1, (INTBIG)str);
 
 	/* now comment out line "cindex" */
 	(void)initinfstr();
 	(void)addstringtoinfstr("; ");
-	(void)addstringtoinfstr((char *)askaid(us_aid, "edit-getline", (INTBIG)win, cindex));
-	(void)askaid(us_aid, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr());
+	(void)addstringtoinfstr((char *)asktool(us_tool, "edit-getline", (INTBIG)win, cindex));
+	(void)asktool(us_tool, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr());
 }
 
 void cli_replaceendfacet(char *str, WINDOWPART *win)
 {
 	REGISTER INTSML i, maxlines, type;
 
-	maxlines = (INTSML)askaid(us_aid, "edit-totallines", (INTBIG)win);
+	maxlines = (INTSML)asktool(us_tool, "edit-totallines", (INTBIG)win);
 
 	/* search for all other "beginfacet" lines */
 	for(i = 0; i < maxlines; i++)
 	{
-		type = cli_linetype((char *)askaid(us_aid, "edit-getline", (INTBIG)win, i));
+		type = cli_linetype((char *)asktool(us_tool, "edit-getline", (INTBIG)win, i));
 		if (type != LINEEND) continue;
 
 		/* found another "beginfacet", delete the text */
-		(void)askaid(us_aid, "edit-deleteline", (INTBIG)win, i);
+		(void)asktool(us_tool, "edit-deleteline", (INTBIG)win, i);
 		i--;
 		maxlines--;
 	}
 
 	/* place this line at the beginning */
-	(void)askaid(us_aid, "edit-addline", (INTBIG)win, maxlines, (INTBIG)str);
+	(void)asktool(us_tool, "edit-addline", (INTBIG)win, maxlines, (INTBIG)str);
 }
