@@ -33,27 +33,27 @@
 #include "conlin.h"
 
 /* the null constraint solver */
-void db_nullconinit(CONSTRAINT*);
-void db_nullconterm(void);
-void db_nullconsetmode(INTSML, char*[]);
-INTBIG db_nullconrequest(char*, INTBIG);
-void db_nullconsolve(NODEPROTO*);
-void db_nullconnewobject(INTBIG, INTBIG);
-void db_nullconkillobject(INTBIG, INTBIG);
-INTSML db_nullconsetobject(INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconmodifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML);
-void db_nullconmodifyarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconmodifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
-void db_nullconmodifynodeproto(NODEPROTO*);
-void db_nullconmodifydescript(INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconnewlib(LIBRARY*);
-void db_nullconkilllib(LIBRARY*);
-void db_nullconnewvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconkillvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconmodifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconinsertvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullcondeletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void db_nullconsetvariable(void);
+static void db_nullconinit(CONSTRAINT*);
+static void db_nullconterm(void);
+static void db_nullconsetmode(INTSML, char*[]);
+static INTBIG db_nullconrequest(char*, INTBIG);
+static void db_nullconsolve(NODEPROTO*);
+static void db_nullconnewobject(INTBIG, INTBIG);
+static void db_nullconkillobject(INTBIG, INTBIG);
+static INTSML db_nullconsetobject(INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullconmodifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML);
+static void db_nullconmodifyarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullconmodifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
+static void db_nullconmodifynodeproto(NODEPROTO*);
+static void db_nullconmodifydescript(INTBIG, INTBIG, INTBIG, UINTBIG*);
+static void db_nullconnewlib(LIBRARY*);
+static void db_nullconkilllib(LIBRARY*);
+static void db_nullconnewvariable(INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullconkillvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, UINTBIG*);
+static void db_nullconmodifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullconinsertvariable(INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullcondeletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void db_nullconsetvariable(void);
 
 CONSTRAINT el_constraints[] =
 {
@@ -127,11 +127,11 @@ void db_nullconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 void db_nullconmodifyarcinst(ARCINST *ai, INTBIG oldx0, INTBIG oldy0, INTBIG oldx1, INTBIG oldy1, INTBIG oldwid, INTBIG oldlen) {}
 void db_nullconmodifyportproto(PORTPROTO *pp, NODEINST *oni, PORTPROTO *opp) {}
 void db_nullconmodifynodeproto(NODEPROTO *np) {}
-void db_nullconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG olddes) {}
+void db_nullconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *olddes) {}
 void db_nullconnewlib(LIBRARY *lib) {}
 void db_nullconkilllib(LIBRARY *lib) {}
 void db_nullconnewvariable(INTBIG addr, INTBIG type, INTBIG skey, INTBIG stype) {}
-void db_nullconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG saddr, INTBIG stype, INTBIG sdes) {}
+void db_nullconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG saddr, INTBIG stype, UINTBIG *olddes) {}
 void db_nullconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype, INTBIG aindex, INTBIG oldval) {}
 void db_nullconinsertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex) {}
 void db_nullcondeletevariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex, INTBIG oldval) {}
