@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: aidtable.c
- * Aid dispatch table
+ * Tool dispatch table
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -32,7 +32,7 @@
 /*
  * sample routines and their arguments:
  *
- * aa_init(INTBIG *argc, char *argv[], AIDENTRY *aid) {}
+ * aa_init(INTBIG *argc, char *argv[], TOOL *tool) {}
  * INTSML aa_set(INTSML count, char *par[]) {}
  * INTBIG aa_request(char *command,...) {}
  * aa_examinenodeproto(NODEPROTO *np) {}
@@ -48,12 +48,12 @@
  *    INTBIG owid, INTBIG olen) {}
  * aa_modifyportproto(PORTPROTO *pp) {}
  * aa_modifynodeproto(NODEPROTO *np) {}
- * aa_modifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG old) {}
+ * aa_modifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *old) {}
  * aa_newobject(INTBIG addr, INTBIG type) {}
  * aa_killobject(INTBIG addr, INTBIG type) {}
  * aa_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype) {}
  * aa_killvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG oldaddr,
- *    INTBIG oldtype, INTBIG olddescript) {}
+ *    INTBIG oldtype, UINTBIG *olddescript) {}
  * aa_modifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype,
  *    INTBIG aindex, INTBIG oldvalue) {}
  * aa_insertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype, INTBIG aindex) {}
@@ -66,7 +66,7 @@
 
 /*
  * first come the interactive tools:
- *    us     user interface aid
+ *    us     user interface tool
  *    io     input/output in many forms
  * now come the synthesis tools:
  *    com    compaction
@@ -77,7 +77,7 @@
  *    vhdl   VHDL compiler (Queen's University)
  *    compen compensation
  *    le     logical effort analyzer/sizer
- * now the aids preceeded by the network tool:
+ * now the tools preceeded by the network tool:
  *    net    network maintenance and comparison
  *    dr     incremental design rule checking
  *    erc    electrical rule checking
@@ -97,22 +97,22 @@
  *    flr    floor planning
  */
 
-#if COMAID
+#if COMTOOL
 # include "compact.h"
   extern COMCOMP com_compactp;
 #endif
 
-#if COMPENAID
+#if COMPENTOOL
 # include "compensate.h"
   extern COMCOMP compen_compensatep;
 #endif
 
-#if DRCAID
+#if DRCTOOL
 # include "drc.h"
   extern COMCOMP dr_drcp;
 #endif
 
-#if ERCAID
+#if ERCTOOL
 # include "erc.h"
   extern COMCOMP erc_tablep;
 #endif
@@ -120,12 +120,12 @@
 # include "eio.h"
 extern COMCOMP io_iop;
 
-#if LOGEFFAID
+#if LOGEFFTOOL
 # include "logeffort.h"
   extern COMCOMP le_tablep;
 #endif
 
-#if MAPPERAID
+#if MAPPERTOOL
 # include "mapper.h"
   extern COMCOMP map_mapperp;
 #endif
@@ -133,27 +133,27 @@ extern COMCOMP io_iop;
 #include "network.h"
 extern COMCOMP net_networkp;
 
-#if PLAAID
+#if PLATOOL
 # include "pla.h"
   extern COMCOMP pla_plap;
 #endif
 
-#if PROJECTAID
+#if PROJECTTOOL
 # include "projecttool.h"
   extern COMCOMP proj_projp;
 #endif
 
-#if ROUTAID
+#if ROUTTOOL
 # include "rout.h"
   extern COMCOMP ro_routerp;
 #endif
 
-#if SCAID
+#if SCTOOL
 # include "sc1.h"
   extern COMCOMP sc_silcomp;
 #endif
 
-#if SIMAID
+#if SIMTOOL
 # include "sim.h"
   extern COMCOMP sim_simulatorp;
 #endif
@@ -161,23 +161,23 @@ extern COMCOMP net_networkp;
 # include "usr.h"
 extern COMCOMP us_userp;
 
-#if VHDLAID
+#if VHDLTOOL
 # include "vhdl.h"
   extern COMCOMP vhdl_comp;
 #endif
 
-AIDENTRY el_aids[] =
+TOOL el_tools[] =
 {
 	/********** the interactive tools **********/
 
 	/* user interface */
-	{"user", AIDON | AIDINCREMENTAL | USEDIALOGS, 0, &us_userp, NOCLUSTER,
+	{"user", TOOLON | TOOLINCREMENTAL | USEDIALOGS, 0, &us_userp, NOCLUSTER,
 	us_init,               us_done,              us_set,				/* init/done/set */
 	us_request,            us_examinenodeproto,  us_slice,				/* request/examine/slice */
 	us_startbatch,         us_endbatch,									/* startbatch/endbatch */
 	us_startobjectchange,  us_endobjectchange,							/* startobject/endobject */
 	us_modifynodeinst,     0,                    0,						/* modnode/modarc/modport */
-	us_modifynodeproto,    0,											/* modnodeproto/moddescript */
+	us_modifynodeproto,    us_modifydescript,							/* modnodeproto/moddescript */
 	us_newobject,          us_killobject,								/* newobject/killobject */
 	us_newvariable,        us_killvariable,								/* newvariable/killvariable */
 	us_modifyvariable,     0,                    0,						/* modvar/insvar/delvar */
@@ -198,9 +198,9 @@ AIDENTRY el_aids[] =
 	0,                     0,                    0,						/* readlib/eraselib/writelib */
 	NOVARIABLE, 0},
 
-#if COMAID
+#if COMTOOL
 	/* compaction module */
-	{"compaction", AIDSYNTHESIS,              0, &com_compactp, NOCLUSTER,
+	{"compaction", TOOLSYNTHESIS,              0, &com_compactp, NOCLUSTER,
 	com_init,              com_done,             com_set,				/* init/done/set */
 	0,                     0,                    com_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -214,9 +214,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if PLAAID
+#if PLATOOL
 	/* PLA generation module */
-	{"pla", AIDSYNTHESIS,                     0, &pla_plap, NOCLUSTER,
+	{"pla", TOOLSYNTHESIS,                     0, &pla_plap, NOCLUSTER,
 	pla_init,              pla_done,             pla_set,				/* init/done/set */
 	0,                     0,                    pla_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -230,9 +230,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if ROUTAID
+#if ROUTTOOL
 	/* wire routing module */
-	{"routing", AIDINCREMENTAL | AIDSYNTHESIS, 0, &ro_routerp, NOCLUSTER,
+	{"routing", TOOLINCREMENTAL | TOOLSYNTHESIS, 0, &ro_routerp, NOCLUSTER,
 	ro_init,               ro_done,              ro_set,				/* init/done/set */
 	0,                     0,                    ro_slice,				/* request/examine/slice */
 	ro_startbatch,         0,											/* startbatch/endbatch */
@@ -246,9 +246,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if SCAID
+#if SCTOOL
 	/* Quisc "Silicon" Compiler module */
-	{"silicon-compiler", AIDSYNTHESIS,	0,	&sc_silcomp,	NOCLUSTER,
+	{"silicon-compiler", TOOLSYNTHESIS,	0,	&sc_silcomp,	NOCLUSTER,
 	sc_init,               sc_done,              sc_set,				/* init/done/set */
 	sc_request,            0,                    sc_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -262,9 +262,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if MAPPERAID
+#if MAPPERTOOL
 	/* mapper module */
-	{"mapper", AIDSYNTHESIS,	0,	&map_mapperp,	NOCLUSTER,
+	{"mapper", TOOLSYNTHESIS,	0,	&map_mapperp,	NOCLUSTER,
 	map_init,              map_done,             map_set,				/* init/done/set */
 	map_request,           map_examinenodeproto, map_slice,				/* request/examine/slice */
 	map_startbatch,        map_endbatch,								/* startbatch/endbatch */
@@ -278,9 +278,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if VHDLAID
+#if VHDLTOOL
 	/* VHDL compiler module */
-	{"vhdl-compiler", AIDSYNTHESIS,	0,	&vhdl_comp,	NOCLUSTER,
+	{"vhdl-compiler", TOOLSYNTHESIS,	0,	&vhdl_comp,	NOCLUSTER,
 	vhdl_init,             vhdl_done,            vhdl_set,				/* init/done/set */
 	vhdl_request,          0,                    vhdl_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -294,9 +294,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if COMPENAID
+#if COMPENTOOL
 	/* compensation module */
-	{"compensation", AIDSYNTHESIS,	0,	&compen_compensatep,	NOCLUSTER,
+	{"compensation", TOOLSYNTHESIS,	0,	&compen_compensatep,	NOCLUSTER,
 	compen_init,           compen_done,          compen_set,			/* init/done/set */
 	0,                     0,                    compen_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -310,9 +310,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if LOGEFFAID
+#if LOGEFFTOOL
 	/* logical effort module */
-	{"logeffort", AIDSYNTHESIS,	0,	&le_tablep,	NOCLUSTER,
+	{"logeffort", TOOLSYNTHESIS,	0,	&le_tablep,	NOCLUSTER,
 	le_init,               le_done,              le_set,				/* init/done/set */
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -327,7 +327,7 @@ AIDENTRY el_aids[] =
 #endif
 
 	/* network maintenance and comparison */
-	{"network", AIDON | AIDINCREMENTAL, 0, &net_networkp, NOCLUSTER,
+	{"network", TOOLON | TOOLINCREMENTAL, 0, &net_networkp, NOCLUSTER,
 	net_init,              net_done,             net_set,				/* init/done/set */
 	net_request,           net_examinenodeproto, net_slice,				/* request/examine/slice */
 	net_startbatch,        net_endbatch,								/* startbatch/endbatch */
@@ -340,9 +340,9 @@ AIDENTRY el_aids[] =
 	net_readlibrary,       net_eraselibrary,     0,						/* readlib/eraselib/writelib */
 	NOVARIABLE, 0},
 
-#if DRCAID
+#if DRCTOOL
 	/* design-rule checker */
-	{"drc", AIDON | AIDINCREMENTAL | AIDANALYSIS, 0, &dr_drcp, NOCLUSTER,
+	{"drc", TOOLON | TOOLINCREMENTAL | TOOLANALYSIS, 0, &dr_drcp, NOCLUSTER,
 	dr_init,               dr_done,              dr_set,				/* init/done/set */
 	0,                     dr_examinenodeproto,  dr_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -356,9 +356,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE,0},
 #endif
 
-#if ERCAID
+#if ERCTOOL
 	/* electrical-rule checker */
-	{"erc", AIDANALYSIS, 0, &erc_tablep, NOCLUSTER,
+	{"erc", TOOLANALYSIS, 0, &erc_tablep, NOCLUSTER,
 	erc_init,              erc_done,             erc_set,				/* init/done/set */
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -372,9 +372,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE,0},
 #endif
 
-#if SIMAID
+#if SIMTOOL
 	/* simulation module */
-	{"simulation", AIDANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
+	{"simulation", TOOLANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
 	sim_init,              sim_done,             sim_set,				/* init/done/set */
 	0,                     0,                    sim_slice,				/* request/examine/slice */
 	sim_startbatch,        0,											/* startbatch/endbatch */
@@ -388,9 +388,9 @@ AIDENTRY el_aids[] =
 	NOVARIABLE, 0},
 #endif
 
-#if PROJECTAID
+#if PROJECTTOOL
 	/* project management module */
-	{"project", AIDON | AIDINCREMENTAL, 0, &proj_projp, NOCLUSTER,
+	{"project", TOOLON | TOOLINCREMENTAL, 0, &proj_projp, NOCLUSTER,
 	proj_init,             proj_done,            proj_set,				/* init/done/set */
 	0,                     0,                    proj_slice,			/* request/examine/slice */
 	proj_startbatch,       0,											/* startbatch/endbatch */
