@@ -46,11 +46,14 @@ INTBIG       el_transistor_width;				/* variable "transistor_width" */
 INTBIG       el_prototype_center;				/* variable "prototype_center" */
 INTBIG       el_node_size_default;				/* variable "NODE_size_default" */
 INTBIG       el_arc_width_default;				/* variable "ARC_width_default" */
+INTBIG       el_attr_width;						/* variable "ATTR_width" */
+INTBIG       el_attr_length;					/* variable "ATTR_length" */
+INTBIG       el_attr_area;						/* variable "ATTR_area" */
 
 CLUSTER     *el_tempcluster;		/* cluster for temporary allocation */
 CLUSTER     *db_cluster;			/* database general allocation */
 
-INTSML       el_maxaid;				/* current number of aids */
+INTSML       el_maxtools;			/* current number of tools */
 LIBRARY     *el_curlib;				/* pointer to current library (list head) */
 
 VIEW        *el_views;				/* list of existing view */
