@@ -33,36 +33,37 @@
 #include "edialogs.h"
 #include "usr.h"
 
-/* prototypes for local routines */
-CHANGE *db_allocchange(void);
-void db_freechange(CHANGE*);
-CHANGEFACET *db_allocchangefacet(void);
-CHANGEBATCH *db_allocchangebatch(void);
-void db_freechangebatch(CHANGEBATCH*);
-void db_killbatch(CHANGEBATCH*);
-char *db_namevariable(INTBIG, INTBIG);
-CHANGEBATCH *db_preparenewbatch(void);
-void db_erasebatch(CHANGEBATCH*);
-void db_freechangefacet(CHANGEFACET*);
-void db_loadhistorylist(short);
-void db_broadcastchange(CHANGE*, INTSML, INTSML);
-INTSML db_reversechange(CHANGE*);
-char *db_describechange(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static INTBIG       db_batchtally;				/* number of batches in list */
+static INTBIG       db_maximumbatches;			/* limit of number of batches */
+static INTBIG       db_batchnumber;				/* batch number counter */
+static CHANGEBATCH *db_currentbatch;			/* current batch of changes */
+static CHANGEBATCH *db_headbatch;				/* most recent change in the list */
+static CHANGEBATCH *db_tailbatch;				/* oldest change in the list */
+static CHANGEBATCH *db_donebatch;				/* last done batch in the list */
+static CHANGEBATCH *db_changebatchfree;			/* head of free change batches */
+static CHANGE      *db_changefree;				/* head of free change modules */
+static CHANGEFACET *db_changefacetfree;			/* head of free change facet modules */
+static TOOL        *db_currenttool;				/* current tool being given a slice */
+       INTSML       db_donextchangequietly = 0;	/* nonzero to do next change quietly */
+       INTSML       db_dochangesquietly = 0;	/* nonzero to do changes quietly */
+       UINTBIG      db_changetimestamp = 0;		/* timestamp for changes to database */
+       INTSML       db_broadcasting = 0;		/* nonzero if broadcasting */
 
-INTBIG       db_batchtally;					/* number of batches in list */
-INTBIG       db_maximumbatches;				/* limit of number of batches */
-INTSML       db_broadcasting = 0;			/* nonzero if broadcasting */
-INTBIG       db_batchnumber;				/* batch number counter */
-CHANGEBATCH *db_currentbatch;				/* current batch of changes */
-CHANGEBATCH *db_headbatch;					/* most recent change in the list */
-CHANGEBATCH *db_tailbatch;					/* oldest change in the list */
-CHANGEBATCH *db_donebatch;					/* last done batch in the list */
-CHANGEBATCH *db_changebatchfree;			/* head of free change batches */
-CHANGE      *db_changefree;					/* head of free change modules */
-CHANGEFACET *db_changefacetfree;			/* head of free change facet modules */
-AIDENTRY    *db_currenttool;				/* current tool being given a slice */
-INTSML       db_donextchangequietly = 0;	/* nonzero to do next change quietly */
-INTSML       db_dochangesquietly = 0;		/* nonzero to do changes quietly */
+/* prototypes for local routines */
+static CHANGE      *db_allocchange(void);
+static void         db_freechange(CHANGE*);
+static CHANGEFACET *db_allocchangefacet(void);
+static CHANGEBATCH *db_allocchangebatch(void);
+static void         db_freechangebatch(CHANGEBATCH*);
+static void         db_killbatch(CHANGEBATCH*);
+static char        *db_namevariable(INTBIG, INTBIG);
+static CHANGEBATCH *db_preparenewbatch(void);
+static void         db_erasebatch(CHANGEBATCH*);
+static void         db_freechangefacet(CHANGEFACET*);
+static void         db_loadhistorylist(short);
+static void         db_broadcastchange(CHANGE*, INTSML, INTSML);
+static INTSML       db_reversechange(CHANGE*);
+static char        *db_describechange(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
 /*
  * Routine to free all memory associated with this module.
@@ -108,7 +109,7 @@ void db_initializechanges(void)
 	/* initialize changes */
 	db_batchtally = 0;
 	db_batchnumber = 1;
-	db_maximumbatches = maxi(el_maxaid + el_maxaid/2 + 1, 20);
+	db_maximumbatches = maxi(el_maxtools + el_maxtools/2 + 1, 20);
 	db_currentbatch = db_headbatch = db_tailbatch = db_donebatch = NOCHANGEBATCH;
 }
 
@@ -178,6 +179,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 			break;
 		case NODEPROTOKILL:
 			major = 1;
+			/* FALLTHROUGH */ 
 		case NODEPROTOMOD:
 			lib = ((NODEPROTO *)obj)->cell->lib;
 			break;
@@ -221,8 +223,8 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	{
 		if (major != 0) np->revisiondate = getcurrenttime();
 		np->adirty = 0;
-		for(i=0; i<el_maxaid; i++)
-			if ((el_aids[i].aidstate & AIDON) == 0) np->adirty |= 1 << i;
+		for(i=0; i<el_maxtools; i++)
+			if ((el_tools[i].toolstate & TOOLON) == 0) np->adirty |= 1 << i;
 	}
 	if (lib != NOLIBRARY)
 	{
@@ -295,6 +297,7 @@ void changesquiet(INTSML quiet)
 void db_broadcastchange(CHANGE *c, INTSML firstchange, INTSML undoredo)
 {
 	REGISTER INTSML i, oldbroadcasting;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/* start the batch if this is the first change */
 	oldbroadcasting = db_broadcasting;
@@ -302,124 +305,128 @@ void db_broadcastchange(CHANGE *c, INTSML firstchange, INTSML undoredo)
 	if (firstchange != 0)
 	{
 		/* broadcast a start-batch on the first change */
-		for(i=0; i<el_maxaid; i++)
-			if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].startbatch != 0)
-				(*el_aids[i].startbatch)(db_currentbatch->aid, undoredo);
+		for(i=0; i<el_maxtools; i++)
+			if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].startbatch != 0)
+				(*el_tools[i].startbatch)(db_currentbatch->tool, undoredo);
 	}
 	switch (c->changetype)
 	{
 		case NODEINSTNEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newobject != 0)
-					(*el_aids[i].newobject)(c->entryaddr, VNODEINST);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newobject != 0)
+					(*el_tools[i].newobject)(c->entryaddr, VNODEINST);
 			break;
 		case NODEINSTKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killobject != 0)
-					(*el_aids[i].killobject)(c->entryaddr, VNODEINST);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killobject != 0)
+					(*el_tools[i].killobject)(c->entryaddr, VNODEINST);
 			break;
 		case NODEINSTMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifynodeinst != 0)
-					(*el_aids[i].modifynodeinst)((NODEINST *)c->entryaddr, c->p1, c->p2,
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifynodeinst != 0)
+					(*el_tools[i].modifynodeinst)((NODEINST *)c->entryaddr, c->p1, c->p2,
 						c->p3, c->p4, (INTSML)c->p5, (INTSML)c->p6);
 			break;
 		case ARCINSTNEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newobject != 0)
-					(*el_aids[i].newobject)(c->entryaddr, VARCINST);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newobject != 0)
+					(*el_tools[i].newobject)(c->entryaddr, VARCINST);
 			break;
 		case ARCINSTKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killobject != 0)
-					(*el_aids[i].killobject)(c->entryaddr, VARCINST);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killobject != 0)
+					(*el_tools[i].killobject)(c->entryaddr, VARCINST);
 			break;
 		case ARCINSTMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifyarcinst != 0)
-					(*el_aids[i].modifyarcinst)((ARCINST *)c->entryaddr, c->p1, c->p2,
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifyarcinst != 0)
+					(*el_tools[i].modifyarcinst)((ARCINST *)c->entryaddr, c->p1, c->p2,
 						c->p3, c->p4, c->p5, c->p6);
 			break;
 		case PORTPROTONEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newobject != 0)
-					(*el_aids[i].newobject)(c->entryaddr, VPORTPROTO);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newobject != 0)
+					(*el_tools[i].newobject)(c->entryaddr, VPORTPROTO);
 			break;
 		case PORTPROTOKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killobject != 0)
-					(*el_aids[i].killobject)(c->entryaddr, VPORTPROTO);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killobject != 0)
+					(*el_tools[i].killobject)(c->entryaddr, VPORTPROTO);
 			break;
 		case PORTPROTOMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifyportproto != 0)
-					(*el_aids[i].modifyportproto)((PORTPROTO *)c->entryaddr, (NODEINST *)c->p1,
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifyportproto != 0)
+					(*el_tools[i].modifyportproto)((PORTPROTO *)c->entryaddr, (NODEINST *)c->p1,
 						(PORTPROTO *)c->p2);
 			break;
 		case NODEPROTONEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newobject != 0)
-					(*el_aids[i].newobject)(c->entryaddr, VNODEPROTO);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newobject != 0)
+					(*el_tools[i].newobject)(c->entryaddr, VNODEPROTO);
 			break;
 		case NODEPROTOKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killobject != 0)
-					(*el_aids[i].killobject)(c->entryaddr, VNODEPROTO);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killobject != 0)
+					(*el_tools[i].killobject)(c->entryaddr, VNODEPROTO);
 			break;
 		case NODEPROTOMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifynodeproto != 0)
-					(*el_aids[i].modifynodeproto)((NODEPROTO *)c->entryaddr);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifynodeproto != 0)
+					(*el_tools[i].modifynodeproto)((NODEPROTO *)c->entryaddr);
 			break;
 		case OBJECTSTART:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].startobjectchange != 0)
-					(*el_aids[i].startobjectchange)(c->entryaddr, c->p1);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].startobjectchange != 0)
+					(*el_tools[i].startobjectchange)(c->entryaddr, c->p1);
 			break;
 		case OBJECTEND:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].endobjectchange != 0)
-					(*el_aids[i].endobjectchange)(c->entryaddr, c->p1);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].endobjectchange != 0)
+					(*el_tools[i].endobjectchange)(c->entryaddr, c->p1);
 			break;
 		case OBJECTNEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newobject != 0)
-					(*el_aids[i].newobject)(c->entryaddr, c->p1);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newobject != 0)
+					(*el_tools[i].newobject)(c->entryaddr, c->p1);
 			break;
 		case OBJECTKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killobject != 0)
-					(*el_aids[i].killobject)(c->entryaddr, c->p1);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killobject != 0)
+					(*el_tools[i].killobject)(c->entryaddr, c->p1);
 			break;
 		case VARIABLENEW:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].newvariable != 0)
-					(*el_aids[i].newvariable)(c->entryaddr, c->p1, c->p2, c->p3);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].newvariable != 0)
+					(*el_tools[i].newvariable)(c->entryaddr, c->p1, c->p2, c->p3);
 			break;
 		case VARIABLEKILL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].killvariable != 0)
-					(*el_aids[i].killvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, c->p5);
+			descript[0] = c->p5;
+			descript[1] = c->p6;
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].killvariable != 0)
+					(*el_tools[i].killvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, descript);
 			break;
 		case VARIABLEMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifyvariable != 0)
-					(*el_aids[i].modifyvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, c->p5);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifyvariable != 0)
+					(*el_tools[i].modifyvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, c->p5);
 			break;
 		case VARIABLEINS:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].insertvariable != 0)
-					(*el_aids[i].insertvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].insertvariable != 0)
+					(*el_tools[i].insertvariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4);
 			break;
 		case VARIABLEDEL:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].deletevariable != 0)
-					(*el_aids[i].deletevariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, c->p5);
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].deletevariable != 0)
+					(*el_tools[i].deletevariable)(c->entryaddr, c->p1, c->p2, c->p3, c->p4, c->p5);
 			break;
 		case DESCRIPTMOD:
-			for(i=0; i<el_maxaid; i++)
-				if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].modifydescript != 0)
-					(*el_aids[i].modifydescript)(c->entryaddr, c->p1, c->p2, c->p4);
+			descript[0] = c->p4;
+			descript[1] = c->p5;
+			for(i=0; i<el_maxtools; i++)
+				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifydescript != 0)
+					(*el_tools[i].modifydescript)(c->entryaddr, c->p1, c->p2, descript);
 			break;
 	}
 	db_broadcasting = oldbroadcasting;
@@ -439,9 +446,9 @@ void db_endbatch(void)
 	/* changes made: apply final constraints to this batch of changes */
 	(*el_curconstraint->solve)(NONODEPROTO);
 
-	for(i=0; i<el_maxaid; i++)
-		if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].endbatch != 0)
-			(*el_aids[i].endbatch)();
+	for(i=0; i<el_maxtools; i++)
+		if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].endbatch != 0)
+			(*el_tools[i].endbatch)();
 
 	db_currentbatch = NOCHANGEBATCH;
 }
@@ -492,7 +499,7 @@ CHANGEBATCH *db_preparenewbatch(void)
 
 	/* miscellaneous initialization */
 	thisbatch->firstchangefacet = NOCHANGEFACET;
-	thisbatch->aid = db_currenttool;
+	thisbatch->tool = db_currenttool;
 	thisbatch->activity = 0;
 	return(thisbatch);
 }
@@ -555,7 +562,9 @@ void db_erasebatch(CHANGEBATCH *batch)
 		{
 			switch (c->p1&VTYPE)
 			{
-				case VVIEW:   freeview((VIEW *)c->entryaddr);      break;
+				case VVIEW:
+					freeview((VIEW *)c->entryaddr);
+					break;
 				case VWINDOWPART:
 					w = (WINDOWPART *)c->entryaddr;
 					if ((w->state&WINDOWTYPE) == TEXTWINDOW || (w->state&WINDOWTYPE) == POPTEXTWINDOW)
@@ -573,7 +582,7 @@ void db_erasebatch(CHANGEBATCH *batch)
 					freecell(cell);
 					break;
 			}
-		} else if (c->changetype == VARIABLEMOD || c->changetype == VARIABLEDEL)
+		} else if (c->changetype == VARIABLEDEL)
 		{
 			/* free the array entry if it is allocated */
 			if ((c->p3&(VCODE1|VCODE2)) != 0 || (c->p3&VTYPE) == VSTRING)
@@ -663,9 +672,9 @@ INTBIG historylistsize(INTBIG newsize)
 /*
  * routine to set the tool for the current (or next) batch of changes
  */
-void db_setcurrenttool(AIDENTRY *aid)
+void db_setcurrenttool(TOOL *tool)
 {
-	db_currenttool = aid;
+	db_currenttool = tool;
 }
 
 /*
@@ -757,9 +766,9 @@ INTSML undonature(INTSML undo)
  * undo, the routine returns zero.  If there is a batch, it is undone and the
  * routine returns the batch number (a positive value) if the batch involved changes to
  * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
- * changes (variables, etc.).  The aid that produced the batch is returned in "aid".
+ * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
-INTSML undoabatch(AIDENTRY **aid)
+INTSML undoabatch(TOOL **tool)
 {
 	REGISTER CHANGEBATCH *batch, *savebatch;
 	REGISTER CHANGE *c;
@@ -769,7 +778,7 @@ INTSML undoabatch(AIDENTRY **aid)
 	if (db_donebatch == NOCHANGEBATCH) return(0);
 	batch = db_donebatch;
 	db_donebatch = db_donebatch->lastchangebatch;
-	*aid = batch->aid;
+	*tool = batch->tool;
 
 	/* look through the changes in this batch */
 	firstchange = 1;
@@ -788,9 +797,9 @@ INTSML undoabatch(AIDENTRY **aid)
 	}
 
 	/* broadcast the end-batch */
-	for(i=0; i<el_maxaid; i++)
-		if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].endbatch != 0)
-			(*el_aids[i].endbatch)();
+	for(i=0; i<el_maxtools; i++)
+		if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].endbatch != 0)
+			(*el_tools[i].endbatch)();
 	db_currentbatch = savebatch;
 
 	/* mark that this batch is undone */
@@ -803,9 +812,9 @@ INTSML undoabatch(AIDENTRY **aid)
  * redo, the routine returns zero.  If there is a batch, it is redone and the
  * routine returns the batch number (a positive value) if the batch involved changes to
  * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
- * changes (variables, etc.).  The aid that produced the batch is returned in "aid".
+ * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
-INTSML redoabatch(AIDENTRY **aid)
+INTSML redoabatch(TOOL **tool)
 {
 	REGISTER CHANGEBATCH *batch, *savebatch;
 	REGISTER CHANGE *c;
@@ -822,7 +831,7 @@ INTSML redoabatch(AIDENTRY **aid)
 		if (batch == NOCHANGEBATCH) return(0);
 	}
 	db_donebatch = batch;
-	*aid = batch->aid;
+	*tool = batch->tool;
 
 	/* look through the changes in this batch */
 	firstchange = 1;
@@ -841,9 +850,9 @@ INTSML redoabatch(AIDENTRY **aid)
 	}
 
 	/* broadcast the end-batch */
-	for(i=0; i<el_maxaid; i++)
-		if ((el_aids[i].aidstate & AIDON) != 0 && el_aids[i].endbatch != 0)
-			(*el_aids[i].endbatch)();
+	for(i=0; i<el_maxtools; i++)
+		if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].endbatch != 0)
+			(*el_tools[i].endbatch)();
 	db_currentbatch = savebatch;
 
 	/* mark that this batch is redone */
@@ -1006,7 +1015,7 @@ INTSML db_reversechange(CHANGE *c)
 			c->changetype = OBJECTNEW;
 			break;
 		case VARIABLENEW:
-			/* args: addr, type, key, newtype */
+			/* args: addr, type, key, newtype, newdescript[0], newdescript[1] */
 			if ((c->p3&VCREF) != 0)
 			{
 				/* change to fixed attribute */
@@ -1020,7 +1029,8 @@ INTSML db_reversechange(CHANGE *c)
 				}
 				c->p3 = var->addr;
 				c->p4 = var->type;
-				c->p5 = var->textdescript;
+				c->p5 = var->textdescript[0];
+				c->p6 = var->textdescript[1];
 				c->changetype = VARIABLEKILL;
 				if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
 				if (c->p1 == VPORTPROTO)
@@ -1042,7 +1052,8 @@ INTSML db_reversechange(CHANGE *c)
 			}
 			c->p3 = var->addr;
 			c->p4 = var->type;
-			c->p5 = var->textdescript;
+			c->p5 = var->textdescript[0];
+			c->p6 = var->textdescript[1];
 			c->changetype = VARIABLEKILL;
 			var->type = VINTEGER;		/* fake it out so no memory is deallocated */
 			nextchangequiet();
@@ -1071,7 +1082,8 @@ INTSML db_reversechange(CHANGE *c)
 						makename(c->p2), db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
-				var->textdescript = c->p5;
+				var->textdescript[0] = c->p5;
+				var->textdescript[1] = c->p6;
 			}
 			db_freevar(c->p3, c->p4);
 			c->p3 = c->p4;
@@ -1083,7 +1095,7 @@ INTSML db_reversechange(CHANGE *c)
 			nextchangequiet();
 			if ((c->p3&VCREF) != 0)
 			{
-				attname = changedvariablename(c->p1, c->p2, c->p4);
+				attname = changedvariablename(c->p1, c->p2, c->p3);
 				if (getind(c->entryaddr, c->p1, attname, c->p4, &oldval) != 0)
 				{
 					ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
@@ -1092,6 +1104,10 @@ INTSML db_reversechange(CHANGE *c)
 				}
 				(void)setind(c->entryaddr, c->p1, attname, c->p4, c->p5);
 				c->p5 = oldval;
+				if (c->p1 == VPORTPROTO)
+				{
+					if (strcmp(attname, "textdescript") == 0) return(1);
+				}
 			} else
 			{
 				if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval) != 0)
@@ -1129,7 +1145,8 @@ INTSML db_reversechange(CHANGE *c)
 		case DESCRIPTMOD:
 			var = getvalkey(c->entryaddr, c->p1, -1, c->p2);
 			if (var == NOVARIABLE) break;
-			oldval = var->textdescript;   var->textdescript = c->p4;   c->p4 = oldval;
+			oldval = var->textdescript[0];   var->textdescript[0] = c->p4;   c->p4 = oldval;
+			oldval = var->textdescript[1];   var->textdescript[1] = c->p5;   c->p5 = oldval;
 			return(1);
 	}
 	return(0);
@@ -1223,8 +1240,8 @@ void showhistorylist(INTSML which)
 			if (batchreport->batchnumber > hibatch) hibatch = batchreport->batchnumber;
 			if (batchreport->batchnumber != which) continue;
 			(void)initinfstr();
-			(void)formatinfstr(M_("Batch %ld from %s aid"), batchreport->batchnumber,
-				batchreport->aid->aidname);
+			(void)formatinfstr(M_("Batch %ld from %s tool"), batchreport->batchnumber,
+				batchreport->tool->toolname);
 			if (batchreport->activity != 0)
 				(void)formatinfstr(M_(", caused by '%s'"), batchreport->activity);
 			(void)addstringtoinfstr(M_(" is:"));
@@ -1439,7 +1456,7 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 				db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLEKILL:
-			/* args: addr, type, key, oldaddr, oldtype, olddescript */
+			/* args: addr, type, key, oldaddr, oldtype, olddescript[0], olddescript[1] */
 			(void)initinfstr();
 			myvar.key = p2;  myvar.type = p4;  myvar.addr = p3;
 			(void)formatinfstr(M_(" Variable '%s' killed on %s [was %s]"), changedvariablename(p1, p2, p4),
@@ -1471,8 +1488,8 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 			return(returninfstr());
 		case DESCRIPTMOD:
 			(void)initinfstr();
-			(void)formatinfstr(M_(" Text descriptor on variable %s changed [was 0%lo]"),
-				makename(p2), p4);
+			(void)formatinfstr(M_(" Text descriptor on variable %s changed [was 0%lo/0%lo]"),
+				makename(p2), p4, p5);
 			return(returninfstr());
 	}
 	return("?");
@@ -1494,7 +1511,7 @@ char *db_namevariable(INTBIG addr, INTBIG type)
 	REGISTER GEOM *geom;
 	REGISTER LIBRARY *lib;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER RTNODE *rtn;
 	REGISTER CELL *c;
 	REGISTER VIEW *v;
@@ -1554,10 +1571,10 @@ char *db_namevariable(INTBIG addr, INTBIG type)
 			if (tech == NOTECHNOLOGY) (void)addstringtoinfstr("Technology(NULL)"); else
 				(void)formatinfstr("Technology(%s)", tech->techname);
 			break;
-		case VAID:
-			aid = (AIDENTRY *)addr;
-			if (aid == NOAID) (void)addstringtoinfstr("Aid(NULL)"); else
-				(void)formatinfstr("Aid(%s)", aid->aidname);
+		case VTOOL:
+			tool = (TOOL *)addr;
+			if (tool == NOTOOL) (void)addstringtoinfstr("Tool(NULL)"); else
+				(void)formatinfstr("Tool(%s)", tool->toolname);
 			break;
 		case VRTNODE:
 			rtn = (RTNODE *)addr;
@@ -1605,7 +1622,7 @@ char *db_namevariable(INTBIG addr, INTBIG type)
 }
 
 /* Undo dialog */
-DIALOGITEM db_undodialogitems[] =
+static DIALOGITEM db_undodialogitems[] =
 {
  /*  1 */ {0, {468,608,492,680}, BUTTON, N_("OK")},
  /*  2 */ {0, {468,16,492,88}, BUTTON, N_("Undo")},
@@ -1614,7 +1631,7 @@ DIALOGITEM db_undodialogitems[] =
  /*  5 */ {0, {8,344,24,456}, CHECK, N_("Show details")},
  /*  6 */ {0, {468,108,492,180}, BUTTON, N_("Redo")}
 };
-DIALOG db_undodialog = {{50,75,555,774}, N_("Change History"), 0, 6, db_undodialogitems};
+static DIALOG db_undodialog = {{50,75,555,774}, N_("Change History"), 0, 6, db_undodialogitems};
 
 /* special items in the "undo" dialog: */
 #define DUND_UNDO      2		/* Undo (button) */
@@ -1626,7 +1643,7 @@ void db_undodlog(void)
 {
 	INTBIG itemHit;
 	INTSML details;
-	AIDENTRY *aid;
+	TOOL *tool;
 
 	/* display the undo dialog box */
 	if (DiaInitDialog(&db_undodialog) != 0) return;
@@ -1652,13 +1669,13 @@ void db_undodlog(void)
 		}
 		if (itemHit == DUND_UNDO)
 		{
-			undoabatch(&aid);
+			undoabatch(&tool);
 			db_loadhistorylist(details);
 			continue;
 		}
 		if (itemHit == DUND_REDO)
 		{
-			redoabatch(&aid);
+			redoabatch(&tool);
 			db_loadhistorylist(details);
 			continue;
 		}
