@@ -35,13 +35,13 @@
 #include "eio.h"
 #include <math.h>
 
-INTBIG      db_contourthresh, db_bestthresh, db_worstthresh;
+static INTBIG      db_contourthresh, db_bestthresh, db_worstthresh;
 
 /* prototypes for local routines */
-INTSML db_addsegment(CONTOUR *con, CONTOURELEMENTTYPE type, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG cx, INTBIG cy, NODEINST *ni);
-INTSML db_addelementtocontour(CONTOUR *con, NODEINST *ni);
-INTSML db_contourendpoints(NODEINST *ni, INTBIG *fx, INTBIG *fy, INTBIG *tx, INTBIG *ty);
-void db_getcontoursegmentparameters(void);
+static INTSML db_addsegment(CONTOUR *con, CONTOURELEMENTTYPE type, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG cx, INTBIG cy, NODEINST *ni);
+static INTSML db_addelementtocontour(CONTOUR *con, NODEINST *ni);
+static INTSML db_contourendpoints(NODEINST *ni, INTBIG *fx, INTBIG *fy, INTBIG *tx, INTBIG *ty);
+static void   db_getcontoursegmentparameters(void);
 
 /*
  * routine to examine all of the geometry in facet "np" and build a contour structure for it.
@@ -151,6 +151,8 @@ CONTOUR *gathercontours(NODEPROTO *np, NODEINST **usearray, INTBIG bestthresh, I
 					fdist = computedistance(fx, fy, ex, ey);
 					tdist = computedistance(tx, ty, ex, ey);
 					dist = mini(fdist, tdist);
+
+					/* LINTED "bestdist" used in proper order */
 					if (bestni == NONODEINST || dist < bestdist)
 					{
 						bestni = oni;
@@ -260,6 +262,7 @@ INTSML db_addelementtocontour(CONTOUR *con, NODEINST *ni)
 					firsty = y;
 				} else
 				{
+					/* LINTED "lastx" and "lasty" are used in proper order */
 					if (db_addsegment(con, LINESEGMENTTYPE, lastx, lasty, x, y, 0, 0, ni) == 0) return(0);
 				}
 				lastx = x;
@@ -430,18 +433,18 @@ void killcontour(CONTOUR *con)
 
 #define DEFARCRES 210			/* 21 degrees */
 
-INTBIG db_arcres, db_arcsag;
-POLYGON *db_contourpoly = NOPOLYGON;
-INTSML db_contoursegmentcount;
+static INTBIG   db_arcres, db_arcsag;
+static POLYGON *db_contourpoly = NOPOLYGON;
+static INTSML   db_contoursegmentcount;
 
 void db_getcontoursegmentparameters(void)
 {
 	REGISTER VARIABLE *var;
 
-	var = getval((INTBIG)io_aid, VAID, VINTEGER, "IO_curve_resolution");
+	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_curve_resolution");
 	if (var == NOVARIABLE) db_arcres = DEFARCRES; else
 		db_arcres = var->addr;
-	var = getval((INTBIG)io_aid, VAID, VINTEGER, "IO_curve_sag");
+	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_curve_sag");
 	if (var == NOVARIABLE) db_arcsag = scalefromdispunit(0.0005f, DISPUNITMM); else
 		db_arcsag = var->addr;
 }
@@ -468,8 +471,8 @@ void setcontoursegmentparameters(INTBIG arcres, INTBIG arcsag)
 	db_arcres = arcres;
 	db_arcsag = arcsag;
 
-	(void)setval((INTBIG)io_aid, VAID, "IO_curve_resolution", arcres, VINTEGER);
-	(void)setval((INTBIG)io_aid, VAID, "IO_curve_sag", arcsag, VINTEGER);
+	(void)setval((INTBIG)io_tool, VTOOL, "IO_curve_resolution", arcres, VINTEGER);
+	(void)setval((INTBIG)io_tool, VTOOL, "IO_curve_sag", arcsag, VINTEGER);
 }
 
 /*
