@@ -33,9 +33,9 @@
 #include "database.h"
 
 /* prototypes for local routines */
-ARCPROTO *db_allocarcproto(CLUSTER*);
-INTSML db_checkshortening(NODEINST*, PORTPROTO*);
-void db_killportproto(PORTPROTO*);
+static ARCPROTO *db_allocarcproto(CLUSTER*);
+static INTSML    db_checkshortening(NODEINST*, PORTPROTO*);
+static void      db_killportproto(PORTPROTO*);
 
 /************************* NODES *************************/
 
@@ -58,7 +58,9 @@ NODEINST *allocnodeinst(CLUSTER *cluster)
 	ni->nextinst = NONODEINST;
 	ni->firstportarcinst = NOPORTARCINST;
 	ni->firstportexpinst = NOPORTEXPINST;
-	ni->textdescript = VTPOSBOXED | (defaulttextsize(5) << VTSIZESH);
+	TDCLEAR(ni->textdescript);
+	defaulttextsize(5, ni->textdescript);
+	TDSETPOS(ni->textdescript, VTPOSBOXED);
 	ni->lowx = ni->highx = ni->lowy = ni->highy = 0;
 	ni->transpose = 0;
 	ni->rotation = 0;
@@ -182,7 +184,7 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 		/* set the change facet environment */
 		db_setchangefacet(parnt);
 
-		/* tell all aids about this nodeinst */
+		/* tell all tools about this nodeinst */
 		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTNEW, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about new node */
@@ -224,6 +226,9 @@ void db_enternodeinst(NODEINST *ni)
 
 	/* mark the nodeinst alive */
 	ni->userbits &= ~DEADN;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -275,7 +280,7 @@ void db_killnodeinst(NODEINST *ni)
 		/* set the change facet environment */
 		db_setchangefacet(ni->parent);
 
-		/* tell all aids about this nodeinst */
+		/* tell all tools about this nodeinst */
 		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTKILL, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about killed node */
@@ -310,6 +315,9 @@ void db_retractnodeinst(NODEINST *ni)
 
 	/* mark the nodeinst dead */
 	ni->userbits |= DEADN;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -371,6 +379,9 @@ void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx
 
 	/* set the change facet environment */
 	db_setchangefacet(ni->parent);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -388,7 +399,9 @@ NODEINST *dummynode(void)
 	node.firstportarcinst = NOPORTARCINST;
 	node.firstportexpinst = NOPORTEXPINST;
 	node.userbits = 0;
-	node.textdescript = VTPOSBOXED | (defaulttextsize(5) << VTSIZESH);
+	TDCLEAR(node.textdescript);
+	defaulttextsize(5, node.textdescript);
+	TDSETPOS(node.textdescript, VTPOSBOXED);
 	node.numvar = 0;
 	return(&node);
 }
@@ -706,7 +719,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 		/* set the change facet environment */
 		db_setchangefacet(parnt);
 
-		/* tell all aids about this arcinst */
+		/* tell all tools about this arcinst */
 		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTNEW, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about new arc */
@@ -766,6 +779,9 @@ void db_enterarcinst(ARCINST *ai)
 
 	/* mark the arcinst alive */
 	ai->userbits &= ~DEADA;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -828,7 +844,7 @@ void db_killarcinst(ARCINST *ai)
 		/* set the change facet environment */
 		db_setchangefacet(ai->parent);
 
-		/* tell all aids about this arcinst */
+		/* tell all tools about this arcinst */
 		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTKILL, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about killed arc */
@@ -890,6 +906,9 @@ void db_retractarcinst(ARCINST *ai)
 
 	/* mark it dead */
 	ai->userbits |= DEADA;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -968,7 +987,7 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 	/* handle change control, constraint, and broadcast */
 	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
 	{
-		/* tell all aids about this arcinst */
+		/* tell all tools about this arcinst */
 		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldx0, oldy0, oldx1, oldy1,
 			oldwid, oldlen);
 
@@ -980,6 +999,9 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 	}
 	db_donextchangequietly = 0;
 
+	/* mark a change to the database */
+	db_changetimestamp++;
+
 	return(0);
 }
 
@@ -1170,7 +1192,9 @@ PORTPROTO *allocportproto(CLUSTER *cluster)
 	pp->subnodeinst = NONODEINST;
 	pp->subportexpinst = NOPORTEXPINST;
 	pp->subportproto = NOPORTPROTO;
-	pp->textdescript = VTPOSBOXED;
+	TDCLEAR(pp->textdescript);
+	defaulttextsize(1, pp->textdescript);
+	TDSETPOS(pp->textdescript, VTPOSBOXED);
 	pp->cachedequivport = NOPORTPROTO;
 	return(pp);
 }
@@ -1287,8 +1311,9 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	pp->subnodeinst = nodeinst;
 	pp->subportproto = portaddress;
 	pp->userbits = portaddress->userbits;
-	pp->textdescript = (defaulttextdescript(nodeinst->geom) & ~VTSIZE) |
-		(defaulttextsize(1) << VTSIZESH);
+	TDCLEAR(pp->textdescript);
+	defaulttextdescript(pp->textdescript, nodeinst->geom);
+	defaulttextsize(1, pp->textdescript);
 	if (allocstring(&pp->protoname, name, np->cell->cluster) != 0)
 	{
 		db_donextchangequietly = 0;
@@ -1339,6 +1364,9 @@ void db_enterportproto(PORTPROTO *pp)
 
 	/* clear cache of port associations in this cell */
 	db_clearportcache(pp->parent);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 void db_clearportcache(NODEPROTO *facet)
@@ -1405,21 +1433,21 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, char *name)
 		return(NOPORTPROTO);
 	}
 
-	/* must be during initialization: no instances of this nodeinst proto */
+	/* must be during initialization: no instances of this nodeproto */
 	if (np->firstinst != NONODEINST) return(NOPORTPROTO);
 
-	/* reject if there is already a portinst with this name */
+	/* reject if there is already a portproto with this name */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (namesame((last=pp)->protoname, name) == 0) return(NOPORTPROTO);
 
-	/* create the portinst proto and link it into the nodeinst proto */
+	/* create the portproto and link it into the nodeinst proto */
 	pp = allocportproto(np->tech->cluster);
 	if (pp == NOPORTPROTO) return(NOPORTPROTO);
 	if (np->firstportproto == NOPORTPROTO) np->firstportproto = pp; else
 		last->nextportproto = pp;
 	pp->nextportproto = NOPORTPROTO;
 
-	/* initialize the values in the portinst proto */
+	/* initialize the values in the portproto */
 	pp->userbits = pp->temp1 = pp->temp2 = 0;
 	pp->network = NONETWORK;
 	pp->parent = np;       pp->connects = arcs;
@@ -1549,6 +1577,9 @@ void db_retractportproto(PORTPROTO *pp)
 
 	/* clear cache of port associations in this cell */
 	db_clearportcache(pp->parent);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
