@@ -35,7 +35,7 @@
 INTBIG db_lasterror;			/* last error message */
 INTSML db_printerrors;			/* flag for printing internal errors */
 
-char *db_errortype[] =
+static char *db_errortype[] =
 {
 	N_("no error"),								/* DBNOERROR */
 	N_("no memory"),							/* DBNOMEM */
@@ -79,7 +79,7 @@ char *db_errortype[] =
 /*
  * database error routine codes
  */
-char *db_routines[] =
+static char *db_routines[] =
 {
 	"addstringtoinfstr",	/*  1 */
 	"addtechnology",		/*  2 */
@@ -160,9 +160,11 @@ void telldatabaseerror(void)
 
 /*
  * These are the routines to log errors:
- *   initerrorlogging(char *s)                   initialize for subsystem "s"
+ *   initerrorlogging(char *s, NODEPROTO *f1, NODEPROTO *f2) initialize for subsystem "s"
  *   e = logerror(char *msg, NODEPROTO *f, k)    log message "msg" in facet "f", sort key "k"
- *   addgeomtoerror(void *e, GEOM *g, INTSML s)  add geom "g" to error "e" (show if "s" nonzero)
+ *   addgeomtoerror(void *e, GEOM *g, INTSML s, INTSML l, NODEINST **p)
+ *                                               add geom "g" to error "e" (show if "s" nonzero)
+ *   addexporttoerror(void *e, PORTPROTO *p, INTSML s)  add export "pp" to error "e"
  *   addlinetoerror(void *e, x1, y1, x2, y2)     add line to error "e"
  *   addpolytoerror(void *e, POLYGON *p)         add polygon to error "e"
  *   addpointtoerror(void *e, x, y)              add point to error "e"
@@ -175,7 +177,7 @@ void telldatabaseerror(void)
  *   s = reportcurrenterror(show, &g1, &g2)      report current error
  */
 
-typedef enum {ERRORTYPEGEOM, ERRORTYPEFACET, ERRORTYPELINE, ERRORTYPEPOINT} ERRORHIGHLIGHTTYPE;
+typedef enum {ERRORTYPEGEOM, ERRORTYPEEXPORT, ERRORTYPELINE, ERRORTYPEPOINT} ERRORHIGHLIGHTTYPE;
 
 #define NOERRORHIGHLIGHT ((ERRORHIGHLIGHT *)-1)
 
@@ -183,9 +185,12 @@ typedef struct
 {
 	ERRORHIGHLIGHTTYPE type;
 	GEOM              *geom;
+	PORTPROTO         *pp;
 	INTBIG             showgeom;
 	INTBIG             x1, y1;
 	INTBIG             x2, y2;
+	INTSML             pathlen;
+	NODEINST         **path;
 } ERRORHIGHLIGHT;
 
 
@@ -202,21 +207,39 @@ typedef struct iErrorList
 	struct iErrorList *nexterrorlist;
 } ERRORLIST;
 
-ERRORLIST *db_errorlistfree = NOERRORLIST;
-ERRORLIST *db_firsterrorlist = NOERRORLIST;
-ERRORLIST *db_curerrorlist = NOERRORLIST;
-ERRORLIST *db_nexterrorlist = NOERRORLIST;
-ERRORLIST *db_preverrorlist = NOERRORLIST;
-char       db_errorsystem[100] = "";
+static ERRORLIST *db_errorlistfree = NOERRORLIST;
+static ERRORLIST *db_firsterrorlist = NOERRORLIST;
+static ERRORLIST *db_curerrorlist = NOERRORLIST;
+static ERRORLIST *db_nexterrorlist = NOERRORLIST;
+static ERRORLIST *db_preverrorlist = NOERRORLIST;
+static char       db_errorsystem[100] = "";
+static NODEPROTO *db_errorfacet1 = NONODEPROTO;
+static NODEPROTO *db_errorfacet2 = NONODEPROTO;
 
-INTSML db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh);
+
+static INTSML db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh);
+static int    db_errorlistascending(const void *e1, const void *e2);
 
 /*
  * Routine to free all previously stored errors and initialize the system.
+ * The errors are described by "system" and up to two facets "facet1" and
+ * "facet2" (may be NONODEPROTO).
  */
-void initerrorlogging(char *system)
+void initerrorlogging(char *system, NODEPROTO *facet1, NODEPROTO *facet2)
+{
+	db_freeerrormemory();
+	db_curerrorlist = NOERRORLIST;
+	db_nexterrorlist = NOERRORLIST;
+	db_preverrorlist = NOERRORLIST;
+	strncpy(db_errorsystem, system, 100);
+	db_errorfacet1 = facet1;
+	db_errorfacet2 = facet2;
+}
+
+void db_freeerrormemory(void)
 {
 	REGISTER ERRORLIST *el;
+	REGISTER ERRORHIGHLIGHT *eh;
 	REGISTER INTBIG i;
 
 	while (db_firsterrorlist != NOERRORLIST)
@@ -225,14 +248,14 @@ void initerrorlogging(char *system)
 		db_firsterrorlist = el->nexterrorlist;
 		efree(el->message);
 		for(i=0; i<el->numhighlights; i++)
-			efree((char *)el->highlights[i]);
+		{
+			eh = el->highlights[i];
+			if (eh->pathlen > 0) efree((char *)eh->path);
+			efree((char *)eh);
+		}
 		if (el->numhighlights > 0) efree((char *)el->highlights);
 		efree((char *)el);
 	}
-	db_curerrorlist = NOERRORLIST;
-	db_nexterrorlist = NOERRORLIST;
-	db_preverrorlist = NOERRORLIST;
-	strncpy(db_errorsystem, system, 100);
 }
 
 /*
@@ -264,12 +287,15 @@ void *logerror(char *message, NODEPROTO *facet, INTBIG sortkey)
 }
 
 /*
- * Routine to add "geom" to the error in "errorlist".  Returns nonzero on error.
+ * Routine to add "geom" to the error in "errorlist".  Also adds a
+ * hierarchical traversal path "path" (which is "pathlen" long).
+ * Returns nonzero on error.
  */
-INTSML addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit)
+INTSML addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit, INTSML pathlen, NODEINST **path)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
+	REGISTER INTSML i;
 
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
@@ -277,14 +303,22 @@ INTSML addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit)
 	eh->type = ERRORTYPEGEOM;
 	eh->geom = geom;
 	eh->showgeom = showit;
+	eh->pathlen = pathlen;
+	if (pathlen > 0)
+	{
+		eh->path = (NODEINST **)emalloc(pathlen * (sizeof (NODEINST *)), db_cluster);
+		if (eh->path == 0) return(1);
+		for(i=0; i<pathlen; i++)
+			eh->path[i] = path[i];
+	}
 	if (db_addtoerrorlist(el, eh) != 0) return(1);
 	return(0);	
 }
 
 /*
- * Routine to add facet "facet" to the error in "errorlist".  Returns nonzero on error.
+ * Routine to add "pp" to the error in "errorlist".  Returns nonzero on error.
  */
-INTSML addfacettoerror(void *errorlist, NODEPROTO *facet)
+INTSML addexporttoerror(void *errorlist, PORTPROTO *pp, INTSML showit)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
@@ -292,8 +326,10 @@ INTSML addfacettoerror(void *errorlist, NODEPROTO *facet)
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
 	if (eh == 0) return(1);
-	eh->type = ERRORTYPEFACET;
-	eh->geom = (GEOM *)facet;
+	eh->type = ERRORTYPEEXPORT;
+	eh->pp = pp;
+	eh->showgeom = showit;
+	eh->pathlen = 0;
 	if (db_addtoerrorlist(el, eh) != 0) return(1);
 	return(0);	
 }
@@ -315,9 +351,11 @@ INTSML addlinetoerror(void *errorlist, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y
 	eh->y1 = y1;
 	eh->x2 = x2;
 	eh->y2 = y2;
+	eh->pathlen = 0;
 	if (db_addtoerrorlist(el, eh) != 0) return(1);
 	return(0);	
 }
+
 /*
  * Routine to add polygon "poly" to the error in "errorlist".
  * Returns nonzero on error.
@@ -360,6 +398,7 @@ INTSML addpointtoerror(void *errorlist, INTBIG x, INTBIG y)
 	eh->type = ERRORTYPEPOINT;
 	eh->x1 = x;
 	eh->y1 = y;
+	eh->pathlen = 0;
 	if (db_addtoerrorlist(el, eh) != 0) return(1);
 	return(0);	
 }
@@ -395,54 +434,51 @@ void termerrorlogging(void)
 
 	/* save the number of errors in "%V" */
 	errs = numerrors();
-	var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_local_capv");
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_local_capv");
 	if (var == NOVARIABLE) olderrs = -1; else
 		olderrs = var->addr;
 	if (errs != olderrs)
 	{
-		setval((INTBIG)us_aid, VAID, "USER_local_capv", errs, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_local_capv", errs, VINTEGER|VDONTSAVE);
 	}
 }
 
 void sorterrors(void)
 {
-	REGISTER ERRORLIST *ep1, *ep2, *prev, *next;
-	REGISTER INTBIG sorted;
+	REGISTER ERRORLIST *ep, **sortedlist;
+	REGISTER INTBIG total, i;
 
-	sorted = 0;
-	while (sorted == 0)
+	total = 0;
+	for(ep = db_firsterrorlist; ep != NOERRORLIST; ep = ep->nexterrorlist) total++;
+	if (total == 0) return;
+	sortedlist = (ERRORLIST **)emalloc(total * (sizeof (ERRORLIST *)), db_cluster);
+	if (sortedlist == 0) return;
+	i = 0;
+	for(ep = db_firsterrorlist; ep != NOERRORLIST; ep = ep->nexterrorlist)
+		sortedlist[i++] = ep;
+	esort(sortedlist, total, sizeof (ERRORLIST *), db_errorlistascending);
+	for(i=0; i<total; i++)
 	{
-		sorted = 1;
-		for(ep1 = db_firsterrorlist; ep1 != NOERRORLIST; ep1 = ep1->nexterrorlist)
-		{
-			ep2 = ep1->nexterrorlist;
-			if (ep2 == NOERRORLIST) continue;
-
-			if (ep1->sortkey <= ep2->sortkey) continue;
-
-			/* reverse the errors */
-			prev = ep1->preverrorlist;
-			next = ep2->nexterrorlist;
-			if (prev == NOERRORLIST)
-			{
-				db_firsterrorlist = ep2;
-				ep2->preverrorlist = NOERRORLIST;
-			} else
-			{
-				prev->nexterrorlist = ep2;
-				ep2->preverrorlist = prev;
-			}
-			ep1->nexterrorlist = next;
-			if (next != NOERRORLIST)
-			{
-				next->preverrorlist = ep1;
-			}
-			ep1->preverrorlist = ep2;
-			ep2->nexterrorlist = ep1;
-			ep1 = ep2;
-			sorted = 0;
-		}
+		ep = sortedlist[i];
+		if (i == 0) ep->preverrorlist = NOERRORLIST; else
+			ep->preverrorlist = sortedlist[i-1];
+		if (i < total-1) ep->nexterrorlist = sortedlist[i+1]; else
+			ep->nexterrorlist = NOERRORLIST;
 	}
+	db_firsterrorlist = sortedlist[0];
+	efree((char *)sortedlist);
+}
+
+/*
+ * Helper routine for "sorterrors()" to sort errors by their key
+ */
+int db_errorlistascending(const void *e1, const void *e2)
+{
+	REGISTER ERRORLIST *er1, *er2;
+
+	er1 = *((ERRORLIST **)e1);
+	er2 = *((ERRORLIST **)e2);
+	return(er1->sortkey - er2->sortkey);
 }
 
 /*
@@ -498,18 +534,21 @@ char *reportpreverror(void)
  * Highlights associated graphics if "showhigh" is nonzero.  Fills "g1" and "g2"
  * with associated geometry modules (if nonzero).
  */
-#define MAXFACETS 5
+#define MAXFACETS 20
 
 char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
 	REGISTER ERRORLIST *el;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *facet, *np;
 	NODEPROTO *facetlist[MAXFACETS];
-	REGISTER INTBIG i, j, consize, numfacets;
+	REGISTER INTBIG i, j, consize, numfacets, havegeoms, newwindows, count;
+	REGISTER INTSML hierpathcount;
+	REGISTER NODEINST **hierpath;
 	INTBIG lx, hx, ly, hy;
 	REGISTER ERRORHIGHLIGHT *eh;
 	REGISTER GEOM *geom1, *geom2;
 	REGISTER WINDOWPART *w;
+	WINDOWPART *neww[4];
 
 	el = db_curerrorlist;
 	if (el == NOERRORLIST)
@@ -522,7 +561,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 	/* turn off highlighting */
 	if (showhigh != 0)
 	{
-		(void)askaid(us_aid, "clear");
+		(void)asktool(us_tool, "clear");
 
 		/* first figure out which facets need to be displayed */
 		numfacets = 0;
@@ -530,14 +569,23 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 		{
 			eh = el->highlights[i];
 			facet = el->facet;
+			hierpathcount = 0;
 			switch (eh->type)
 			{
 				case ERRORTYPEGEOM:
 					if (eh->showgeom == 0) facet = NONODEPROTO; else
+					{
 						facet = geomparent(eh->geom);
+						if (eh->pathlen > 0)
+						{
+							hierpathcount = eh->pathlen;
+							hierpath = eh->path;
+						}
+					}
 					break;
-				case ERRORTYPEFACET:
-					facet = (NODEPROTO *)eh->geom;
+				case ERRORTYPEEXPORT:
+					if (eh->showgeom == 0) facet = NONODEPROTO; else
+						facet = eh->pp->parent;
 					break;
 			}
 			if (facet == NONODEPROTO) continue;
@@ -546,32 +594,93 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			if (j < numfacets) continue;
 			if (numfacets >= MAXFACETS) break;
 			facetlist[numfacets] = facet;
+
+			/* add this hierarchical path */
+			np = facet;
+			for(j=hierpathcount-1; j>=0; j--)
+			{
+				(void)setvalkey((INTBIG)np, VNODEPROTO, us_facet_descent_path, (INTBIG)hierpath[j],
+					VNODEINST|VDONTSAVE);
+				np = hierpath[j]->parent;
+			}
 			numfacets++;
 		}
 
 		/* be sure that all requested facets are shown */
+		newwindows = 0;
 		for(i=0; i<numfacets; i++)
 		{
+			/* see if the facet is already being displayed */
 			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 				if (w->curnodeproto == facetlist[i]) break;
-			if (w != NOWINDOWPART) continue;
+			if (w != NOWINDOWPART)
+			{
+				/* already displayed: mark this facet done */
+				facetlist[i] = NONODEPROTO;
+				continue;
+			}
 
 			/* not displayed: find a window to use */
 			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 			{
+				if (w->curnodeproto == NONODEPROTO) break;
+				if (w->curnodeproto == db_errorfacet1 ||
+					w->curnodeproto == db_errorfacet2) continue;
 				for(j=0; j<numfacets; j++)
 					if (w->curnodeproto == facetlist[j]) break;
 				if (j >= numfacets) break;
 			}
-			if (w == NOWINDOWPART) w = us_wantnewwindow(0);
-			el_curwindowpart = w;
-			us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
-			us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, 0, 0);
+			if (w != NOWINDOWPART)
+			{
+				/* found a window: show the facet there */
+				el_curwindowpart = w;
+				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
+				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, 0, 0);
+				facetlist[i] = NONODEPROTO;
+				continue;
+			}
+
+			/* keep a count of the number of new windows needed */
+			newwindows++;
+		}
+		while (newwindows > 0)
+		{
+			neww[0] = us_wantnewwindow(0);
+			newwindows--;
+			if (newwindows > 0)
+			{
+				el_curwindowpart = neww[0];
+				neww[1] = us_splitcurrentwindow(2, 0, &neww[0]);
+				newwindows--;
+			}
+			if (newwindows > 0)
+			{
+				el_curwindowpart = neww[0];
+				neww[2] = us_splitcurrentwindow(1, 0, &neww[0]);
+				newwindows--;
+			}
+			if (newwindows > 0)
+			{
+				el_curwindowpart = neww[1];
+				neww[3] = us_splitcurrentwindow(1, 0, &neww[1]);
+				newwindows--;
+			}
+			count = 0;
+			for(i=0; i<numfacets; i++)
+			{
+				if (facetlist[i] == NONODEPROTO) continue;
+				el_curwindowpart = neww[count++];
+				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
+				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, 0, 0);
+				facetlist[i] = NONODEPROTO;
+				if (count >= 4) break;
+			}
 		}
 	}
 
-	/* now show the errors */
+	/* first show the geometry associated with this error */
 	geom1 = geom2 = NOGEOM;
+	havegeoms = 0;
 	for(i=0; i<el->numhighlights; i++)
 	{
 		eh = el->highlights[i];
@@ -580,21 +689,47 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			case ERRORTYPEGEOM:
 				if (geom1 == NOGEOM) geom1 = eh->geom; else
 					if (geom2 == NOGEOM) geom2 = eh->geom;
-				if (showhigh != 0 && eh->showgeom != 0)
-					(void)askaid(us_aid, "show-object", (INTBIG)eh->geom);
+				if (showhigh == 0 || eh->showgeom == 0) continue;
+
+				/* include this geometry module in list to show */
+				if (havegeoms == 0) (void)initinfstr(); else
+					(void)addtoinfstr('\n');
+				havegeoms++;
+				(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+					describenodeproto(geomparent(eh->geom)), (INTBIG)eh->geom);
 				break;
+			case ERRORTYPEEXPORT:
+				if (havegeoms == 0) (void)initinfstr(); else
+					(void)addtoinfstr('\n');
+				havegeoms++;
+				(void)formatinfstr("FACET=%s TEXT=0%lo;0%lo;-",
+					describenodeproto(eh->pp->parent), (INTBIG)eh->pp->subnodeinst->geom,
+						(INTBIG)eh->pp);
+				break;
+		}
+	}
+
+	if (havegeoms != 0)
+		(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr());
+
+	/* now show the lines and points associated with this error */
+	for(i=0; i<el->numhighlights; i++)
+	{
+		eh = el->highlights[i];
+		switch (eh->type)
+		{
 			case ERRORTYPELINE:
 				if (showhigh != 0)
-					(void)askaid(us_aid, "show-line", eh->x1, eh->y1, eh->x2, eh->y2,
+					(void)asktool(us_tool, "show-line", eh->x1, eh->y1, eh->x2, eh->y2,
 						el->facet);
 				break;
 			case ERRORTYPEPOINT:
 				if (showhigh != 0)
 				{
 					consize = lambdaoffacet(el->facet) * 5;
-					(void)askaid(us_aid, "show-line", eh->x1-consize, eh->y1-consize,
+					(void)asktool(us_tool, "show-line", eh->x1-consize, eh->y1-consize,
 						eh->x1+consize, eh->y1+consize, el->facet);
-					(void)askaid(us_aid, "show-line", eh->x1-consize, eh->y1+consize,
+					(void)asktool(us_tool, "show-line", eh->x1-consize, eh->y1+consize,
 						eh->x1+consize, eh->y1-consize, el->facet);
 				}
 				break;
