@@ -52,19 +52,19 @@ typedef struct
 	INTBIG   lx, hx, ly, hy;
 } RSEARCH;
 
-RSEARCH *db_rsearchfree = NORSEARCH;
+static RSEARCH *db_rsearchfree = NORSEARCH;
 
 INTSML db_minrtnodesize = 4;
 INTSML db_maxrtnodesize = 8;
 
 /* prototypes for local routines */
-RSEARCH *db_allocrsearch(void);
-void db_freersearch(RSEARCH*);
-void db_removertnode(RTNODE*, INTSML, NODEPROTO*);
-void db_reinsert(RTNODE*, NODEPROTO*);
-INTSML db_findgeom(RTNODE*, GEOM*, RTNODE**, INTSML*);
-INTSML db_findgeomanywhere(RTNODE*, GEOM*, RTNODE**, INTSML*);
-void db_figbounds(RTNODE*);
+static RSEARCH *db_allocrsearch(void);
+static void     db_freersearch(RSEARCH*);
+static void     db_removertnode(RTNODE*, INTSML, NODEPROTO*);
+static void     db_reinsert(RTNODE*, NODEPROTO*);
+static INTSML   db_findgeom(RTNODE*, GEOM*, RTNODE**, INTSML*);
+static INTSML   db_findgeomanywhere(RTNODE*, GEOM*, RTNODE**, INTSML*);
+static void     db_figbounds(RTNODE*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -280,6 +280,8 @@ void linkgeom(GEOM *geom, NODEPROTO *parnt)
 
 			/* accumulate the least expansion */
 			expand = newarea - area;
+
+			/* LINTED "bestexpand" used in proper order */
 			if (i != 0 && expand > bestexpand) continue;
 			bestexpand = expand;
 			bestsubnode = i;
@@ -411,11 +413,15 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 				oldareaplus = ((mmaxi(hxv, rtn->highx) - mmini(lxv, rtn->lowx)) / scaledown) *
 					((mmaxi(hyv, rtn->highy) - mmini(lyv, rtn->lowy)) / scaledown);
 #endif
+
+				/* LINTED "bestnewexpand" used in proper order */
 				if (bestnewnode < 0 || newareaplus-newarea < bestnewexpand)
 				{
 					bestnewexpand = newareaplus-newarea;
 					bestnewnode = i;
 				}
+
+				/* LINTED "bestoldexpand" used in proper order */
 				if (bestoldnode < 0 || oldareaplus-oldarea < bestoldexpand)
 				{
 					bestoldexpand = oldareaplus-oldarea;
@@ -863,10 +869,9 @@ void db_rtnbbox(RTNODE *rtn, INTSML child, INTBIG *lx, INTBIG *hx, INTBIG *ly, I
  */
 void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 {
-	REGISTER INTBIG end0extend, end1extend, radius, angle,
+	REGISTER INTBIG end0extend, end1extend, radius, angle, j, pts,
 		xs, ys, xe, ye, xc, yc, xv, yv;
 	INTBIG x1, y1, x2, y2, num, xp, yp, plx, phx, ply, phy;
-	INTBIG j, pts;
 	double startoffset, endangle, ctx, cty, a, b, p;
 	XARRAY trans;
 	REGISTER ARCINST *ai;
@@ -955,20 +960,6 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 
 		/* get the bounding box of the polygon as the arc extent */
 		getbbox(poly, lx, hx, ly, hy);
-
-#if 0
-		/* include any text on the arc */
-		pts = tech_displayableavars(ai, NOWINDOWPART);
-		for(j=0; j<pts; j++)
-		{
-			var = tech_filldisplayableavar(ai, poly, NOWINDOWPART, 0);
-			getbbox(poly, &plx, &phx, &ply, &phy);
-			if (plx < *lx) *lx = plx;
-			if (phx > *hx) *hx = phx;
-			if (ply < *ly) *ly = ply;
-			if (phy > *hy) *hy = phy;
-		}
-#endif
 		return;
 	}
 	if (geom->entrytype == OBJNODEINST)
@@ -1070,20 +1061,6 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 			*ly = ni->lowy;   *hy = ni->highy;
 			xformbox(lx, hx, ly, hy, trans);
 		}
-
-#if 0
-		/* include any text on the node */
-		pts = tech_displayablenvars(ni, NOWINDOWPART);
-		for(j=0; j<pts; j++)
-		{
-			var = tech_filldisplayablenvar(ni, poly, NOWINDOWPART, 0);
-			getbbox(poly, &plx, &phx, &ply, &phy);
-			if (plx < *lx) *lx = plx;
-			if (phx > *hx) *hx = phx;
-			if (ply < *ly) *ly = ply;
-			if (phy > *hy) *hy = phy;
-		}
-#endif
 	}
 }
 
@@ -1117,7 +1094,7 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 			{
 				var = &ni->firstvar[i];
 				if ((var->type&VDISPLAY) != 0 &&
-					(var->textdescript&VTINTERIOR) != 0) break;
+					TDGETINTERIOR(var->textdescript) != 0) break;
 			}
 			if (i < ni->numvar) continue;
 		}
