@@ -32,6 +32,22 @@
 #include "database.h"
 #include "dblang.h"
 
+#define EVALUATIONCACHESIZE 10
+typedef struct
+{
+	UINTBIG  timestamp;
+	char    *code;
+	INTBIG   type;
+	INTBIG   value;
+} EVALUATIONCACHE;
+
+static EVALUATIONCACHE db_evaluationcache[EVALUATIONCACHESIZE];
+static INTBIG db_evaluationcachesize = 0;
+static INTBIG db_evaluationcachelast = 0;
+
+/* prototypes for local routines */
+static void db_enterqueryincache(char *code, INTBIG type, INTBIG value);
+
 /****************************** LANGUAGE INTERFACE ******************************/
 
 /*
@@ -118,6 +134,22 @@ INTSML doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval)
 	long ival;
 	double fval;
 #endif
+	REGISTER INTBIG i, index;
+
+	/* search cache of evaluations */
+	for(i=0; i<db_evaluationcachesize; i++)
+	{
+		index = db_evaluationcachelast - i - 1;
+		if (index < 0) index += EVALUATIONCACHESIZE;
+		if (db_evaluationcache[index].timestamp != db_changetimestamp) continue;
+		if (strcmp(db_evaluationcache[index].code, code) != 0) continue;
+		if (db_evaluationcache[index].type != type) continue;
+
+		/* found in cache: return value */
+		*retval = db_evaluationcache[index].value;
+		return(0);
+	}
+/*ttyputmsg("Time %d (****EVALUATING****): %s", db_changetimestamp, code);*/
 
 	switch (language)
 	{
@@ -135,6 +167,7 @@ INTSML doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval)
 
 			/* convert the evaluation to a string */
 			if (lsp_describeobject(obj, type, retval) != 0) return(1);
+			db_enterqueryincache(code, type, *retval);
 			return(0);
 #endif
 
@@ -150,6 +183,7 @@ INTSML doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval)
 
 			/* convert the result to the desired type */
 			*retval = tcl_converttoelectric(tcl_interp->result, type);
+			db_enterqueryincache(code, type, *retval);
 			return(0);
 #endif
 
@@ -178,6 +212,7 @@ INTSML doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval)
 					*retval = myatoi(str);
 					break;
 			}
+			db_enterqueryincache(code, type, *retval);
 			return(0);
 #endif
 
@@ -283,6 +318,7 @@ INTSML doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval)
 				retarray[0] = *retval;
 				*retval = (INTBIG)retarray;
 			}
+			db_enterqueryincache(code, type, *retval);
 			return(0);
 #endif
 	}
@@ -449,11 +485,49 @@ INTSML languageconverse(INTBIG language)
 	return(1);
 }
 
+/*
+ * Routine to enter code "code" which returns "value" of type "type" into the
+ * cache of evaluations.
+ */
+void db_enterqueryincache(char *code, INTBIG type, INTBIG value)
+{
+	if (db_evaluationcachelast < db_evaluationcachesize)
+	{
+		efree((char *)db_evaluationcache[db_evaluationcachelast].code);
+		if ((db_evaluationcache[db_evaluationcachelast].type&VTYPE) == VSTRING)
+			efree((char *)db_evaluationcache[db_evaluationcachelast].value);
+	}
+	db_evaluationcache[db_evaluationcachelast].timestamp = db_changetimestamp;
+	(void)allocstring(&db_evaluationcache[db_evaluationcachelast].code, code, db_cluster);
+	db_evaluationcache[db_evaluationcachelast].type = type;
+	if ((type&VTYPE) == VSTRING)
+	{
+		(void)allocstring((char **)&db_evaluationcache[db_evaluationcachelast].value,
+			(char *)value, db_cluster);
+	} else
+	{
+		db_evaluationcache[db_evaluationcachelast].value = value;
+	}
+	db_evaluationcachelast++;
+	if (db_evaluationcachelast > db_evaluationcachesize)
+		db_evaluationcachesize = db_evaluationcachelast;
+	if (db_evaluationcachelast >= EVALUATIONCACHESIZE)
+		db_evaluationcachelast = 0;
+}
+
 /*
  * routine called to shutdown interpreter when the program exits
  */
 void db_termlanguage(void)
 {
+	REGISTER INTBIG i;
+
+	for(i=0; i<db_evaluationcachesize; i++)
+	{
+		efree((char *)db_evaluationcache[i].code);
+		if ((db_evaluationcache[i].type&VTYPE) == VSTRING)
+			efree((char *)db_evaluationcache[i].value);
+	}
 #if LANGMM
 	if (db_mathematicalink != NULL)
 	{
