@@ -33,114 +33,114 @@
 
 #include "global.h"
 #include "dblang.h"
-ELKObject lsp_displayablesym;
-INTSML lsp_strportinited = 0;
-ELKObject lsp_strport;
+static ELKObject lsp_displayablesym;
+static INTSML    lsp_strportinited = 0;
+static ELKObject lsp_strport;
 
 #define Ensure_Type(x,t) if (TYPE(x) != t) { Wrong_Type(x, t); return(Null); }
 
 /* prototypes for local routines */
-int EElectric_Equal(ELKObject, ELKObject);
-int ENodeInst_Print(ELKObject, ELKObject, int, int, int);
-int ENodeProto_Print(ELKObject, ELKObject, int, int, int);
-int EPortArcInst_Print(ELKObject, ELKObject, int, int, int);
-int EPortExpInst_Print(ELKObject, ELKObject, int, int, int);
-int EPortProto_Print(ELKObject, ELKObject, int, int, int);
-int EArcInst_Print(ELKObject, ELKObject, int, int, int);
-int EArcProto_Print(ELKObject, ELKObject, int, int, int);
-int EGeom_Print(ELKObject, ELKObject, int, int, int);
-int ELibrary_Print(ELKObject, ELKObject, int, int, int);
-int ETechnology_Print(ELKObject, ELKObject, int, int, int);
-int EAid_Print(ELKObject, ELKObject, int, int, int);
-int ERTNode_Print(ELKObject, ELKObject, int, int, int);
-int ENetwork_Print(ELKObject, ELKObject, int, int, int);
-int ECell_Print(ELKObject, ELKObject, int, int, int);
-int EView_Print(ELKObject, ELKObject, int, int, int);
-int EWindow_Print(ELKObject, ELKObject, int, int, int);
-int EGraphics_Print(ELKObject, ELKObject, int, int, int);
-int EConstraint_Print(ELKObject, ELKObject, int, int, int);
-int EWindowFrame_Print(ELKObject, ELKObject, int, int, int);
-ELKObject P_ENodeInstP(ELKObject);
-ELKObject P_ENodeProtoP(ELKObject);
-ELKObject P_EPortArcInstP(ELKObject);
-ELKObject P_EPortExpInstP(ELKObject);
-ELKObject P_EPortProtoP(ELKObject);
-ELKObject P_EArcInstP(ELKObject);
-ELKObject P_EArcProtoP(ELKObject);
-ELKObject P_EGeomP(ELKObject);
-ELKObject P_ELibraryP(ELKObject);
-ELKObject P_ETechnologyP(ELKObject);
-ELKObject P_EAidP(ELKObject);
-ELKObject P_ERTNodeP(ELKObject);
-ELKObject P_ENetworkP(ELKObject);
-ELKObject P_ECellP(ELKObject);
-ELKObject P_EViewP(ELKObject);
-ELKObject P_EWindowP(ELKObject);
-ELKObject P_EGraphicsP(ELKObject);
-ELKObject P_EConstraintP(ELKObject);
-ELKObject P_EWindowFrameP(ELKObject);
-ELKObject Make_EElectric(INTBIG, INTSML);
-void init_lib_electric(void);
-INTSML lsp_getnumericobject(ELKObject, INTBIG*);
-char *lsp_getstringobject(ELKObject);
-void lsp_getaddrandtype(ELKObject, INTBIG*, INTBIG*);
-ELKObject lsp_makevarobject(INTBIG, INTBIG);
-ELKObject lsp_curlib(void);
-ELKObject lsp_curtech(void);
-ELKObject lsp_getval(ELKObject, ELKObject);
-ELKObject lsp_setval(ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_setind(ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_delval(ELKObject, ELKObject);
-ELKObject lsp_initsearch(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_nextobject(ELKObject);
-ELKObject lsp_getaid(ELKObject);
-ELKObject lsp_maxaid(void);
-ELKObject lsp_indexaid(ELKObject);
-ELKObject lsp_aidturnon(ELKObject, ELKObject);
-ELKObject lsp_aidturnoff(ELKObject);
-ELKObject lsp_getlibrary(ELKObject);
-ELKObject lsp_newlibrary(ELKObject, ELKObject);
-ELKObject lsp_killlibrary(ELKObject);
-ELKObject lsp_eraselibrary(ELKObject);
-ELKObject lsp_selectlibrary(ELKObject);
-ELKObject lsp_getnodeproto(ELKObject);
-ELKObject lsp_newnodeproto(ELKObject, ELKObject);
-ELKObject lsp_killnodeproto(ELKObject);
-ELKObject lsp_copynodeproto(ELKObject, ELKObject, ELKObject);
-ELKObject lsp_iconview(ELKObject);
-ELKObject lsp_contentsview(ELKObject);
-ELKObject lsp_newnodeinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_modifynodeinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_killnodeinst(ELKObject);
-ELKObject lsp_replacenodeinst(ELKObject, ELKObject);
-ELKObject lsp_nodefunction(ELKObject);
-ELKObject lsp_newarcinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject,
-	ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_modifyarcinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_killarcinst(ELKObject);
-ELKObject lsp_replacearcinst(ELKObject, ELKObject);
-ELKObject lsp_newportproto(ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_portposition(ELKObject, ELKObject);
-ELKObject lsp_getportproto(ELKObject, ELKObject);
-ELKObject lsp_killportproto(ELKObject, ELKObject);
-ELKObject lsp_moveportproto(ELKObject, ELKObject, ELKObject, ELKObject);
-ELKObject lsp_undoabatch(void);
-ELKObject lsp_noundoallowed(void);
-ELKObject lsp_getview(ELKObject);
-ELKObject lsp_newview(ELKObject, ELKObject);
-ELKObject lsp_killview(ELKObject);
-ELKObject lsp_tellaid(long, ELKObject[]);
-ELKObject lsp_getarcproto(ELKObject);
-ELKObject lsp_getcell(ELKObject);
-ELKObject lsp_gettechnology(ELKObject);
-ELKObject lsp_getpinproto(ELKObject);
-ELKObject lsp_getnetwork(ELKObject, ELKObject);
+static int EElectric_Equal(ELKObject, ELKObject);
+static int ENodeInst_Print(ELKObject, ELKObject, int, int, int);
+static int ENodeProto_Print(ELKObject, ELKObject, int, int, int);
+static int EPortArcInst_Print(ELKObject, ELKObject, int, int, int);
+static int EPortExpInst_Print(ELKObject, ELKObject, int, int, int);
+static int EPortProto_Print(ELKObject, ELKObject, int, int, int);
+static int EArcInst_Print(ELKObject, ELKObject, int, int, int);
+static int EArcProto_Print(ELKObject, ELKObject, int, int, int);
+static int EGeom_Print(ELKObject, ELKObject, int, int, int);
+static int ELibrary_Print(ELKObject, ELKObject, int, int, int);
+static int ETechnology_Print(ELKObject, ELKObject, int, int, int);
+static int ETool_Print(ELKObject, ELKObject, int, int, int);
+static int ERTNode_Print(ELKObject, ELKObject, int, int, int);
+static int ENetwork_Print(ELKObject, ELKObject, int, int, int);
+static int ECell_Print(ELKObject, ELKObject, int, int, int);
+static int EView_Print(ELKObject, ELKObject, int, int, int);
+static int EWindow_Print(ELKObject, ELKObject, int, int, int);
+static int EGraphics_Print(ELKObject, ELKObject, int, int, int);
+static int EConstraint_Print(ELKObject, ELKObject, int, int, int);
+static int EWindowFrame_Print(ELKObject, ELKObject, int, int, int);
+static ELKObject P_ENodeInstP(ELKObject);
+static ELKObject P_ENodeProtoP(ELKObject);
+static ELKObject P_EPortArcInstP(ELKObject);
+static ELKObject P_EPortExpInstP(ELKObject);
+static ELKObject P_EPortProtoP(ELKObject);
+static ELKObject P_EArcInstP(ELKObject);
+static ELKObject P_EArcProtoP(ELKObject);
+static ELKObject P_EGeomP(ELKObject);
+static ELKObject P_ELibraryP(ELKObject);
+static ELKObject P_ETechnologyP(ELKObject);
+static ELKObject P_EToolP(ELKObject);
+static ELKObject P_ERTNodeP(ELKObject);
+static ELKObject P_ENetworkP(ELKObject);
+static ELKObject P_ECellP(ELKObject);
+static ELKObject P_EViewP(ELKObject);
+static ELKObject P_EWindowP(ELKObject);
+static ELKObject P_EGraphicsP(ELKObject);
+static ELKObject P_EConstraintP(ELKObject);
+static ELKObject P_EWindowFrameP(ELKObject);
+static ELKObject Make_EElectric(INTBIG, INTSML);
+static void init_lib_electric(void);
+static INTSML lsp_getnumericobject(ELKObject, INTBIG*);
+static char *lsp_getstringobject(ELKObject);
+static void lsp_getaddrandtype(ELKObject, INTBIG*, INTBIG*);
+static ELKObject lsp_makevarobject(INTBIG, INTBIG);
+static ELKObject lsp_curlib(void);
+static ELKObject lsp_curtech(void);
+static ELKObject lsp_getval(ELKObject, ELKObject);
+static ELKObject lsp_setval(ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_setind(ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_delval(ELKObject, ELKObject);
+static ELKObject lsp_initsearch(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_nextobject(ELKObject);
+static ELKObject lsp_gettool(ELKObject);
+static ELKObject lsp_maxtool(void);
+static ELKObject lsp_indextool(ELKObject);
+static ELKObject lsp_toolturnon(ELKObject, ELKObject);
+static ELKObject lsp_toolturnoff(ELKObject);
+static ELKObject lsp_getlibrary(ELKObject);
+static ELKObject lsp_newlibrary(ELKObject, ELKObject);
+static ELKObject lsp_killlibrary(ELKObject);
+static ELKObject lsp_eraselibrary(ELKObject);
+static ELKObject lsp_selectlibrary(ELKObject);
+static ELKObject lsp_getnodeproto(ELKObject);
+static ELKObject lsp_newnodeproto(ELKObject, ELKObject);
+static ELKObject lsp_killnodeproto(ELKObject);
+static ELKObject lsp_copynodeproto(ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_iconview(ELKObject);
+static ELKObject lsp_contentsview(ELKObject);
+static ELKObject lsp_newnodeinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_modifynodeinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_killnodeinst(ELKObject);
+static ELKObject lsp_replacenodeinst(ELKObject, ELKObject);
+static ELKObject lsp_nodefunction(ELKObject);
+static ELKObject lsp_newarcinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject,
+					ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_modifyarcinst(ELKObject, ELKObject, ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_killarcinst(ELKObject);
+static ELKObject lsp_replacearcinst(ELKObject, ELKObject);
+static ELKObject lsp_newportproto(ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_portposition(ELKObject, ELKObject);
+static ELKObject lsp_getportproto(ELKObject, ELKObject);
+static ELKObject lsp_killportproto(ELKObject, ELKObject);
+static ELKObject lsp_moveportproto(ELKObject, ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_undoabatch(void);
+static ELKObject lsp_noundoallowed(void);
+static ELKObject lsp_getview(ELKObject);
+static ELKObject lsp_newview(ELKObject, ELKObject);
+static ELKObject lsp_killview(ELKObject);
+static ELKObject lsp_telltool(long, ELKObject[]);
+static ELKObject lsp_getarcproto(ELKObject);
+static ELKObject lsp_getcell(ELKObject);
+static ELKObject lsp_gettechnology(ELKObject);
+static ELKObject lsp_getpinproto(ELKObject);
+static ELKObject lsp_getnetwork(ELKObject, ELKObject);
 
 /****************************** ELECTRIC OBJECTS ******************************/
 
 /* the internal LISP types */
-long T_ENodeInst, T_ENodeProto, T_EPortArcInst, T_EPortExpInst, T_EPortProto,
-	T_EArcInst, T_EArcProto, T_EGeom, T_ELibrary, T_ETechnology, T_EAid,
+static long T_ENodeInst, T_ENodeProto, T_EPortArcInst, T_EPortExpInst, T_EPortProto,
+	T_EArcInst, T_EArcProto, T_EGeom, T_ELibrary, T_ETechnology, T_ETool,
 	T_ERTNode, T_ENetwork, T_ECell, T_EView, T_EWindow, T_EGraphics, T_EConstraint,
 	T_EWindowFrame;
 
@@ -156,7 +156,7 @@ struct S_EArcProto    { ARCPROTO    *handle; };
 struct S_EGeom        { GEOM        *handle; };
 struct S_ELibrary     { LIBRARY     *handle; };
 struct S_ETechnology  { TECHNOLOGY  *handle; };
-struct S_EAid         { AIDENTRY    *handle; };
+struct S_ETool        { TOOL        *handle; };
 struct S_ERTNode      { RTNODE      *handle; };
 struct S_ENetwork     { NETWORK     *handle; };
 struct S_ECell        { CELL        *handle; };
@@ -178,7 +178,7 @@ struct S_EWindowFrame { WINDOWFRAME *handle; };
 #define EGEOM(obj)        ((struct S_EGeom *)POINTER(obj))
 #define ELIBRARY(obj)     ((struct S_ELibrary *)POINTER(obj))
 #define ETECHNOLOGY(obj)  ((struct S_ETechnology *)POINTER(obj))
-#define EAID(obj)         ((struct S_EAid *)POINTER(obj))
+#define ETOOL(obj)        ((struct S_ETool *)POINTER(obj))
 #define ERTNODE(obj)      ((struct S_ERTNode *)POINTER(obj))
 #define ENETWORK(obj)     ((struct S_ENetwork *)POINTER(obj))
 #define ECELL(obj)        ((struct S_ECell *)POINTER(obj))
@@ -215,8 +215,8 @@ int ELibrary_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, "#[library %s]", ELIBRARY(w)->handle->libname);  return(0); }
 int ETechnology_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, "#[technology %s]", ETECHNOLOGY(w)->handle->techname);  return(0); }
-int EAid_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
-{ Printf(port, "#[aid %s]", EAID(w)->handle->aidname);  return(0); }
+int ETool_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
+{ Printf(port, "#[tool %s]", ETOOL(w)->handle->toolname);  return(0); }
 int ERTNode_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, "#[r-tree %u]", ERTNODE(w)->handle);  return(0); }
 int ENetwork_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
@@ -245,7 +245,7 @@ ELKObject P_EArcProtoP(ELKObject x)    { return(TYPE(x) == T_EArcProto    ? True
 ELKObject P_EGeomP(ELKObject x)        { return(TYPE(x) == T_EGeom        ? Trueob : Falseob); }
 ELKObject P_ELibraryP(ELKObject x)     { return(TYPE(x) == T_ELibrary     ? Trueob : Falseob); }
 ELKObject P_ETechnologyP(ELKObject x)  { return(TYPE(x) == T_ETechnology  ? Trueob : Falseob); }
-ELKObject P_EAidP(ELKObject x)         { return(TYPE(x) == T_EAid         ? Trueob : Falseob); }
+ELKObject P_EToolP(ELKObject x)        { return(TYPE(x) == T_ETool        ? Trueob : Falseob); }
 ELKObject P_ERTNodeP(ELKObject x)      { return(TYPE(x) == T_ERTNode      ? Trueob : Falseob); }
 ELKObject P_ENetworkP(ELKObject x)     { return(TYPE(x) == T_ENetwork     ? Trueob : Falseob); }
 ELKObject P_ECellP(ELKObject x)        { return(TYPE(x) == T_ECell        ? Trueob : Falseob); }
@@ -660,6 +660,7 @@ char *lsp_getstringobject(ELKObject obj)
 	{
 		case T_Symbol:
 			obj = SYMBOL(obj)->name;
+			/* FALLTHROUGH */ 
 		case T_String:
 			str = STRING(obj)->data;
 			len = STRING(obj)->size;
@@ -722,7 +723,7 @@ void lsp_getaddrandtype(ELKObject oaddr, INTBIG *addr, INTBIG *type)
 	if (otype == T_EGeom)        *type = VGEOM; else
 	if (otype == T_ELibrary)     *type = VLIBRARY; else
 	if (otype == T_ETechnology)  *type = VTECHNOLOGY; else
-	if (otype == T_EAid)         *type = VAID; else
+	if (otype == T_ETool)        *type = VTOOL; else
 	if (otype == T_ERTNode)      *type = VRTNODE; else
 	if (otype == T_ENetwork)     *type = VNETWORK; else
 	if (otype == T_ECell)        *type = VCELL; else
@@ -780,9 +781,9 @@ ELKObject lsp_makevarobject(INTBIG type, INTBIG addr)
 		case VTECHNOLOGY:
 			ret = Make_EElectric(addr, (INTSML)T_ETechnology);
 			if (ETECHNOLOGY(ret)->handle == NOTECHNOLOGY) return(Null); else return(ret);
-		case VAID:
-			ret = Make_EElectric(addr, (INTSML)T_EAid);
-			if (EAID(ret)->handle == NOAID) return(Null); else return(ret);
+		case VTOOL:
+			ret = Make_EElectric(addr, (INTSML)T_ETool);
+			if (ETOOL(ret)->handle == NOTOOL) return(Null); else return(ret);
 		case VRTNODE:
 			ret = Make_EElectric(addr, (INTSML)T_ERTNode);
 			if (ERTNODE(ret)->handle == NORTNODE) return(Null); else return(ret);
@@ -876,6 +877,8 @@ ELKObject lsp_setval(ELKObject oaddr, ELKObject oname, ELKObject onaddr, ELKObje
 				(void)allocstring(&((char **)naddr)[i], (char *)thisaddr,
 					el_tempcluster); else
 						((INTBIG *)naddr)[i] = thisaddr;
+
+			/* LINTED "lasttype" used in proper order */
 			if (i != 0 && lasttype == VINTEGER && ntype == VFLOAT)
 			{
 				f = castfloat(thisaddr);
@@ -987,59 +990,59 @@ ELKObject lsp_nextobject(ELKObject osea)
 	return(Make_EElectric((INTBIG)g, (INTSML)T_EGeom));
 }
 
-/****************************** AID ROUTINES ******************************/
+/****************************** TOOL ROUTINES ******************************/
 
-ELKObject lsp_getaid(ELKObject oname)
+ELKObject lsp_gettool(ELKObject oname)
 {
 	char *name;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	/* get inputs from LISP */
 	name = lsp_getstringobject(oname);
 	if (name == 0) return(Null);
 
-	aid = getaid(name);
-	if (aid == NOAID) return(Null);
-	return(Make_EElectric((INTBIG)aid, (INTSML)T_EAid));
+	tool = gettool(name);
+	if (tool == NOTOOL) return(Null);
+	return(Make_EElectric((INTBIG)tool, (INTSML)T_ETool));
 }
 
-ELKObject lsp_maxaid(void)
+ELKObject lsp_maxtool(void)
 {
-	return(Make_Fixnum(el_maxaid));
+	return(Make_Fixnum(el_maxtools));
 }
 
-ELKObject lsp_indexaid(ELKObject oindex)
+ELKObject lsp_indextool(ELKObject oindex)
 {
 	INTBIG aindex;
 
 	/* get inputs from LISP */
 	if (lsp_getnumericobject(oindex, &aindex) != 0) return(Null);
 
-	if (aindex < 0 || aindex >= el_maxaid) return(Null);
-	return(Make_EElectric((INTBIG)&el_aids[aindex], (INTSML)T_EAid));
+	if (aindex < 0 || aindex >= el_maxtools) return(Null);
+	return(Make_EElectric((INTBIG)&el_tools[aindex], (INTSML)T_ETool));
 }
 
-ELKObject lsp_aidturnon(ELKObject oaid, ELKObject onocatchup)
+ELKObject lsp_toolturnon(ELKObject otool, ELKObject onocatchup)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	INTBIG nocatchup;
 
 	/* get inputs from LISP */
-	Ensure_Type(oaid, T_EAid);   aid = EAID(oaid)->handle;
+	Ensure_Type(otool, T_ETool);   tool = ETOOL(otool)->handle;
 	if (lsp_getnumericobject(onocatchup, &nocatchup) != 0) return(Null);
 
-	aidturnon(aid, (INTSML)nocatchup);
+	toolturnon(tool, (INTSML)nocatchup);
 	return(Null);
 }
 
-ELKObject lsp_aidturnoff(ELKObject oaid)
+ELKObject lsp_toolturnoff(ELKObject otool)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	/* get inputs from LISP */
-	Ensure_Type(oaid, T_EAid);   aid = EAID(oaid)->handle;
+	Ensure_Type(otool, T_ETool);   tool = ETOOL(otool)->handle;
 
-	aidturnoff(aid, 1);
+	toolturnoff(tool, 1);
 	return(Null);
 }
 
@@ -1265,7 +1268,7 @@ ELKObject lsp_nodefunction(ELKObject oni)
 	/* get inputs from LISP */
 	Ensure_Type(oni, T_ENodeInst);   ni = ENODEINST(oni)->handle;
 
-	return(Make_Integer(nodefunction(ni, 0)));
+	return(Make_Integer(nodefunction(ni)));
 }
 
 /****************************** ARCINST ROUTINES ******************************/
@@ -1429,10 +1432,10 @@ ELKObject lsp_moveportproto(ELKObject onp, ELKObject oopp, ELKObject onni, ELKOb
 
 ELKObject lsp_undoabatch(void)
 {
-	INTBIG aid;
+	INTBIG tool;
 
-	if (undoabatch((AIDENTRY **)&aid) == 0) return(Null);
-	return(Make_Fixnum(aid));
+	if (undoabatch((TOOL **)&tool) == 0) return(Null);
+	return(Make_Fixnum(tool));
 }
 
 ELKObject lsp_noundoallowed(void)
@@ -1485,15 +1488,15 @@ ELKObject lsp_killview(ELKObject ov)
 
 /*************************** MISCELLANEOUS ROUTINES ***************************/
 
-ELKObject lsp_tellaid(long argc, ELKObject argv[])
+ELKObject lsp_telltool(long argc, ELKObject argv[])
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER INTSML i, val;
 	char *par[20], *ret;
 
 	/* get inputs from LISP */
 	if (argc < 1) return(Null);
-	Ensure_Type(argv[0], T_EAid);   aid = EAID(argv[0])->handle;
+	Ensure_Type(argv[0], T_ETool);   tool = ETOOL(argv[0])->handle;
 	argc--;   argv++;
 	for(i=0; i<argc; i++)
 	{
@@ -1502,7 +1505,7 @@ ELKObject lsp_tellaid(long argc, ELKObject argv[])
 		(void)allocstring(&par[i], ret, el_tempcluster);
 	}
 
-	val = tellaid(aid, (INTSML)argc, par);
+	val = telltool(tool, (INTSML)argc, par);
 	for(i=0; i<argc; i++) efree(par[i]);
 	return(Make_Fixnum(val));
 }
@@ -1602,8 +1605,8 @@ void init_lib_electric(void)
 		EElectric_Equal, EElectric_Equal, ELibrary_Print, NOFUNC);
 	T_ETechnology = Define_Type(0, "technology", NOFUNC, sizeof (struct S_ETechnology),
 		EElectric_Equal, EElectric_Equal, ETechnology_Print, NOFUNC);
-	T_EAid = Define_Type(0, "aid", NOFUNC, sizeof (struct S_EAid),
-		EElectric_Equal, EElectric_Equal, EAid_Print, NOFUNC);
+	T_ETool = Define_Type(0, "tool", NOFUNC, sizeof (struct S_ETool),
+		EElectric_Equal, EElectric_Equal, ETool_Print, NOFUNC);
 	T_ERTNode = Define_Type(0, "rtnode", NOFUNC, sizeof (struct S_ERTNode),
 		EElectric_Equal, EElectric_Equal, ERTNode_Print, NOFUNC);
 	T_ENetwork = Define_Type(0, "network", NOFUNC, sizeof (struct S_ENetwork),
@@ -1632,7 +1635,7 @@ void init_lib_electric(void)
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EGeomP, "geom?", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ELibraryP, "library?", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ETechnologyP, "technology?", 1, 1, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EAidP, "aid?", 1, 1, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EToolP, "tool?", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ERTNodeP, "rtnode?", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ENetworkP, "network?", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ECellP, "cell?", 1, 1, EVAL);
@@ -1655,12 +1658,12 @@ void init_lib_electric(void)
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_initsearch, "initsearch", 5, 5, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_nextobject, "nextobject", 1, 1, EVAL);
 
-	/* define the aid predicates */
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getaid, "getaid", 1, 1, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_maxaid, "maxaid", 0, 0, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_indexaid, "indexaid", 1, 1, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_aidturnon, "aidturnon", 2, 2, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_aidturnoff, "aidturnoff", 1, 1, EVAL);
+	/* define the tool predicates */
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_gettool, "gettool", 1, 1, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_maxtool, "maxtool", 0, 0, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_indextool, "indextool", 1, 1, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_toolturnon, "toolturnon", 2, 2, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_toolturnoff, "toolturnoff", 1, 1, EVAL);
 
 	/* define the library predicates */
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getlibrary, "getlibrary", 1, 1, EVAL);
@@ -1708,7 +1711,7 @@ void init_lib_electric(void)
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_killview, "killview", 1, 1, EVAL);
 
 	/* define the miscellaneous predicates */
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_tellaid, "tellaid", 1, MANY, VARARGS);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_telltool, "telltool", 1, MANY, VARARGS);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getarcproto, "getarcproto", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getcell, "getcell", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_gettechnology, "gettechnology", 1, 1, EVAL);
