@@ -48,72 +48,74 @@
 
 #define BUFSIZE 500
 
-char *tcl_outputbuffer, *tcl_outputloc, *tcl_inputbuffer, *tcl_inputloc;
-Tcl_Interp *tcl_interp = 0;
+       char       *tcl_outputbuffer, *tcl_outputloc;
+static char       *tcl_inputbuffer;
+       Tcl_Interp *tcl_interp = 0;
 
 /* prototypes for local routines */
-void tcl_dumpoutput(char *str);
-INTSML tcl_getinput(void);
-void tcl_converttoanyelectric(char *tclstr, INTBIG *addr, INTBIG *type);
-void tcl_converttoscalartcl(INTBIG addr, INTBIG type);
-char *tcl_converttotcl(INTBIG addr, INTBIG type);
-INTBIG tcl_converttowarnedelectric(char *name, INTBIG want, char *msg);
-int tcl_tkconsoleclose(ClientData instanceData, Tcl_Interp *interp);
-int tcl_tkconsoleinput(ClientData instanceData, char *buf, int bufSize, int *errorCode);
-int tcl_tkconsoleoutput(ClientData instanceData, char *buf, int toWrite, int *errorCode);
-void tcl_tkconsolewatch(ClientData instanceData, int mask);
+static void tcl_dumpoutput(char *str);
+static void tcl_converttoanyelectric(char *tclstr, INTBIG *addr, INTBIG *type);
+static void tcl_converttoscalartcl(INTBIG addr, INTBIG type);
+static char *tcl_converttotcl(INTBIG addr, INTBIG type);
+static INTBIG tcl_converttowarnedelectric(char *name, INTBIG want, char *msg);
+static int tcl_tkconsoleclose(ClientData instanceData, Tcl_Interp *interp);
+static int tcl_tkconsoleinput(ClientData instanceData, char *buf, int bufSize, int *errorCode);
+static int tcl_tkconsoleoutput(ClientData instanceData, char *buf, int toWrite, int *errorCode);
+static void tcl_tkconsolewatch(ClientData instanceData, int mask);
 
-int tcl_curlib(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_curtech(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_setval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_setind(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_delval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_initsearch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_nextobject(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_maxaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_indexaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_aidturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_aidturnoff(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_eraselibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_selectlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_copynodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_iconview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_contentsview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_modifynodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_replacenodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_nodefunction(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_modifyarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_replacearcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_portposition(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_undoabatch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_noundoallowed(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_newview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_tellaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getarcproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getcell(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_gettechnology(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getpinproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_getnetwork(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_curlib(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_curtech(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_setval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_setind(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_delval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_initsearch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_nextobject(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_gettool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_maxtool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_indextool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_toolturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_toolturnoff(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_eraselibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_selectlibrary(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_copynodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_iconview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_contentsview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_modifynodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_replacenodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_nodefunction(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_modifyarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_replacearcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_portposition(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_undoabatch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_noundoallowed(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_newview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_telltool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_asktool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getarcproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getcell(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_gettechnology(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getpinproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getnetwork(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+#ifdef USETK
+  static int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+#endif
 
 /************************* TCL: ELECTRIC ROUTINES *************************/
 /*
@@ -151,7 +153,6 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	tcl_inputbuffer = (char *)emalloc(BUFSIZE, db_cluster);
 	if (tcl_outputbuffer == 0 || tcl_inputbuffer == 0) return;
 	tcl_outputloc = tcl_outputbuffer;
-	tcl_inputloc = 0;
 
 	/* set console channels */
 	consoleChannel = Tcl_CreateChannel(&consoleChannelType, "console0", (ClientData)TCL_STDIN, TCL_READABLE);
@@ -250,11 +251,11 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	Tcl_CreateCommand(tcl_interp, "delval",          tcl_delval,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "initsearch",      tcl_initsearch,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "nextobject",      tcl_nextobject,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "getaid",          tcl_getaid,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "maxaid",          tcl_maxaid,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "indexaid",        tcl_indexaid,        (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "aidturnon",       tcl_aidturnon,       (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "aidturnoff",      tcl_aidturnoff,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "gettool",         tcl_gettool,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "maxtool",         tcl_maxtool,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "indextool",       tcl_indextool,       (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "toolturnon",      tcl_toolturnon,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "toolturnoff",     tcl_toolturnoff,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "getlibrary",      tcl_getlibrary,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "newlibrary",      tcl_newlibrary,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "killlibrary",     tcl_killlibrary,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
@@ -285,8 +286,8 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	Tcl_CreateCommand(tcl_interp, "getview",         tcl_getview,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "newview",         tcl_newview,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "killview",        tcl_killview,        (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "tellaid",         tcl_tellaid,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "askaid",          tcl_askaid,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "telltool",        tcl_telltool,        (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "asktool",         tcl_asktool,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "getarcproto",     tcl_getarcproto,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "getcell",         tcl_getcell,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "gettechnology",   tcl_gettechnology,   (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
@@ -332,7 +333,7 @@ void tcl_converttoanyelectric(char *tclstr, INTBIG *addr, INTBIG *type)
 	if (namesamen(tclstr, "#geom",         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VGEOM;        return; }
 	if (namesamen(tclstr, "#library",      8) == 0) { *addr = myatoi(&tclstr[8]);  *type = VLIBRARY;     return; }
 	if (namesamen(tclstr, "#technology",  11) == 0) { *addr = myatoi(&tclstr[11]); *type = VTECHNOLOGY;  return; }
-	if (namesamen(tclstr, "#aid",          4) == 0) { *addr = myatoi(&tclstr[4]);  *type = VAID;         return; }
+	if (namesamen(tclstr, "#tool",         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VTOOL;        return; }
 	if (namesamen(tclstr, "#rtnode",       7) == 0) { *addr = myatoi(&tclstr[7]);  *type = VRTNODE;      return; }
 	if (namesamen(tclstr, "#network",      8) == 0) { *addr = myatoi(&tclstr[8]);  *type = VNETWORK;     return; }
 	if (namesamen(tclstr, "#cell",         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VCELL;        return; }
@@ -380,7 +381,7 @@ INTBIG tcl_converttoelectric(char *tclstr, INTBIG type)
 		case VGEOM:        if (namesamen(tclstr, "#geom",         5) == 0) return(myatoi(&tclstr[5]));  break;
 		case VLIBRARY:     if (namesamen(tclstr, "#library",      8) == 0) return(myatoi(&tclstr[8]));  break;
 		case VTECHNOLOGY:  if (namesamen(tclstr, "#technology",  11) == 0) return(myatoi(&tclstr[11])); break;
-		case VAID:         if (namesamen(tclstr, "#aid",          4) == 0) return(myatoi(&tclstr[4]));  break;
+		case VTOOL:        if (namesamen(tclstr, "#tool",         5) == 0) return(myatoi(&tclstr[5]));  break;
 		case VRTNODE:      if (namesamen(tclstr, "#rtnode",       7) == 0) return(myatoi(&tclstr[7]));  break;
 		case VNETWORK:     if (namesamen(tclstr, "#network",      8) == 0) return(myatoi(&tclstr[8]));  break;
 		case VCELL:        if (namesamen(tclstr, "#cell",         5) == 0) return(myatoi(&tclstr[5]));  break;
@@ -495,7 +496,7 @@ void tcl_converttoscalartcl(INTBIG addr, INTBIG type)
 		case VGEOM:        sprintf(line, "#geom%ld",        addr);    break;
 		case VLIBRARY:     sprintf(line, "#library%ld",     addr);    break;
 		case VTECHNOLOGY:  sprintf(line, "#technology%ld",  addr);    break;
-		case VAID:         sprintf(line, "#aid%ld",         addr);    break;
+		case VTOOL:        sprintf(line, "#tool%ld",        addr);    break;
 		case VRTNODE:      sprintf(line, "#rtnode%ld",      addr);    break;
 		case VNETWORK:     sprintf(line, "#network%ld",     addr);    break;
 		case VCELL:        sprintf(line, "#cell%ld",        addr);    break;
@@ -518,7 +519,6 @@ int tcl_tkconsoleinput(ClientData instanceData, char *buf, int bufSize, int *err
 
 	*errorCode = 0;
 	*tcl_outputloc = 0;
-	tcl_inputloc = 0;
 	pt = ttygetlinemessages(tcl_outputbuffer);
 	tcl_outputloc = tcl_outputbuffer;
 	len = strlen(pt);
@@ -566,32 +566,6 @@ void tcl_dumpoutput(char *str)
 	}
 }
 
-INTSML tcl_getinput(void)
-{
-	char *pt;
-	INTSML ret;
-
-	if (tcl_inputloc == 0)
-	{
-		/* nothing in the buffer: get a line */
-		*tcl_outputloc = 0;
-		pt = ttygetlinemessages(tcl_outputbuffer);
-		tcl_outputloc = tcl_outputbuffer;
-		if (pt == 0) return(EOF);
-		(void)strcpy(tcl_inputbuffer, pt);
-		tcl_inputloc = tcl_inputbuffer;
-	}
-
-	/* get the next character */
-	ret = *tcl_inputloc++;
-	if (ret == 0)
-	{
-		ret = '\n';
-		tcl_inputloc = 0;
-	}
-	return(ret);
-}
-
 /************************* DATABASE EXAMINATION ROUTINES *************************/
 
 int tcl_curlib(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
@@ -803,97 +777,97 @@ int tcl_nextobject(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	return TCL_OK;
 }
 
-/****************************** AID ROUTINES ******************************/
+/****************************** TOOL ROUTINES ******************************/
 
-int tcl_getaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_gettool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, "Usage: getaid NAME", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: gettool NAME", (char *)NULL);
 		return TCL_ERROR;
 	}
 
 	/* call Electric */
-	aid = getaid(argv[1]);
+	tool = gettool(argv[1]);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)aid, VAID), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)tool, VTOOL), (char *) NULL);
 	return TCL_OK;
 }
 
-int tcl_maxaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_maxtool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	/* get input */
 	if (argc != 1)
 	{
-		Tcl_AppendResult(interp, "Usage: maxaid", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: maxtool", (char *)NULL);
 		return TCL_ERROR;
 	}
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(el_maxaid, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(el_maxtools, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
-int tcl_indexaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_indextool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER INTBIG aindex;
 
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, "Usage: indexaid INDEX", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: indextool INDEX", (char *)NULL);
 		return TCL_ERROR;
 	}
 	aindex = myatoi(argv[1]);
 
 	/* call Electric */
-	if (aindex < 0 || aindex >= el_maxaid) aid = NOAID; else aid = &el_aids[aindex];
+	if (aindex < 0 || aindex >= el_maxtools) tool = NOTOOL; else tool = &el_tools[aindex];
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)aid, VAID), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)tool, VTOOL), (char *) NULL);
 	return TCL_OK;
 }
 
-int tcl_aidturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_toolturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER INTBIG nocatchup;
 
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, "Usage: aidturnon AID NOCATCHUP", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: toolturnon TOOL NOCATCHUP", (char *)NULL);
 		return TCL_ERROR;
 	}
-	aid = (AIDENTRY *)tcl_converttowarnedelectric(argv[1], VAID, "first");
-	if (aid == NOAID) return TCL_ERROR;
+	tool = (TOOL *)tcl_converttowarnedelectric(argv[1], VTOOL, "first");
+	if (tool == NOTOOL) return TCL_ERROR;
 	nocatchup = myatoi(argv[2]);
 
 	/* call Electric */
-	aidturnon(aid, (INTSML)nocatchup);
+	toolturnon(tool, (INTSML)nocatchup);
 	return TCL_OK;
 }
 
-int tcl_aidturnoff(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_toolturnoff(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, "Usage: aidturnoff AID", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: toolturnoff TOOL", (char *)NULL);
 		return TCL_ERROR;
 	}
-	aid = (AIDENTRY *)tcl_converttowarnedelectric(argv[1], VAID, "first");
-	if (aid == NOAID) return TCL_ERROR;
+	tool = (TOOL *)tcl_converttowarnedelectric(argv[1], VTOOL, "first");
+	if (tool == NOTOOL) return TCL_ERROR;
 
 	/* call Electric */
-	aidturnoff(aid, 1);
+	toolturnoff(tool, 1);
 	return TCL_OK;
 }
 
@@ -1238,7 +1212,7 @@ int tcl_nodefunction(ClientData dummy, Tcl_Interp *interp, int argc, char **argv
 	if (ni == NONODEINST) return TCL_ERROR;
 
 	/* call Electric */
-	fun = nodefunction(ni, 0);
+	fun = nodefunction(ni);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl(fun, VINTEGER), (char *) NULL);
@@ -1489,7 +1463,7 @@ int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 
 int tcl_undoabatch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	AIDENTRY *aid;
+	TOOL *tool;
 
 	if (argc != 1)
 	{
@@ -1498,14 +1472,14 @@ int tcl_undoabatch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	}
 
 	/* call Electric */
-	if (undoabatch(&aid) == 0)
+	if (undoabatch(&tool) == 0)
 	{
 		Tcl_AppendResult(interp, _("Error during undoabatch"), (char *)NULL);
 		return TCL_ERROR;
 	}
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)aid, VAID), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)tool, VTOOL), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1586,63 +1560,63 @@ int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 
 /*************************** MISCELLANEOUS ROUTINES ***************************/
 
-int tcl_tellaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_telltool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
-	int aidArgc, ret;
-	char **aidArgv;
+	REGISTER TOOL *tool;
+	int toolArgc, ret;
+	char **toolArgv;
 
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, "Usage: tellaid AID {PARAMETERS}", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: telltool TOOL {PARAMETERS}", (char *)NULL);
 		return TCL_ERROR;
 	}
-	aid = (AIDENTRY *)tcl_converttowarnedelectric(argv[1], VAID, "first");
-	ret = Tcl_SplitList(interp, argv[2], &aidArgc, &aidArgv);
-	if (aid == NOAID || ret != TCL_OK) return TCL_ERROR;
+	tool = (TOOL *)tcl_converttowarnedelectric(argv[1], VTOOL, "first");
+	ret = Tcl_SplitList(interp, argv[2], &toolArgc, &toolArgv);
+	if (tool == NOTOOL || ret != TCL_OK) return TCL_ERROR;
 
 	/* call Electric */
-	ret = tellaid(aid, (INTSML)aidArgc, aidArgv);
-	ckfree((char *)aidArgv);
+	ret = telltool(tool, (INTSML)toolArgc, toolArgv);
+	ckfree((char *)toolArgv);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
-int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+int tcl_asktool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	INTBIG addr, addr0, addr1, addr2, addr3, type;
-	int aidArgc, ret, i, argcS, first;
-	char **aidArgv, **argvS, *command;
+	int toolArgc, ret, i, argcS, first;
+	char **toolArgv, **argvS, *command;
 
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, "Usage: askaid AID {PARAMETERS}", (char *)NULL);
+		Tcl_AppendResult(interp, "Usage: asktool TOOL {PARAMETERS}", (char *)NULL);
 		return TCL_ERROR;
 	}
-	aid = (AIDENTRY *)tcl_converttowarnedelectric(argv[1], VAID, "first");
-	ret = Tcl_SplitList(interp, argv[2], &aidArgc, &aidArgv);
-	if (aid == NOAID || ret != TCL_OK) return TCL_ERROR;
+	tool = (TOOL *)tcl_converttowarnedelectric(argv[1], VTOOL, "first");
+	ret = Tcl_SplitList(interp, argv[2], &toolArgc, &toolArgv);
+	if (tool == NOTOOL || ret != TCL_OK) return TCL_ERROR;
 
-	command = aidArgv[0];
-	for (i=0; i<aidArgc; i++) aidArgv[i] = aidArgv[i+1];
-	aidArgv[aidArgc] = NULL;
-	aidArgc--;
+	command = toolArgv[0];
+	for (i=0; i<toolArgc; i++) toolArgv[i] = toolArgv[i+1];
+	toolArgv[toolArgc] = NULL;
+	toolArgc--;
 
 	/* call Electric */
-	if (aidArgc == 0)
+	if (toolArgc == 0)
 	{
-		ret = askaid(aid, command);
-	} else if (aidArgc == 1)
+		ret = asktool(tool, command);
+	} else if (toolArgc == 1)
 	{
-		/* special case for user_aid: show-multiple command */
+		/* special case for user_tool: show-multiple command */
 		if (strcmp(command, "show-multiple") == 0)
 		{
-			ret = Tcl_SplitList(interp, aidArgv[0], &argcS, &argvS);
+			ret = Tcl_SplitList(interp, toolArgv[0], &argcS, &argvS);
 			if (ret == TCL_OK)
 			{
 				(void)initinfstr();
@@ -1655,33 +1629,33 @@ int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 					(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
 						describenodeproto(((GEOM *)addr)->entryaddr.ni->parent), addr);
 				}
-				ret = askaid(aid, command, (INTBIG)returninfstr());
+				ret = asktool(tool, command, (INTBIG)returninfstr());
 			}
 		} else
 		{
-			tcl_converttoanyelectric(aidArgv[0], &addr0, &type);
-			ret = askaid(aid, command, addr0);
+			tcl_converttoanyelectric(toolArgv[0], &addr0, &type);
+			ret = asktool(tool, command, addr0);
 		}
-	} else if (aidArgc == 2)
+	} else if (toolArgc == 2)
 	{
-		tcl_converttoanyelectric(aidArgv[0], &addr0, &type);
-		tcl_converttoanyelectric(aidArgv[1], &addr1, &type);
-		ret = askaid(aid, command, addr0, addr1);
-	} else if (aidArgc == 3)
+		tcl_converttoanyelectric(toolArgv[0], &addr0, &type);
+		tcl_converttoanyelectric(toolArgv[1], &addr1, &type);
+		ret = asktool(tool, command, addr0, addr1);
+	} else if (toolArgc == 3)
 	{
-		tcl_converttoanyelectric(aidArgv[0], &addr0, &type);
-		tcl_converttoanyelectric(aidArgv[1], &addr1, &type);
-		tcl_converttoanyelectric(aidArgv[2], &addr2, &type);
-		ret = askaid(aid, command, addr0, addr1, addr2);
-	} else if (aidArgc == 4)
+		tcl_converttoanyelectric(toolArgv[0], &addr0, &type);
+		tcl_converttoanyelectric(toolArgv[1], &addr1, &type);
+		tcl_converttoanyelectric(toolArgv[2], &addr2, &type);
+		ret = asktool(tool, command, addr0, addr1, addr2);
+	} else if (toolArgc == 4)
 	{
-		tcl_converttoanyelectric(aidArgv[0], &addr0, &type);
-		tcl_converttoanyelectric(aidArgv[1], &addr1, &type);
-		tcl_converttoanyelectric(aidArgv[2], &addr2, &type);
-		tcl_converttoanyelectric(aidArgv[3], &addr3, &type);
-		ret = askaid(aid, command, addr0, addr1, addr2, addr3);
+		tcl_converttoanyelectric(toolArgv[0], &addr0, &type);
+		tcl_converttoanyelectric(toolArgv[1], &addr1, &type);
+		tcl_converttoanyelectric(toolArgv[2], &addr2, &type);
+		tcl_converttoanyelectric(toolArgv[3], &addr3, &type);
+		ret = asktool(tool, command, addr0, addr1, addr2, addr3);
 	}
-	ckfree((char *)aidArgv);
+	ckfree((char *)toolArgv);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
@@ -1943,10 +1917,10 @@ INTSML tcl_pulldownindex(POPUPMENU *pm, char *prevmenu)
 
 	/* allocate new space with one more */
 	newpulldownmenus = (TkMenuReferences **)emalloc((tcl_pulldownmenucount+1) *
-		(sizeof (TkMenuReferences *)), us_aid->cluster);
+		(sizeof (TkMenuReferences *)), us_tool->cluster);
 	if (newpulldownmenus == 0) return(-1);
 	newpulldowns = (POPUPMENU **)emalloc((tcl_pulldownmenucount+1) *
-		(sizeof (POPUPMENU *)), us_aid->cluster);
+		(sizeof (POPUPMENU *)), us_tool->cluster);
 	if (newpulldowns == 0) return(-1);
 
 	/* copy former arrays then delete them */
@@ -2070,7 +2044,7 @@ INTSML tcl_loadtclmsg(char *s, ...)
 	char line[256];
 
 	var_start(ap, s);
-	(void)vsprintf(line, s, ap);
+	evsnprintf(line, 256, s, ap);
 	va_end(ap);
 
 	if (Tcl_VarEval(tcl_interp, line, 0) == TCL_ERROR)
@@ -2122,7 +2096,7 @@ int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 			setdefaultcursortype(NULLCURSOR);
 #endif
 			us_forceeditchanges();
-			us_execute(pm->list[j].response, us_aid->aidstate&ECHOBIND, 1, 1);
+			us_execute(pm->list[j].response, us_tool->toolstate&ECHOBIND, 1, 1);
 			setactivity(pm->list[j].attribute);
 		}
 	}
