@@ -32,10 +32,12 @@
 #include "database.h"
 
 /* prototypes for local routines */
-void db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*, INTBIG*);
-void db_validatearcinst(ARCINST*);
-void db_setarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
-INTBIG db_scaleunits(INTBIG *value, INTBIG num, INTBIG den);
+static void   db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*, INTBIG*);
+static void   db_validatearcinst(ARCINST*);
+static void   db_setarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
+static INTBIG db_scaleunits(INTBIG *value, INTBIG num, INTBIG den);
+static void   db_scalearcinst(ARCINST *ai, INTBIG num, INTBIG denom);
+static void   db_scalenodeinst(NODEINST *ni, INTBIG num, INTBIG denom);
 
 /****************************** LIBRARIES ******************************/
 
@@ -157,6 +159,9 @@ LIBRARY *newlibrary(char *name, char *file)
 	/* tell constraint system about new library */
 	(*el_curconstraint->newlib)(lib);
 
+	/* mark a change to the database */
+	db_changetimestamp++;
+
 	/* report library address */
 	return(lib);
 }
@@ -189,6 +194,9 @@ void selectlibrary(LIBRARY *lib)
 
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		changetechnologylambda(tech, el_curlib->lambda[tech->techindex]);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 void killlibrary(LIBRARY *lib)
@@ -242,9 +250,9 @@ void eraselibrary(LIBRARY *lib)
 	/* flush all batched changes */
 	noundoallowed();
 
-	for(i=0; i<el_maxaid; i++) 
-		if (el_aids[i].eraselibrary != 0)
-			(*el_aids[i].eraselibrary)(lib);
+	for(i=0; i<el_maxtools; i++) 
+		if (el_tools[i].eraselibrary != 0)
+			(*el_tools[i].eraselibrary)(lib);
 
 	/* erase the nodes, ports, arcs, and geometry modules in each nodeproto */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -334,6 +342,9 @@ void eraselibrary(LIBRARY *lib)
 
 	/* now erase the library information */
 	if (lib->numvar != 0) db_freevars(&lib->firstvar, &lib->numvar);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /****************************** LAMBDA ******************************/
@@ -633,6 +644,9 @@ void changetechnologylambda(TECHNOLOGY *tech, INTBIG newlambda)
 
 	/* finally, reset the default lambda value */
 	tech->deflambda = newlambda;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -792,6 +806,9 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 			ttyputmsg(_("Recommend redisplay"));
 		}
 	}
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
