@@ -66,27 +66,28 @@ typedef struct
 static SPAREPAGES db_sparepages[SPAREPAGELIMIT];
 static INTBIG db_sparepagecount = 0;
 static INTBIG db_pagesize, db_pagebits;
-#endif
 INTBIG        db_clustercount = 0;
 CLUSTER     *db_firstcluster;	/* top of list of clusters */
 CLUSTER     *db_clusterfree;	/* list of free memory clusters */
 
+char    *db_getmorememory(CLUSTER*, INTBIG, INTBIG);
+char    *db_getpages(INTBIG);
+void     db_coalescecluster(CLUSTER*);
+void     db_printoneclusterarena(CLUSTER*, INTSML, INTBIG*, INTBIG*, INTBIG*);
+#endif
+
 /* prototypes for local routines */
-char *db_getmorememory(CLUSTER*, INTBIG, INTBIG);
-char *db_getpages(INTBIG);
-void db_printoneclusterarena(CLUSTER*, INTSML, INTBIG*, INTBIG*, INTBIG*);
-void db_coalescecluster(CLUSTER*);
 #ifndef HAVE_GETPAGESIZE
-  INTBIG getpagesize(void);
+  static INTBIG getpagesize(void);
 #endif
 #ifndef HAVE_VALLOC
-  char *valloc(INTBIG);
+  static char  *valloc(INTBIG);
 #endif
 #ifdef DEBUGMEMORY
-  void db_checkmemoryblock(char *addr);
-  void db_checkcluster(CLUSTER *clus);
-  FILE *db_memerrio = 0;
-  char db_initialdirectory[256];
+  static void   db_checkmemoryblock(char *addr);
+  static void   db_checkcluster(CLUSTER *clus);
+  static FILE  *db_memerrio = 0;
+  static char   db_initialdirectory[256];
 #endif
 
 /*
@@ -102,7 +103,7 @@ void db_coalescecluster(CLUSTER*);
  *   every cell (in CELL->cluster)
  *   every technology (TECHNOLOGY->cluster)
  *   every library (LIBRARY->cluster)
- *   every aid (AIDENTRY->cluster)
+ *   every tool (TOOL->cluster)
  *   every constraint (CONSTRAINT->cluster)
  *   one for temporary use (el_tempcluster)
  *   one for general database use (db_cluster)
@@ -539,8 +540,8 @@ void db_checkallmemoryfree(void)
 	freecluster(el_tempcluster);
 	for(i=0; el_constraints[i].conname != 0; i++)
 		freecluster(el_constraints[i].cluster);
-	for(i = el_maxaid-1; i >= 0; i--)
-		freecluster(el_aids[i].cluster);
+	for(i = el_maxtools-1; i >= 0; i--)
+		freecluster(el_tools[i].cluster);
 	while (db_clusterfree != NOCLUSTER)
 	{
 		clus = db_clusterfree;
