@@ -68,63 +68,48 @@ static INTBIG maxnumpts = MAXNUMPTS; /* apply default (PJA:920527) */
 #define DOWN        2
 #define LEFT        3
 
-POLYLISTHEAD db_mrg_polycoordlist;
-POLYCOORD   *db_mrg_free_poly_list;
-BOXPOLY     *db_mrg_free_box_list;
-BOXLISTHEAD *db_mrg_free_boxhead_list;
-BOXLISTHEAD *db_mrg_curr_facet;
+static POLYLISTHEAD db_mrg_polycoordlist;
+static POLYCOORD   *db_mrg_free_poly_list;
+static BOXPOLY     *db_mrg_free_box_list;
+static BOXLISTHEAD *db_mrg_free_boxhead_list;
+static BOXLISTHEAD *db_mrg_curr_facet;
 
 /* working storage for "db_mrg_write_polygon()" */
 static INTBIG *db_mrgxbuf, *db_mrgybuf;
 static INTSML db_mrgbuflen = 0;
 
 /* prototypes for local routines */
-INTBIG mrg_set_maxnumpts(INTBIG);
-INTSML db_mrg_included(BOXPOLY*, BOXPOLY*);
-void db_mrg_remove_inclusion(BOXLISTHEAD*);
-void db_mrg_remove_overlap(BOXLISTHEAD*);
-BOXPOLY *db_mrg_breakbox(BOXPOLY*, BOXPOLY*, INTSML*);
-BOXPOLY *db_mrg_do_break(BOXPOLY*, BOXPOLY*, INTSML*);
-void db_mrg_write_lists(void(*)(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML));
-POLYCOORD *db_mrg_getpoly(void);
-INTSML db_mrg_mergeboxwithpolygon(BOXPOLY*);
-INTSML db_mrg_check_intersect(BOXPOLY*, POLYCOORD*, INTSML*);
-INTSML db_mrg_check_point(INTBIG[], INTBIG[], INTBIG[], INTBIG[]);
-void db_mrg_insert1(INTSML, BOXPOLY*);
-void db_mrg_insert2(INTSML, BOXPOLY*);
-void db_mrg_insert3(INTSML, BOXPOLY*);
-void db_mrg_insert4(INTSML, BOXPOLY*);
-void db_mrg_write_polygon(void(*)(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML), INTSML, TECHNOLOGY*);
-INTSML db_mrg_pred(INTSML);
-INTSML db_mrg_succ(INTSML);
-INTSML db_mrg_nxtside(INTSML);
-INTSML db_mrg_prevside(INTSML);
-void db_mrg_assign_edge(POLYCOORD*, INTBIG[], INTBIG[]);
-void db_mrg_housekeeper(void);
-void db_mrg_insert5(INTSML, INTSML, BOXPOLY*);
-BOXPOLY *db_mrg_getbox(void);
-void db_mrg_trash(BOXPOLY*);
-void db_mrg_dump_free_box_list(void);
-void db_mrg_assign_box(BOXPOLY*, INTBIG, INTBIG, INTBIG, INTBIG);
-void db_mrg_killpoly(POLYCOORD*);
-void db_mrg_dump_free_poly_list(void);
-void db_mrg_remove_poly_list(void);
-BOXLISTHEAD *db_mrg_get_lay_head(void);
-void db_mrg_dump_free_boxhead_list(void);
-void db_mrg_remove_boxhead_list(void);
-
-INTBIG mrg_set_maxnumpts(INTBIG npts) /* set maximum number of vertices allowed on polygon (PJA:920527) */
-{
-	INTBIG cmax;
-
-	if (npts <= 0)
-	{ /* nonsense */
-		return(0);
-	}
-	cmax = maxnumpts; /* will return current maximum */
-	maxnumpts = npts; /* set as new maximum */
-	return(cmax); /* and return the old max */
-}
+static INTSML       db_mrg_included(BOXPOLY*, BOXPOLY*);
+static void         db_mrg_remove_inclusion(BOXLISTHEAD*);
+static void         db_mrg_remove_overlap(BOXLISTHEAD*);
+static BOXPOLY     *db_mrg_breakbox(BOXPOLY*, BOXPOLY*, INTSML*);
+static BOXPOLY     *db_mrg_do_break(BOXPOLY*, BOXPOLY*, INTSML*);
+static void         db_mrg_write_lists(void(*)(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML));
+static POLYCOORD   *db_mrg_getpoly(void);
+static INTSML       db_mrg_mergeboxwithpolygon(BOXPOLY*);
+static INTSML       db_mrg_check_intersect(BOXPOLY*, POLYCOORD*, INTSML*);
+static INTSML       db_mrg_check_point(INTBIG[], INTBIG[], INTBIG[], INTBIG[]);
+static void         db_mrg_insert1(INTSML, BOXPOLY*);
+static void         db_mrg_insert2(INTSML, BOXPOLY*);
+static void         db_mrg_insert3(INTSML, BOXPOLY*);
+static void         db_mrg_insert4(INTSML, BOXPOLY*);
+static void         db_mrg_write_polygon(void(*)(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML), INTSML, TECHNOLOGY*);
+static INTSML       db_mrg_succ(INTSML);
+static INTSML       db_mrg_nxtside(INTSML);
+static INTSML       db_mrg_prevside(INTSML);
+static void         db_mrg_assign_edge(POLYCOORD*, INTBIG[], INTBIG[]);
+static void         db_mrg_housekeeper(void);
+static void         db_mrg_insert5(INTSML, INTSML, BOXPOLY*);
+static BOXPOLY     *db_mrg_getbox(void);
+static void         db_mrg_trash(BOXPOLY*);
+static void         db_mrg_dump_free_box_list(void);
+static void         db_mrg_assign_box(BOXPOLY*, INTBIG, INTBIG, INTBIG, INTBIG);
+static void         db_mrg_killpoly(POLYCOORD*);
+static void         db_mrg_dump_free_poly_list(void);
+static void         db_mrg_remove_poly_list(void);
+static BOXLISTHEAD *db_mrg_get_lay_head(void);
+static void         db_mrg_dump_free_boxhead_list(void);
+static void         db_mrg_remove_boxhead_list(void);
 
 void mrginit(void)
 {
@@ -278,7 +263,7 @@ void db_mrg_remove_overlap(BOXLISTHEAD *layhead)
 				}
 			} else if (rtc == 2) /* independent... do nothing */
 			{
-				;
+				/* EMPTY */ 
 			} else
 			{
 				/* rtc = 0, replace me on list with list returned by break */
@@ -333,6 +318,7 @@ BOXPOLY *db_mrg_breakbox(BOXPOLY *me, BOXPOLY *him, INTSML *rtc)
 			} else
 			{
 				/* if we get here, we are in deep trouble */
+				/* EMPTY */ 
 			}
 		} else /* if we got here, a break occurred..do something with list */
 		{
@@ -680,6 +666,8 @@ void db_mrg_write_lists(void (*writepolygon)(INTSML, TECHNOLOGY*, INTBIG*, INTBI
 					{
 						/* not the first on list */
 						garbage = boxscanptr;
+
+						/* LINTED "oldboxscan" used in proper order */
 						oldboxscan->nextbox = boxscanptr->nextbox;
 						boxscanptr = boxscanptr->nextbox;
 						garbage->nextbox = NULL;
@@ -1846,32 +1834,32 @@ typedef struct Impoly
 	struct Impoly *nextmpoly;			/* next polygon in linked list */
 } MPOLY;
 
-MPOLY  *db_mpolylist = NOMPOLY;			/* the list of active MPOLYs */
-MPOLY  *db_mpolyfree = NOMPOLY;			/* the list of unused MPOLYs */
-MPOLY  *db_mergenewmp = NOMPOLY;		/* temporary MPOLY for merging */
+static MPOLY  *db_mpolylist = NOMPOLY;		/* the list of active MPOLYs */
+static MPOLY  *db_mpolyfree = NOMPOLY;		/* the list of unused MPOLYs */
+static MPOLY  *db_mergenewmp = NOMPOLY;		/* temporary MPOLY for merging */
 
 /* for figuring out what to do at an intersection */
-INTBIG *db_mergeintpol;					/* polygon with intersection */
-INTBIG *db_mergeintpt;					/* point with intersection */
-INTBIG *db_mergeintleaveangle;			/* angle of intersection */
-INTBIG  db_mergeintcount;				/* number of intersection */
-INTBIG  db_mergeinttotal = 0;			/* size of intersection arrays */
+static INTBIG *db_mergeintpol;				/* polygon with intersection */
+static INTBIG *db_mergeintpt;				/* point with intersection */
+static INTBIG *db_mergeintleaveangle;		/* angle of intersection */
+static INTBIG  db_mergeintcount;			/* number of intersection */
+       INTBIG  db_mergeinttotal = 0;		/* size of intersection arrays */
 
-INTSML db_mergeaddholetopoly(MPOLY *holemplist, MPOLY *newmp);
-void   db_mergeaddintersectionpoint(INTBIG polygon, INTBIG point);
-INTSML db_mergeaddintersectionpoints(MPOLY *mp, MPOLY *omp);
-MPOLY *db_mergeallocpoly(void);
-INTSML db_mergecopypoly(MPOLY *smp, MPOLY *dmp);
-INTSML db_mergeensurespace(MPOLY *mp, INTBIG count);
-INTBIG db_mergefindstartingpoint(MPOLY *mp, MPOLY *omp);
-void   db_mergefreepoly(MPOLY *mp);
-INTSML db_mergeinsertpoint(MPOLY *newmp, INTBIG *insert, INTBIG x, INTBIG y);
-INTSML db_mergeisinside(INTBIG x, INTBIG y, MPOLY *mp);
-INTSML db_mergelinesintersect(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
-		INTBIG ofx, INTBIG ofy, INTBIG otx, INTBIG oty, INTBIG *ix, INTBIG *iy);
-INTSML db_mergepoly(MPOLY *mp, MPOLY *omp);
-void   db_mergesimplifyandbbox(MPOLY *mp);
-INTSML db_mergewalkedge(MPOLY *mp, INTBIG i, MPOLY *omp, MPOLY *newmp);
+static INTSML db_mergeaddholetopoly(MPOLY *holemplist, MPOLY *newmp);
+static void   db_mergeaddintersectionpoint(INTBIG polygon, INTBIG point);
+static INTSML db_mergeaddintersectionpoints(MPOLY *mp, MPOLY *omp);
+static MPOLY *db_mergeallocpoly(void);
+static INTSML db_mergecopypoly(MPOLY *smp, MPOLY *dmp);
+static INTSML db_mergeensurespace(MPOLY *mp, INTBIG count);
+static INTBIG db_mergefindstartingpoint(MPOLY *mp, MPOLY *omp);
+static void   db_mergefreepoly(MPOLY *mp);
+static INTSML db_mergeinsertpoint(MPOLY *newmp, INTBIG *insert, INTBIG x, INTBIG y);
+static INTSML db_mergeisinside(INTBIG x, INTBIG y, MPOLY *mp);
+static INTSML db_mergelinesintersect(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
+				INTBIG ofx, INTBIG ofy, INTBIG otx, INTBIG oty, INTBIG *ix, INTBIG *iy);
+static INTSML db_mergepoly(MPOLY *mp, MPOLY *omp);
+static void   db_mergesimplifyandbbox(MPOLY *mp);
+static INTSML db_mergewalkedge(MPOLY *mp, INTBIG i, MPOLY *omp, MPOLY *newmp);
 
 /* #define DEBUGWALK       1 */		/* uncomment to debug polygon point traversal */
 /* #define SHOWRESULTS     1 */		/* uncomment to show results of each merge */
@@ -2147,8 +2135,10 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 					var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)latoa(mp->x[i]),
 						VSTRING|VDISPLAY);
 					if (var != NOVARIABLE)
-						var->textdescript = (var->textdescript & ~(VTSIZE|VTPOSITION)) |
-							(VTPOSDOWN | (TXT1L<<VTSIZESH));
+					{
+						TDSETPOS(var->textdescript, VTPOSDOWN);
+						TDSETSIZE(var->textdescript, TXTSETQLAMBDA(4));
+					}
 					endobjectchange((INTBIG)ni, VNODEINST);
 				}
 			}
@@ -2175,8 +2165,10 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 					var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)latoa(mp->y[i]),
 						VSTRING|VDISPLAY);
 					if (var != NOVARIABLE)
-						var->textdescript = (var->textdescript & ~(VTSIZE|VTPOSITION)) |
-							(VTPOSLEFT | (TXT1L<<VTSIZESH));
+					{
+						TDSETPOS(var->textdescript, VTPOSLEFT);
+						TDSETSIZE(var->textdescript, TXTSETQLAMBDA(4));
+					}
 					endobjectchange((INTBIG)ni, VNODEINST);
 				}
 			}
@@ -2492,6 +2484,8 @@ INTSML db_mergeaddholetopoly(MPOLY *holemplist, MPOLY *newmp)
 					if (newmp->seen[k] == 0)
 					{
 						dist = computedistance(holemp->x[j], holemp->y[j], newmp->x[k], newmp->y[k]);
+
+						/* LINTED "bestdist" used in proper order */
 						if (besthole == NOMPOLY || dist < bestdist)
 						{
 							bestdist = dist;
@@ -2938,9 +2932,9 @@ INTSML db_mergelinesintersect(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
 	if (maxi(fy,ty) < mini(ofy,oty)) return(0);
 
 	/* determine the angle of the lines */
-	ang = atan2(ty-fy, tx-fx);
+	ang = atan2((double)(ty-fy), (double)(tx-fx));
 	if (ang < 0.0) ang += EPI*2.0;
-	oang = atan2(oty-ofy, otx-ofx);
+	oang = atan2((double)(oty-ofy), (double)(otx-ofx));
 	if (oang < 0.0) oang += EPI*2.0;
 
 	/* special case if they are at the same angle */
