@@ -33,22 +33,24 @@
 #include "egraphics.h"
 #include "usr.h"
 
+#define PRINTFRAMEQLAMBDA 60		/* size of text in frames (in quarter lambda units) */
+
 /* hierarchical traversal data structures */
-NODEINST **db_hierpath;
-INTBIG     db_hierdepth = 0;
-INTBIG     db_hierlimit = 0;
+static NODEINST **db_hierpath;
+static INTBIG     db_hierdepth = 0;
+static INTBIG     db_hierlimit = 0;
 
 /* prototypes for local routines */
-INTSML db_schematic_pages(NODEPROTO*);
-char  *db_getframedesc(NODEPROTO*);
-INTSML db_copyxlibvars(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, LIBRARY*);
-INTSML db_portassociate(NODEINST*, NODEINST*, INTSML);
-INTSML db_doesntconnect(ARCPROTO*[], PORTPROTO*);
-void   db_changeallports(PORTPROTO*);
-INTSML db_addtohierpath(NODEINST *ni);
-void   db_insertcell(CELL *cell);
-void   db_retractcell(CELL *cell);
-INTBIG db_namehash(char *name);
+static INTSML db_schematic_pages(NODEPROTO*);
+static char  *db_getframedesc(NODEPROTO*);
+static INTSML db_copyxlibvars(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, LIBRARY*);
+static INTSML db_portassociate(NODEINST*, NODEINST*, INTSML);
+static INTSML db_doesntconnect(ARCPROTO*[], PORTPROTO*);
+static void   db_changeallports(PORTPROTO*);
+static INTSML db_addtohierpath(NODEINST *ni);
+static void   db_insertcell(CELL *cell);
+static void   db_retractcell(CELL *cell);
+static INTBIG db_namehash(char *name);
 
 /*
  * Routine to free all memory associated with this module.
@@ -567,6 +569,9 @@ void db_insertnodeproto(NODEPROTO *np)
 		np->nextincell = np->cell->firstincell;
 		np->cell->firstincell = np;
 	}
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -632,6 +637,9 @@ void db_retractnodeproto(NODEPROTO *np)
 
 	/* clear cache of port associations in this cell */
 	db_clearportcache(np);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
@@ -825,6 +833,7 @@ void gettraversalpath(NODEINST ***nilist, INTSML *depth)
 			ni = descentparent(np);
 			if (ni == NONODEINST) break;
 			if (db_addtohierpath(ni) != 0) break;
+			if (np == ni->proto) break;
 			np = ni->proto;
 		}
 		*depth = (INTSML)db_hierdepth;
@@ -901,6 +910,7 @@ NODEINST *descentparent(NODEPROTO *np)
 	var = getvalkey((INTBIG)np, VNODEPROTO, VNODEINST, us_facet_descent_path);
 	if (var == NOVARIABLE) return(NONODEINST);
 	ni = (NODEINST *)var->addr;
+	if (ni->parent == np) return(NONODEINST);
 
 	/* validate this pointer: node must be a current instance of this facet */
 	for(vni = np->firstinst; vni != NONODEINST; vni = vni->nextinst)
@@ -1008,6 +1018,9 @@ VIEW *newview(char *vname, char *svname)
 	}
 	db_donextchangequietly = 0;
 
+	/* mark a change to the database */
+	db_changetimestamp++;
+
 	/* return the view */
 	return(v);
 }
@@ -1056,6 +1069,9 @@ INTSML killview(VIEW *view)
 		(void)db_change((INTBIG)v, OBJECTKILL, VVIEW, 0, 0, 0, 0, 0);
 	}
 	db_donextchangequietly = 0;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 	return(0);
 }
 
@@ -1268,6 +1284,8 @@ static GRAPHICS tech_frame = {LAYERO, MENTXT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 #define FRAMESCALE  700.0f
+#define HASCHXSIZE  ( 8.5f  / FRAMESCALE)
+#define HASCHYSIZE  ( 5.5f  / FRAMESCALE)
 #define ASCHXSIZE   (11.0f  / FRAMESCALE)
 #define ASCHYSIZE   ( 8.5f  / FRAMESCALE)
 #define BSCHXSIZE   (17.0f  / FRAMESCALE)
@@ -1296,6 +1314,7 @@ INTSML framesize(INTBIG *x, INTBIG *y, NODEPROTO *np)
 	if (*size == 0) return(1);
 	switch (size[0])
 	{
+		case 'h': wid = HASCHXSIZE;  hei = HASCHYSIZE;  break;
 		case 'a': wid = ASCHXSIZE;   hei = ASCHYSIZE;   break;
 		case 'b': wid = BSCHXSIZE;   hei = BSCHYSIZE;   break;
 		case 'c': wid = CSCHXSIZE;   hei = CSCHYSIZE;   break;
@@ -1333,7 +1352,7 @@ INTSML framepolys(NODEPROTO *np)
 	}
 
 	/* compute number of polygons */
-	total = 2+(xsections-1)*2+(ysections-1)*2+xsections*2+ysections*2+10;
+	total = 2+(xsections-1)*2+(ysections-1)*2+xsections*2+ysections*2+12;
 	return(total);
 }
 
@@ -1351,6 +1370,7 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 	size = db_getframedesc(np);
 	switch (size[0])
 	{
+		case 'h': wid = HASCHXSIZE;  hei = HASCHYSIZE;  break;
 		case 'a': wid = ASCHXSIZE;   hei = ASCHYSIZE;   break;
 		case 'b': wid = BSCHXSIZE;   hei = BSCHYSIZE;   break;
 		case 'c': wid = CSCHXSIZE;   hei = CSCHYSIZE;   break;
@@ -1444,7 +1464,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 		}
 		poly->count = 4;
 		poly->style = TEXTBOX;
-		poly->font = TXT6L;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 		poly->tech = el_curtech;
 		(void)sprintf(line, "%d", xsections-pindex);
 		poly->string = line;
@@ -1465,7 +1486,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 		}
 		poly->count = 4;
 		poly->style = TEXTBOX;
-		poly->font = TXT6L;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 		poly->tech = el_curtech;
 		line[0] = 'A' + pindex;
 		line[1] = 0;
@@ -1494,7 +1516,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 6;
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->font = TXT6L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 				poly->tech = el_curtech;
 				poly->string = ndstring;
 				break;
@@ -1507,7 +1530,7 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->style = CLOSEDRECT;
 				break;
 			case 3:			/* designer name */
-				var = getval((INTBIG)us_aid, VAID, VSTRING, "USER_drawing_designer_name");
+				var = getval((INTBIG)us_tool, VTOOL, VSTRING, "USER_drawing_designer_name");
 				if (var == NOVARIABLE) break;
 				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
 				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
@@ -1515,7 +1538,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 4;
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->font = TXT6L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 				poly->tech = el_curtech;
 				poly->string = (char *)var->addr;
 				break;
@@ -1536,7 +1560,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 6;
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->font = TXT6L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 				poly->tech = el_curtech;
 				poly->string = ndstring;
 				break;
@@ -1557,11 +1582,12 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 6;
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->font = TXT6L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 				poly->tech = el_curtech;
 				poly->string = ndstring;
 				break;
-			case 8:			/* frame around company name */
+			case 8:			/* frame around project name */
 				poly->xv[0] =  schxsize/2 - framewid - xlogobox;
 				poly->yv[0] = -schysize/2 + framewid + ylogobox / 4 * 3;
 				poly->xv[1] =  schxsize/2 - framewid;
@@ -1569,8 +1595,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->count = 2;
 				poly->style = CLOSEDRECT;
 				break;
-			case 9:			/* company name */
-				var = getval((INTBIG)us_aid, VAID, VSTRING, "USER_drawing_company_name");
+			case 9:			/* project name */
+				var = getval((INTBIG)us_tool, VTOOL, VSTRING, "USER_drawing_project_name");
 				if (var == NOVARIABLE) break;
 				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
 				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
@@ -1578,7 +1604,30 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 4;
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->font = TXT6L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
+				poly->tech = el_curtech;
+				poly->string = (char *)var->addr;
+				break;
+			case 10:		/* frame around company name */
+				poly->xv[0] =  schxsize/2 - framewid - xlogobox;
+				poly->yv[0] = -schysize/2 + framewid + ylogobox;
+				poly->xv[1] =  schxsize/2 - framewid;
+				poly->yv[1] = -schysize/2 + framewid + ylogobox / 4 * 5;
+				poly->count = 2;
+				poly->style = CLOSEDRECT;
+				break;
+			case 11:		/* company name */
+				var = getval((INTBIG)us_tool, VTOOL, VSTRING, "USER_drawing_company_name");
+				if (var == NOVARIABLE) break;
+				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
+				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
+				poly->yv[0] = poly->yv[1] = -schysize/2 + framewid + ylogobox;
+				poly->yv[2] = poly->yv[3] = poly->yv[0] + ylogobox / 4;
+				poly->count = 4;
+				poly->style = TEXTBOX;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(PRINTFRAMEQLAMBDA));
 				poly->tech = el_curtech;
 				poly->string = (char *)var->addr;
 				break;
@@ -1777,7 +1826,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 		ni->temp1 = (UINTBIG)toni;
 
 		/* copy miscellaneous information */
-		toni->textdescript = ni->textdescript;
+		TDCOPY(toni->textdescript, ni->textdescript);
 		toni->userbits = ni->userbits;
 	}
 
@@ -1886,7 +1935,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 
 		/* copy miscellaneous information */
 		ppt->userbits = pp->userbits;
-		ppt->textdescript = pp->textdescript;
+		TDCOPY(ppt->textdescript, pp->textdescript);
 	}
 
 	/* copy facet variables */
@@ -2019,7 +2068,7 @@ INTSML db_copyxlibvars(INTBIG fromaddr, INTBIG fromtype, INTBIG toaddr,
 		if (skipit != 0) continue;
 		var = setvalkey(toaddr, totype, key, addr, type);
 		if (var == NOVARIABLE) return(-1);
-		var->textdescript = (*firstvar)[i].textdescript;
+		TDCOPY(var->textdescript, (*firstvar)[i].textdescript);
 		if (newaddr != 0) efree((char *)newaddr);
 	}
 	return(failures);
@@ -2298,7 +2347,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np, INTSML ignoreportnames,
 
 	/* copy all variables on the nodeinst */
 	(void)copyvars((INTBIG)ni, VNODEINST, (INTBIG)newno, VNODEINST);
-	newno->textdescript = ni->textdescript;
+	TDCOPY(newno->textdescript, ni->textdescript);
 
 	/* now delete the original nodeinst */
 	db_killnodeinst(ni);
@@ -2582,6 +2631,9 @@ void db_changeport(PORTPROTO *pp, NODEINST *newsubno, PORTPROTO *newsubpt)
 
 	/* update all port characteristics exported from this one */
 	changeallports(pp);
+
+	/* mark a change to the database */
+	db_changetimestamp++;
 }
 
 /*
