@@ -67,12 +67,14 @@ static INTBIG    **tech_drcconndistancew = 0;		/* cache for "drcmindistance" */
 static INTBIG    **tech_drcuncondistancew = 0;		/* cache for "drcmindistance" */
 static INTBIG    **tech_drcconndistancem = 0;		/* cache for "drcmindistance" */
 static INTBIG    **tech_drcuncondistancem = 0;		/* cache for "drcmindistance" */
+static INTBIG    **tech_drcedgedistance = 0;		/* cache for "drcmindistance" */
 static char     ***tech_drccondistancerule = 0;		/* cache for "drcmindistance" */
 static char     ***tech_drcuncondistancerule = 0;	/* cache for "drcmindistance" */
 static char     ***tech_drccondistancewrule = 0;	/* cache for "drcmindistance" */
 static char     ***tech_drcuncondistancewrule = 0;	/* cache for "drcmindistance" */
 static char     ***tech_drccondistancemrule = 0;	/* cache for "drcmindistance" */
 static char     ***tech_drcuncondistancemrule = 0;	/* cache for "drcmindistance" */
+static char     ***tech_drcedgedistancerule = 0;	/* cache for "drcmindistance" */
 static TECHNOLOGY *tech_3dcurtech = NOTECHNOLOGY;
 static VARIABLE   *tech_3dcurthicknessvar;
 static VARIABLE   *tech_3dcurheightvar;
@@ -89,17 +91,19 @@ typedef struct Iroutinelist
 } ROUTINELIST;
 static ROUTINELIST *tech_firstcache = NOROUTINELIST;
 
-/* prototypes for local routines */
-INTBIG tech_getdrcmindistance(TECHNOLOGY*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char **);
-void   tech_3ddefaultlayerheight(TECHNOLOGY *tech);
-void   tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy,
-		INTBIG lambda);
-INTBIG tech_arcprotowidthoffset(ARCPROTO *ap, INTBIG lambda);
+/* shared prototypes */
 void   tech_initmaxdrcsurround(void);
-void   tech_initnodesizeoffset(void);
-void   tech_initlayerfunction(void);
-void   tech_initlayername(void);
-void   tech_initarcwidthoffset(void);
+
+/* prototypes for local routines */
+static INTBIG tech_getdrcmindistance(TECHNOLOGY*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG*, char **);
+static void   tech_3ddefaultlayerheight(TECHNOLOGY *tech);
+static void   tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy,
+				INTBIG lambda);
+static INTBIG tech_arcprotowidthoffset(ARCPROTO *ap, INTBIG lambda);
+static void   tech_initnodesizeoffset(void);
+static void   tech_initlayerfunction(void);
+static void   tech_initlayername(void);
+static void   tech_initarcwidthoffset(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -132,12 +136,14 @@ void db_freetechnologymemory(void)
 	if (tech_drcuncondistancew != 0) efree((char *)tech_drcuncondistancew);
 	if (tech_drcconndistancem != 0) efree((char *)tech_drcconndistancem);
 	if (tech_drcuncondistancem != 0) efree((char *)tech_drcuncondistancem);
+	if (tech_drcedgedistance != 0) efree((char *)tech_drcedgedistance);
 	if (tech_drccondistancerule != 0) efree((char *)tech_drccondistancerule);
 	if (tech_drcuncondistancerule != 0) efree((char *)tech_drcuncondistancerule);
 	if (tech_drccondistancewrule != 0) efree((char *)tech_drccondistancewrule);
 	if (tech_drcuncondistancewrule != 0) efree((char *)tech_drcuncondistancewrule);
 	if (tech_drccondistancemrule != 0) efree((char *)tech_drccondistancemrule);
 	if (tech_drcuncondistancemrule != 0) efree((char *)tech_drcuncondistancemrule);
+	if (tech_drcedgedistancerule != 0) efree((char *)tech_drcedgedistancerule);
 }
 
 /******************** TECHNOLOGY ALLOCATION ********************/
@@ -404,6 +410,7 @@ void tech_initmaxdrcsurround(void)
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *t;
 	REGISTER INTBIG j, total, l, *dist, m;
+	INTBIG edge;
 
 	if (tech_drcmaxdistances != 0) efree((char *)tech_drcmaxdistances);
 	if (tech_drcwidelimit != 0) efree((char *)tech_drcwidelimit);
@@ -417,12 +424,14 @@ void tech_initmaxdrcsurround(void)
 	if (tech_drcuncondistancew != 0) efree((char *)tech_drcuncondistancew);
 	if (tech_drcconndistancem != 0) efree((char *)tech_drcconndistancem);
 	if (tech_drcuncondistancem != 0) efree((char *)tech_drcuncondistancem);
+	if (tech_drcedgedistance != 0) efree((char *)tech_drcedgedistance);
 	if (tech_drccondistancerule != 0) efree((char *)tech_drccondistancerule);
 	if (tech_drcuncondistancerule != 0) efree((char *)tech_drcuncondistancerule);
 	if (tech_drccondistancewrule != 0) efree((char *)tech_drccondistancewrule);
 	if (tech_drcuncondistancewrule != 0) efree((char *)tech_drcuncondistancewrule);
 	if (tech_drccondistancemrule != 0) efree((char *)tech_drccondistancemrule);
 	if (tech_drcuncondistancemrule != 0) efree((char *)tech_drcuncondistancemrule);
+	if (tech_drcedgedistancerule != 0) efree((char *)tech_drcedgedistancerule);
 
 	tech_drcmaxdistances = (INTBIG **)emalloc((el_maxtech * (sizeof (INTBIG *))), db_cluster);
 	if (tech_drcmaxdistances == 0) return;
@@ -448,6 +457,8 @@ void tech_initmaxdrcsurround(void)
 	if (tech_drcconndistancem == 0) return;
 	tech_drcuncondistancem = (INTBIG **)emalloc((el_maxtech * (sizeof (INTBIG *))), db_cluster);
 	if (tech_drcuncondistancem == 0) return;
+	tech_drcedgedistance = (INTBIG **)emalloc((el_maxtech * (sizeof (INTBIG *))), db_cluster);
+	if (tech_drcedgedistance == 0) return;
 	tech_drccondistancerule = (char ***)emalloc((el_maxtech * (sizeof (char **))), db_cluster);
 	if (tech_drccondistancerule == 0) return;
 	tech_drcuncondistancerule = (char ***)emalloc((el_maxtech * (sizeof (char **))), db_cluster);
@@ -460,6 +471,8 @@ void tech_initmaxdrcsurround(void)
 	if (tech_drccondistancemrule == 0) return;
 	tech_drcuncondistancemrule = (char ***)emalloc((el_maxtech * (sizeof (char **))), db_cluster);
 	if (tech_drcuncondistancemrule == 0) return;
+	tech_drcedgedistancerule = (char ***)emalloc((el_maxtech * (sizeof (char **))), db_cluster);
+	if (tech_drcedgedistancerule == 0) return;
 
 	for(t = el_technologies; t != NOTECHNOLOGY; t = t->nexttechnology)
 	{
@@ -475,12 +488,14 @@ void tech_initmaxdrcsurround(void)
 		tech_drcuncondistancew[t->techindex] = 0;
 		tech_drcconndistancem[t->techindex] = 0;
 		tech_drcuncondistancem[t->techindex] = 0;
+		tech_drcedgedistance[t->techindex] = 0;
 		tech_drccondistancerule[t->techindex] = 0;
 		tech_drcuncondistancerule[t->techindex] = 0;
 		tech_drccondistancewrule[t->techindex] = 0;
 		tech_drcuncondistancewrule[t->techindex] = 0;
 		tech_drccondistancemrule[t->techindex] = 0;
 		tech_drcuncondistancemrule[t->techindex] = 0;
+		tech_drcedgedistancerule[t->techindex] = 0;
 
 		var = getvalkey((INTBIG)t, VTECHNOLOGY, VFRACT, dr_wide_limitkey);
 		if (var != NOVARIABLE) tech_drcwidelimit[t->techindex] = var->addr;
@@ -504,6 +519,9 @@ void tech_initmaxdrcsurround(void)
 		if (var != NOVARIABLE) tech_drcconndistancem[t->techindex] = (INTBIG *)var->addr;
 		var = getvalkey((INTBIG)t, VTECHNOLOGY, VFRACT|VISARRAY, dr_unconnected_distancesMkey);
 		if (var != NOVARIABLE) tech_drcuncondistancem[t->techindex] = (INTBIG *)var->addr;
+		var = getvalkey((INTBIG)t, VTECHNOLOGY, VFRACT|VISARRAY, dr_edge_distanceskey);
+		if (var != NOVARIABLE) tech_drcedgedistance[t->techindex] = (INTBIG *)var->addr;
+
 		var = getvalkey((INTBIG)t, VTECHNOLOGY, VSTRING|VISARRAY, dr_connected_distances_rulekey);
 		if (var != NOVARIABLE) tech_drccondistancerule[t->techindex] = (char **)var->addr;
 		var = getvalkey((INTBIG)t, VTECHNOLOGY, VSTRING|VISARRAY, dr_unconnected_distances_rulekey);
@@ -516,6 +534,8 @@ void tech_initmaxdrcsurround(void)
 		if (var != NOVARIABLE) tech_drccondistancemrule[t->techindex] = (char **)var->addr;
 		var = getvalkey((INTBIG)t, VTECHNOLOGY, VSTRING|VISARRAY, dr_unconnected_distancesM_rulekey);
 		if (var != NOVARIABLE) tech_drcuncondistancemrule[t->techindex] = (char **)var->addr;
+		var = getvalkey((INTBIG)t, VTECHNOLOGY, VSTRING|VISARRAY, dr_edge_distances_rulekey);
+		if (var != NOVARIABLE) tech_drcedgedistancerule[t->techindex] = (char **)var->addr;
 
 		/* compute max distances if there are any there */
 		if (tech_drcuncondistance[t->techindex] == 0) continue;
@@ -526,7 +546,7 @@ void tech_initmaxdrcsurround(void)
 		{
 			m = XX;
 			for(j=0; j<total; j++)
-				m = maxi(m, tech_getdrcmindistance(t, l, j, 0, 1, 0, 0));
+				m = maxi(m, tech_getdrcmindistance(t, l, j, 0, 1, 0, &edge, 0));
 			dist[l] = m;
 		}
 		nextchangequiet();
@@ -664,18 +684,30 @@ void registertechnologycache(void (*proc)(void), INTBIG count, INTBIG *variablek
  */
 void db_inittechcache(void)
 {
-	INTBIG keys[9];
+	INTBIG keys[20];
 
-	keys[0] = dr_max_distanceskey;
-	keys[1] = dr_connected_distanceskey;
-	keys[2] = dr_unconnected_distanceskey;
-	keys[3] = dr_connected_distancesWkey;
-	keys[4] = dr_unconnected_distancesWkey;
-	keys[5] = dr_connected_distancesMkey;
-	keys[6] = dr_unconnected_distancesMkey;
-	keys[7] = dr_min_widthkey;
-	keys[8] = dr_wide_limitkey;
-	registertechnologycache(tech_initmaxdrcsurround, 9, keys);
+	keys[0] = dr_wide_limitkey;
+	keys[1] = dr_min_widthkey;
+	keys[2] = dr_min_width_rulekey;
+	keys[3] = dr_min_node_sizekey;
+	keys[4] = dr_min_node_size_rulekey;
+	keys[5] = dr_connected_distanceskey;
+	keys[6] = dr_connected_distances_rulekey;
+	keys[7] = dr_unconnected_distanceskey;
+	keys[8] = dr_unconnected_distances_rulekey;
+	keys[9] = dr_connected_distancesWkey;
+	keys[10] = dr_connected_distancesW_rulekey;
+	keys[11] = dr_unconnected_distancesWkey;
+	keys[12] = dr_unconnected_distancesW_rulekey;
+	keys[13] = dr_connected_distancesMkey;
+	keys[14] = dr_connected_distancesM_rulekey;
+	keys[15] = dr_unconnected_distancesMkey;
+	keys[16] = dr_unconnected_distancesM_rulekey;
+	keys[17] = dr_edge_distanceskey;
+	keys[18] = dr_edge_distances_rulekey;
+	keys[19] = dr_max_distanceskey;
+
+	registertechnologycache(tech_initmaxdrcsurround, 20, keys);
 
 	keys[0] = db_tech_node_width_offset;
 	registertechnologycache(tech_initnodesizeoffset, 1, keys);
@@ -1006,39 +1038,21 @@ void tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx,
 
 /*
  * routine to return the function code for nodeinst "ni" (see "efunction.h").
- * Any extra information about the instance is returned in the string
- * pointer "extra" (which is set to zero if there is no other information).
- * If "extra" is zero, it is ignored.
  */
-INTBIG nodefunction(NODEINST *ni, char **extra)
+INTBIG nodefunction(NODEINST *ni)
 {
 	REGISTER INTSML type;
-	REGISTER VARIABLE *var;
-	static INTBIG SCHEME_array_func = 0;
 
-	if (extra != 0) *extra = 0;
 	if (ni->proto->primindex == 0) return(NPUNKNOWN);
 	type = (INTSML)((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
 	switch (type)
 	{
-		case NPRESIST:		/* resistor */
-			if (extra == 0) break;
-			var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_resistancekey);
-			if (var != NOVARIABLE) *extra = describesimplevariable(var);
-			break;
-
 		case NPCAPAC:		/* capacitor */
 			switch (ni->userbits&NTECHBITS)
 			{
 				case CAPACNORM: type = NPCAPAC;    break;	/* Capacitor is normal */
 				case CAPACELEC: type = NPECAPAC;   break;	/* Capacitor is Electrolytic */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_capacitancekey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
 			break;
 
 		case NPDIODE:		/* diode */
@@ -1047,18 +1061,6 @@ INTBIG nodefunction(NODEINST *ni, char **extra)
 				case DIODENORM:  type = NPDIODE;    break;	/* Diode is normal */
 				case DIODEZENER: type = NPDIODEZ;   break;	/* Diode is Zener */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_diodekey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
-			break;
-
-		case NPINDUCT:		/* inductor */
-			if (extra == 0) break;
-			var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_inductancekey);
-			if (var != NOVARIABLE) *extra = describesimplevariable(var);
 			break;
 
 		case NPTRANS:		/* undefined transistor: look at its transistor type */
@@ -1074,12 +1076,6 @@ INTBIG nodefunction(NODEINST *ni, char **extra)
 				case TRANDMES:  type = NPTRADMES;    break;	/* Transistor is Depletion MESFET */
 				case TRANEMES:  type = NPTRAEMES;    break;	/* Transistor is Enhancement MESFET */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_transistortypekey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
 			break;
 
 		case NPTRANS4:		/* undefined 4-port-transistor: look at its transistor type */
@@ -1095,20 +1091,6 @@ INTBIG nodefunction(NODEINST *ni, char **extra)
 				case TRANDMES:  type = NPTRA4DMES;   break;	/* Transistor is Depletion MESFET */
 				case TRANEMES:  type = NPTRA4EMES;   break;	/* Transistor is Enhancement MESFET */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_transistortypekey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
-			break;
-
-		case NPARRAY:		/* fixed array device: look for more information */
-			if (extra == 0) break;
-			if (SCHEME_array_func == 0) SCHEME_array_func = makekey("SCHEM_array_function");
-			var = getvalkey((INTBIG)ni, VNODEINST, -1, SCHEME_array_func);
-			if (var != NOVARIABLE)
-				*extra = describesimplevariable(var);
 			break;
 
 		case NPSOURCE:		/* source node: look for more information */
@@ -1125,12 +1107,6 @@ INTBIG nodefunction(NODEINST *ni, char **extra)
 				case SOURCEDCAN:   type = NPSOURCEDC;   break;	/* Source is DC Analysis */
 				case SOURCEEXT:    type = NPSOURCEX;    break;	/* Source is Extension */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_sourcekey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
 			break;
 
 		case NPTLINE:		/* two-port device: look for more information */
@@ -1142,12 +1118,6 @@ INTBIG nodefunction(NODEINST *ni, char **extra)
 				case TWOPCCCS:  type = NPCCCS;     break;	/* Two-port is Current gain (CCCS) */
 				case TWOPTLINE: type = NPTLINE;    break;	/* Two-port is Transmission Line */
 			}
-			if (extra != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_twoportkey);
-				if (var != NOVARIABLE)
-					*extra = describesimplevariable(var);
-			}
 			break;
 	}
 	return(type);
@@ -1247,7 +1217,7 @@ INTSML isfet(GEOM *pos)
 	REGISTER INTBIG fun;
 
 	if (pos->entrytype != OBJNODEINST) return(0);
-	fun = nodefunction(pos->entryaddr.ni, 0);
+	fun = nodefunction(pos->entryaddr.ni);
 	switch (fun)
 	{
 		case NPTRANMOS:   case NPTRA4NMOS:
@@ -1275,8 +1245,8 @@ void transistorsize(NODEINST *ni, INTBIG *length, INTBIG *width)
 	INTBIG lx, ly, hx, hy;
 	REGISTER INTBIG count, i;
 	REGISTER INTBIG fx, fy, tx, ty, lambda;
-	char *extra;
-	REGISTER VARIABLE *var;
+	char *pt;
+	REGISTER VARIABLE *var, *varl, *varw;
 
 	*length = *width = -1;
 	switch ((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH)
@@ -1284,8 +1254,10 @@ void transistorsize(NODEINST *ni, INTBIG *length, INTBIG *width)
 		case NPTRANMOS:   case NPTRA4NMOS:
 		case NPTRADMOS:   case NPTRA4DMOS:
 		case NPTRAPMOS:   case NPTRA4PMOS:
-		case NPTRAEMES:   case NPTRA4EMES:
+		case NPTRANJFET:  case NPTRA4NJFET:
+		case NPTRAPJFET:  case NPTRA4PJFET:
 		case NPTRADMES:   case NPTRA4DMES:
+		case NPTRAEMES:   case NPTRA4EMES:
 			var = gettrace(ni);
 			if (var != NOVARIABLE)
 			{
@@ -1318,14 +1290,40 @@ void transistorsize(NODEINST *ni, INTBIG *length, INTBIG *width)
 
 		case NPTRANS:
 		case NPTRANS4:
-			(void)nodefunction(ni, &extra);
-			if (extra != 0 && (*extra == '-' || *extra == '+' || isdigit(*extra)))
+			lambda = lambdaofnode(ni);
+			varl = getvalkey((INTBIG)ni, VNODEINST, -1, el_attr_length);
+			varw = getvalkey((INTBIG)ni, VNODEINST, -1, el_attr_width);
+			if (varl != NOVARIABLE || varw != NOVARIABLE)
 			{
-				lambda = lambdaofnode(ni);
-				*width = atofr(extra) * lambda / WHOLE;
-				while (*extra != '/' && *extra != 0) extra++;
-				if (*extra != '/') *length = lambda; else
-					*length = atofr(&extra[1]) * lambda / WHOLE;
+				if (varl != NOVARIABLE)
+				{
+					pt = describesimplevariable(varl);
+					if (*pt == '-' || *pt == '+' || isdigit(*pt))
+					{
+						*length = atofr(pt) * lambda / WHOLE;
+					}
+				}
+				if (varw != NOVARIABLE)
+				{
+					pt = describesimplevariable(varw);
+					if (*pt == '-' || *pt == '+' || isdigit(*pt))
+					{
+						*width = atofr(pt) * lambda / WHOLE;
+					}
+				}
+			} else
+			{
+				/* no length/width, look for area */
+				var = getvalkey((INTBIG)ni, VNODEINST, -1, el_attr_area);
+				if (var != NOVARIABLE)
+				{
+					pt = describesimplevariable(var);
+					if (*pt == '-' || *pt == '+' || isdigit(*pt))
+					{
+						*length = atofr(pt) * lambda / WHOLE;
+						*width = lambda;
+					}
+				}
 			}
 			break;
 	}
@@ -1347,7 +1345,7 @@ void transistorports(NODEINST *ni, PORTPROTO **gateleft, PORTPROTO **gateright,
 {
 	REGISTER INTBIG fun;
 
-	fun = nodefunction(ni, 0);
+	fun = nodefunction(ni);
 	*activetop = *gateright = *activebottom = NOPORTPROTO;
 	*gateleft = ni->proto->firstportproto;
 	if (*gateleft == NOPORTPROTO) return;
@@ -2149,22 +2147,23 @@ void tech_3ddefaultlayerheight(TECHNOLOGY *tech)
  * routine to tell the minimum distance between layers "layer1" and "layer2" in
  * technology "tech".  If "connected" is zero, the two layers are not connected,
  * if it is nonzero, they are connected electrically.  A negative return means
- * that the two layers can overlap.  If there is a rule associated with this
+ * that the two layers can overlap.  If the distance is an edge rule, "edge"
+ * is set nonzero.  If there is a rule associated with this
  * it is returned in "rule".  This routine accesses the database
  * variables "DRC_min_connected_distances" and "DRC_min_unconnected_distances"
  * in the technologies.
  */
 INTBIG tech_getdrcmindistance(TECHNOLOGY *tech, INTBIG layer1, INTBIG layer2,
-	INTBIG connected, INTBIG widerules, INTBIG multicut, char **rule)
+	INTBIG connected, INTBIG wide, INTBIG multicut, INTBIG *edge, char **rule)
 {
-	REGISTER INTBIG pindex, temp, *addr, *specialaddr, ti;
-	REGISTER char **rules, **specialrules;
+	REGISTER INTBIG pindex, temp, *addr, *edgeaddr, *multiaddr, *wideaddr, ti, dist;
+	REGISTER char **rules, **edgerules, **multirules, **widerules;
 
 	if (layer1 < 0 || layer2 < 0) return(XX);
 
 	/* make sure cache of information is valid */
 	ti = tech->techindex;
-	specialaddr = 0;
+	multiaddr = wideaddr = 0;
 	if (connected != 0)
 	{
 		if (tech_drcconndistance == 0)
@@ -2174,15 +2173,16 @@ INTBIG tech_getdrcmindistance(TECHNOLOGY *tech, INTBIG layer1, INTBIG layer2,
 		}
 		addr = tech_drcconndistance[ti];
 		rules = tech_drccondistancerule[ti];
-		if (widerules != 0)
+		edgeaddr = 0;
+		if (wide != 0)
 		{
-			specialaddr = tech_drcconndistancew[ti];
-			specialrules = tech_drccondistancewrule[ti];
+			wideaddr = tech_drcconndistancew[ti];
+			widerules = tech_drccondistancewrule[ti];
 		}
 		if (multicut != 0)
 		{
-			specialaddr = tech_drcconndistancem[ti];
-			specialrules = tech_drccondistancemrule[ti];
+			multiaddr = tech_drcconndistancem[ti];
+			multirules = tech_drccondistancemrule[ti];
 		}
 	} else
 	{
@@ -2193,34 +2193,69 @@ INTBIG tech_getdrcmindistance(TECHNOLOGY *tech, INTBIG layer1, INTBIG layer2,
 		}
 		addr = tech_drcuncondistance[ti];
 		rules = tech_drcuncondistancerule[ti];
-		if (widerules != 0)
+		edgeaddr = tech_drcedgedistance[ti];
+		edgerules = tech_drcedgedistancerule[ti];
+		if (wide != 0)
 		{
-			specialaddr = tech_drcuncondistancew[ti];
-			specialrules = tech_drcuncondistancewrule[ti];
+			wideaddr = tech_drcuncondistancew[ti];
+			widerules = tech_drcuncondistancewrule[ti];
 		}
 		if (multicut != 0)
 		{
-			specialaddr = tech_drcuncondistancem[ti];
-			specialrules = tech_drcuncondistancemrule[ti];
+			multiaddr = tech_drcuncondistancem[ti];
+			multirules = tech_drcuncondistancemrule[ti];
 		}
 	}
-	if (addr == 0) return(XX);
+	if (addr == 0 && edgeaddr == 0) return(XX);
 
 	/* compute index into connectedness tables */
 	if (layer1 > layer2) { temp = layer1; layer1 = layer2;  layer2 = temp; }
 	pindex = (layer1+1) * (layer1/2) + (layer1&1) * ((layer1+1)/2);
 	pindex = layer2 + tech->layercount * layer1 - pindex;
+
+	/* presume the standard rule */
+	*edge = 0;
+	dist = addr[pindex];
+	if (edgeaddr != 0 && edgeaddr[pindex] > dist)
+	{
+		dist = edgeaddr[pindex];
+		rules = edgerules;
+		*edge = 1;
+	}
 	if (rule != 0)
 	{
 		*rule = 0; 
 		if (rules != 0 && rules[pindex][0] != 0) 
 			*rule = rules[pindex];
-		if (specialaddr != 0 && specialaddr[pindex] >= 0 &&
-			specialrules != 0 && specialrules[pindex][0] != 0) 
-				*rule = specialrules[pindex];
 	}
-	if (specialaddr != 0 && specialaddr[pindex] >= 0) return(specialaddr[pindex]);
-	return(addr[pindex]);
+
+	/* see if the multi-rule is there and is worse */
+	if (multiaddr != 0 && multiaddr[pindex] > dist)
+	{
+		dist = multiaddr[pindex];
+		*edge = 0;
+		if (rule != 0)
+		{
+			*rule = 0; 
+			if (multirules != 0 && multirules[pindex][0] != 0) 
+				*rule = multirules[pindex];
+		}
+	}
+
+	/* see if the wide-rule is there and is worse */
+	if (wideaddr != 0 && wideaddr[pindex] > dist)
+	{
+		dist = wideaddr[pindex];
+		*edge = 0;
+		if (rule != 0)
+		{
+			*rule = 0; 
+			if (widerules != 0 && widerules[pindex][0] != 0) 
+				*rule = widerules[pindex];
+		}
+	}
+
+	return(dist);
 }
 
 /*
@@ -2258,7 +2293,7 @@ INTBIG maxdrcsurround(TECHNOLOGY *tech, LIBRARY *lib, INTBIG layer)
  * A negative return means that the two layers can overlap.
  */
 INTBIG drcmindistance(TECHNOLOGY *tech, LIBRARY *lib, INTBIG layer1, INTBIG size1,
-	INTBIG layer2, INTBIG size2, INTBIG connected, INTBIG multicut, char **rule)
+	INTBIG layer2, INTBIG size2, INTBIG connected, INTBIG multicut, INTBIG *edge, char **rule)
 {
 	REGISTER INTBIG i, widerules, widelimit, lambda;
 
@@ -2269,7 +2304,7 @@ INTBIG drcmindistance(TECHNOLOGY *tech, LIBRARY *lib, INTBIG layer1, INTBIG size
 	if (size1 > widelimit || size2 > widelimit) widerules = 1;
 
 	/* get the un-scaled distance */
-	i = tech_getdrcmindistance(tech, layer1, layer2, connected, widerules, multicut, rule);
+	i = tech_getdrcmindistance(tech, layer1, layer2, connected, widerules, multicut, edge, rule);
 
 	/* scale result for current lambda value */
 	if (i > 0) i = i * lambda / WHOLE;
