@@ -34,6 +34,7 @@
 #include "tech.h"
 #include "tecmocmos.h"
 #include "efunction.h"
+#include "usr.h"
 
 /*
  * when arcs are curved (with "arc curve" or "arc center") the number of
@@ -51,7 +52,7 @@ static INTBIG tech_moscutlx, tech_moscuthx, tech_moscutly, tech_moscuthy,
 	tech_moscuttotal, tech_moscutsx, tech_moscutsy;
 
 /* for displayable variables */
-static INTBIG tech_ndisplayindex, tech_ndisplaysubindex, tech_adisplayindex;
+static INTBIG tech_ndisplayindex, tech_ndisplaysubindex;
 
 /* for circular arcs */
 static INTSML tech_arcpieces, tech_anglebase, tech_anglerange;
@@ -66,13 +67,12 @@ static INTSML    tech_numvar;
 static VARIABLE *tech_firstvar;
 
 /* prototypes for local routines */
-void db_adjusttree(NODEPROTO*);
-void tech_shortenmostrans(NODEINST*, POLYGON*, TECH_POLYGON*, INTBIG, INTBIG, TECH_PORTS*);
-INTSML db_stillinport(ARCINST*, INTSML, INTBIG, INTBIG);
-INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *np);
-VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
-	INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
-	WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval);
+static void      db_adjusttree(NODEPROTO*);
+static void      tech_shortenmostrans(NODEINST*, POLYGON*, TECH_POLYGON*, INTBIG, INTBIG, TECH_PORTS*);
+static INTBIG    tech_displayableanyvars(WINDOWPART *win, NODEPROTO *np);
+static VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
+					INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
+					WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval);
 
 /******************** GENERAL ********************/
 
@@ -630,6 +630,7 @@ void tech_moscutpoly(NODEINST *ni, INTBIG cut, INTBIG descrip[])
 		if (cut < tech_moscutsx)
 		{
 			/* bottom edge: it's ok as is */
+			/* EMPTY */ 
 		} else if (cut < tech_moscuttopedge)
 		{
 			/* top edge: shift up */
@@ -1180,7 +1181,9 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 		if (thissg != 0)
 		{
 			/* compute intersection of this and previous line */
-			(void)intersect(pthisx,pthisy, pangle, thisx,thisy, angle, &x, &y);
+
+			/* LINTED "pthisx", "pthisy", and "pangle" used in proper order */
+			(void)intersect(pthisx, pthisy, pangle, thisx, thisy, angle, &x, &y);
 			thisx = x;   thisy = y;
 			xform(thisx+xoff, thisy+yoff, &poly->xv[thissg], &poly->yv[thissg], trans);
 		} else
@@ -1732,6 +1735,7 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet)
 {
 	REGISTER INTBIG i, total;
 	REGISTER VARIABLE *var;
+	REGISTER char *name;
 
 	tech_ndisplayindex = tech_ndisplaysubindex = total = 0;
 	if (win == NOWINDOWPART) win = el_curwindowpart;
@@ -1739,10 +1743,17 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet)
 	{
 		var = &tech_firstvar[i];
 		if ((var->type&VDISPLAY) == 0) continue;
-		if ((var->textdescript&VTINTERIOR) != 0)
+		if (TDGETINTERIOR(var->textdescript) != 0)
 		{
 			if (win != NOWINDOWPART && facet != win->curnodeproto) continue;
 		}
+		if ((us_useroptions&HIDEATTRIBUTES) != 0)
+		{
+			/* see if this is an attribute variable */
+			name = makename(var->key);
+			if (namesamen(name, "attr_", 5) == 0) continue;
+			if (namesamen(name, "attrP_", 6) == 0) continue;
+		}
 		if ((var->type&VISARRAY) == 0) total++; else
 			total += getlength(var);
 	}
@@ -1757,9 +1768,10 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
 		WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval)
 {
-	REGISTER INTBIG descript, len, language;
+	REGISTER INTBIG len, language, hidden;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER INTSML whichindex;
-	REGISTER char *query;
+	REGISTER char *query, *name;
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 	static VARIABLE retvar;
@@ -1776,7 +1788,7 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	{
 		if (tech_ndisplayindex >= tech_numvar)
 		{
-			descript = 0;
+			TDCLEAR(descript);
 			poly->string = "ERROR";
 			var = NOVARIABLE;
 			break;
@@ -1785,57 +1797,68 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 		if (varnoeval != 0)
 			(*varnoeval) = var;
 		if ((var->type&VDISPLAY) != 0 &&
-			((var->textdescript&VTINTERIOR) == 0 || win == NOWINDOWPART ||
+			(TDGETINTERIOR(var->textdescript) == 0 || win == NOWINDOWPART ||
 				facet == win->curnodeproto))
 		{
-			descript = var->textdescript;
-			if ((descript&VTDISPLAYPART) != VTDISPLAYNAME)
+			hidden = 0;
+			if ((us_useroptions&HIDEATTRIBUTES) != 0)
 			{
-				language = var->type & (VCODE1|VCODE2);
-				if (language != 0)
-				{
-					if ((var->type&VISARRAY) == 0) query = (char *)var->addr; else
-						query = ((char **)var->addr)[0];
-					retvar.key = var->key;
-					retvar.type = var->type & ~(VCODE1|VCODE2|VISARRAY|VLENGTH);
-					retvar.textdescript = descript;
-					if (doquerry(query, language, retvar.type, &retvar.addr) == 0)
-						var = &retvar;
-				}
+				/* see if this is an attribute variable */
+				name = makename(var->key);
+				if (namesamen(name, "attr_", 5) == 0) hidden = 1;
+				if (namesamen(name, "attrP_", 6) == 0) hidden = 1;
 			}
-			if ((var->type&VISARRAY) == 0)
+			if (hidden == 0)
 			{
-				tech_ndisplayindex++;
-				tech_ndisplaysubindex = 0;
-				if ((descript&VTPOSITION) == VTPOSBOXED)
+				TDCOPY(descript, var->textdescript);
+				if (TDGETDISPPART(descript) != VTDISPLAYNAME)
 				{
-					makerectpoly(lx, hx, ly, hy, poly);
-					poly->style = CLOSED;
-				}
-				poly->string = describedisplayedvariable(var, -1, -1);
-				break;
-			}
-			len = getlength(var);
-			if (tech_ndisplaysubindex < len)
-			{
-				whichindex = (INTSML)tech_ndisplaysubindex++;
-				poly->string = describedisplayedvariable(var, whichindex, -1);
-				if ((descript&VTPOSITION) == VTPOSBOXED)
-				{
-					makerectpoly(lx, hx, ly, hy, poly);
-					poly->style = CLOSED;
-				} else
-				{
-					if (type == VNODEINST)
+					language = var->type & (VCODE1|VCODE2);
+					if (language != 0)
 					{
-						/* multiline variables only work on nodes! */
-						ni = (NODEINST *)addr;
-						if (win == NOWINDOWPART) win = el_curwindowpart;
-						getdisparrayvarlinepos((INTBIG)ni, VNODEINST, tech, win, var,
-							whichindex, &poly->xv[0], &poly->yv[0], 0);
+						if ((var->type&VISARRAY) == 0) query = (char *)var->addr; else
+							query = ((char **)var->addr)[0];
+						retvar.key = var->key;
+						retvar.type = var->type & ~(VCODE1|VCODE2|VISARRAY|VLENGTH);
+						TDCOPY(retvar.textdescript, descript);
+						if (doquerry(query, language, retvar.type, &retvar.addr) == 0)
+							var = &retvar;
 					}
 				}
-				break;
+				if ((var->type&VISARRAY) == 0)
+				{
+					tech_ndisplayindex++;
+					tech_ndisplaysubindex = 0;
+					if (TDGETPOS(descript) == VTPOSBOXED)
+					{
+						makerectpoly(lx, hx, ly, hy, poly);
+						poly->style = CLOSED;
+					}
+					poly->string = describedisplayedvariable(var, -1, -1);
+					break;
+				}
+				len = getlength(var);
+				if (tech_ndisplaysubindex < len)
+				{
+					whichindex = (INTSML)tech_ndisplaysubindex++;
+					poly->string = describedisplayedvariable(var, whichindex, -1);
+					if (TDGETPOS(descript) == VTPOSBOXED)
+					{
+						makerectpoly(lx, hx, ly, hy, poly);
+						poly->style = CLOSED;
+					} else
+					{
+						if (type == VNODEINST)
+						{
+							/* multiline variables only work on nodes! */
+							ni = (NODEINST *)addr;
+							if (win == NOWINDOWPART) win = el_curwindowpart;
+							getdisparrayvarlinepos((INTBIG)ni, VNODEINST, tech, win, var,
+								whichindex, &poly->xv[0], &poly->yv[0], 0);
+						}
+					}
+					break;
+				}
 			}
 		}
 		tech_ndisplayindex++;
