@@ -39,31 +39,34 @@
 #  include <sys/time.h>
 #endif
 
-char  *db_keywordbuffer;
-INTSML db_keywordbufferlength = 0;
+#define NUMDESCRIPTIONBUFS 4
 
-char  *db_tryfilename;
-INTSML db_tryfilenamelen = 0;
+static char  *db_keywordbuffer;
+static INTSML db_keywordbufferlength = 0;
+
+/* working memory for "db_tryfile()" */
+static char  *db_tryfilename;
+static INTBIG db_tryfilenamelen = 0;
 
 /* working memory for "describenodeproto()" */
-INTSML db_descnpnodeswitch = 0;
-char  *db_descnpoutput[2];
-INTSML db_descnpoutputsize[2] = {0, 0};
+static INTSML db_descnpnodeswitch = 0;
+static char  *db_descnpoutput[NUMDESCRIPTIONBUFS];
+static INTSML db_descnpoutputsize[NUMDESCRIPTIONBUFS] = {0, 0};
 
 /* working memory for "describenodeinst()" */
-INTSML db_descninodeswitch = 0;
-char *db_descnioutput[2];
-INTSML db_descnioutputsize[2] = {0, 0};
+static INTSML db_descninodeswitch = 0;
+static char  *db_descnioutput[NUMDESCRIPTIONBUFS];
+static INTSML db_descnioutputsize[NUMDESCRIPTIONBUFS] = {0, 0};
 
 /* working memory for "describearcinst()" */
-INTSML db_descaiarcswitch = 0;
-char *db_descaioutput[2];
-INTSML db_descaioutputsize[2] = {0, 0};
+static INTSML db_descaiarcswitch = 0;
+static char  *db_descaioutput[NUMDESCRIPTIONBUFS];
+static INTSML db_descaioutputsize[NUMDESCRIPTIONBUFS] = {0, 0};
 
 /* working memory for "describearcproto()" */
-INTSML db_descaparcswitch = 0;
-char *db_descapoutput[2];
-INTSML db_descapoutputsize[2] = {0, 0};
+static INTSML db_descaparcswitch = 0;
+static char  *db_descapoutput[NUMDESCRIPTIONBUFS];
+static INTSML db_descapoutputsize[NUMDESCRIPTIONBUFS] = {0, 0};
 
 /* working memory for "makeplural()" */
 static INTBIG db_pluralbufsize = 0;
@@ -95,20 +98,20 @@ typedef struct
 	INTBIG infstrinuse;				/* nonzero if in use */
 } INFSTR;
 
-INFSTR  db_infstrings[INFSTRCOUNT];	/* a stack of infinite strings */
-INFSTR *db_infstrstackptr[INFSTRCOUNT];/* a stack of infinite strings */
-INFSTR *db_curinf = NOINFSTR;		/* the current infinite string */
-INTBIG  db_infstrpointer;			/* base position of the stack in the list */
-INTBIG  db_infstrstackpos;			/* position within the stack */
-INTSML  db_firstinf = 0;			/* initialization flag */
+static INFSTR  db_infstrings[INFSTRCOUNT];	/* a stack of infinite strings */
+static INFSTR *db_infstrstackptr[INFSTRCOUNT];/* a stack of infinite strings */
+static INFSTR *db_curinf = NOINFSTR;		/* the current infinite string */
+static INTBIG  db_infstrpointer;			/* base position of the stack in the list */
+static INTBIG  db_infstrstackpos;			/* position within the stack */
+static INTSML  db_firstinf = 0;			/* initialization flag */
 
 /* prototypes for local routines */
-INTSML db_beginsearch(char**);
-INTSML db_makestringvar(INTBIG, INTBIG, INTSML);
-INTSML db_addstring(char*);
-FILE *db_tryfile(char*, char*, char*, char*, char**);
-void db_shuffle(char*, char*);
-INTBIG db_insensitivechar(INTBIG c);
+static INTSML db_beginsearch(char**);
+static INTSML db_makestringvar(INTBIG, INTBIG, INTSML);
+static INTSML db_addstring(char*);
+static FILE  *db_tryfile(char*, char*, char*, char*, char**);
+static void   db_shuffle(char*, char*);
+static INTBIG db_insensitivechar(INTBIG c);
 
 /*
  * Routine to free all memory associated with this module.
@@ -123,13 +126,13 @@ void db_freetextmemory(void)
 	for(i=0; i<INFSTRCOUNT; i++)
 		efree((char *)db_infstrings[i].infstr);
 
-	for(i=0; i<2; i++)
+	for(i=0; i<NUMDESCRIPTIONBUFS; i++)
 		if (db_descnpoutputsize[i] != 0) efree(db_descnpoutput[i]);
-	for(i=0; i<2; i++)
+	for(i=0; i<NUMDESCRIPTIONBUFS; i++)
 		if (db_descnioutputsize[i] != 0) efree(db_descnioutput[i]);
-	for(i=0; i<2; i++)
+	for(i=0; i<NUMDESCRIPTIONBUFS; i++)
 		if (db_descaioutputsize[i] != 0) efree(db_descaioutput[i]);
-	for(i=0; i<2; i++)
+	for(i=0; i<NUMDESCRIPTIONBUFS; i++)
 		if (db_descapoutputsize[i] != 0) efree(db_descapoutput[i]);
 
 	/* free file type memory */
@@ -252,6 +255,43 @@ INTBIG myatoi(char *pp)
 	return(num * sign);
 }
 
+/*
+ * Routine to convert a HUGE integer (64 bits) to a string.
+ * This routine does the work by hand, but it can be done with
+ * special "printf" format conversions, of which these are known:
+ *    Windows: "%I64d"
+ *    Sun:     "%" PRIx64
+ *    Linux:   "%lld"
+ */
+char *hugeinttoa(INTHUGE a)
+{
+	static char ret[NUMDESCRIPTIONBUFS][40];
+	static INTBIG which = 0;
+	REGISTER char *curbuf, digit;
+	REGISTER INTBIG i, neg;
+
+	curbuf = ret[which++];
+	if (which >= NUMDESCRIPTIONBUFS) which = 0;
+
+	if (a >= 0) neg = 0; else
+	{
+		neg = 1;
+		a = -a;
+	}
+
+	curbuf[i=39] = 0;
+	while (i > 0)
+	{
+		digit = (char)(a % 10);
+		curbuf[--i] = '0' + digit;
+		a /= 10;
+		if (a == 0) break;
+	}
+	if (neg != 0)
+		curbuf[--i] = '-';
+	return(&curbuf[i]);
+}
+
 char *explainduration(float duration)
 {
 	static char elapsed[200];
@@ -638,18 +678,18 @@ LIBRARY *getlibrary(char *libname)
 }
 
 /*
- * routine to find aid "aidname".  Returns NOAID if it cannot be found
+ * routine to find tool "toolname".  Returns NOTOOL if it cannot be found
  */
-AIDENTRY *getaid(char *aidname)
+TOOL *gettool(char *toolname)
 {
 	REGISTER INTSML i;
 
-	for(i=0; i<el_maxaid; i++)
-		if (namesame(aidname, el_aids[i].aidname) == 0) return(&el_aids[i]);
-	return(NOAID);
+	for(i=0; i<el_maxtools; i++)
+		if (namesame(toolname, el_tools[i].toolname) == 0) return(&el_tools[i]);
+	return(NOTOOL);
 }
 
-struct
+static struct
 {
 	char  *name;
 	char  *symbol;
@@ -796,12 +836,12 @@ INTSML stringmatch(char *keyword, char *input)
 
 /************************* COMMAND COMPLETION CODE *************************/
 
-INTSML  db_filestrlen;
-char    db_filekey[100];
-char    db_directorypath[256];
-char    db_fileextension[10];
-INTSML  db_filecount, db_filetotal;
-char  **db_filesindir;
+static INTSML  db_filestrlen;
+static char    db_filekey[100];
+static char    db_directorypath[256];
+static char    db_fileextension[10];
+static INTSML  db_filecount, db_filetotal;
+static char  **db_filesindir;
 
 void requiredextension(char *extension)
 {
@@ -955,14 +995,14 @@ char *nextlibs(void)
 }
 
 /*
- * routines to do command completion on aid names
+ * routines to do command completion on tool names
  */
 static INTSML db_poscomcomp;
-INTSML topofaids(char **c) { db_poscomcomp = 0; return(1); }
-char *nextaids(void)
+INTSML topoftools(char **c) { db_poscomcomp = 0; return(1); }
+char *nexttools(void)
 {
-	if (db_poscomcomp >= el_maxaid) return(0);
-	return(el_aids[db_poscomcomp++].aidname);
+	if (db_poscomcomp >= el_maxtools) return(0);
+	return(el_tools[db_poscomcomp++].toolname);
 }
 
 /*
@@ -1091,6 +1131,25 @@ char *nextnets(void)
 
 /************************* OUTPUT PREPARATION *************************/
 
+/*
+ * routine to return the full name of node "ni", including its local name.
+ * Technology considerations are ignored.
+ */
+char *ntdescribenodeinst(NODEINST *ni)
+{
+	REGISTER TECHNOLOGY *curtech;
+	REGISTER char *ret;
+
+	if (ni == NONODEINST) return("***NONODEINST***");
+
+	if (ni->proto->primindex == 0) return(describenodeinst(ni));
+	curtech = el_curtech;
+	el_curtech = ni->proto->tech;
+	ret = describenodeinst(ni);
+	el_curtech = curtech;
+	return(ret);
+}
+
 /* routine to return the name of nodeinst "ni" */
 char *describenodeinst(NODEINST *ni)
 {
@@ -1107,7 +1166,7 @@ char *describenodeinst(NODEINST *ni)
 
 	/* get output buffer */
 	db_descninodeswitch++;
-	if (db_descninodeswitch >= 2) db_descninodeswitch = 0;
+	if (db_descninodeswitch >= NUMDESCRIPTIONBUFS) db_descninodeswitch = 0;
 
 	/* make sure buffer has enough room */
 	len = strlen(protoname) + strlen((char *)var->addr) + 3;
@@ -1146,7 +1205,7 @@ char *describearcinst(ARCINST *ai)
 
 	/* get output buffer */
 	db_descaiarcswitch++;
-	if (db_descaiarcswitch >= 2) db_descaiarcswitch = 0;
+	if (db_descaiarcswitch >= NUMDESCRIPTIONBUFS) db_descaiarcswitch = 0;
 
 	/* make sure buffer has enough room */
 	len = strlen(pname) + strlen((char *)var->addr) + 3;
@@ -1215,7 +1274,7 @@ char *describenodeproto(NODEPROTO *np)
 
 	/* get output buffer */
 	db_descnpnodeswitch++;
-	if (db_descnpnodeswitch >= 2) db_descnpnodeswitch = 0;
+	if (db_descnpnodeswitch >= NUMDESCRIPTIONBUFS) db_descnpnodeswitch = 0;
 
 	if (np->primindex != 0)
 	{
@@ -1283,7 +1342,7 @@ char *describearcproto(ARCPROTO *ap)
 
 	/* get output buffer */
 	db_descaparcswitch++;
-	if (db_descaparcswitch >= 2) db_descaparcswitch = 0;
+	if (db_descaparcswitch >= NUMDESCRIPTIONBUFS) db_descaparcswitch = 0;
 
 	/* make sure buffer has enough room */
 	len = strlen(ap->tech->techname) + strlen(ap->protoname) + 2;
@@ -1445,7 +1504,7 @@ char *frtoa(INTBIG i)
  */
 INTSML isanumber(char *pp)
 {
-	INTSML xflag;
+	INTBIG xflag, founddigits;
 
 	/* ignore the minus sign */
 	if (*pp == '+' || *pp == '-') pp++;
@@ -1460,17 +1519,26 @@ INTSML isanumber(char *pp)
 	/* there must be something to check */
 	if (*pp == 0) return(0);
 
+	founddigits = 0;
 	if (xflag != 0)
 	{
-		while (isxdigit(*pp)) pp++;
+		while (isxdigit(*pp))
+		{
+			pp++;
+			founddigits = 1;
+		}
 	} else
 	{
-		while (isdigit(*pp) || *pp == '.') pp++;
+		while (isdigit(*pp) || *pp == '.')
+		{
+			pp++;
+			founddigits = 1;
+		}
 	}
 	if (*pp == 0) return(1);
 
 	/* handle exponent of floating point numbers */
-	if (xflag != 0 || (*pp != 'e' && *pp != 'E')) return(0);
+	if (xflag != 0 || founddigits == 0 || (*pp != 'e' && *pp != 'E')) return(0);
 	pp++;
 	if (*pp == '+' || *pp == '-') pp++;
 	if (*pp == 0) return(0);
@@ -1490,44 +1558,34 @@ INTBIG truefontsize(INTBIG font, WINDOWPART *w, TECHNOLOGY *tech)
 	REGISTER LIBRARY *lib;
 
 	/* keep special font codes */
-	if (font < 0) return(font);
+	if (font == TXTEDITOR || font == TXTMENU) return(font);
+
+	/* absolute font sizes are easy */
+	if ((font&TXTPOINTS) != 0) return((font&TXTPOINTS) >> TXTPOINTSSH);
 
 	/* detemine default, min, and max size of font */
 	if (w->curnodeproto == NONODEPROTO) lib = el_curlib; else
 		lib = w->curnodeproto->cell->lib;
 	lambda = lib->lambda[tech->techindex];
-	switch (font)
+	if ((font&TXTQLAMBDA) != 0)
 	{
-		case TXT4P:  return(4);
-		case TXT6P:  return(6);
-		case TXT8P:  return(8);
-		case TXT10P: return(10);
-		case TXT12P: return(12);
-		case TXT14P: return(14);
-		case TXT16P: return(16);
-		case TXT18P: return(18);
-		case TXT20P: return(20);
-		case TXTHL:  height = lambda/2;   break;
-		case TXT1L:  height = lambda;     break;
-		case TXT2L:  height = lambda*2;   break;
-		case TXT3L:  height = lambda*3;   break;
-		case TXT4L:  height = lambda*4;   break;
-		case TXT5L:  height = lambda*5;   break;
-		case TXT6L:  height = lambda*6;   break;
-		default:     return(12);
+		height = TXTGETQLAMBDA(font);
+		height = height * lambda / 4;
+		pixperlam = applyyscale(w, height);
+		return(pixperlam);
 	}
-	pixperlam = applyyscale(w, height);
-	return(pixperlam);
+	return(applyyscale(w, lambda));
 }
 
 /*
- * routine to return the default text descriptor.  This text will be
+ * routine to set the default text descriptor into "td".  This text will be
  * placed on "geom".
  */
-INTBIG defaulttextdescript(GEOM *geom)
+void defaulttextdescript(UINTBIG *descript, GEOM *geom)
 {
 	REGISTER VARIABLE *txtvar;
-	REGISTER INTBIG descript, dx, dy, goleft, goright, goup, godown;
+	REGISTER INTBIG dx, dy, goleft, goright, goup, godown;
+	INTBIG *defdescript;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	static INTBIG user_default_text_style = 0, user_default_text_smart_style = 0;
@@ -1537,29 +1595,40 @@ INTBIG defaulttextdescript(GEOM *geom)
 	if (user_default_text_smart_style == 0)
 		user_default_text_smart_style = makekey("USER_default_text_smart_style");
 
-	txtvar = getvalkey((INTBIG)us_aid, VAID, VINTEGER, user_default_text_style);
-	if (txtvar == NOVARIABLE) descript = VTPOSCENT; else
-		descript = txtvar->addr;
+	txtvar = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, user_default_text_style);
+	if (txtvar == NOVARIABLE)
+	{
+		TDSETPOS(descript, VTPOSCENT);
+	} else
+	{
+		defdescript = (INTBIG *)txtvar->addr;
+		TDSETPOS(descript, TDGETPOS(defdescript));
+		TDSETSIZE(descript, TDGETSIZE(defdescript));
+		TDSETFACE(descript, TDGETFACE(defdescript));
+		TDSETITALIC(descript, TDGETITALIC(defdescript));
+		TDSETBOLD(descript, TDGETBOLD(defdescript));
+		TDSETUNDERLINE(descript, TDGETUNDERLINE(defdescript));
+	}
 	if (geom != NOGEOM)
 	{
 		/* set text size */
 		if (geom->entrytype == OBJARCINST)
 		{
-			descript |= defaulttextsize(4) << VTSIZESH;
+			defaulttextsize(4, descript);
 		} else
 		{
 			ni = geom->entryaddr.ni;
 			if (ni->proto == gen_invispinprim)
 			{
-				descript |= defaulttextsize(2) << VTSIZESH;
+				defaulttextsize(2, descript);
 			} else
 			{
-				descript |= defaulttextsize(3) << VTSIZESH;
+				defaulttextsize(3, descript);
 			}
 		}
 
 		/* handle smart text placement relative to attached object */
-		txtvar = getvalkey((INTBIG)us_aid, VAID, VINTEGER, user_default_text_smart_style);
+		txtvar = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, user_default_text_smart_style);
 		if (txtvar != NOVARIABLE)
 		{
 			/* figure out location of object relative to environment */
@@ -1605,98 +1674,97 @@ INTBIG defaulttextdescript(GEOM *geom)
 			}
 			if (goleft != 0)
 			{
-				switch (descript&VTPOSITION)
+				switch (TDGETPOS(descript))
 				{
 					case VTPOSCENT:
 					case VTPOSRIGHT:
 					case VTPOSLEFT:
-						descript = (descript & ~VTPOSITION) | VTPOSLEFT;
+						TDSETPOS(descript, VTPOSLEFT);
 						break;
 					case VTPOSUP:
 					case VTPOSUPLEFT:
 					case VTPOSUPRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSUPLEFT;
+						TDSETPOS(descript, VTPOSUPLEFT);
 						break;
 					case VTPOSDOWN:
 					case VTPOSDOWNLEFT:
 					case VTPOSDOWNRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSDOWNLEFT;
+						TDSETPOS(descript, VTPOSDOWNLEFT);
 						break;
 				}
 			}
 			if (goright != 0)
 			{
-				switch (descript&VTPOSITION)
+				switch (TDGETPOS(descript))
 				{
 					case VTPOSCENT:
 					case VTPOSRIGHT:
 					case VTPOSLEFT:
-						descript = (descript & ~VTPOSITION) | VTPOSRIGHT;
+						TDSETPOS(descript, VTPOSRIGHT);
 						break;
 					case VTPOSUP:
 					case VTPOSUPLEFT:
 					case VTPOSUPRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSUPRIGHT;
+						TDSETPOS(descript, VTPOSUPRIGHT);
 						break;
 					case VTPOSDOWN:
 					case VTPOSDOWNLEFT:
 					case VTPOSDOWNRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSDOWNRIGHT;
+						TDSETPOS(descript, VTPOSDOWNRIGHT);
 						break;
 				}
 			}
 			if (goup != 0)
 			{
-				switch (descript&VTPOSITION)
+				switch (TDGETPOS(descript))
 				{
 					case VTPOSCENT:
 					case VTPOSUP:
 					case VTPOSDOWN:
-						descript = (descript & ~VTPOSITION) | VTPOSUP;
+						TDSETPOS(descript, VTPOSUP);
 						break;
 					case VTPOSRIGHT:
 					case VTPOSUPRIGHT:
 					case VTPOSDOWNRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSUPRIGHT;
+						TDSETPOS(descript, VTPOSUPRIGHT);
 						break;
 					case VTPOSLEFT:
 					case VTPOSUPLEFT:
 					case VTPOSDOWNLEFT:
-						descript = (descript & ~VTPOSITION) | VTPOSUPLEFT;
+						TDSETPOS(descript, VTPOSUPLEFT);
 						break;
 				}
 			}
 			if (godown != 0)
 			{
-				switch (descript&VTPOSITION)
+				switch (TDGETPOS(descript))
 				{
 					case VTPOSCENT:
 					case VTPOSUP:
 					case VTPOSDOWN:
-						descript = (descript & ~VTPOSITION) | VTPOSDOWN;
+						TDSETPOS(descript, VTPOSDOWN);
 						break;
 					case VTPOSRIGHT:
 					case VTPOSUPRIGHT:
 					case VTPOSDOWNRIGHT:
-						descript = (descript & ~VTPOSITION) | VTPOSDOWNRIGHT;
+						TDSETPOS(descript, VTPOSDOWNRIGHT);
 						break;
 					case VTPOSLEFT:
 					case VTPOSUPLEFT:
 					case VTPOSDOWNLEFT:
-						descript = (descript & ~VTPOSITION) | VTPOSDOWNLEFT;
+						TDSETPOS(descript, VTPOSDOWNLEFT);
 						break;
 				}
 			}
 		}
 	}
-	return(descript);
 }
 
-#define DEFEXPORTSIZE      TXT2L
-#define DEFINVPINTEXTSIZE  TXT1L
-#define DEFNODETEXTSIZE    TXT1L
-#define DEFARCTEXTSIZE     TXT1L
-#define DEFFACETTEXTSIZE   TXT4L
+#define DEFEXPORTSIZE      TXTSETQLAMBDA(8)
+#define DEFINVPINTEXTSIZE  TXTSETQLAMBDA(4)
+#define DEFNODETEXTSIZE    TXTSETQLAMBDA(4)
+#define DEFARCTEXTSIZE     TXTSETQLAMBDA(4)
+#define DEFFACETTEXTSIZE   TXTSETQLAMBDA(16)
 
 /*
  * Routine to determine the size of text to use for a particular type of text:
@@ -1706,9 +1774,8 @@ INTBIG defaulttextdescript(GEOM *geom)
  * 4:  arc name
  * 5:  facet name
  */
-INTBIG defaulttextsize(INTBIG texttype)
+void defaulttextsize(INTBIG texttype, UINTBIG *descript)
 {
-	INTBIG size;
 	REGISTER VARIABLE *var;
 	static INTBIG export_size = 0, node_size = 0, arc_size = 0, facet_size = 0,
 		nonlayout_size = 0;
@@ -1719,36 +1786,162 @@ INTBIG defaulttextsize(INTBIG texttype)
 	if (facet_size == 0) facet_size = makekey("USER_default_facet_text_size");
 	if (nonlayout_size == 0) nonlayout_size = makekey("USER_default_nonlayout_text_size");
 
-	size = 0;
+	TDSETSIZE(descript, TXTSETQLAMBDA(4));
 	switch (texttype)
 	{
 		case 1:
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, export_size);
-			if (var != NOVARIABLE) size = var->addr; else
-				size = DEFEXPORTSIZE;
+			var = getvalkey((INTBIG)us_tool, VTOOL, -1, export_size);
+			if (var == NOVARIABLE) TDSETSIZE(descript, DEFEXPORTSIZE); else
+			{
+				if ((var->type&VISARRAY) != 0) TDCOPY(descript, (UINTBIG *)var->addr); else
+					TDSETSIZE(descript, var->addr);
+			}				
 			break;
 		case 2:
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, nonlayout_size);
-			if (var != NOVARIABLE) size = var->addr; else
-				size = DEFINVPINTEXTSIZE;
+			var = getvalkey((INTBIG)us_tool, VTOOL, -1, nonlayout_size);
+			if (var == NOVARIABLE) TDSETSIZE(descript, DEFINVPINTEXTSIZE); else
+			{
+				if ((var->type&VISARRAY) != 0) TDCOPY(descript, (UINTBIG *)var->addr); else
+					TDSETSIZE(descript, var->addr);
+			}
 			break;
 		case 3:
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, node_size);
-			if (var != NOVARIABLE) size = var->addr; else
-				size = DEFNODETEXTSIZE;
+			var = getvalkey((INTBIG)us_tool, VTOOL, -1, node_size);
+			if (var == NOVARIABLE) TDSETSIZE(descript, DEFNODETEXTSIZE); else
+			{
+				if ((var->type&VISARRAY) != 0) TDCOPY(descript, (UINTBIG *)var->addr); else
+					TDSETSIZE(descript, var->addr);
+			}
 			break;
 		case 4:
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, arc_size);
-			if (var != NOVARIABLE) size = var->addr; else
-				size = DEFARCTEXTSIZE;
+			var = getvalkey((INTBIG)us_tool, VTOOL, -1, arc_size);
+			if (var == NOVARIABLE) TDSETSIZE(descript, DEFARCTEXTSIZE); else
+			{
+				if ((var->type&VISARRAY) != 0) TDCOPY(descript, (UINTBIG *)var->addr); else
+					TDSETSIZE(descript, var->addr);
+			}
 			break;
 		case 5:
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, facet_size);
-			if (var != NOVARIABLE) size = var->addr; else
-				size = DEFFACETTEXTSIZE;
+			var = getvalkey((INTBIG)us_tool, VTOOL, -1, facet_size);
+			if (var == NOVARIABLE) TDSETSIZE(descript, DEFFACETTEXTSIZE); else
+			{
+				if ((var->type&VISARRAY) != 0) TDCOPY(descript, (UINTBIG *)var->addr); else
+					TDSETSIZE(descript, var->addr);
+			}
 			break;
 	}
-	return(size);
+}
+
+/*
+ * Routine to get the X offset field of text descriptor words "td".  This routine
+ * implements the macro "TDGETXOFF".
+ */
+INTBIG gettdxoffset(UINTBIG *td)
+{
+	REGISTER INTBIG offset, scale;
+
+	offset = (td[0] & VTXOFF) >> VTXOFFSH;
+	if ((td[0]&VTXOFFNEG) != 0) offset = -offset;
+	scale = TDGETOFFSCALE(td) + 1;
+	return(offset * scale);
+}
+
+/*
+ * Routine to get the Y offset field of text descriptor words "td".  This routine
+ * implements the macro "TDGETYOFF".
+ */
+INTBIG gettdyoffset(UINTBIG *td)
+{
+	REGISTER INTBIG offset, scale;
+
+	offset = (td[0] & VTYOFF) >> VTYOFFSH;
+	if ((td[0]&VTYOFFNEG) != 0) offset = -offset;
+	scale = TDGETOFFSCALE(td) + 1;
+	return(offset * scale);
+}
+
+/*
+ * Routine to set the X offset field of text descriptor words "td" to "value".
+ * This routine implements the macro "TDSETOFF".
+ */
+void settdoffset(UINTBIG *td, INTBIG x, INTBIG y)
+{
+	REGISTER INTBIG scale;
+
+	td[0] = td[0] & ~(VTXOFF|VTYOFF|VTXOFFNEG|VTYOFFNEG);
+	if (x < 0)
+	{
+		x = -x;
+		td[0] |= VTXOFFNEG;
+	}
+	if (y < 0)
+	{
+		y = -y;
+		td[0] |= VTYOFFNEG;
+	}
+	scale = maxi(x,y) >> VTOFFMASKWID;
+	x /= (scale + 1);
+	y /= (scale + 1);
+	td[0] |= (x << VTXOFFSH);
+	td[0] |= (y << VTYOFFSH);
+	TDSETOFFSCALE(td, scale);
+}
+
+/*
+ * Routine to validate the variable offset (x,y) and clip or grid it
+ * to acceptable values.
+ */
+void propervaroffset(INTBIG *x, INTBIG *y)
+{
+	REGISTER INTBIG scale, realx, realy, negx, negy;
+
+	negx = negy = 1;
+	realx = *x;   realy = *y;
+	if (realx < 0) { realx = -realx;   negx = -1; }
+	if (realy < 0) { realy = -realy;   negy = -1; }
+	if (realx > 077777) realx = 077777;
+	if (realy > 077777) realy = 077777;
+	scale = (maxi(realx, realy) >> VTOFFMASKWID) + 1;
+	realx /= scale;
+	realy /= scale;
+	*x = realx * scale * negx;
+	*y = realy * scale * negy;
+}
+
+/*
+ * Routine to clear the text descriptor array in "t".
+ * This routine implements the macro "TDCLEAR".
+ */
+void tdclear(UINTBIG *t)
+{
+	REGISTER INTBIG i;
+
+	for(i=0; i<TEXTDESCRIPTSIZE; i++) t[i] = 0;
+}
+
+/*
+ * Routine to copy the text descriptor array in "s" to "d".
+ * This routine implements the macro "TDCOPY".
+ */
+void tdcopy(UINTBIG *d, UINTBIG *s)
+{
+	REGISTER INTBIG i;
+
+	for(i=0; i<TEXTDESCRIPTSIZE; i++) d[i] = s[i];
+}
+
+/*
+ * Routine to compare the text descriptor arrays in "t1" to "t2"
+ * and return nonzero if they are different.
+ * This routine implements the macro "TDDIFF".
+ */
+INTSML tddiff(UINTBIG *t1, UINTBIG *t2)
+{
+	REGISTER INTBIG i;
+
+	for(i=0; i<TEXTDESCRIPTSIZE; i++)
+		if (t1[i] != t2[i]) return(1);
+	return(0);
 }
 
 /*
@@ -1776,7 +1969,7 @@ char *describedisplayedvariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 	if ((var->type&VDISPLAY) != 0)
 	{
 		name = truevariablename(var);
-		switch (var->textdescript&VTDISPLAYPART)
+		switch (TDGETDISPPART(var->textdescript))
 		{
 			case VTDISPLAYNAME:
 				(void)addstringtoinfstr(name);
@@ -1828,7 +2021,7 @@ char *truevariablename(VARIABLE *var)
 char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 {
 	REGISTER INTSML err;
-	REGISTER INTBIG i, len;
+	REGISTER INTBIG i, len, *addr;
 
 	if (var == NOVARIABLE)
 	{
@@ -1847,6 +2040,7 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 		{
 			/* compute the array length */
 			len = getlength(var);
+			addr = (INTBIG *)var->addr;
 
 			/* if asking for a single entry, get it */
 			if (aindex >= 0)
@@ -1857,8 +2051,7 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 					/* index the array in pairs */
 					aindex *= 2;
 					if (aindex < len)
-					err += db_makestringvar(((INTBIG *)var->addr)[aindex+1],
-						((INTBIG *)var->addr)[aindex], purpose);
+					err += db_makestringvar(addr[aindex+1], addr[aindex], purpose);
 				} else
 				{
 					/* normal array indexing */
@@ -1867,21 +2060,21 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 					{
 						case VCHAR:
 						err += db_makestringvar(var->type,
-							((INTBIG)((char *)var->addr)[aindex]), purpose);
+							((INTBIG)((char *)addr)[aindex]), purpose);
 						break;
 
 						case VDOUBLE:
 						err += db_makestringvar(var->type,
-							((INTBIG)((double *)var->addr)[aindex]), purpose);
+							((INTBIG)((double *)addr)[aindex]), purpose);
 						break;
 
 						case VSHORT:
 						err += db_makestringvar(var->type,
-							((INTBIG)((INTSML *)var->addr)[aindex]), purpose);
+							((INTBIG)((INTSML *)addr)[aindex]), purpose);
 						break;
 
 						default:
-						err += db_makestringvar(var->type, ((INTBIG *)var->addr)[aindex], purpose);
+						err += db_makestringvar(var->type, addr[aindex], purpose);
 						break;
 					}
 				}
@@ -1899,8 +2092,7 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 					{
 						/* index the array in pairs */
 						if (i+1 < len)
-							err += db_makestringvar(((INTBIG *)var->addr)[i+1],
-								((INTBIG *)var->addr)[i], purpose);
+							err += db_makestringvar(addr[i+1], addr[i], purpose);
 						i++;
 					} else
 					{
@@ -1909,21 +2101,21 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 						{
 							case VCHAR:
 							err += db_makestringvar(var->type,
-								((INTBIG)((char *)var->addr)[i]), purpose);
+								((INTBIG)((char *)addr)[i]), purpose);
 							break;
 
 							case VDOUBLE:
 							err += db_makestringvar(var->type,
-								((INTBIG)((double *)var->addr)[i]), purpose);
+								((INTBIG)((double *)addr)[i]), purpose);
 							break;
 
 							case VSHORT:
 							err += db_makestringvar(var->type,
-								((INTBIG)((INTSML *)var->addr)[i]), purpose);
+								((INTBIG)((INTSML *)addr)[i]), purpose);
 							break;
 
 							default:
-							err += db_makestringvar(var->type, ((INTBIG *)var->addr)[i], purpose);
+							err += db_makestringvar(var->type, addr[i], purpose);
 							break;
 						}
 					}
@@ -1959,7 +2151,7 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 	REGISTER RTNODE *rtn;
 	REGISTER LIBRARY *lib;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER NETWORK *net;
 	REGISTER CELL *cell;
 	REGISTER VIEW *view;
@@ -1994,7 +2186,7 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 			return(err);
 		case VFLOAT:
 		case VDOUBLE:
-			(void)sprintf(line, "%f", castfloat(addr));
+			(void)sprintf(line, "%g", castfloat(addr));
 			return(addstringtoinfstr(line));
 		case VNODEINST:
 			ni = (NODEINST *)addr;
@@ -2051,11 +2243,11 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 			if (tech == NOTECHNOLOGY) return(addstringtoinfstr("***NOTECHNOLOGY***"));
 			if (purpose <= 0) return(addstringtoinfstr(tech->techname));
 			return(db_addstring(tech->techname));
-		case VAID:
-			aid = (AIDENTRY *)addr;
-			if (aid == NOAID) return(addstringtoinfstr("***NOAID***"));
-			if (purpose <= 0) return(addstringtoinfstr(aid->aidname));
-			return(db_addstring(aid->aidname));
+		case VTOOL:
+			tool = (TOOL *)addr;
+			if (tool == NOTOOL) return(addstringtoinfstr("***NOTOOL***"));
+			if (purpose <= 0) return(addstringtoinfstr(tool->toolname));
+			return(db_addstring(tool->toolname));
 		case VRTNODE:
 			rtn = (RTNODE *)addr;
 			if (rtn == NORTNODE) return(addstringtoinfstr("***NORTNODE***"));
@@ -2147,12 +2339,15 @@ char *describesimplevariable(VARIABLE *var)
 		case VINTEGER:
 			sprintf(line, "%ld", var->addr);
 			return(line);
+		case VFRACT:
+			strcpy(line, frtoa(var->addr));
+			return(line);
 		case VSHORT:
 			sprintf(line, "%ld", var->addr&0xFFFF);
 			return(line);
 		case VFLOAT:
 		case VDOUBLE:
-			sprintf(line, "%f", castfloat(var->addr));
+			sprintf(line, "%g", castfloat(var->addr));
 			return(line);
 	}
 	return("");
@@ -2201,171 +2396,6 @@ char *unitsname(INTBIG units)
 
 /************************* INTERNATIONALIZATION *************************/
 
-#ifdef MACOS
-	extern DIALOG gra_fontdialog;
-#endif
-#ifdef WIN32
-	extern DIALOG db_severeerrordialog, gra_sesplaydialog;
-#endif
-#ifdef ONUNIX
-	extern DIALOG db_severeerrordialog, gra_sesplaydialog, gra_xfontdialog,
-		gra_fileindialog, gra_fileoutdialog;
-#endif
-#if DRCAID
-	extern DIALOG dr_optionsdialog, dr_hierdialog, dr_errdialog;
-#endif
-#if COMAID
-	extern DIALOG com_optionsdialog;
-#endif
-#if COMPENAID
-	extern DIALOG compen_factorsdialog;
-#endif
-#if ERCAID
-	extern DIALOG erc_optionsdialog;
-#endif
-#if LOGEFFAID
-	extern DIALOG le_leoptionsdialog, le_capacitancedialog, le_logeffortdialog;
-#endif
-#if PROJECTAID
-	extern DIALOG proj_usersdialog, proj_passworddialog, proj_listdialog,
-		proj_commentsdialog, proj_oldversdialog;
-#endif
-#if ROUTAID
-	extern DIALOG ro_optionsdialog;
-#endif
-#if SCAID
-	extern DIALOG sc_optionsdialog;
-#endif
-#if SIMAID
-	extern DIALOG sim_optionsdialog, sim_alsclockdialog, sim_spiceoptdialog,
-		sim_verilogoptdialog, sim_fasthenrydialog, sim_fasthenryarcdialog,
-		sim_widedialog;
-#endif
-#if VHDLAID
-	extern DIALOG vhdl_optionsdialog;
-#endif
-	extern DIALOG db_undodialog,
-#if IOCIF
-	io_cifoptionsdialog,
-#endif
-#if IODEF
-	io_defoptionsdialog,
-#endif
-#if IODXF
-	io_dxfoptionsdialog,
-#endif
-#if IOEDIF
-	io_edifoptionsdialog,
-#endif
-#if IOGDS
-	io_gdsoptionsdialog,
-#endif
-#if IOSKILL
-	io_skilloptionsdialog, io_skilllibdialog,
-#endif
-	net_optionsdialog, io_techadjlamdialog, io_liboptdialog,
-	us_movetodialog, us_eprogressdialog, us_progressdialog, us_3ddepthdialog,
-	us_aboutgnudialog, us_alignmentdialog, us_defarcdialog, us_arcsizedialog,
-	us_arraydialog, us_artworkdialog, us_patterndialog, us_attrdialog,
-	us_changedialog, us_noyesdialog, us_yesnodialog, us_noyesalwaysdialog,
-	us_okmessagedialog, us_colormixdialog, us_menuposdialog, us_createtodialog,
-	us_copyfacetdialog, us_editfacetdialog, us_newfacetdialog, us_facetlistdialog,
-	us_facetdialog, us_drawingoptdialog, us_multigetinfodialog, us_shownodedialog,
-	us_showarcdialog, us_showtextdialog, us_portinfodialog, us_griddialog,
-	us_helpdialog, us_iconoptdialog, us_highlightlayerdialog, us_librarypathdialog,
-	us_chglibrarydialog, us_annringdialog, us_spelldialog, us_defnodedialog,
-	us_resistancedialog, us_capacitancedialog, us_inductancedialog, us_vccsdialog,
-	us_areadialog, us_widlendialog, us_gaindialog, us_sourcedialog, us_txtsardialog,
-	us_nodesizedialog, us_optionsavingdialog, us_outlinedialog, us_portdialog,
-	us_portdisplaydialog, us_printingoptdialog, us_quickkeydialog, us_quitdialog,
-	us_rendialog, us_seloptdialog, us_selnamedialog, us_spreaddialog,
-	us_tecedlibtotechdialog, us_dependentlibdialog, us_techvarsdialog,
-	us_techselectdialog, us_techsetdialog, us_deftextdialog, us_unitsdialog,
-	us_variabledialog, us_newviewdialog, us_visiblelaydialog, us_windowviewdialog,
-	us_listdialog, us_ttyinputdialog, us_ttyfulldialog, us_purelayerdialog,
-	us_txtmodsizedialog, us_viewseldialog, us_rulesdialogdesc, us_techdifoptdialog;
-
-
-DIALOG *db_alldialogs[] =
-{
-#ifdef MACOS
-	&gra_fontdialog,
-#endif
-#ifdef WIN32
-	&db_severeerrordialog, &gra_sesplaydialog,
-#endif
-#ifdef ONUNIX
-	&db_severeerrordialog, &gra_sesplaydialog, &gra_xfontdialog, &gra_fileindialog, &gra_fileoutdialog,
-#endif
-#if DRCAID
-	&dr_optionsdialog, &dr_hierdialog, &dr_errdialog,
-#endif
-#if COMAID
-	&com_optionsdialog,
-#endif
-#if COMPENAID
-	&compen_factorsdialog,
-#endif
-#if ERCAID
-	&erc_optionsdialog,
-#endif
-#if LOGEFFAID
-	&le_leoptionsdialog, &le_capacitancedialog, &le_logeffortdialog,
-#endif
-#if PROJECTAID
-	&proj_usersdialog, &proj_passworddialog, &proj_listdialog, &proj_commentsdialog, &proj_oldversdialog,
-#endif
-#if ROUTAID
-	&ro_optionsdialog,
-#endif
-#if SCAID
-	&sc_optionsdialog,
-#endif
-#if SIMAID
-	&sim_optionsdialog, &sim_alsclockdialog, &sim_spiceoptdialog, &sim_verilogoptdialog,
-	&sim_fasthenrydialog, &sim_fasthenryarcdialog, &sim_widedialog,
-#endif
-#if VHDLAID
-	&vhdl_optionsdialog,
-#endif
-	&db_undodialog,
-#if IOCIF
-	&io_cifoptionsdialog,
-#endif
-#if IODEF
-	&io_defoptionsdialog,
-#endif
-#if IODXF
-	&io_dxfoptionsdialog,
-#endif
-#if IOEDIF
-	&io_edifoptionsdialog,
-#endif
-#if IOGDS
-	&io_gdsoptionsdialog,
-#endif
-#if IOSKILL
-	&io_skilloptionsdialog, &io_skilllibdialog,
-#endif
-	&net_optionsdialog, &io_techadjlamdialog, &io_liboptdialog, &us_purelayerdialog,
-	&us_movetodialog, &us_eprogressdialog, &us_progressdialog, &us_3ddepthdialog, &us_aboutgnudialog,
-	&us_alignmentdialog, &us_defarcdialog, &us_arcsizedialog, &us_arraydialog, &us_artworkdialog,
-	&us_patterndialog, &us_attrdialog, &us_changedialog, &us_noyesdialog, &us_yesnodialog, &us_noyesalwaysdialog,
-	&us_okmessagedialog, &us_colormixdialog, &us_menuposdialog, &us_createtodialog, &us_copyfacetdialog,
-	&us_editfacetdialog, &us_newfacetdialog, &us_facetlistdialog, &us_facetdialog, &us_drawingoptdialog,
-	&us_multigetinfodialog, &us_shownodedialog, &us_showarcdialog, &us_showtextdialog, &us_portinfodialog,
-	&us_griddialog, &us_helpdialog, &us_iconoptdialog, &us_highlightlayerdialog, &us_librarypathdialog,
-	&us_chglibrarydialog, &us_annringdialog, &us_spelldialog, &us_defnodedialog, &us_resistancedialog,
-	&us_capacitancedialog, &us_inductancedialog, &us_vccsdialog, &us_areadialog, &us_widlendialog,
-	&us_gaindialog, &us_sourcedialog, &us_nodesizedialog, &us_optionsavingdialog, &us_outlinedialog,
-	&us_portdialog, &us_portdisplaydialog, &us_printingoptdialog, &us_quickkeydialog, &us_quitdialog,
-	&us_rendialog, &us_seloptdialog, &us_selnamedialog, &us_spreaddialog, &us_tecedlibtotechdialog,
-	&us_dependentlibdialog, &us_techvarsdialog, &us_techselectdialog, &us_techsetdialog, &us_deftextdialog,
-	&us_unitsdialog, &us_variabledialog, &us_newviewdialog, &us_visiblelaydialog, &us_windowviewdialog,
-	&us_listdialog, &us_ttyinputdialog, &us_ttyfulldialog, &us_txtsardialog, &us_txtmodsizedialog,
-	&us_viewseldialog, &us_rulesdialogdesc, &us_techdifoptdialog,
-0};
-
 char *db_stoppingreason[] =
 {
 	N_("Contour gather"),		/* STOPREASONCONTOUR */
@@ -2400,39 +2430,43 @@ char *db_stoppingreason[] =
 	0
 };
 
+/*
+ * Routine to translate internal strings in the database.
+ */
 void db_inittranslation(void)
 {
-	REGISTER INTBIG i, j;
-	DIALOG *dia;
-	DIALOGITEM *item;
+	REGISTER INTBIG i;
 
 	/* pretranslate the reasons for stopping */
 	for(i=0; db_stoppingreason[i] != 0; i++)
 		db_stoppingreason[i] = _(db_stoppingreason[i]);
+}
 
-	/* pretranslate all strings in dialogs */
-	for(i=0; db_alldialogs[i] != 0; i++)
+/*
+ * Routine to ensure that dialog "dia" is translated.
+ */
+void DiaTranslate(DIALOG *dia)
+{
+	REGISTER INTBIG j;
+	DIALOGITEM *item;
+
+	if (dia->translated != 0) return;
+	dia->translated = 1;
+	if (dia->movable != 0) dia->movable = _(dia->movable);
+	for(j=0; j<dia->items; j++)
 	{
-		dia = db_alldialogs[i];
-		if (dia->translated != 0)
-			error("Dialog translated twice");
-		dia->translated = 1;
-		if (dia->movable != 0) dia->movable = _(dia->movable);
-		for(j=0; j<dia->items; j++)
+		item = &dia->list[j];
+		switch (item->type&ITEMTYPE)
 		{
-			item = &dia->list[j];
-			switch (item->type&ITEMTYPE)
-			{
-				case BUTTON:
-				case DEFBUTTON:
-				case CHECK:
-				case RADIO:
-				case MESSAGE:
-				case EDITTEXT:
-					if (*item->msg != 0)
-						item->msg = _(item->msg);
-					break;
-			}
+			case BUTTON:
+			case DEFBUTTON:
+			case CHECK:
+			case RADIO:
+			case MESSAGE:
+			case EDITTEXT:
+				if (*item->msg != 0)
+					item->msg = _(item->msg);
+				break;
 		}
 	}
 }
@@ -2750,13 +2784,30 @@ INTSML addstringtoinfstr(char *pp)
 	return(0);
 }
 
+/*
+ * Routine to do a variable-arguments "sprintf" to line "line" which
+ * is "len" in size.
+ */
+void evsnprintf(char *line, INTBIG len, char *msg, va_list ap)
+{
+#ifdef HAVE_VSNPRINTF
+	(void)vsnprintf(line, len-1, msg, ap);
+#else
+#  ifdef WIN32
+	(void)_vsnprintf(line, len-1, msg, ap);
+#  else
+	(void)vsprintf(line, msg, ap);
+#  endif
+#endif
+}
+
 INTSML formatinfstr(char *msg, ...)
 {
 	va_list ap;
 	char line[8192];
 
 	var_start(ap, msg);
-	(void)vsprintf(line, msg, ap);
+	evsnprintf(line, 8192, msg, ap);
 	va_end(ap);
 	return(addstringtoinfstr(line));
 }
@@ -3101,7 +3152,8 @@ FILE *xopen(char *file, INTBIG filetype, char *otherdir, char **truename)
  */
 FILE *db_tryfile(char *pp, char *rarg, char *extension, char *otherdir, char **truename)
 {
-	REGISTER INTSML len;
+	REGISTER INTBIG len;
+	REGISTER char *pt;
 
 	len = strlen(pp) + 1;
 	if (extension != 0) len += strlen(extension) + 1;
@@ -3118,9 +3170,12 @@ FILE *db_tryfile(char *pp, char *rarg, char *extension, char *otherdir, char **t
 	if (otherdir != 0)
 	{
 		(void)strcat(db_tryfilename, otherdir);
-#ifdef ONUNIX
-		(void)strcat(db_tryfilename, "/");
-#endif
+		len = strlen(db_tryfilename);
+		if (db_tryfilename[len-1] != DIRSEP)
+		{
+			db_tryfilename[len++] = DIRSEP;
+			db_tryfilename[len] = 0;
+		}
 	}
 	(void)strcat(db_tryfilename, pp);
 	if (extension != 0)
@@ -3128,6 +3183,19 @@ FILE *db_tryfile(char *pp, char *rarg, char *extension, char *otherdir, char **t
 		(void)strcat(db_tryfilename, ".");
 		(void)strcat(db_tryfilename, extension);
 	}
+
+	/* now extend this to the full path name */
+	pt = fullfilename(db_tryfilename);
+	len = strlen(pt) + 1;
+	if (len > db_tryfilenamelen)
+	{
+		efree(db_tryfilename);
+		db_tryfilenamelen = 0;
+		db_tryfilename = (char *)emalloc(len, db_cluster);
+		if (db_tryfilename == 0) return(NULL);
+		db_tryfilenamelen = len;
+	}
+	strcpy(db_tryfilename, pt);
 	*truename = db_tryfilename;
 	return(fopen(db_tryfilename, rarg));
 }
@@ -3153,7 +3221,7 @@ FILE *xcreate(char *name, INTBIG filetype, char *prompt, char **truename)
 	describefiletype(filetype&FILETYPE, &extension, &winfilter, &mactype, &binary, &shortname, &longname);
 
 	pt = truepath(name);
-	if (prompt != 0 && (us_aid->aidstate&USEDIALOGS) != 0)
+	if (prompt != 0 && (us_tool->toolstate&USEDIALOGS) != 0)
 	{
 		next = (char *)fileselect(prompt, filetype | FILETYPEWRITE, pt);
 		if (next == 0 || *next == 0)
@@ -3290,7 +3358,15 @@ INTSML xputs(char *s, FILE *f)
  */
 INTBIG xfread(char *buf, INTBIG size, INTBIG count, FILE *f)
 {
-	return(fread(buf, size, count, f));
+	REGISTER INTBIG ret;
+
+	for(;;)
+	{
+		ret = fread(buf, size, count, f);
+		if (ret == count || feof(f) != 0) break;
+		clearerr(f);
+	}
+	return(ret);
 }
 
 /*
@@ -3299,7 +3375,15 @@ INTBIG xfread(char *buf, INTBIG size, INTBIG count, FILE *f)
  */
 INTBIG xfwrite(char *buf, INTBIG size, INTBIG count, FILE *f)
 {
-	return(fwrite(buf, size, count, f));
+	REGISTER INTBIG ret;
+
+	for(;;)
+	{
+		ret = fwrite(buf, size, count, f);
+		if (ret == count || feof(f) != 0) break;
+		clearerr(f);
+	}
+	return(ret);
 }
 
 /*
