@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: drc.c
- * Design-rule check aid
+ * Design-rule check tool
  * WRitten by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if DRCAID
+#if DRCTOOL
 
 #include "global.h"
 #include "egraphics.h"
@@ -40,8 +40,8 @@
 #include "usr.h"
 #include "usrdiacom.h"
 
-/* the DRC aid table */
-COMCOMP dr_drccp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
+/* the DRC tool table */
+static COMCOMP dr_drccp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
 	NOBACKUP, INPUTOPT, " \t", M_("facet to be rechecked"), M_("check current facet")};
 static KEYWORD drcnotopt[] =
 {
@@ -120,7 +120,7 @@ static DCHECK   *dr_firstdcheck;
 static DCHECK   *dr_dcheckfree;
 
 /*
- * The meaning of "aid:drc.DRC_pointout" is as follows:
+ * The meaning of "tool:drc.DRC_pointout" is as follows:
  *  0: not identifying errors
  *  1: errors being identified
  * >1: some errors have already been identified
@@ -131,7 +131,7 @@ static INTBIG    dr_pointout;						/* cached value of "DRC_pointout" */
 static INTBIG    dr_verbosekey;						/* key for "DRC_verbose" */
        INTBIG    dr_ignore_listkey;					/* key for "DRC_ignore_list" */
        INTBIG    dr_lastgooddrckey;					/* key for "DRC_last_good_drc" */
-       INTBIG    dr_incrementalonkey;				/* key for "DRC_incrementalon" */
+static INTBIG    dr_incrementalonkey;				/* key for "DRC_incrementalon" */
 static INTBIG    dr_optionskey;						/* key for "DRC_options" */
        INTBIG    dr_options;						/* cached value of "DRC_options" */
        INTBIG    dr_max_distanceskey;				/* key for "DRC_max_distances" */
@@ -152,21 +152,47 @@ static INTBIG    dr_optionskey;						/* key for "DRC_options" */
        INTBIG    dr_connected_distancesM_rulekey;	/* key for "DRC_min_connected_distances_multi_rule" */
        INTBIG    dr_unconnected_distancesMkey;		/* key for "DRC_min_unconnected_distances_multi" */
        INTBIG    dr_unconnected_distancesM_rulekey;	/* key for "DRC_min_unconnected_distances_multi_rule" */
-       AIDENTRY *dr_aid;							/* the DRC aid object */
+       INTBIG    dr_edge_distanceskey;				/* key for "DRC_min_edge_distances" */
+       INTBIG    dr_edge_distances_rulekey;			/* key for "DRC_min_edge_distances_rule" */
+       TOOL     *dr_tool;							/* the DRC tool object */
+char *dr_variablenames[] =
+{
+	"DRC_max_distances",
+	"DRC_wide_limit",
+	"DRC_min_width",
+	"DRC_min_width_rule",
+	"DRC_min_node_size",
+	"DRC_min_node_size_rule",
+	"DRC_min_connected_distances",
+	"DRC_min_connected_distances_rule",
+	"DRC_min_unconnected_distances",
+	"DRC_min_unconnected_distances_rule",
+	"DRC_min_connected_distances_wide",
+	"DRC_min_connected_distances_wide_rule",
+	"DRC_min_unconnected_distances_wide",
+	"DRC_min_unconnected_distances_wide_rule",
+	"DRC_min_connected_distances_multi",
+	"DRC_min_connected_distances_multi_rule",
+	"DRC_min_unconnected_distances_multi",
+	"DRC_min_unconnected_distances_multi_rule",
+	"DRC_min_edge_distances",
+	"DRC_min_edge_distances_rule",
+	0
+};
 
 /* prototypes for local routines */
-DCHECK    *dr_allocdcheck(void);
-void       dr_batchdlog(NODEPROTO *facet);
-NODEPROTO *dr_checkthisfacet(INTSML, char*);
-char      *dr_errordlog(char *prompt);
-void       dr_freedcheck(DCHECK*);
-void       dr_optionsdlog(void);
-void       dr_rulesdlog(void);
-void       dr_queuecheck(GEOM*, INTSML);
-void       dr_reporterrors(void);
-void       dr_setignore(GEOM*, GEOM*);
-void       dr_unignore(NODEPROTO*, GEOM*);
-void       dr_unqueuecheck(LIBRARY *lib);
+static DCHECK    *dr_allocdcheck(void);
+static void       dr_batchdlog(NODEPROTO *facet);
+static NODEPROTO *dr_checkthisfacet(INTSML, char*);
+static char      *dr_errordlog(char *prompt);
+static void       dr_freedcheck(DCHECK*);
+static void       dr_optionsdlog(void);
+static void       dr_rulesdlog(void);
+static void       dr_queuecheck(GEOM*, INTSML);
+static void       dr_reporterrors(void);
+static void       dr_setignore(GEOM*, GEOM*);
+static void       dr_unignore(NODEPROTO*, GEOM*);
+static void       dr_unqueuecheck(LIBRARY *lib);
 
 /*
  * routine to allocate a new dcheck module from the pool (if any) or memory
@@ -177,7 +203,7 @@ DCHECK *dr_allocdcheck(void)
 
 	if (dr_dcheckfree == NODCHECK)
 	{
-		d = (DCHECK *)emalloc(sizeof (DCHECK), dr_aid->cluster);
+		d = (DCHECK *)emalloc(sizeof (DCHECK), dr_tool->cluster);
 		if (d == 0) return(NODCHECK);
 	} else
 	{
@@ -239,14 +265,14 @@ void dr_unqueuecheck(LIBRARY *lib)
 
 /******************** CONTROL ********************/
 
-void dr_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void dr_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	REGISTER VARIABLE *var;
 
 	/* only initialize during pass 1 */
-	if (thisaid == NOAID || thisaid == 0) return;
+	if (thistool == NOTOOL || thistool == 0) return;
 
-	dr_aid = thisaid;
+	dr_tool = thistool;
 
 	/* initialize the design-rule checker lists */
 	dr_dcheckfree = NODCHECK;
@@ -258,11 +284,11 @@ void dr_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 	dr_lastgooddrckey = makekey("DRC_last_good_drc");
 	dr_incrementalonkey = makekey("DRC_incrementalon");
 	dr_optionskey = makekey("DRC_options");
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_optionskey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_optionskey);
 	if (var == NOVARIABLE) dr_options = 0; else
 		dr_options = var->addr;
 	nextchangequiet();
-	(void)setvalkey((INTBIG)dr_aid, VAID, dr_pointoutkey, 0, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_pointoutkey, 0, VINTEGER|VDONTSAVE);
 	dr_pointout = 0;
 	DiaDeclareHook("drcopt", &dr_drcp, dr_optionsdlog);
 	DiaDeclareHook("drcrules", &dr_drccp, dr_rulesdlog);
@@ -270,6 +296,7 @@ void dr_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 
 void dr_done(void)
 {
+#ifdef DEBUGMEMORY
 	REGISTER DCHECK *d;
 
 	while (dr_firstdcheck != NODCHECK)
@@ -285,6 +312,7 @@ void dr_done(void)
 		efree((char *)d);
 	}
 	drcb_term();
+#endif
 }
 
 INTSML dr_set(INTSML count, char *par[])
@@ -302,11 +330,11 @@ INTSML dr_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_verbosekey);
+		var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_verbosekey);
 		if (var == NOVARIABLE) i = 0; else i = var->addr;
 		if (i == 0) ttyputmsg(M_("Design rule checker is brief")); else
  			ttyputmsg(M_("Design rule checker is verbose"));
-		var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_pointoutkey);
+		var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_pointoutkey);
 		if (var == NOVARIABLE) i = 0; else i = var->addr;
 		if (i == 0) ttyputmsg(M_("Errors will not be highlighted")); else
 			ttyputmsg(M_("Errors will be highlighted"));
@@ -346,10 +374,10 @@ INTSML dr_set(INTSML count, char *par[])
 	if (namesamen(pp, "check", l) == 0)
 	{
 		/* make sure network tool is on */
-		if ((net_aid->aidstate&AIDON) == 0)
+		if ((net_tool->toolstate&TOOLON) == 0)
 		{
 			ttyputerr(M_("Network tool must be running...turning it on"));
-			aidturnon(net_aid, 0);
+			toolturnon(net_tool, 0);
 			ttyputerr(M_("...now reissue the DRC command"));
 			return(1);
 		}
@@ -413,12 +441,12 @@ INTSML dr_set(INTSML count, char *par[])
 		newpar[0] = "cif";
 		newpar[1] = "output";
 		newpar[2] = "include-cloak-layer";
-		(void)tellaid(io_aid, 3, newpar);
-		(void)askaid(io_aid, "write", (INTBIG)np->cell->lib, (INTBIG)"cif");
+		(void)telltool(io_tool, 3, newpar);
+		(void)asktool(io_tool, "write", (INTBIG)np->cell->lib, (INTBIG)"cif");
 		newpar[0] = "cif";
 		newpar[1] = "output";
 		newpar[2] = "ignore-cloak-layer";
-		(void)tellaid(io_aid, 3, newpar);
+		(void)telltool(io_tool, 3, newpar);
 		return(0);
 	}
 
@@ -426,17 +454,17 @@ INTSML dr_set(INTSML count, char *par[])
 	{
 		if (count == 1)
 		{
-			ttyputusage("tellaid drc batch OPTIONS");
+			ttyputusage("telltool drc batch OPTIONS");
 			return(0);
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "run", l) == 0)
 		{
 			/* make sure network tool is on */
-			if ((net_aid->aidstate&AIDON) == 0)
+			if ((net_tool->toolstate&TOOLON) == 0)
 			{
 				ttyputerr(M_("Network tool must be running...turning it on"));
-				aidturnon(net_aid, 0);
+				toolturnon(net_tool, 0);
 				ttyputerr(M_("...now reissue the DRC command"));
 				return(1);
 			}
@@ -470,28 +498,28 @@ INTSML dr_set(INTSML count, char *par[])
 		}
 		if (namesamen(pp, "use-dialog", l) == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options | DRCHIERDIALOG, VINTEGER);
 			ttyputmsg(M_("Hierarchical DRC will use a dialog interface"));
 			return(0);
 		}
 		if (namesamen(pp, "no-dialog", l) == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options & ~DRCHIERDIALOG, VINTEGER);
 			ttyputmsg(M_("Hierarchical DRC will not use a dialog interface"));
 			return(0);
 		}
 		if (namesamen(pp, "just-1-error", l) == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options | DRCFIRSTERROR, VINTEGER);
 			ttyputmsg(M_("Hierarchical DRC will stop after first error in a facet"));
 			return(0);
 		}
 		if (namesamen(pp, "all-errors", l) == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options & ~DRCFIRSTERROR, VINTEGER);
 			ttyputmsg(M_("Hierarchical DRC will find all errors in a facet"));
 			return(0);
@@ -504,7 +532,7 @@ INTSML dr_set(INTSML count, char *par[])
 			ttyputmsg(M_("All date information about valid DRC is reset"));
 			return(0);
 		}
-		ttyputbadusage("tellaid drc batch");
+		ttyputbadusage("telltool drc batch");
 		return(1);
 	}
 
@@ -512,17 +540,17 @@ INTSML dr_set(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid drc shortcheck (run|ignore|unignore)");
+			ttyputusage("telltool drc shortcheck (run|ignore|unignore)");
 			return(1);
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "run", l) == 0)
 		{
 			/* make sure network tool is on */
-			if ((net_aid->aidstate&AIDON) == 0)
+			if ((net_tool->toolstate&TOOLON) == 0)
 			{
 				ttyputerr(M_("Network tool must be running...turning it on"));
-				aidturnon(net_aid, 0);
+				toolturnon(net_tool, 0);
 				ttyputerr(M_("...now reissue the DRC command"));
 				return(1);
 			}
@@ -532,7 +560,7 @@ INTSML dr_set(INTSML count, char *par[])
 		{
 			if (count < 3)
 			{
-				ttyputusage("tellaid drc shortcheck ignore FACET");
+				ttyputusage("telltool drc shortcheck ignore FACET");
 				return(1);
 			}
 			return(dr_flatignore(par[2]));
@@ -541,12 +569,12 @@ INTSML dr_set(INTSML count, char *par[])
 		{
 			if (count < 3)
 			{
-				ttyputusage("tellaid drc shortcheck unignore FACET");
+				ttyputusage("telltool drc shortcheck unignore FACET");
 				return(1);
 			}
 			return(dr_flatunignore(par[2]));
 		}
-		ttyputbadusage("tellaid drc shortcheck");
+		ttyputbadusage("telltool drc shortcheck");
 		return(1);
 	}
 
@@ -554,12 +582,12 @@ INTSML dr_set(INTSML count, char *par[])
 	{
 		if (negate == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_verbosekey, 1, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_verbosekey, 1, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("DRC verbose"));
 		} else
 		{
-			if (getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_verbosekey) != NOVARIABLE)
-				(void)delvalkey((INTBIG)dr_aid, VAID, dr_verbosekey);
+			if (getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_verbosekey) != NOVARIABLE)
+				(void)delvalkey((INTBIG)dr_tool, VTOOL, dr_verbosekey);
 			ttyputverbose(M_("DRC brief"));
 		}
 		return(0);
@@ -569,12 +597,12 @@ INTSML dr_set(INTSML count, char *par[])
 	{
 		if (negate == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options | DRCREASONABLE, VINTEGER);
 			ttyputverbose(M_("DRC will consider only reasonable number of polygons"));
 		} else
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				dr_options & ~DRCREASONABLE, VINTEGER);
 			ttyputverbose(M_("DRC will consider all polygons"));
 		}
@@ -585,16 +613,16 @@ INTSML dr_set(INTSML count, char *par[])
 	{
 		if (negate == 0)
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_pointoutkey, 1, VINTEGER);
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_pointoutkey, 1, VINTEGER);
 			ttyputverbose(M_("DRC will identify errors"));
 		} else
 		{
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_pointoutkey, 0, VINTEGER);
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_pointoutkey, 0, VINTEGER);
 			ttyputverbose(M_("DRC will not identify errors"));
 		}
 		return(0);
 	}
-	ttyputbadusage("tellaid drc");
+	ttyputbadusage("telltool drc");
 	return(1);
 }
 
@@ -607,15 +635,15 @@ void dr_examinenodeproto(NODEPROTO *np)
 	if (stopping(STOPREASONDRC)) return;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0) return;
+	if ((net_tool->toolstate&TOOLON) == 0) return;
 
 	/* setup for identifying errors */
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_pointoutkey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_pointoutkey);
 	if (var != NOVARIABLE) dr_pointout = var->addr; else
 		dr_pointout = 0;
 
 	/* clear errors */
-	initerrorlogging(_("DRC"));
+	initerrorlogging(_("DRC"), np, NONODEPROTO);
 
 	drcb_initincrementalcheck(np);
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -633,20 +661,20 @@ void dr_slice(void)
 	REGISTER VARIABLE *var;
 
 	/* see if the tool should be off */
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_incrementalonkey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_incrementalonkey);
 	if (var != NOVARIABLE && var->addr == 0)
 	{
-		aidturnoff(dr_aid, 0);
+		toolturnoff(dr_tool, 0);
 		return;
 	}
 
 	if (dr_firstdcheck == NODCHECK) return;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(M_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		return;
 	}
 
@@ -663,7 +691,7 @@ void dr_slice(void)
 	}
 
 	/* clear errors */
-	initerrorlogging(_("DRC"));
+	initerrorlogging(_("DRC"), NONODEPROTO, NONODEPROTO);
 
 	np = NONODEPROTO;
 	didcheck = 0;
@@ -719,7 +747,7 @@ void dr_reporterrors(void)
 	GEOM *geom1, *geom2;
 
 	/* setup for identifying errors */
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_pointoutkey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_pointoutkey);
 	if (var != NOVARIABLE) dr_pointout = var->addr; else
 		dr_pointout = 0;
 
@@ -749,12 +777,12 @@ void dr_reporterrors(void)
 			if (namesamen(answer, "highlight-off", len) == 0)
 			{
 				dr_pointout = 0;
-				setvalkey((INTBIG)dr_aid, VAID, dr_pointoutkey, 0, VINTEGER|VDONTSAVE);
+				setvalkey((INTBIG)dr_tool, VTOOL, dr_pointoutkey, 0, VINTEGER|VDONTSAVE);
 				continue;
 			}
 			if (namesamen(answer, "drc-off", len) == 0)
 			{
-				aidturnoff(dr_aid, 0);
+				toolturnoff(dr_tool, 0);
 				continue;
 			}
 			if (namesamen(answer, "ignore-error", len) == 0)
@@ -836,7 +864,7 @@ void dr_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
 
 	if (key == dr_optionskey)
 	{
-		var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_optionskey);
+		var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_optionskey);
 		if (var != NOVARIABLE) dr_options = var->addr;
 	}
 }
@@ -846,7 +874,7 @@ void dr_readlibrary(LIBRARY *lib)
 	REGISTER VARIABLE *var;
 
 	/* recache DRC variables */
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_optionskey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_optionskey);
 	if (var != NOVARIABLE) dr_options = var->addr;
 }
 
@@ -978,7 +1006,7 @@ NODEPROTO *dr_checkthisfacet(INTSML count, char *name)
 /****************************** DIALOGS ******************************/
 
 /* Hierarchical DRC */
-DIALOGITEM dr_hierdialoglist[] =
+static DIALOGITEM dr_hierdialoglist[] =
 {
  /*  1 */ {0, {8,8,32,72}, BUTTON, N_("Check")},
  /*  2 */ {0, {8,344,32,408}, BUTTON, N_("Done")},
@@ -986,7 +1014,7 @@ DIALOGITEM dr_hierdialoglist[] =
  /*  4 */ {0, {8,214,32,326}, BUTTON, N_("Show Prev Error")},
  /*  5 */ {0, {8,94,32,206}, BUTTON, N_("Show Next Error")}
 };
-DIALOG dr_hierdialog = {{50,75,191,492}, N_("Hierarchical DRC"), 0, 5, dr_hierdialoglist};
+static DIALOG dr_hierdialog = {{50,75,191,492}, N_("Hierarchical DRC"), 0, 5, dr_hierdialoglist};
 
 /* special items for the "hierarchical drc" dialog: */
 #define DHDR_CHECK    1		/* Check (button) */
@@ -1057,7 +1085,7 @@ void dr_batchdlog(NODEPROTO *facet)
 }
 
 /* DRC: Options */
-DIALOGITEM dr_optionsdialogitems[] =
+static DIALOGITEM dr_optionsdialogitems[] =
 {
  /*  1 */ {0, {240,220,264,284}, BUTTON, N_("OK")},
  /*  2 */ {0, {176,220,200,284}, BUTTON, N_("Cancel")},
@@ -1072,7 +1100,7 @@ DIALOGITEM dr_optionsdialogitems[] =
  /* 11 */ {0, {168,32,184,192}, CHECK, N_("Just 1 error per facet")},
  /* 12 */ {0, {8,8,24,248}, CHECK, N_("Ignore center cuts in large contacts")}
 };
-DIALOG dr_optionsdialog = {{50,75,323,368}, N_("DRC Options"), 0, 12, dr_optionsdialogitems};
+static DIALOG dr_optionsdialog = {{50,75,323,368}, N_("DRC Options"), 0, 12, dr_optionsdialogitems};
 
 /* special items for the "DRC Options" dialog: */
 #define DDRO_HIGHERRORS    3
@@ -1096,13 +1124,13 @@ void dr_optionsdlog(void)
 
 	if (DiaInitDialog(&dr_optionsdialog) != 0) return;
 
-	var = getvalkey((INTBIG)dr_aid, VAID, VINTEGER, dr_pointoutkey);
+	var = getvalkey((INTBIG)dr_tool, VTOOL, VINTEGER, dr_pointoutkey);
 	if (var == NOVARIABLE) higherrors = 0; else higherrors = var->addr;
 	if (higherrors != 0) DiaSetControl(DDRO_HIGHERRORS, 1);
 	if ((dr_options&DRCHIERDIALOG) != 0) DiaSetControl(DDRO_HIERDIALOG, 1);
 	if ((dr_options&DRCFIRSTERROR) != 0) DiaSetControl(DDRO_JUST1ERROR, 1);
 	if ((dr_options&DRCREASONABLE) != 0) DiaSetControl(DDRO_FEWERCUTS, 1);
-	if ((dr_aid->aidstate & AIDON) != 0) DiaSetControl(DDRO_DRCON, 1);
+	if ((dr_tool->toolstate & TOOLON) != 0) DiaSetControl(DDRO_DRCON, 1);
 
 	/* loop until done */
 	for(;;)
@@ -1129,29 +1157,29 @@ void dr_optionsdlog(void)
 		if (DiaGetControl(DDRO_HIGHERRORS) != 0) newhigherrors = 1; else
 			newhigherrors = 0;
 		if (newhigherrors != higherrors)
-			(void)setvalkey((INTBIG)dr_aid, VAID, dr_pointoutkey,
+			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_pointoutkey,
 				newhigherrors, VINTEGER);
 		options = 0;
 		if (DiaGetControl(DDRO_HIERDIALOG) != 0) options |= DRCHIERDIALOG;
 		if (DiaGetControl(DDRO_JUST1ERROR) != 0) options |= DRCFIRSTERROR;
 		if (DiaGetControl(DDRO_FEWERCUTS) != 0) options |= DRCREASONABLE;
 		if (options != dr_options)
-	 		(void)setvalkey((INTBIG)dr_aid, VAID, dr_optionskey, options, VINTEGER);
+	 		(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey, options, VINTEGER);
 
 		/* change state of DRC */
 		if (DiaGetControl(DDRO_DRCON) != 0)
 		{
-			if ((dr_aid->aidstate & AIDON) == 0)
+			if ((dr_tool->toolstate & TOOLON) == 0)
 			{
-				aidturnon(dr_aid, 0);
-				setvalkey((INTBIG)dr_aid, VAID, dr_incrementalonkey, 1, VINTEGER);
+				toolturnon(dr_tool, 0);
+				setvalkey((INTBIG)dr_tool, VTOOL, dr_incrementalonkey, 1, VINTEGER);
 			}
 		} else
 		{
-			if ((dr_aid->aidstate & AIDON) != 0)
+			if ((dr_tool->toolstate & TOOLON) != 0)
 			{
-				aidturnoff(dr_aid, 0);
-				setvalkey((INTBIG)dr_aid, VAID, dr_incrementalonkey, 0, VINTEGER);
+				toolturnoff(dr_tool, 0);
+				setvalkey((INTBIG)dr_tool, VTOOL, dr_incrementalonkey, 0, VINTEGER);
 			}
 		}
 
@@ -1210,8 +1238,8 @@ void dr_rulesdlog(void)
 {
 	REGISTER INTBIG changed, i;
 	REGISTER VARIABLE *varcon, *varuncon, *varconW, *varunconW, *varconM, *varunconM,
-		*varconR, *varunconR, *varconWR, *varunconWR, *varconMR, *varunconMR, *varmindist,
-		*varmindistR, *var;
+		*varedge, *varconR, *varunconR, *varconWR, *varunconWR, *varconMR, *varunconMR,
+		*varedgeR, *varmindist, *varmindistR, *var;
 	REGISTER DRCRULES *rules;
 
 	/* create a RULES structure */
@@ -1239,6 +1267,8 @@ void dr_rulesdlog(void)
 		dr_connected_distancesMkey);
 	varunconM = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VFRACT|VISARRAY,
 		dr_unconnected_distancesMkey);
+	varedge = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VFRACT|VISARRAY,
+		dr_edge_distanceskey);
 	varconR = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY,
 		dr_connected_distances_rulekey);
 	varunconR = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY,
@@ -1251,6 +1281,8 @@ void dr_rulesdlog(void)
 		dr_connected_distancesM_rulekey);
 	varunconMR = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY,
 		dr_unconnected_distancesM_rulekey);
+	varedgeR = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY,
+		dr_edge_distances_rulekey);
 
 	/* put the distances into the rules structure */
 	for(i=0; i<rules->numlayers; i++)
@@ -1274,6 +1306,9 @@ void dr_rulesdlog(void)
 			rules->conlistM[i] = ((INTBIG *)varconM->addr)[i];
 		if (varunconM != NOVARIABLE)
 			rules->unconlistM[i] = ((INTBIG *)varunconM->addr)[i];
+		if (varedge != NOVARIABLE)
+			rules->edgelist[i] = ((INTBIG *)varedge->addr)[i];
+
 		if (varconR != NOVARIABLE && ((char **)varconR->addr)[i][0] != 0)
 			(void)reallocstring(&rules->conlistR[i], ((char **)varconR->addr)[i], el_tempcluster);
 		if (varunconR != NOVARIABLE && ((char **)varunconR->addr)[i][0] != 0)
@@ -1286,6 +1321,8 @@ void dr_rulesdlog(void)
 			(void)reallocstring(&rules->conlistMR[i], ((char **)varconMR->addr)[i], el_tempcluster);
 		if (varunconMR != NOVARIABLE && ((char **)varunconMR->addr)[i][0] != 0)
 			(void)reallocstring(&rules->unconlistMR[i], ((char **)varunconMR->addr)[i], el_tempcluster);
+		if (varedgeR != NOVARIABLE && ((char **)varedgeR->addr)[i][0] != 0)
+			(void)reallocstring(&rules->edgelistR[i], ((char **)varedgeR->addr)[i], el_tempcluster);
 	}
 	var = getvalkey((INTBIG)el_curtech, VTECHNOLOGY, VFRACT, dr_wide_limitkey);
 	if (var != NOVARIABLE) rules->widelimit = var->addr;
@@ -1312,6 +1349,8 @@ void dr_rulesdlog(void)
 			(INTBIG)rules->conlistM, VFRACT|VISARRAY|(rules->utsize<<VLENGTHSH));
 		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_unconnected_distancesMkey,
 			(INTBIG)rules->unconlistM, VFRACT|VISARRAY|(rules->utsize<<VLENGTHSH));
+		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_edge_distanceskey,
+			(INTBIG)rules->edgelist, VFRACT|VISARRAY|(rules->utsize<<VLENGTHSH));
 		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_connected_distances_rulekey,
 			(INTBIG)rules->conlistR, VSTRING|VISARRAY|(rules->utsize<<VLENGTHSH));
 		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_unconnected_distances_rulekey,
@@ -1324,6 +1363,8 @@ void dr_rulesdlog(void)
 			(INTBIG)rules->conlistMR, VSTRING|VISARRAY|(rules->utsize<<VLENGTHSH));
 		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_unconnected_distancesM_rulekey,
 			(INTBIG)rules->unconlistMR, VSTRING|VISARRAY|(rules->utsize<<VLENGTHSH));
+		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_edge_distances_rulekey,
+			(INTBIG)rules->edgelistR, VSTRING|VISARRAY|(rules->utsize<<VLENGTHSH));
 		setvalkey((INTBIG)el_curtech, VTECHNOLOGY, dr_wide_limitkey,
 			rules->widelimit, VFRACT|VDONTSAVE);
 	}
@@ -1367,6 +1408,9 @@ DRCRULES *dr_allocaterules(INTBIG layercount, char *techname)
 	if (rules->conlistM == 0) return(NODRCRULES);
 	rules->unconlistM = (INTBIG *)emalloc(rules->utsize * SIZEOFINTBIG, el_tempcluster);
 	if (rules->unconlistM == 0) return(NODRCRULES);
+	rules->edgelist = (INTBIG *)emalloc(rules->utsize * SIZEOFINTBIG, el_tempcluster);
+	if (rules->edgelist == 0) return(NODRCRULES);
+
 	rules->conlistR = (char **)emalloc(rules->utsize * (sizeof (char *)), el_tempcluster);
 	if (rules->conlistR == 0) return(NODRCRULES);
 	rules->unconlistR = (char **)emalloc(rules->utsize * (sizeof (char *)), el_tempcluster);
@@ -1379,6 +1423,8 @@ DRCRULES *dr_allocaterules(INTBIG layercount, char *techname)
 	if (rules->conlistMR == 0) return(NODRCRULES);
 	rules->unconlistMR = (char **)emalloc(rules->utsize * (sizeof (char *)), el_tempcluster);
 	if (rules->unconlistMR == 0) return(NODRCRULES);
+	rules->edgelistR = (char **)emalloc(rules->utsize * (sizeof (char *)), el_tempcluster);
+	if (rules->edgelistR == 0) return(NODRCRULES);
 
 	for(i=0; i<rules->numlayers; i++)
 	{
@@ -1394,12 +1440,14 @@ DRCRULES *dr_allocaterules(INTBIG layercount, char *techname)
 		rules->unconlistW[i] = XX;
 		rules->conlistM[i] = XX;
 		rules->unconlistM[i] = XX;
+		rules->edgelist[i] = XX;
 		(void)allocstring(&rules->conlistR[i], "", el_tempcluster);
 		(void)allocstring(&rules->unconlistR[i], "", el_tempcluster);
 		(void)allocstring(&rules->conlistWR[i], "", el_tempcluster);
 		(void)allocstring(&rules->unconlistWR[i], "", el_tempcluster);
 		(void)allocstring(&rules->conlistMR[i], "", el_tempcluster);
 		(void)allocstring(&rules->unconlistMR[i], "", el_tempcluster);
+		(void)allocstring(&rules->edgelistR[i], "", el_tempcluster);
 	}
 	rules->widelimit = K10;
 	return(rules);
@@ -1419,6 +1467,7 @@ void dr_freerules(DRCRULES *rules)
 	efree((char *)rules->unconlistW);
 	efree((char *)rules->conlistM);
 	efree((char *)rules->unconlistM);
+	efree((char *)rules->edgelist);
 	efree((char *)rules->minwidth);
 	for(i=0; i<rules->utsize; i++)
 	{
@@ -1428,6 +1477,7 @@ void dr_freerules(DRCRULES *rules)
 		efree((char *)rules->unconlistWR[i]);
 		efree((char *)rules->conlistMR[i]);
 		efree((char *)rules->unconlistMR[i]);
+		efree((char *)rules->edgelistR[i]);
 	}
 	for(i=0; i<rules->numlayers; i++)
 	{
@@ -1441,6 +1491,7 @@ void dr_freerules(DRCRULES *rules)
 	efree((char *)rules->unconlistWR);
 	efree((char *)rules->conlistMR);
 	efree((char *)rules->unconlistMR);
+	efree((char *)rules->edgelistR);
 	efree((char *)rules->minwidthR);
 	efree((char *)rules->layernames);
 }
@@ -1448,7 +1499,7 @@ void dr_freerules(DRCRULES *rules)
 /****************************** DESIGN-RULE EDITING DIALOG ******************************/
 
 /* DRC: Rules */
-DIALOGITEM us_rulesdialogitems[] =
+static DIALOGITEM us_rulesdialogitems[] =
 {
  /*  1 */ {0, {8,516,32,580}, BUTTON, N_("OK")},
  /*  2 */ {0, {40,516,64,580}, BUTTON, N_("Cancel")},
@@ -1463,20 +1514,20 @@ DIALOGITEM us_rulesdialogitems[] =
  /* 11 */ {0, {112,308,128,424}, MESSAGE, N_("Minimum Width:")},
  /* 12 */ {0, {112,454,128,502}, EDITTEXT, ""},
  /* 13 */ {0, {112,514,128,596}, EDITTEXT, ""},
- /* 14 */ {0, {216,308,232,387}, MESSAGE, N_("Normal:")},
- /* 15 */ {0, {240,324,256,450}, MESSAGE, N_("When connected:")},
- /* 16 */ {0, {240,454,256,502}, EDITTEXT, ""},
- /* 17 */ {0, {240,514,256,595}, EDITTEXT, ""},
- /* 18 */ {0, {268,324,284,450}, MESSAGE, N_("Not connected:")},
- /* 19 */ {0, {268,454,284,502}, EDITTEXT, ""},
- /* 20 */ {0, {268,514,284,595}, EDITTEXT, ""},
- /* 21 */ {0, {292,308,308,520}, MESSAGE, N_("Wide (when bigger than this):")},
- /* 22 */ {0, {316,324,332,450}, MESSAGE, N_("When connected:")},
- /* 23 */ {0, {316,454,332,502}, EDITTEXT, ""},
- /* 24 */ {0, {316,514,332,595}, EDITTEXT, ""},
- /* 25 */ {0, {344,324,360,450}, MESSAGE, N_("Not connected:")},
- /* 26 */ {0, {344,454,360,502}, EDITTEXT, ""},
- /* 27 */ {0, {344,514,360,595}, EDITTEXT, ""},
+ /* 14 */ {0, {180,308,196,387}, MESSAGE, N_("Normal:")},
+ /* 15 */ {0, {204,324,220,450}, MESSAGE, N_("When connected:")},
+ /* 16 */ {0, {204,454,220,502}, EDITTEXT, ""},
+ /* 17 */ {0, {204,514,220,595}, EDITTEXT, ""},
+ /* 18 */ {0, {232,324,248,450}, MESSAGE, N_("Not connected:")},
+ /* 19 */ {0, {232,454,248,502}, EDITTEXT, ""},
+ /* 20 */ {0, {232,514,248,595}, EDITTEXT, ""},
+ /* 21 */ {0, {288,308,304,520}, MESSAGE, N_("Wide (when bigger than this):")},
+ /* 22 */ {0, {312,324,328,450}, MESSAGE, N_("When connected:")},
+ /* 23 */ {0, {312,454,328,502}, EDITTEXT, ""},
+ /* 24 */ {0, {312,514,328,595}, EDITTEXT, ""},
+ /* 25 */ {0, {340,324,356,450}, MESSAGE, N_("Not connected:")},
+ /* 26 */ {0, {340,454,356,502}, EDITTEXT, ""},
+ /* 27 */ {0, {340,514,356,595}, EDITTEXT, ""},
  /* 28 */ {0, {368,308,384,396}, MESSAGE, N_("Multiple cuts:")},
  /* 29 */ {0, {392,324,408,450}, MESSAGE, N_("When connected:")},
  /* 30 */ {0, {392,454,408,502}, EDITTEXT, ""},
@@ -1484,16 +1535,19 @@ DIALOGITEM us_rulesdialogitems[] =
  /* 32 */ {0, {420,324,436,450}, MESSAGE, N_("Not connected:")},
  /* 33 */ {0, {420,454,436,502}, EDITTEXT, ""},
  /* 34 */ {0, {420,514,436,595}, EDITTEXT, ""},
- /* 35 */ {0, {216,452,232,523}, MESSAGE, N_("Distance")},
- /* 36 */ {0, {216,528,232,583}, MESSAGE, N_("Rule")},
+ /* 35 */ {0, {180,452,196,523}, MESSAGE, N_("Distance")},
+ /* 36 */ {0, {180,528,196,583}, MESSAGE, N_("Rule")},
  /* 37 */ {0, {24,328,48,488}, BUTTON, N_("Factory Reset of Rules")},
- /* 38 */ {0, {292,526,308,574}, EDITTEXT, ""}
+ /* 38 */ {0, {288,526,304,574}, EDITTEXT, ""},
+ /* 39 */ {0, {260,324,276,450}, MESSAGE, N_("Edge:")},
+ /* 40 */ {0, {260,454,276,502}, EDITTEXT, ""},
+ /* 41 */ {0, {260,514,276,595}, EDITTEXT, ""}
 };
-DIALOG us_rulesdialogdesc = {{50,75,495,680}, N_("Design Rules"), 0, 38, us_rulesdialogitems};
+static DIALOG us_rulesdialogdesc = {{50,75,495,680}, N_("Design Rules"), 0, 41, us_rulesdialogitems};
 
-void       us_loaddrcdialog(DRCRULES *rules);
-void       us_loaddrcdistance(DRCRULES *rules);
-char      *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex);
+static void       us_loaddrcdialog(DRCRULES *rules);
+static void       us_loaddrcdistance(DRCRULES *rules);
+static char      *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex);
 
 /* special items for the "DRC Rules" dialog: */
 #define DDRR_FROMLAYER     3		/* From layer (scroll) */
@@ -1515,6 +1569,8 @@ char      *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex);
 #define DDRR_UCONDISTMR   34		/* Unconnected multi distance rule (edit text) */
 #define DDRR_FACTORYRST   37		/* Factor Reset (button) */
 #define DDRR_WIDELIMIT    38		/* Wide limit (edit text) */
+#define DDRR_EDGEDIST     40		/* Edge distance (edit text) */
+#define DDRR_EDGEDISTR    41		/* Edge distance rule (edit text) */
 
 /*
  * Routine to implement a dialog for design rule editing.  This is called from the design-rule checker
@@ -1532,9 +1588,9 @@ char      *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex);
  */
 INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 {
-	REGISTER INTBIG itemHit, i, dist, layer1, layer2, temp, dindex;
+	REGISTER INTBIG itemHit, i, j, dist, layer1, layer2, temp, dindex;
 	REGISTER INTSML changed;
-	REGISTER char *pt;
+	REGISTER char *pt, *varname;
 
 	if (DiaInitDialog(&us_rulesdialogdesc) != 0) return(0);
 	DiaInitTextDialog(DDRR_FROMLAYER, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, 0,
@@ -1560,8 +1616,10 @@ INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 	{
 		itemHit = DiaNextHit();
 		if (itemHit == OK || itemHit == CANCEL || itemHit == DDRR_FACTORYRST) break;
-		if (itemHit == DDRR_CONDIST || itemHit == DDRR_UCONDIST || itemHit == DDRR_CONDISTW ||
-			itemHit == DDRR_UCONDISTW || itemHit == DDRR_CONDISTM || itemHit == DDRR_UCONDISTM)
+		if (itemHit == DDRR_CONDIST || itemHit == DDRR_UCONDIST ||
+			itemHit == DDRR_CONDISTW || itemHit == DDRR_UCONDISTW ||
+			itemHit == DDRR_CONDISTM || itemHit == DDRR_UCONDISTM ||
+			itemHit == DDRR_EDGEDIST)
 		{
 			/* typed into distance field */
 			i = DiaGetCurLine(DDRR_TOLAYER);
@@ -1599,14 +1657,20 @@ INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 			{
 				if (rules->unconlistM[dindex] != dist) changed++;
 				rules->unconlistM[dindex] = dist;
+			} else if (itemHit == DDRR_EDGEDIST)
+			{
+				if (rules->edgelist[dindex] != dist) changed++;
+				rules->edgelist[dindex] = dist;
 			}
 
 			pt = us_loadoptlistline(rules, dindex, i);
 			DiaSetScrollLine(DDRR_TOLAYER, i, pt);
 			continue;
 		}
-		if (itemHit == DDRR_CONDISTR || itemHit == DDRR_UCONDISTR || itemHit == DDRR_CONDISTWR ||
-			itemHit == DDRR_UCONDISTWR || itemHit == DDRR_CONDISTMR || itemHit == DDRR_UCONDISTMR)
+		if (itemHit == DDRR_CONDISTR || itemHit == DDRR_UCONDISTR ||
+			itemHit == DDRR_CONDISTWR || itemHit == DDRR_UCONDISTWR ||
+			itemHit == DDRR_CONDISTMR || itemHit == DDRR_UCONDISTMR ||
+			itemHit == DDRR_EDGEDISTR)
 		{
 			/* typed into rule field */
 			i = DiaGetCurLine(DDRR_TOLAYER);
@@ -1641,6 +1705,10 @@ INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 			{
 				if (strcmp(rules->unconlistMR[dindex], pt) != 0) changed++;
 				(void)reallocstring(&rules->unconlistMR[dindex], pt, el_tempcluster);
+			} else if (itemHit == DDRR_EDGEDISTR)
+			{
+				if (strcmp(rules->edgelistR[dindex], pt) != 0) changed++;
+				(void)reallocstring(&rules->edgelistR[dindex], pt, el_tempcluster);
 			}
 			continue;
 		}
@@ -1693,7 +1761,27 @@ INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 	if (itemHit != OK) changed = 0;
 	if (itemHit == DDRR_FACTORYRST)
 	{
-		/* "factory reset" was clicked */
+		/* "factory reset" was clicked, start by deleting all DRC variables */
+		for(j=0; dr_variablenames[j] != 0; j++)
+		{
+			if (getval((INTBIG)tech, VTECHNOLOGY, -1, dr_variablenames[j]) == NOVARIABLE) continue;
+			delval((INTBIG)tech, VTECHNOLOGY, dr_variablenames[j]);
+		}
+
+		/* set all technology-defined DRC variables */
+		for(i=0; tech->variables[i].name != 0; i++)
+		{
+			varname = tech->variables[i].name;
+			for(j=0; dr_variablenames[j] != 0; j++)
+				if (namesame(varname, dr_variablenames[j]) == 0) break;
+			if (dr_variablenames[j] == 0) continue;
+
+			/* reset the variable */
+			if (setval((INTBIG)tech, VTECHNOLOGY, tech->variables[i].name,
+				(INTBIG)tech->variables[i].value, tech->variables[i].type & ~VDONTSAVE) == NOVARIABLE) break;
+		}
+
+		/* call the technology-specific routine to do any extra work */
 		(void)asktech(tech, "factory-reset");
 	}
 	return(changed);
@@ -1702,7 +1790,6 @@ INTSML dr_rulesdialog(TECHNOLOGY *tech, DRCRULES *rules)
 void us_loaddrcdialog(DRCRULES *rules)
 {
 	REGISTER INTBIG i, j, layer1, layer2, temp, dindex;
-	REGISTER INTBIG *list;
 	REGISTER char *line;
 
 	j = DiaGetCurLine(DDRR_FROMLAYER);
@@ -1710,8 +1797,6 @@ void us_loaddrcdialog(DRCRULES *rules)
 		DiaSetText(DDRR_MINWIDTH, frtoa(rules->minwidth[j]));
 	DiaSetText(DDRR_MINWIDTHR, rules->minwidthR[j]);
 	DiaLoadTextDialog(DDRR_TOLAYER, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, 0);
-	if (DiaGetControl(11) != 0) list = rules->unconlist; else
-		list = rules->conlist;
 	for(i=0; i<rules->numlayers; i++)
 	{
 		layer1 = j;
@@ -1728,7 +1813,8 @@ void us_loaddrcdialog(DRCRULES *rules)
 
 char *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex)
 {
-	REGISTER char *condist, *uncondist, *wcondist, *wuncondist, *mcondist, *muncondist;
+	REGISTER char *condist, *uncondist, *wcondist, *wuncondist,
+		*mcondist, *muncondist, *edgedist;
 
 	if (rules->conlist[dindex] < 0) condist = ""; else
 		condist = frtoa(rules->conlist[dindex]);
@@ -1742,9 +1828,11 @@ char *us_loadoptlistline(DRCRULES *rules, INTBIG dindex, INTBIG lindex)
 		mcondist = frtoa(rules->conlistM[dindex]);
 	if (rules->unconlistM[dindex] < 0) muncondist = ""; else
 		muncondist = frtoa(rules->unconlistM[dindex]);
+	if (rules->edgelist[dindex] < 0) edgedist = ""; else
+		edgedist = frtoa(rules->edgelist[dindex]);
 	(void)initinfstr();
-	(void)formatinfstr("%s (%s/%s/%s/%s/%s/%s)", rules->layernames[lindex],
-		condist, uncondist, wcondist, wuncondist, mcondist, muncondist);
+	(void)formatinfstr("%s (%s/%s/%s/%s/%s/%s/%s)", rules->layernames[lindex],
+		condist, uncondist, wcondist, wuncondist, mcondist, muncondist, edgedist);
 	return(returninfstr());
 }
 
@@ -1771,16 +1859,20 @@ void us_loaddrcdistance(DRCRULES *rules)
 		DiaSetText(DDRR_CONDISTM, frtoa(rules->conlistM[dindex]));
 	if (rules->unconlistM[dindex] < 0) DiaSetText(DDRR_UCONDISTM, ""); else
 		DiaSetText(DDRR_UCONDISTM, frtoa(rules->unconlistM[dindex]));
+	if (rules->edgelist[dindex] < 0) DiaSetText(DDRR_EDGEDIST, ""); else
+		DiaSetText(DDRR_EDGEDIST, frtoa(rules->edgelist[dindex]));
+
 	DiaSetText(DDRR_CONDISTR, rules->conlistR[dindex]);
 	DiaSetText(DDRR_UCONDISTR, rules->unconlistR[dindex]);
 	DiaSetText(DDRR_CONDISTWR, rules->conlistWR[dindex]);
 	DiaSetText(DDRR_UCONDISTWR, rules->unconlistWR[dindex]);
 	DiaSetText(DDRR_CONDISTMR, rules->conlistMR[dindex]);
 	DiaSetText(DDRR_UCONDISTMR, rules->unconlistMR[dindex]);
+	DiaSetText(DDRR_EDGEDISTR, rules->edgelistR[dindex]);
 }
 
 /* DRC error */
-DIALOGITEM dr_errdialogitems[] =
+static DIALOGITEM dr_errdialogitems[] =
 {
  /*  1 */ {0, {88,40,112,104}, BUTTON, N_("OK")},
  /*  2 */ {0, {128,232,152,360}, BUTTON, N_("Stop Checking")},
@@ -1792,7 +1884,7 @@ DIALOGITEM dr_errdialogitems[] =
  /*  8 */ {0, {160,232,184,360}, BUTTON, N_("Stop Checking")},
  /*  9 */ {0, {160,96,184,224}, BUTTON, N_("Continue Silently")}
 };
-DIALOG dr_errdialog = {{50,75,243,444}, N_("DRC Violation"), 0, 9, dr_errdialogitems};
+static DIALOG dr_errdialog = {{50,75,243,444}, N_("DRC Violation"), 0, 9, dr_errdialogitems};
 
 /* special items for "DRC error" dialog: */
 #define DDRE_QUITNOW      2		/* Quit-checking, for now (button) */
@@ -1839,4 +1931,4 @@ char *dr_errordlog(char *prompt)
 	return(ret);
 }
 
-#endif  /* DRCAID - at top */
+#endif  /* DRCTOOL - at top */
