@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if DRCAID
+#if DRCTOOL
 
 #include "global.h"
 #include "drc.h"
@@ -53,11 +53,11 @@ static char        dr_yminfile[132];
 static char        dr_ymaxfile[132];
 
 /* prototypes for local routines */
-INTSML dr_readshorterrors(INTBIG);
-void   dr_flatprint(NODEPROTO*, XARRAY);
-void   dr_transistor_hack(POLYGON*, NODEINST*);
-void   dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO*);
-void   dr_flatprop(ARCINST*, INTBIG);
+static INTSML dr_readshorterrors(INTBIG);
+static void   dr_flatprint(NODEPROTO*, XARRAY);
+static void   dr_transistor_hack(POLYGON*, NODEINST*);
+static void   dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO*);
+static void   dr_flatprop(ARCINST*, INTBIG);
 
 /*
  * routine to flag facet "facet" as ignorable for flat DRC
@@ -340,7 +340,7 @@ INTSML dr_readshorterrors(INTBIG where)
 				if (errors == 0)
 				{
 					/* start by removing any highlighting */
-					(void)askaid(us_aid, "clear");
+					(void)asktool(us_tool, "clear");
 					flushscreen(); /* empty graphics buffer */
 				}
 
@@ -351,7 +351,7 @@ INTSML dr_readshorterrors(INTBIG where)
 				layname = layername(dr_maintech, atoi(layer));
 				ttyputmsg(_("Error on %s layer from X(%s...%s) Y(%s...%s)"),
 					layname, latoa(lx), latoa(hx), latoa(ly), latoa(hy));
-				(void)askaid(us_aid, "show-area", lx, hx, ly, hy, el_curwindowpart->curnodeproto);
+				(void)asktool(us_tool, "show-area", lx, hx, ly, hy, el_curwindowpart->curnodeproto);
 				flushscreen(); /* empty graphics buffer */
 				errors++;
 			} else if (line[0] == '*')
@@ -390,7 +390,7 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 	for(i = 0; i < dr_nflat_ignored; i++) if (facet == dr_flatignored[i]) return;
 
 	/* make sure there is a polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, dr_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, dr_tool->cluster);
 
 	/* reset the arcinst node values */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -518,6 +518,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 	REGISTER PORTPROTO *pp, *spp;
 	REGISTER PORTARCINST *pi, *spi;
 	REGISTER INTSML drain, portnum, type;
+	INTBIG edge;
 	REGISTER TECH_NODES *thistn;
 
 	type = (INTSML)((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
@@ -566,7 +567,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 		active_overlap = st->lwidth + st->rwidth;
 		i=0; do lay = &thistn->ele[i++].basics; while (lay->portnum != 0);
 		gate_min_distance = (INTSML)drcmindistance(ni->proto->tech, ni->parent->cell->lib,
-			lay->layernum, 0, lay->layernum, 0, 0, 0, 0);
+			lay->layernum, 0, lay->layernum, 0, 0, 0, &edge, 0);
 		if (active_overlap > gate_min_distance)
 		{
 			correction = ((active_overlap - gate_min_distance) / WHOLE) * lambda;
@@ -690,4 +691,4 @@ void dr_flatprop(ARCINST *ai, INTBIG nindex)
 	}
 }
 
-#endif  /* DRCAID - at top */
+#endif  /* DRCTOOL - at top */
