@@ -245,26 +245,6 @@ void CChildFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 		controlkeydown = 0;
 	if ((GetKeyState(VK_SHIFT) & 0x8000) != 0) shiftkeydown = 2; else
 		shiftkeydown = 0;
-	if (nChar == VK_NUMPAD0 && controlkeydown != 0)
-		{ gra_keyaction('0'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD1 && controlkeydown != 0)
-		{ gra_keyaction('1'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD2 && controlkeydown != 0)
-		{ gra_keyaction('2'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD3 && controlkeydown != 0)
-		{ gra_keyaction('3'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD4 && controlkeydown != 0)
-		{ gra_keyaction('4'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD5 && controlkeydown != 0)
-		{ gra_keyaction('5'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD6 && controlkeydown != 0)
-		{ gra_keyaction('6'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD7 && controlkeydown != 0)
-		{ gra_keyaction('7'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD8 && controlkeydown != 0)
-		{ gra_keyaction('8'+0200, nFlags, nRepCnt); return; }
-	if (nChar == VK_NUMPAD9 && controlkeydown != 0)
-		{ gra_keyaction('9'+0200, nFlags, nRepCnt); return; }
 
 	/* handle function keys */
 	if (nChar == VK_F1) { gra_keyaction(FUNCTIONF1, nFlags, nRepCnt); return; }
@@ -280,6 +260,31 @@ void CChildFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	if (nChar == VK_F11) { gra_keyaction(FUNCTIONF11, nFlags, nRepCnt); return; }
 	if (nChar == VK_F12) { gra_keyaction(FUNCTIONF12, nFlags, nRepCnt); return; }
 
+	/* handle control keys */
+	if (controlkeydown != 0)
+	{
+		if (nChar == VK_NUMPAD0)
+			{ gra_keyaction('0'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD1)
+			{ gra_keyaction('1'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD2)
+			{ gra_keyaction('2'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD3)
+			{ gra_keyaction('3'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD4)
+			{ gra_keyaction('4'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD5)
+			{ gra_keyaction('5'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD6)
+			{ gra_keyaction('6'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD7)
+			{ gra_keyaction('7'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD8)
+			{ gra_keyaction('8'+0200, nFlags, nRepCnt); return; }
+		if (nChar == VK_NUMPAD9)
+			{ gra_keyaction('9'+0200, nFlags, nRepCnt); return; }
+	}
+
 	if ((nFlags&0x100) != 0)
 	{
 		if (nChar == VK_DELETE)
