@@ -114,6 +114,6 @@ void CElectricMsgView::OnSize(UINT nType, int cx, int cy)
 
 	CEditView::OnSize(nType, cx, cy);
 
-	if (cx != 0 && cy != 0)
+	if (cx != 0 && cy != 0 && gra_messageswindow != 0)
 		gra_resize(gra_messageswindow, cx, cy);
 }
