@@ -14,6 +14,9 @@
 #define IDC_CURSORTTY                   135
 #define IDD_DIALOG2                     136
 #define IDD_DIALOG3                     137
+#define IDD_DIALOG4                     139
+#define IDB_BITMAP1                     140
+#define IDB_BITMAP2                     142
 #define ID_ELECTRIC_MENU01              32772
 #define ID_ELECTRIC_MENU02              32773
 #define ID_ELECTRIC_MENU03              32774
@@ -43,6 +46,7 @@
 #define ID_ELECTRIC_MENU27              32798
 #define ID_ELECTRIC_MENU28              32799
 #define ID_ELECTRIC_MENU29              32800
+#define ID_ACCELERATOR_EX               32801
 #define ID_ACCELERATOR_A                40000
 #define ID_ACCELERATOR_B                40001
 #define ID_ACCELERATOR_C                40002
@@ -163,8 +167,8 @@
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_3D_CONTROLS                     1
-#define _APS_NEXT_RESOURCE_VALUE        139
-#define _APS_NEXT_COMMAND_VALUE         32801
+#define _APS_NEXT_RESOURCE_VALUE        143
+#define _APS_NEXT_COMMAND_VALUE         32802
 #define _APS_NEXT_CONTROL_VALUE         1000
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
