@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: compact.h
- * One-dimensional compactor aid
+ * One-dimensional compactor tool
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -33,7 +33,7 @@ extern "C"
 {
 #endif
 
-void com_init(INTBIG*, char*[], AIDENTRY*);
+void com_init(INTBIG*, char*[], TOOL*);
 void com_done(void);
 INTSML com_set(INTSML, char*[]);
 void com_slice(void);
