@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: compensate.h
- * Aid for compensating geometry
+ * Tool for compensating geometry
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -33,7 +33,7 @@ extern "C"
 {
 #endif
 
-void compen_init(INTBIG*, char*[], AIDENTRY*);
+void compen_init(INTBIG*, char*[], TOOL*);
 void compen_done(void);
 INTSML compen_set(INTSML, char*[]);
 void compen_slice(void);
