@@ -116,22 +116,23 @@
 /********************* SOURCE MODULE CONFIGURATION *********************/
 
 /* The tools (User and I/O are always enabled) */
-#define COMAID             1
-#define COMPENAID          1
-#define DRCAID             1
-#define ERCAID             1
-#define LOGEFFAID          1
-#define MAPPERAID          0
-#define PLAAID             1
-#define PROJECTAID         1
-#define ROUTAID            1
-#define SCAID              1
-#define SIMAID             1
-#define VHDLAID            1
+#define COMTOOL            1
+#define COMPENTOOL         1
+#define DRCTOOL            1
+#define ERCTOOL            1
+#define LOGEFFTOOL         1
+#define MAPPERTOOL         0
+#define PLATOOL            1
+#define PROJECTTOOL        1
+#define ROUTTOOL           1
+#define SCTOOL             1
+#define SIMTOOL            1
+#define VHDLTOOL           1
 
 /* special features of tools */
-#define ROUTAIDSUN         FORCESUNTOOLS
-#define LOGEFFAIDSUN       FORCESUNTOOLS
+#define ROUTTOOLSUN         FORCESUNTOOLS
+#define SIMTOOLIRSIM        FORCEIRSIMTOOL
+#define LOGEFFTOOLSUN       FORCESUNTOOLS
 
 /* The I/O modules (Binary, Text, and printer formats are always enabled) */
 #define IOCIF              1
@@ -159,6 +160,7 @@
 #define TECMOCMOS          1
 #define TECMOCMOSOLD       1
 #define TECMOCMOSSUB       1
+#define TECMOCMOS2         0
 #define TECNMOS            1
 #define TECPCB             1
 #define TECRCMOS           1
