@@ -61,7 +61,6 @@ typedef struct
 
 /***************** FOR THE TEXT-TO-GRAPHICS SYSTEM *************/
 
-extern char      *cli_linconops[];
 extern NODEPROTO *cli_curfacet;		/* the current facet being equated to text */
 extern INTSML     cli_ownchanges;	/* set if changes are internally generated */
 extern INTSML     cli_textlines;	/* number of declaration/connection lines */
@@ -195,11 +194,11 @@ void cli_linconmodifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML,
 void cli_linconmodifyarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void cli_linconmodifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
 void cli_linconmodifynodeproto(NODEPROTO*);
-void cli_linconmodifydescript(INTBIG, INTBIG, INTBIG, INTBIG);
+void cli_linconmodifydescript(INTBIG, INTBIG, INTBIG, UINTBIG*);
 void cli_linconnewlib(LIBRARY*);
 void cli_linconkilllib(LIBRARY*);
 void cli_linconnewvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void cli_linconkillvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void cli_linconkillvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, UINTBIG*);
 void cli_linconmodifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void cli_linconinsertvariable(INTBIG, INTBIG, INTBIG, INTBIG);
 void cli_lincondeletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
