@@ -110,37 +110,12 @@ typedef struct Ichangebatch
 	struct Ichangebatch *nextchangebatch;	/* next in list */
 	struct Ichangebatch *lastchangebatch;	/* last in list */
 	CHANGEFACET         *firstchangefacet;	/* the facet in which this change was made */
-	AIDENTRY            *aid;				/* aid that made this batch */
+	TOOL                *tool;				/* tool that made this batch */
 	char                *activity;			/* description of activity */
 	INTBIG               batchnumber;		/* identifying index of this batch */
 	INTSML               done;				/* nonzero if this batch was done */
 } CHANGEBATCH;
 
-/*************************** MEMORY ALLOCATION ****************************/
-
-/*
- * the original memory allocation scheme presumed that it would be more
- * efficient to allocate many of a given object whenever more are needed.
- * A linked list of unused objects would then be maintained, and only when
- * the list was empty would the system allocate more.  Freeing simply added
- * the object to the unused list.
- *
- * One problem, though, is that for very large libraries that have been
- * edited for a long time, the memory arena gets fragmented as bits of
- * the library get scattered throughout memory.  On virtual machines with
- * small amounts of physical memory, this causes painful thrashing, because
- * a small facet may require hundreds of page faults simply to display.
- *
- * The solution is to break memory into clusters of activity, as is
- * documented in the module "dbmemory.c".  When using clustering, however,
- * one cannot do bulk allocation because each object might need to be
- * allocated from a different cluster.
- */
-
-extern CLUSTER     *db_clusterfree;			/* list of free memory clusters */
-extern CLUSTER     *db_firstcluster;		/* top of list of clusters */
-extern WINDOWPART  *db_windowpartfree;		/* top of free list of windows */
-
 /*************************** BOX MERGING ****************************/
 
 /* box descriptor */
@@ -178,18 +153,6 @@ typedef struct Ipolylisthead
 	INTSML             numedge, modified;
 } POLYLISTHEAD;
 
-/* polygon edge ring head name */
-extern POLYLISTHEAD db_mrg_polycoordlist;
-
-/* free list heads */
-extern POLYCOORD   *db_mrg_free_poly_list;
-extern BOXPOLY     *db_mrg_free_box_list;
-extern BOXLISTHEAD *db_mrg_free_boxhead_list;
-
-extern BOXLISTHEAD *db_mrg_curr_facet;
-
-extern POLYGON     *db_staticpolygons;
-
 /*************************** ERROR CODES ****************************/
 
 /* error messages */
@@ -296,6 +259,7 @@ extern INTBIG  db_tech_arc_width_offset;		/* variable "TECH_arc_width_offset" */
 
 extern INTSML  db_donextchangequietly;			/* nonzero to do next change quietly */
 extern INTSML  db_dochangesquietly;				/* nonzero to do changes quietly */
+extern UINTBIG db_changetimestamp;				/* timestamp for changes to database */
 
 /*************************** PROTOTYPES ****************************/
 
@@ -319,6 +283,7 @@ CELL        *db_findcellname(char*, LIBRARY*);
 void         db_forcehierarchicalanalysis(NODEPROTO*);
 void         db_freearcproto(ARCPROTO *ap);
 void         db_freechangememory(void);
+void         db_freeerrormemory(void);
 void         db_freegeomemory(void);
 void         db_freemathmemory(void);
 void         db_freemergememory(void);
@@ -360,10 +325,8 @@ void         db_retractnodeproto(NODEPROTO*);
 void         db_retractportproto(PORTPROTO*);
 void         db_retractwindowpart(WINDOWPART *w);
 void         db_rtnbbox(RTNODE*, INTSML, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-void         db_scalearcinst(ARCINST *ai, INTBIG num, INTBIG denom);
-void         db_scalenodeinst(NODEINST *ni, INTBIG num, INTBIG denom);
 void         db_setchangefacet(NODEPROTO*);
-void         db_setcurrenttool(AIDENTRY*);
+void         db_setcurrenttool(TOOL*);
 INTSML       db_stillinport(ARCINST*, INTSML, INTBIG, INTBIG);
 void         db_termlanguage(void);
 void         db_undodlog(void);
