@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: drc.h
- * Design-rule check aid
+ * Design-rule check tool
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -61,9 +61,11 @@ typedef struct
 	char   **conlistMR;			/* minimum distance rules when connected (multi-cut) */
 	INTBIG  *unconlistM;		/* minimum distances when unconnected (multi-cut) */
 	char   **unconlistMR;		/* minimum distance rules when unconnected (multi-cut) */
+	INTBIG  *edgelist;			/* edge distances */
+	char   **edgelistR;			/* edge distance rules */
 } DRCRULES;
 
-extern AIDENTRY *dr_aid;							/* the DRC aid object */
+extern TOOL     *dr_tool;							/* the DRC tool object */
 extern INTBIG    dr_max_distanceskey;				/* key for "DRC_max_distances" */
 extern INTBIG    dr_wide_limitkey;					/* key for "DRC_wide_limit" */
 extern INTBIG    dr_min_widthkey;					/* key for "DRC_min_width" */
@@ -82,11 +84,13 @@ extern INTBIG    dr_connected_distancesMkey;		/* key for "DRC_min_connected_dist
 extern INTBIG    dr_connected_distancesM_rulekey;	/* key for "DRC_min_connected_distances_multi_rule" */
 extern INTBIG    dr_unconnected_distancesMkey;		/* key for "DRC_min_unconnected_distances_multi" */
 extern INTBIG    dr_unconnected_distancesM_rulekey;	/* key for "DRC_min_unconnected_distances_multi_rule" */
-extern INTBIG    dr_ignore_listkey;					/* key for aid:drc.DRC_ignore_list */
+extern INTBIG    dr_edge_distanceskey;				/* key for "DRC_min_edge_distances" */
+extern INTBIG    dr_edge_distances_rulekey;			/* key for "DRC_min_edge_distances_rule" */
+extern INTBIG    dr_ignore_listkey;					/* key for tool:drc.DRC_ignore_list */
 extern INTBIG    dr_lastgooddrckey;					/* key for "DRC_last_good_drc" */
 extern INTBIG    dr_options;						/* cached options */
 
-void     dr_init(INTBIG*, char*[], AIDENTRY*);
+void     dr_init(INTBIG*, char*[], TOOL*);
 void     dr_done(void);
 INTSML   dr_set(INTSML, char*[]);
 void     dr_examinenodeproto(NODEPROTO*);
@@ -109,7 +113,7 @@ void      dr_freerules(DRCRULES *rules);
 INTBIG    drcb_check(NODEPROTO*);
 INTSML    drcb_debug(void);
 void      drcb_reset_dates(void);
-INTSML    drcb_initincrementalcheck(NODEPROTO *facet);
+void      drcb_initincrementalcheck(NODEPROTO *facet);
 INTSML    drcb_checkincremental(GEOM *geom, INTSML partial);
 void      drcb_term(void);
 
