@@ -61,7 +61,9 @@
  * DiaLoadTextDialog(item, top, next, done, sortpos)
  * DiaStuffLine(item, msg)              add line "msg" to item "item"
  * DiaSelectLine(item, l)               select line "l" in item "item"
+ * DiaSelectLines(item, c, l)           select "c" lines in "l" in item "item"
  * which = DiaGetCurLine(item)          get current line number in scroll item "item"
+ * *which = DiaGetCurLines(item)        get array of selected lines in scroll item "item"
  * msg = DiaGetScrollLine(item, l)      get line "l" in scroll item "item"
  * DiaSetScrollLine(item, l, msg)       set line "l" in scroll item "item"
  *
@@ -92,23 +94,24 @@ extern "C"
 #define CHECK        2			/* standard check-box */
 #define RADIO        3			/* standard radio-button */
 #define SCROLL       4			/* scrolling list of text */
-#define MESSAGE      5			/* non-editable text */
-#define EDITTEXT     6			/* editable text */
-#define ICON         7			/* 32x32 icon */
-#define USERDRAWN  010			/* open area for user graphics */
-#define POPUP      011			/* popup menu */
-#define PROGRESS   012			/* progress bar (0-100%) */
-#define DIVIDELINE 013			/* dividing line */
+#define SCROLLMULTI  5			/* scrolling list of text (multiple lines can be selected) */
+#define MESSAGE      6			/* non-editable text */
+#define EDITTEXT     7			/* editable text */
+#define ICON       010			/* 32x32 icon */
+#define USERDRAWN  011			/* open area for user graphics */
+#define POPUP      012			/* popup menu */
+#define PROGRESS   013			/* progress bar (0-100%) */
+#define DIVIDELINE 014			/* dividing line */
 #define INACTIVE  0200
 
 /* the last parameter to "DiaInitTextDialog" */
-#define SCSELMOUSE    1			/* mouse clicks select in scroll area */
-#define SCSELKEY      2			/* key strokes select in scroll area */
-#define SCDOUBLEQUIT  4			/* double-click in scroll area exits dialog */
-#define SCREPORT      8			/* report selections in the scroll area */
-#define SCHORIZBAR   16			/* want horizontal scroll-bar in scroll area */
-#define SCSMALLFONT  32			/* want small text in scroll area */
-#define SCFIXEDWIDTH 64			/* want fixed-width text in scroll area */
+#define SCSELMOUSE      1		/* mouse clicks select in scroll area */
+#define SCSELKEY        2		/* key strokes select in scroll area */
+#define SCDOUBLEQUIT    4		/* double-click in scroll area exits dialog */
+#define SCREPORT        8		/* report selections in the scroll area */
+#define SCHORIZBAR     16		/* want horizontal scroll-bar in scroll area */
+#define SCSMALLFONT    32		/* want small text in scroll area */
+#define SCFIXEDWIDTH   64		/* want fixed-width text in scroll area */
 
 /* the mode to "DiaDrawLine" */
 #define DLMODEON      1			/* draw the line on */
@@ -133,53 +136,56 @@ typedef struct
 } DIALOG;
 
 /* prototypes for dialog routines */
-void   DiaCharacterEdit(INTBIG item);
-void   DiaDeclareHook(char *terminputkeyword, COMCOMP *getlinecomp, void (*routine)(void));
-void   DiaDefaultButton(INTBIG item);
-void   DiaDimItem(INTBIG item);
-void   DiaDoneDialog(void);
-void   DiaDrawLine(INTBIG item, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG mode);
-void   DiaDrawRect(INTBIG item, RECTAREA *rect, INTBIG r, INTBIG g, INTBIG b);
-void   DiaEditControl(INTBIG item);
-void   DiaFillPoly(INTBIG item, INTBIG *x, INTBIG *y, INTBIG count, INTBIG r, INTBIG g, INTBIG b);
-void   DiaFrameRect(INTBIG item, RECTAREA *r);
-INTBIG DiaGetControl(INTBIG item);
-INTBIG DiaGetCurLine(INTBIG item);
-void   DiaGetMouse(INTSML *x, INTSML *y);
-INTSML DiaGetNextCharacter(INTBIG *item);
-INTBIG DiaGetPopupEntry(INTBIG item);
-char  *DiaGetScrollLine(INTBIG item, INTBIG which);
-char  *DiaGetText(INTBIG item);
-void   DiaGetTextInfo(char *msg, INTBIG *wid, INTBIG *hei);
-INTSML DiaInitDialog(DIALOG *dialog);
-void   DiaInitTextDialog(INTBIG item, INTSML (*toplist)(char **),
-		char *(*nextinlist)(void), void (*donelist)(void),
-		INTBIG sortpos, INTBIG flags);
-void   DiaItemRect(INTBIG item, RECTAREA *rect);
-void   DiaLoadTextDialog(INTBIG item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
-		void (*donelist)(void), INTBIG sortpos);
-INTBIG DiaNextHit(void);
-void   DiaNoEditControl(INTBIG item);
-void   DiaOpaqueEdit(INTBIG item);
-void   DiaPercent(INTBIG item, INTBIG p);
-void   DiaPutText(INTBIG item, char *msg, INTBIG x, INTBIG y);
-void   DiaRedispRoutine(INTBIG item, void (*routine)(RECTAREA*));
-void   DiaSelectLine(INTBIG item, INTBIG which);
-void   DiaSetControl(INTBIG item, INTBIG value);
-void   DiaSetPopup(INTBIG item, INTBIG count, char **names);
-void   DiaSetPopupEntry(INTBIG item, INTBIG entry);
-void   DiaSetScrollLine(INTBIG item, INTBIG which, char *msg);
-void   DiaSetText(INTBIG item, char *msg);
-void   DiaStuffLine(INTBIG item, char *line);
-void   DiaUnDimItem(INTBIG item);
-INTSML DiaValidEntry(INTBIG item);
+void    DiaCharacterEdit(INTBIG item);
+void    DiaDeclareHook(char *terminputkeyword, COMCOMP *getlinecomp, void (*routine)(void));
+void    DiaDefaultButton(INTBIG item);
+void    DiaDimItem(INTBIG item);
+void    DiaDoneDialog(void);
+void    DiaDrawLine(INTBIG item, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG mode);
+void    DiaDrawRect(INTBIG item, RECTAREA *rect, INTBIG r, INTBIG g, INTBIG b);
+void    DiaEditControl(INTBIG item);
+void    DiaFillPoly(INTBIG item, INTBIG *x, INTBIG *y, INTBIG count, INTBIG r, INTBIG g, INTBIG b);
+void    DiaFrameRect(INTBIG item, RECTAREA *r);
+INTBIG  DiaGetControl(INTBIG item);
+INTBIG  DiaGetCurLine(INTBIG item);
+INTBIG *DiaGetCurLines(INTBIG item);
+void    DiaGetMouse(INTSML *x, INTSML *y);
+INTSML  DiaGetNextCharacter(INTBIG *item);
+INTBIG  DiaGetPopupEntry(INTBIG item);
+char   *DiaGetScrollLine(INTBIG item, INTBIG which);
+char   *DiaGetText(INTBIG item);
+void    DiaGetTextInfo(char *msg, INTBIG *wid, INTBIG *hei);
+INTSML  DiaInitDialog(DIALOG *dialog);
+void    DiaInitTextDialog(INTBIG item, INTSML (*toplist)(char **),
+			char *(*nextinlist)(void), void (*donelist)(void),
+			INTBIG sortpos, INTBIG flags);
+void    DiaItemRect(INTBIG item, RECTAREA *rect);
+void    DiaLoadTextDialog(INTBIG item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
+			void (*donelist)(void), INTBIG sortpos);
+INTBIG  DiaNextHit(void);
+void    DiaNoEditControl(INTBIG item);
+void    DiaOpaqueEdit(INTBIG item);
+void    DiaPercent(INTBIG item, INTBIG p);
+void    DiaPutText(INTBIG item, char *msg, INTBIG x, INTBIG y);
+void    DiaRedispRoutine(INTBIG item, void (*routine)(RECTAREA*));
+void    DiaSelectLine(INTBIG item, INTBIG which);
+void    DiaSelectLines(INTBIG item, INTBIG count, INTBIG *lines);
+void    DiaSetControl(INTBIG item, INTBIG value);
+void    DiaSetPopup(INTBIG item, INTBIG count, char **names);
+void    DiaSetPopupEntry(INTBIG item, INTBIG entry);
+void    DiaSetScrollLine(INTBIG item, INTBIG which, char *msg);
+void    DiaSetText(INTBIG item, char *msg);
+void    DiaStuffLine(INTBIG item, char *line);
+void    DiaUnDimItem(INTBIG item);
+INTSML  DiaValidEntry(INTBIG item);
 
 /* a modeless dialog */
-void   DiaMessageInDialog(char*, ...);
+void    DiaMessageInDialog(char*, ...);
 
-INTSML DiaNullDlogList(char**);
-char  *DiaNullDlogItem(void);
-void   DiaNullDlogDone(void);
+INTSML  DiaNullDlogList(char**);
+char   *DiaNullDlogItem(void);
+void    DiaNullDlogDone(void);
+void    DiaTranslate(DIALOG *dia);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
