@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: eio.h
- * Input/output aid: header file
+ * Input/output tool: header file
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -72,7 +72,7 @@ extern "C"
 #define FPADS                   19		/* PADS netlist */
 #define FECAD                   20		/* ECAD netlist */
 
-/* aid:inout.IO_state: */
+/* tool:inout.IO_state: */
 #define NUMIOSTATEBITWORDS       2		/* number of words for these bits */
 
 #define CIFINSQUARE             01		/* 0: bit set for CIF input to square wires */
@@ -120,7 +120,6 @@ extern "C"
 extern FILE        *io_fileout;			/* channel for output */
 extern jmp_buf      io_filerror;		/* nonlocal jump when I/O fails */
 extern INTSML       io_cifbase;			/* index used when writing CIF */
-extern INTBIG       io_state;			/* key for "IO_state" */
 extern INTBIG       io_postscriptfilename;/* key for "IO_postscript_filename" */
 extern INTBIG       io_postscriptfiledate;/* key for "IO_postscript_filedate" */
 extern INTBIG       io_postscriptepsscale;/* key for "IO_postscript_EPS_scale" */
@@ -143,9 +142,10 @@ extern INTBIG       io_filetypesdf;		/* SDF disk file descriptor */
 extern INTBIG       io_filetypesue;		/* SUE disk file descriptor */
 extern INTBIG       io_filetypetlib;	/* Text library disk file descriptor */
 extern INTBIG       io_filetypevhdl;	/* VHDL disk file descriptor */
+extern INTBIG       io_libinputrecursivedepth;	/* for recursing when reading dependent libraries */
 
 /* prototypes for tool interface */
-void io_init(INTBIG*, char*[], AIDENTRY*);
+void io_init(INTBIG*, char*[], TOOL*);
 void io_done(void);
 INTSML io_set(INTSML, char*[]);
 INTBIG io_request(char*, va_list);
@@ -156,7 +156,6 @@ INTBIG    *io_getstatebits(void);
 void       io_setstatebits(INTBIG *bits);
 PORTPROTO *io_convertoldportname(char *portname, NODEPROTO *np);
 void       io_fixnewlib(LIBRARY *lib, INTBIG statusitem);
-void       io_setoutputbloat(char *layer, INTBIG amount);
 NODEPROTO *io_convertoldprimitives(TECHNOLOGY *tech, char *name);
 INTSML     io_setuptechorder(TECHNOLOGY *tech);
 INTSML     io_nextplotlayer(INTBIG i);
