@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: erc.h
- * Aid for electrical rules checking
+ * Tool for electrical rules checking
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -33,7 +33,7 @@ extern "C"
 {
 #endif
 
-void erc_init(INTBIG*, char*[], AIDENTRY*);
+void erc_init(INTBIG*, char*[], TOOL*);
 void erc_done(void);
 INTSML erc_set(INTSML, char*[]);
 
