@@ -265,7 +265,6 @@ INTBIG io_doneinterpreter(void);
 INTBIG io_initparser(void);
 INTSML io_infromfile(FILE*);
 INTSML io_parsefile(void);
-INTBIG io_parsestatement(void);
 INTBIG io_doneparser(void);
 INTSML io_fatalerrors(void);
 void io_iboundbox(INTBIG*, INTBIG*, INTBIG*, INTBIG*);
@@ -278,10 +277,8 @@ void io_bbbox(INTBIG, INTBIG, INTBIG, point, INTBIG, INTBIG, INTBIG*, INTBIG*, I
 char *io_makepath(void);
 void io_freepath(path);
 INTSML io_appendpoint(path, point);
-char *io_maketlist(void);
 tentry io_removetentry(tlist);
 INTBIG io_tlistlength(tlist);
-char *io_storename(char*);
 INTBIG io_findlayernum(char*);
 void io_outputusercommand(INTSML, char*);
 void io_outputds(INTBIG, char*, INTBIG, INTBIG, INTBIG, INTBIG);
