@@ -33,9 +33,9 @@ extern "C"
 {
 #endif
 
-extern AIDENTRY    *le_aid;				/* the Logical Effort aid object */
+extern TOOL    *le_tool;				/* the Logical Effort tool object */
 
-void le_init(INTBIG*, char*[], AIDENTRY*);
+void le_init(INTBIG*, char*[], TOOL*);
 void le_done(void);
 INTSML le_set(INTSML, char*[]);
 
