@@ -33,12 +33,12 @@ extern "C"
 {
 #endif
 
-extern AIDENTRY *pla_aid;
+extern TOOL     *pla_tool;
 extern INTBIG    pla_lam;				/* Feature size */
 extern INTBIG    pla_filetypeplatab;	/* PLA table disk file descriptor */
 
 /* prototypes for tool interface */
-void pla_init(INTBIG*, char*[], AIDENTRY*);
+void pla_init(INTBIG*, char*[], TOOL*);
 void pla_done(void);
 INTSML pla_set(INTSML, char*[]);
 void pla_slice(void);
