@@ -211,7 +211,7 @@ extern FILE   *pla_fin;					/* Pointer to the input file */
 #define END				21
 #define UNDEFINED       22
 
-extern AIDENTRY *pla_aid;		/* the PLA aid object */
+extern TOOL *pla_tool;		/* the PLA tool object */
 
 /* prototypes for intramodule routines */
 void pla_displayoptions(void);
