@@ -33,19 +33,19 @@ extern "C"
 {
 #endif
 
-void proj_init(INTBIG*, char*[], AIDENTRY*);
+void proj_init(INTBIG*, char*[], TOOL*);
 void proj_done(void);
 INTSML proj_set(INTSML, char*[]);
 void proj_slice(void);
-void proj_startbatch(AIDENTRY*, INTSML);
+void proj_startbatch(TOOL*, INTSML);
 void proj_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTSML,INTSML);
 void proj_modifyarcinst(ARCINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void proj_modifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
-void proj_modifydescript(INTBIG, INTBIG, INTBIG, INTBIG);
+void proj_modifydescript(INTBIG, INTBIG, INTBIG, UINTBIG*);
 void proj_newobject(INTBIG, INTBIG);
 void proj_killobject(INTBIG, INTBIG);
 void proj_newvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void proj_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void proj_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, UINTBIG*);
 void proj_modifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void proj_insertvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void proj_deletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
