@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: rout.h
- * Header file for the wire routing aid
+ * Header file for the wire routing tool
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -49,10 +49,9 @@ extern "C"
 #define MIMICUNROUTES        0100			/* bit set if mimic can unroute */
 #define MIMICIGNOREPORTS     0200			/* bit set if mimic ignores ports */
 
-extern AIDENTRY *ro_aid;				/* the Router aid object */
+extern TOOL     *ro_tool;				/* the Router tool object */
 extern INTBIG    ro_statekey;			/* cached key for "ROUT_state" */
 extern INTBIG    ro_state;				/* cached value for "ROUT_state" */
-extern INTBIG    ro_optionskey;			/* cached key for "ROUT_options" */
 extern INTBIG    ro_preferedkey;		/* cached key for "ROUT_prefered_arc" */
 
 /****************************** AUTO-STITCH ROUTING ******************************/
@@ -66,9 +65,6 @@ typedef struct Icheck
 	struct Icheck *nextcheck;			/* next in list */
 } RCHECK;
 extern RCHECK *ro_firstrcheck;
-extern RCHECK *ro_rcheckfree;
-
-extern AIDENTRY *ro_source;				/* source of batch of changes */
 
 /****************************** MIMIC ROUTING ******************************/
 
@@ -88,11 +84,11 @@ extern INTBIG ro_mazeboundary;
 /****************************** ROUTINES ******************************/
 
 /* prototypes for tool interface */
-void ro_init(INTBIG*, char*[], AIDENTRY*);
+void ro_init(INTBIG*, char*[], TOOL*);
 void ro_done(void);
 INTSML ro_set(INTSML, char*[]);
 void ro_slice(void);
-void ro_startbatch(AIDENTRY*, INTSML);
+void ro_startbatch(TOOL*, INTSML);
 void ro_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTSML,INTSML);
 void ro_modifyarcinst(ARCINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void ro_modifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
@@ -102,18 +98,18 @@ void ro_newvariable(INTBIG, INTBIG, INTBIG, INTBIG);
 
 /* prototypes for intratool interface */
 void   ro_autostitch(void);
-INTBIG ro_didaccept(ARCINST*, ARCINST*, ARCINST*);
 INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 		INTBIG **xplist, INTBIG **yplist);
 void   ro_freemazememory(void);
 void   ro_freemimicmemory(void);
 void   ro_freerivermemory(void);
+void   ro_freercheck(RCHECK*);
 INTBIG ro_getoptions(void);
 void   ro_mazeroutecell(void);
 void   ro_mazerouteselected(void);
 void   ro_mimicstitch(INTSML forced);
 INTSML ro_river(NODEPROTO*);
-#if ROUTAIDSUN
+#if ROUTTOOLSUN
   void ro_par(void);
 #endif
 
