@@ -736,12 +736,12 @@ typedef struct tbuffer
 #define SC_ALS_FORMAT 1
 #define SC_SILOS_FORMAT 2
 
-extern AIDENTRY   *sc_aid;				/* the Silicon Compiler aid object */
+extern TOOL       *sc_tool;				/* the Silicon Compiler tool object */
 extern INTBIG      sc_filetypescsim;	/* Silicon compiler simulation file descriptor */
 extern INTBIG      sc_filetypesctab;	/* Silicon compiler table file descriptor */
 
 /* prototypes for tool interface */
-void sc_init(INTBIG*, char*[], AIDENTRY*);
+void sc_init(INTBIG*, char*[], TOOL*);
 void sc_done(void);
 INTSML sc_set(INTSML, char*[]);
 INTBIG sc_request(char*, va_list);
