@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: sim.h
- * Simulation aid: header file
+ * Simulation tool: header file
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -56,7 +56,7 @@ extern "C"
 #define SIMRUNYESQPARSE  2				/* run simulation, parse output */
 #define SIMRUNYESQ       3				/* run simulation */
 
-extern AIDENTRY  *sim_aid;				/* the Simulator aid object */
+extern TOOL      *sim_tool;				/* the Simulator tool object */
 extern INTBIG     sim_format;			/* key for "SIM_format" (ESIM, etc) */
 extern INTBIG     sim_netfile;			/* key for "SIM_netfile" */
 extern INTBIG     sim_dontrun;			/* key for "SIM_dontrun" */
@@ -66,7 +66,6 @@ extern int        sim_fromsim[2];		/* pipe from the simulator process */
 extern INTBIG     sim_process;			/* process number of simulator */
 extern INTBIG     sim_filetypeesim;		/* ESIM netlist disk file descriptor */
 extern INTBIG     sim_filetypefasthenry;/* FastHenry netlist disk file descriptor */
-extern INTBIG     sim_filetypehspiceout;/* HSPICE output disk file descriptor */
 extern INTBIG     sim_filetypemossim;	/* MOSSIM netlist disk file descriptor */
 extern INTBIG     sim_filetypepal;		/* PAL netlist disk file descriptor */
 extern INTBIG     sim_filetypeals;		/* ALS netlist disk file descriptor */
@@ -98,18 +97,21 @@ extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
 #define VDD_STRENGTH    6
 
 /* the meaning of "sim_window_state" */
-#define FULLSTATE       01				/* set for full 12-state simulation */
-#define SHOWWAVEFORM    02				/* set to show waveform window */
-#define ADVANCETIME     04				/* set to advance time to end of simulation */
-#define BUSBASEBITS    070				/* base to use for bus display */
-#define BUSBASE10        0				/*   use base 10 for bus display */
-#define BUSBASE2       010				/*   use base 2 for bus display */
-#define BUSBASE8       020				/*   use base 8 for bus display */
-#define BUSBASE16      040				/*   use base 16 for bus display */
-#define WAVEPLACE     0300				/* location of waveform windows */
-#define WAVEPLACECAS     0				/*   cascade waveform windows */
-#define WAVEPLACETHOR 0100				/*   cascade waveform windows */
-#define WAVEPLACETVER 0200				/*   cascade waveform windows */
+#define FULLSTATE         01			/* set for full 12-state simulation */
+#define SHOWWAVEFORM      02			/* set to show waveform window */
+#define ADVANCETIME       04			/* set to advance time to end of simulation */
+#define BUSBASEBITS      070			/* base to use for bus display */
+#define BUSBASE10          0			/*   use base 10 for bus display */
+#define BUSBASE2         010			/*   use base 2 for bus display */
+#define BUSBASE8         020			/*   use base 8 for bus display */
+#define BUSBASE16        040			/*   use base 16 for bus display */
+#define WAVEPLACE       0300			/* location of waveform windows */
+#define WAVEPLACECAS       0			/*   cascade waveform windows */
+#define WAVEPLACETHOR   0100			/*   cascade waveform windows */
+#define WAVEPLACETVER   0200			/*   cascade waveform windows */
+#define SIMENGINE      01400			/* simulation engine to use */
+#define SIMENGINEALS       0			/*   use ALS simulation engine */
+#define SIMENGINEIRSIM  0400			/*   use IRSIM simulation engine */
 
 extern INTBIG  sim_window_state;		/* cached key for "SIM_window_state" */
 extern INTBIG  sim_window_signal_order;	/* cached key for "SIM_window_signal_order" */
@@ -123,12 +125,10 @@ INTBIG  sim_window_isactive(NODEPROTO **np);
 void    sim_window_redraw(void);
 void    sim_window_setlines(INTBIG);
 INTBIG  sim_window_getlines(void);
-void    sim_window_setvislines(INTBIG count);
 INTBIG  sim_window_getvislines(void);
 void    sim_window_settopline(INTBIG count);
 INTBIG  sim_window_gettopline(void);
 void    sim_window_savegraph(void);
-void    sim_window_displaymode(INTSML full);
 void    sim_window_displaycolor(INTBIG strength, INTBIG color);
 INTBIG  sim_window_newtrace(INTBIG, char*, INTBIG);
 INTSML  sim_window_buscommand(void);
@@ -166,7 +166,6 @@ void    sim_window_gettimerange(float*, float*);
 void    sim_window_gettimeextents(float*, float*);
 void    sim_window_updatelayoutwindow(void);
 void    sim_windowconvertengineeringnotation(float, char*);
-void    sim_window_addhighlightednet(INTSML);
 
 /********************* for ESIM *********************/
 
@@ -218,7 +217,7 @@ extern INTBIG sim_listingfile;			/* key for "SIM_listingfile" */
 
 /********************* for FASTHENRY *********************/
 
-/* the meaning of "aid:sim.SIM_fasthenry_state" */
+/* the meaning of "tool:sim.SIM_fasthenry_state" */
 #define FHUSESINGLEFREQ       01			/* use single frequency */
 #define FHMAKEMULTIPOLECKT    02			/* make multipole circuit */
 #define FHMAKEPOSTSCRIPTVIEW  04			/* make PostScript view */
@@ -242,25 +241,22 @@ extern INTBIG sim_fasthenryztailkey;		/* cached key for "SIM_fasthenry_z_tail" *
 extern INTBIG sim_fasthenrygroupnamekey;	/* cached key for "SIM_fasthenry_group_name" */
 
 /* prototypes for tool interface */
-void   sim_init(INTBIG*, char*[], AIDENTRY*);
+void   sim_init(INTBIG*, char*[], TOOL*);
 void   sim_done(void);
 INTSML sim_set(INTSML, char*[]);
 void   sim_slice(void);
-void   sim_startbatch(AIDENTRY*, INTSML);
+void   sim_startbatch(TOOL*, INTSML);
 void   sim_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTSML,INTSML);
 void   sim_modifyarcinst(ARCINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void   sim_modifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
 void   sim_newobject(INTBIG, INTBIG);
 void   sim_killobject(INTBIG, INTBIG);
 void   sim_newvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void   sim_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void   sim_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, UINTBIG*);
 void   sim_modifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void   sim_insertvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void   sim_deletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
-INTSML simals_charhandlerschem(WINDOWPART*, INTSML);
-INTSML simals_charhandlerwave(WINDOWPART*, INTSML);
-
 /* prototypes for intratool interface */
 void     sim_freespicememory(void);
 void     sim_freeirsimmemory(void);
