@@ -198,10 +198,10 @@ typedef CHANNEL *CHNPTR;
 /*
  * Now come all the global variables declared extern for reference by other files
  */
-extern MODPTR      simals_modroot, simals_modptr2, simals_primroot;
+extern MODPTR      simals_modroot, simals_primroot;
 extern ROWPTR      simals_rowptr2;
 extern IOPTR       simals_ioptr2;
-extern CONPTR      simals_conptr2, simals_levelptr, simals_cellroot;
+extern CONPTR      simals_levelptr, simals_cellroot;
 extern EXPTR       simals_exptr2;
 extern NODEPTR     simals_noderoot, simals_drive_node;
 extern LINKPTR     simals_linkfront, simals_linkback, simals_setroot;
@@ -209,12 +209,11 @@ extern TRAKPTR     simals_trakroot;
 extern LOADPTR     simals_chekroot;
 extern char      **simals_rowptr1, **simals_ioptr1;
 extern char       *simals_instbuf;
-extern INTBIG      simals_loop_count, simals_pseq, simals_nseq, *simals_instptr,
-				   simals_ibufsize, simals_iptrsize, simals_trakfull, simals_trakptr;
+extern INTBIG      simals_pseq, simals_nseq, *simals_instptr,
+				   simals_trakfull, simals_trakptr;
 extern INTBIG      simals_no_update;		/* cached key for "SIM_als_no_update" */
 extern INTSML      simals_seed_flag, simals_trace_all_nodes;
-extern float       simals_time_abs, simals_delta_def,
-				   simals_linear_def, simals_exp_def, simals_random_def, simals_abs_def;
+extern float       simals_time_abs;
 extern NODEPROTO  *simals_mainproto;
 extern INTBIG      simals_trace_size;
 
@@ -226,7 +225,6 @@ LINKPTR   simals_alloc_link_mem(void);
 #else
   char   *simals_alloc_mem(INTBIG);
 #endif
-INTSML    simals_alloc_ptr_buffer(INTBIG**, INTBIG*, INTBIG);
 void      simals_annotate_command(INTSML, char*[]);
 INTBIG    simals_atoi(char*);
 void      simals_build_actel_command(INTSML, char*[]);
@@ -267,3 +265,7 @@ void      simals_trace_command(INTSML, char*[]);
 void      simals_trans_number_to_state(INTBIG, char*);
 INTBIG    simals_trans_state_to_number(char*);
 void      simals_vector_command(INTSML, char*[]);
+
+INTSML    simals_startsimulation(NODEPROTO *np);
+INTSML    simals_charhandlerschem(WINDOWPART*, INTSML);
+INTSML    simals_charhandlerwave(WINDOWPART*, INTSML);
