@@ -34,7 +34,7 @@ extern "C"
 
 /* prototypes for technology routines */
 INTSML dodcmosn_initprocess(TECHNOLOGY *tech, INTSML pass);
-void dodcmosn_shapenodepoly(NODEINST*, INTSML, POLYGON*);
+void dodcmosn_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
