@@ -33,13 +33,13 @@ extern "C"
 {
 #endif
 
-#define	MOCMOSSUBSTICKFIGURE   02	/* set for stick-figure display */
-#define	MOCMOSSUBMETALS       034	/* number of metal layers */
-#define	MOCMOSSUB2METAL         0	/* 2-metal rules */
-#define	MOCMOSSUB3METAL        04	/* 3-metal rules */
-#define	MOCMOSSUB4METAL       010	/* 4-metal rules */
-#define	MOCMOSSUB5METAL       014	/* 5-metal rules */
-#define	MOCMOSSUB6METAL       020	/* 6-metal rules */
+#define MOCMOSSUBMETALS       034	/* number of metal layers */
+#define MOCMOSSUB2METAL         0	/* 2-metal rules */
+#define MOCMOSSUB3METAL        04	/* 3-metal rules */
+#define MOCMOSSUB4METAL       010	/* 4-metal rules */
+#define MOCMOSSUB5METAL       014	/* 5-metal rules */
+#define MOCMOSSUB6METAL       020	/* 6-metal rules */
+#define MOCMOSSUBNOCONV       040	/* don't convert to new "mocmos" technology */
 
 extern TECHNOLOGY *mocmossub_tech;			/* the technology */
 
