@@ -109,8 +109,6 @@ extern NODEPROTO  *sch_transistor4prim;	/* 4-port transistor */
 extern ARCPROTO   *sch_wirearc;			/* wire arc */
 extern ARCPROTO   *sch_busarc;			/* bus arc */
 
-extern INTBIG      sch_transistortypekey;	/* key for "SCHEM_transistor_type" */
-extern INTBIG      sch_sourcekey;		/* key for "SCHEM_source" */
 extern INTBIG      sch_meterkey;		/* key for "SCHEM_meter_type" */
 extern INTBIG      sch_diodekey;		/* key for "SCHEM_diode" */
 extern INTBIG      sch_capacitancekey;	/* key for "SCHEM_capacitance" */
@@ -118,6 +116,7 @@ extern INTBIG      sch_resistancekey;	/* key for "SCHEM_resistance" */
 extern INTBIG      sch_inductancekey;	/* key for "SCHEM_inductance" */
 extern INTBIG      sch_twoportkey;		/* key for "SCHEM_twoport_type" */
 extern INTBIG      sch_functionkey;		/* key for "SCHEM_function" */
+extern INTBIG      sch_spicemodelkey;	/* key for "SIM_spice_model" */
 extern INTBIG      sch_wirepinsizex;	/* X size if wire-pin primitives */
 extern INTBIG      sch_wirepinsizey;	/* Y size if wire-pin primitives */
 
