@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usr.h
- * User interface aid: header file
+ * User interface tool: header file
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -62,7 +62,7 @@ extern "C"
 #define NFIRSTOPA       017600000000		/* index of first opaque layer (if any) */
 #define NFIRSTOPASH               25		/* right shift of NFIRSTOPA */
 
-/* the meaning of ARCPROTO->userbits: (bits 0-22 (037777777) used globally) */
+	/* the meaning of ARCPROTO->userbits: (bits 0-22,31 (020037777777) used globally) */
 #define CANCONNECT         040000000		/* temporary for finding port connections */
 #define AHASOPA           0100000000		/* set if prototype has opaque graphics */
 #define AFIRSTOPA       017600000000		/* index of first opaque layer (if any) */
@@ -70,7 +70,7 @@ extern "C"
 
 /* the meaning of PORTPROTO->userbits: (bits 0-31 used globally) */
 
-/* the meaning of "us_aid->aidstate" (bits 0-6 (0177) used globally) */
+/* the meaning of "us_tool->toolstate" (bits 0-6 (0177) used globally) */
 #define NOKEYLOCK            0200000		/* set to ignore key lockout after errors */
 #define JUSTTHEFACTS         0400000		/* set to print only informative messages */
 #define NODETAILS           01000000		/* set to make no mention of specific commands */
@@ -84,7 +84,7 @@ extern "C"
 #define TTYAUDIT          0400000000		/* set to log messages window */
 #define TERMBEEP         01000000000		/* set to enable terminal beep */
 
-/* the meaning of "aid:user.USER_optionflags" */
+/* the meaning of "tool:user.USER_optionflags" */
 #define NOTEXTSELECT              01		/* set to disable selection of ALL text unless "special" option used */
 #define DRAWTINYFACETS            02		/* clear to "hash-out" tiny facets */
 #define CHECKDATE                 04		/* set to check facet dates */
@@ -110,6 +110,10 @@ extern "C"
 #define EXPORTSCROSS         0400000		/* exports drawn as crosses */
 #define EXPORTSOFF          01000000		/* exports not drawn */
 #define EXPORTSSHORT        01400000		/* exports drawn as shortened text */
+#define HIDEATTRIBUTES      02000000		/* set to supress attribute display */
+
+/* the meaning of "JAVA_flags" on the user tool object */
+#define JAVANOCOMPILER             1		/* disable compiler */
 
 /* special keys */
 #define CTRLCKEY                  03		/* the Control-C key */
@@ -142,34 +146,41 @@ extern "C"
 #define CANRUNPROCESS            010		/* can run subprocesses (fork and exec) */
 #define CANHAVENOWINDOWS         020		/* can exist with no edit windows */
 #define CANSTATUSPERFRAME        040		/* can put separate status info in each frame */
+#define CANCHOOSEFACES          0100		/* can choose alternate type faces */
+#define CANMODIFYFONTS          0200		/* can modify fonts with italic, bold, etc. */
 
-/* the icon styles (in aid:user.USER_icon_style) */
-#define ICONSTYLESIDEIN            03			/* side number for input ports     (         */
-#define ICONSTYLESIDEINSH           0			/* shift for ICONSTYLESIDEIN */
-#define ICONSTYLESIDEOUT          014			/* side number for input ports      0=left   */
-#define ICONSTYLESIDEOUTSH          2			/* shift for ICONSTYLESIDEOUT */
-#define ICONSTYLESIDEBIDIR        060			/* side number for input ports      1=right  */
-#define ICONSTYLESIDEBIDIRSH        4			/* shift for ICONSTYLESIDEBIDIR */
-#define ICONSTYLESIDEPOWER       0300			/* side number for input ports      2=top    */
-#define ICONSTYLESIDEPOWERSH        6			/* shift for ICONSTYLESIDEPOWER */
-#define ICONSTYLESIDEGROUND     01400			/* side number for input ports      3=bottom */
-#define ICONSTYLESIDEGROUNDSH       8			/* shift for ICONSTYLESIDEGROUND */
-#define ICONSTYLESIDECLOCK      06000			/* side number for input ports     )         */
-#define ICONSTYLESIDECLOCKSH       10			/* shift for ICONSTYLESIDECLOCK */
-#define ICONSTYLEPORTLOC      0140000			/* location of ports */
-#define ICONSTYLEPORTLOCSH         14			/* shift for ICONSTYLEPORTLOC */
-#define ICONSTYLEPORTSTYLE    0600000			/* style of port text */
-#define ICONSTYLEPORTSTYLESH       16			/* shift for ICONSTYLEPORTSTYLE */
-#define ICONSTYLEDRAWNOLEADS 01000000			/* nonzero to remove leads */
-#define ICONSTYLEDRAWNOBODY  02000000			/* nonzero to remove body */
-#define ICONSTYLETECH       014000000			/* technology of ports  0=generic, 1=schematic */
-#define ICONSTYLETECHSH            20			/* shift for ICONSTYLETECH */
+/* the icon styles (in tool:user.USER_icon_style) */
+#define ICONSTYLESIDEIN             03			/* side number for input ports     (         */
+#define ICONSTYLESIDEINSH            0			/* shift for ICONSTYLESIDEIN */
+#define ICONSTYLESIDEOUT           014			/* side number for input ports      0=left   */
+#define ICONSTYLESIDEOUTSH           2			/* shift for ICONSTYLESIDEOUT */
+#define ICONSTYLESIDEBIDIR         060			/* side number for input ports      1=right  */
+#define ICONSTYLESIDEBIDIRSH         4			/* shift for ICONSTYLESIDEBIDIR */
+#define ICONSTYLESIDEPOWER        0300			/* side number for input ports      2=top    */
+#define ICONSTYLESIDEPOWERSH         6			/* shift for ICONSTYLESIDEPOWER */
+#define ICONSTYLESIDEGROUND      01400			/* side number for input ports      3=bottom */
+#define ICONSTYLESIDEGROUNDSH        8			/* shift for ICONSTYLESIDEGROUND */
+#define ICONSTYLESIDECLOCK       06000			/* side number for input ports     )         */
+#define ICONSTYLESIDECLOCKSH        10			/* shift for ICONSTYLESIDECLOCK */
+#define ICONSTYLEPORTLOC       0140000			/* location of ports */
+#define ICONSTYLEPORTLOCSH          14			/* shift for ICONSTYLEPORTLOC */
+#define ICONSTYLEPORTSTYLE     0600000			/* style of port text */
+#define ICONSTYLEPORTSTYLESH        16			/* shift for ICONSTYLEPORTSTYLE */
+#define ICONSTYLEDRAWNOLEADS  01000000			/* nonzero to remove leads */
+#define ICONSTYLEDRAWNOBODY   02000000			/* nonzero to remove body */
+#define ICONSTYLETECH        014000000			/* technology of ports  0=generic, 1=schematic */
+#define ICONSTYLETECHSH             20			/* shift for ICONSTYLETECH */
+#define ICONINSTLOC          060000000			/* instance location */
+#define ICONINSTLOCSH               22			/* shift for ICONINSTLOC */
+#define ICONSTYLEREVEXPORT  0100000000			/* nonzero to reverse export order */
 
-#define ICONSTYLEEFAULT (0<<ICONSTYLESIDEINSH) | (1<<ICONSTYLESIDEOUTSH) | \
-						(2<<ICONSTYLESIDEBIDIRSH) | (3<<ICONSTYLESIDEPOWERSH) | \
-						(3<<ICONSTYLESIDEGROUNDSH) | (0<<ICONSTYLESIDECLOCKSH) | \
-						(1<<ICONSTYLEPORTLOCSH) | (0<<ICONSTYLEPORTSTYLESH) | \
-						(0<<ICONSTYLETECHSH)
+#define ICONSTYLEDEFAULT (0<<ICONSTYLESIDEINSH) | (1<<ICONSTYLESIDEOUTSH) | \
+						 (2<<ICONSTYLESIDEBIDIRSH) | (3<<ICONSTYLESIDEPOWERSH) | \
+						 (3<<ICONSTYLESIDEGROUNDSH) | (0<<ICONSTYLESIDECLOCKSH) | \
+						 (1<<ICONSTYLEPORTLOCSH) | (0<<ICONSTYLEPORTSTYLESH) | \
+						 (0<<ICONSTYLETECHSH)
+#define ICONLEADDEFLEN   2
+#define ICONLEADDEFSEP   2
 
 /* the "style" parameter to "us_getcolormap()" */
 #define COLORSEXISTING             0		/* reload existing colors */
@@ -227,7 +238,6 @@ extern "C"
 /******************** VARIABLES ********************/
 
 /* static display information */
-extern INTSML       us_gotstatus;			/* nature of status terminal (see above) */
 extern INTSML       us_longcount;			/* number of long commands */
 extern INTSML     (*us_displayroutine)(POLYGON*, WINDOWPART*); /* routine for graphics display */
 extern INTSML       us_cursorstate;			/* see defines above */
@@ -265,7 +275,6 @@ extern INTBIG       us_quickkeys;			/* cached key for "USER_quick_keys" */
 extern INTBIG       us_interactiveangle;	/* cached key for "USER_interactive_angle" */
 extern INTBIG       us_tinylambdaperpixel;	/* cached key for "USER_tiny_lambda_per_pixel" */
 extern INTBIG       us_techstate;			/* cached key for "TECH_state" */
-extern INTBIG       us_techlaststate;		/* cached key for "TECH_last_state" */
 extern INTBIG       us_ignoreoptionchanges;	/* cached key for "USER_ignore_option_changes" */
 extern INTBIG       us_displayunits;		/* cached key for "USER_display_units" */
 
@@ -274,7 +283,6 @@ extern INTBIG       us_tinyratio;			/* mirror for "USER_tiny_lambda_per_pixel" *
 extern INTBIG       us_separatechar;		/* separating character in port names */
 
 /* file type descriptors */
-extern INTBIG us_filetypecadrc;				/* Startup file */
 extern INTBIG us_filetypecolormap;			/* Color map */
 extern INTBIG us_filetypehelp;				/* Help */
 extern INTBIG us_filetypelog;				/* Log */
@@ -291,7 +299,6 @@ extern INTBIG       us_alignment;			/* current alignment in lambda */
 extern INTBIG       us_edgealignment;		/* current edge alignment in lambda */
 extern INTSML       us_dupdistset;			/* nonzero if duplication distance is valid */
 extern NODEINST    *us_dupnode;				/* a node that was duplicated */
-extern LIBRARY     *us_clipboardlib;		/* library with cut/copy/paste facet */
 extern NODEPROTO   *us_clipboardfacet;		/* facet with cut/copy/paste objects */
 extern INTBIG       us_dupx, us_dupy;		/* amount to move duplicated objects */
 extern WINDOWFRAME *us_menuframe;			/* window frame on which menu resides */
@@ -537,22 +544,23 @@ extern KEYWORD *us_pathiskey;				/* the current keyword list */
 /******************** PROTOTYPES ********************/
 
 /* prototypes for tool interface */
-void us_init(INTBIG*, char*[], AIDENTRY*);
+void us_init(INTBIG*, char*[], TOOL*);
 void us_done(void);
 INTSML us_set(INTSML, char*[]);
 INTBIG us_request(char*, va_list);
 void us_examinenodeproto(NODEPROTO*);
 void us_slice(void);
-void us_startbatch(AIDENTRY*, INTSML);
+void us_startbatch(TOOL*, INTSML);
 void us_endbatch(void);
 void us_startobjectchange(INTBIG, INTBIG);
 void us_endobjectchange(INTBIG, INTBIG);
 void us_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTSML,INTSML);
 void us_modifynodeproto(NODEPROTO*);
+void us_modifydescript(INTBIG, INTBIG, INTBIG, UINTBIG*);
 void us_newobject(INTBIG, INTBIG);
 void us_killobject(INTBIG, INTBIG);
 void us_newvariable(INTBIG, INTBIG, INTBIG, INTBIG);
-void us_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void us_killvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, UINTBIG*);
 void us_modifyvariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void us_readlibrary(LIBRARY*);
 void us_eraselibrary(LIBRARY*);
@@ -591,8 +599,8 @@ void us_menu(INTSML, char*[]);
 void us_mirror(INTSML, char*[]);
 void us_move(INTSML, char*[]);
 void us_node(INTSML, char*[]);
-void us_offaid(INTSML, char*[]);
-void us_onaid(INTSML, char*[]);
+void us_offtool(INTSML, char*[]);
+void us_ontool(INTSML, char*[]);
 void us_outhier(INTSML, char*[]);
 void us_package(INTSML, char*[]);
 void us_port(INTSML, char*[]);
@@ -606,7 +614,7 @@ void us_size(INTSML, char*[]);
 void us_spread(INTSML, char*[]);
 void us_system(INTSML, char*[]);
 void us_technology(INTSML, char*[]);
-void us_tellaid(INTSML, char*[]);
+void us_telltool(INTSML, char*[]);
 void us_terminal(INTSML, char*[]);
 void us_text(INTSML, char*[]);
 void us_undo(INTSML, char*[]);
@@ -653,6 +661,7 @@ void           us_abortcommand(char*, ...);
 void           us_abortedmsg(void);
 void           us_addfacetcenter(NODEINST *ni);
 INTSML         us_addhighlight(HIGHLIGHT*);
+void           us_addpossiblearcconnections(void);
 void           us_adjustdisplayabletext(NODEINST*);
 void           us_adjustlambda(INTBIG, INTBIG);
 void           us_adjustperpendicularsnappoints(HIGHLIGHT*, HIGHLIGHT*);
@@ -661,7 +670,6 @@ void           us_adjusttangentsnappoints(HIGHLIGHT*, HIGHLIGHT*);
 INTBIG         us_alignvalue(INTBIG, INTBIG, INTBIG*);
 EDITOR        *us_alloceditor(void);
 USERCOM       *us_allocusercom(void);
-INTSML         us_alreadyfacetcenter(NODEPROTO *np);
 INTSML         us_appendargs(USERCOM*);
 void           us_arrayfromfile(char *file);
 void           us_beginchanges(void);
@@ -679,6 +687,8 @@ void           us_cleanupfacet(NODEPROTO*, INTSML);
 void           us_clearhighlightcount(void);
 void           us_clearwindow(WINDOWPART*);
 char          *us_commandvarname(INTSML);
+void           us_computearcfartextbit(ARCINST *ai);
+void           us_computenodefartextbit(NODEINST *ni);
 UINTBIG        us_computewipestate(NODEINST *ni);
 NODEPROTO     *us_convertfacet(NODEPROTO*, TECHNOLOGY*);
 void           us_copylisttofacet(GEOM**, NODEPROTO*, NODEPROTO*, INTSML, INTSML);
@@ -695,11 +705,11 @@ void           us_delfacetmessage(NODEPROTO*);
 INTSML         us_delhighlight(HIGHLIGHT*);
 void           us_delnodeprotocenter(NODEPROTO*);
 INTSML         us_demandxy(INTBIG*, INTBIG*);
-void           us_describecontents(NODEINST*);
+void           us_describecontents(NODEPROTO*);
 char          *us_describefont(INTBIG);
 char          *us_describemenunode(COMMANDBINDING *commandbinding);
 char          *us_describestyle(INTBIG);
-char          *us_describetextdescript(INTBIG);
+char          *us_describetextdescript(UINTBIG*);
 char          *us_displayedportname(PORTPROTO *pp, INTBIG dispstyle);
 void           us_docommands(FILE*, INTSML, char*);
 void           us_doexpand(NODEINST*, INTBIG, INTBIG);
@@ -717,8 +727,8 @@ void           us_drawhorizontalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG,
 void           us_drawmenu(INTSML, WINDOWFRAME*);
 void           us_drawmenuentry(INTBIG, INTBIG, char*);
 INTSML         us_drawnodeinst(NODEINST*, INTSML, XARRAY, INTSML, WINDOWPART*);
-void           us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w);
-void           us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w);
+void           us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, INTSML ignoreinherit);
+void           us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w, INTSML ignoreinherit);
 void           us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
 void           us_drawverticalslider(WINDOWPART*, INTSML, INTSML, INTSML, INTSML);
 void           us_drawverticalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
@@ -737,15 +747,19 @@ void           us_erasewindow(WINDOWPART*);
 INTSML         us_evaluatevariable(char*, INTBIG*, INTBIG*, char**);
 void           us_execute(USERCOM*, INTBIG, INTSML, INTSML);
 INTSML         us_expandaddrtypearray(INTBIG*, INTBIG**, INTBIG**, INTBIG);
-void           us_expandttybuffers(INTSML);
 void           us_explorebuttonhandler(WINDOWPART*, INTSML, INTSML, INTSML);
 INTSML         us_explorecharhandler(WINDOWPART*, INTSML);
 void           us_explorepan(WINDOWPART*, INTBIG);
 void           us_exploreredisphandler(WINDOWPART*);
+int            us_exportnameindexascending(const void *e1, const void *e2);
+int            us_exportnametypeascending(const void *e1, const void *e2);
 INTSML         us_facetedithandler(WINDOWPART*, INTSML);
-INTBIG         us_figuregrabpoint(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+INTSML         us_facetfromtech(NODEPROTO *facet, TECHNOLOGY *tech);
+INTSML         us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, PORTPROTO *toport,
+				INTBIG *xcur, INTBIG *ycur);
+void           us_figuregrabpoint(UINTBIG*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_figuretechopaque(TECHNOLOGY*);
-INTBIG         us_figurevariableplace(INTBIG, INTSML, char*[]);
+void           us_figurevariableplace(UINTBIG*, INTSML, char*[]);
 INTSML         us_fillcomcomp(USERCOM*, COMCOMP*[]);
 void           us_findlowerport(NODEINST**, PORTPROTO**);
 void           us_findobject(INTBIG, INTBIG, WINDOWPART*, HIGHLIGHT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
@@ -774,17 +788,17 @@ void           us_getcolormap(TECHNOLOGY*, INTSML, INTSML);
 INTSML         us_getcolormapentry(char*, INTSML);
 COMCOMP       *us_getcomcompfromkeyword(char *keyword);
 void           us_gethighaddrtype(HIGHLIGHT *high, INTBIG *addr, INTBIG *type);
-INTBIG         us_gethighdescript(HIGHLIGHT *high);
+void           us_gethighdescript(HIGHLIGHT *high, UINTBIG *descript);
 GEOM         **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo);
-NODEINST      *us_gethighnodeinst(HIGHLIGHT *high);
 char          *us_gethighstring(HIGHLIGHT *high);
 void           us_gethightextcenter(HIGHLIGHT*, INTBIG*, INTBIG*, INTSML*);
+void           us_getlenwidoffset(NODEINST *ni, UINTBIG *descript, INTBIG *xoff, INTBIG *yoff);
 void           us_getlowleft(NODEINST*, INTBIG*, INTBIG*);
 VARIABLE      *us_getmacro(char*);
 MACROPACK     *us_getmacropack(char*);
 void           us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBIG *nhy);
 void           us_getnodedisplayposition(NODEINST *ni, INTBIG *xpos, INTBIG *ypos);
-NODEINST      *us_getnodeonarcinst(GEOM**, PORTPROTO**, GEOM*, PORTPROTO*, INTBIG, INTBIG);
+NODEINST      *us_getnodeonarcinst(GEOM**, PORTPROTO**, GEOM*, PORTPROTO*, INTBIG, INTBIG, INTBIG);
 UINTBIG        us_getobject(INTSML, INTSML);
 TECHNOLOGY    *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 HIGHLIGHT     *us_getonehighlight(void);
@@ -821,20 +835,23 @@ char          *us_keyname(INTSML);
 void           us_killcurrentwindow(INTSML);
 void           us_killwindowpickanother(WINDOWPART*);
 char          *us_layerletters(TECHNOLOGY*, INTSML);
-void           us_layouttext(char *layer, INTBIG tsize, INTBIG scale, char *msg);
+void           us_layouttext(char *layer, INTBIG tsize, INTBIG scale, INTBIG font,
+					INTBIG italic, INTBIG bold, INTBIG underline, char *msg);
+int            us_librarytemp1ascending(const void *e1, const void *e2);
 INTBIG         us_makearcuserbits(ARCPROTO*);
 USERCOM       *us_makecommand(char*);
-char          *us_makefacetline(NODEPROTO*, INTSML);
+ARCINST       *us_makeconnection(NODEINST*, PORTPROTO*, ARCPROTO*, NODEINST*, PORTPROTO*,
+				ARCPROTO*, NODEPROTO*, INTBIG, INTBIG, ARCINST**, ARCINST**, INTSML, INTSML, INTBIG*);
+char          *us_makefacetline(NODEPROTO*, INTBIG);
 INTSML         us_makehighlight(char*, HIGHLIGHT*);
 char          *us_makehighlightstring(HIGHLIGHT*);
-NODEPROTO     *us_makeiconfacet(PORTPROTO*, char*, char*, TECHNOLOGY*, LIBRARY*);
-void           us_makenewportproto(NODEPROTO*, NODEINST*, PORTPROTO*, char*, INTBIG, INTBIG, INTBIG);
+NODEPROTO     *us_makeiconfacet(PORTPROTO*, char*, char*, LIBRARY*);
+void           us_makenewportproto(NODEPROTO*, NODEINST*, PORTPROTO*, char*, INTBIG, INTBIG, UINTBIG*);
 INTSML         us_makescreen(INTBIG*, INTBIG*, INTBIG*, INTBIG*, WINDOWPART*);
-void           us_maketextpoly(char*, WINDOWPART*, INTBIG, INTBIG, NODEINST*, TECHNOLOGY*, INTBIG, POLYGON*);
-void           us_manhattantravel(NODEINST*, INTSML);
+void           us_maketextpoly(char*, WINDOWPART*, INTBIG, INTBIG, NODEINST*, TECHNOLOGY*, UINTBIG*, POLYGON*);
 void           us_manymove(GEOM**, NODEINST**, INTBIG, INTBIG, INTBIG);
 INTSML         us_modarcbits(INTSML, INTSML, char*, GEOM**);
-void           us_modifytextdescript(HIGHLIGHT*, INTBIG);
+void           us_modifytextdescript(HIGHLIGHT*, UINTBIG*);
 void           us_moveselectedtext(INTBIG numtexts, char **textlist, INTBIG odx, INTBIG ody);
 NODEPROTO     *us_needfacet(void);
 INTSML         us_needwindow(void);
@@ -853,11 +870,11 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU**, INTSML*, INTSML, INTSML, INTSML, INTSML
 PORTPROTO     *us_portdetails(PORTPROTO*, INTSML, char*[], NODEINST*, INTBIG*, INTBIG*, INTSML, char*);
 void           us_portsynchronize(LIBRARY*);
 INTSML         us_preventloss(LIBRARY*, char*, INTSML);
-void           us_printarcaidinfo(ARCINST*);
+void           us_printarctoolinfo(ARCINST*);
 void           us_printcolorvalue(INTSML);
 void           us_printmacro(VARIABLE*);
 void           us_printmacros(void);
-void           us_printnodeaidinfo(NODEINST*);
+void           us_printnodetoolinfo(NODEINST*);
 void           us_printtechnology(TECHNOLOGY*);
 void           us_pushhighlight(void);
 char          *us_putintoinfstr(char *str);
@@ -875,21 +892,22 @@ void           us_removeubchange(NODEPROTO*);
 void           us_renameport(PORTPROTO*, char*);
 NODEINST      *us_replacenodeinst(NODEINST *oldni, NODEPROTO *newnp, INTSML ignoreportnames, INTSML allowdeletedports);
 void           us_rgbtohsv(INTSML, INTSML, INTSML, float*, float*, float*);
-INTBIG         us_rotatedescript(GEOM*, INTBIG);
-INTBIG         us_rotatedescriptI(GEOM*, INTBIG);
+void           us_rotatedescript(GEOM*, UINTBIG*);
+void           us_rotatedescriptI(GEOM*, UINTBIG*);
 ARCINST       *us_runarcinst(NODEINST*, PORTPROTO*, INTBIG, INTBIG, NODEINST*, PORTPROTO*, INTBIG, INTBIG, ARCPROTO*, INTBIG);
 INTSML         us_samecontents(NODEPROTO *np1, NODEPROTO *np2, INTBIG explain);
+void           us_saveoptions(void);
 void           us_scaletowindow(INTBIG*, INTBIG*, WINDOWPART*);
 void           us_scaletraceinfo(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_scanforkeyequiv(POPUPMENU*);
 void           us_selectsnap(HIGHLIGHT*, INTBIG, INTBIG);
-void           us_setaid(INTSML, char*[], INTSML);
+void           us_settool(INTSML, char*[], INTSML);
 void           us_setalignment(WINDOWFRAME*);
 void           us_setarcname(ARCINST*, char*);
 void           us_setarcproto(ARCPROTO*, INTSML);
 void           us_setcolorentry(INTSML, INTSML, INTSML, INTSML, INTSML, INTSML);
 void           us_setcursorpos(WINDOWFRAME*, INTBIG, INTBIG);
-INTBIG         us_setdescriptoffset(INTBIG, INTBIG, INTBIG);
+void           us_setdescriptoffset(UINTBIG*, INTBIG, INTBIG);
 void           us_setfacetname(WINDOWPART*);
 void           us_setfacetsize(WINDOWPART*);
 void           us_setfind(HIGHLIGHT*, INTBIG, INTBIG, INTBIG, INTBIG);
@@ -922,7 +940,8 @@ void           us_skeletonize(NODEPROTO *np, char *newname, LIBRARY *newlib, INT
 void           us_slideleft(INTBIG);
 void           us_slideup(INTBIG);
 NODEPROTO    **us_sortlib(LIBRARY*, char*, INTSML);
-WINDOWPART    *us_splitcurrentwindow(INTSML, INTSML);
+int            us_sortpopupmenuascending(const void *e1, const void *e2);
+WINDOWPART    *us_splitcurrentwindow(INTSML, INTSML, WINDOWPART**);
 INTBIG         us_spreadaround(NODEINST *ni, INTBIG amount, char *direction);
 void           us_spreadrotateconnection(NODEINST *theni);
 void           us_squarescreen(WINDOWPART*, WINDOWPART*, INTSML, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
@@ -961,6 +980,7 @@ INTSML         us_topofwindows(char**);
 void           us_undisplayobject(GEOM*);
 void           us_undoportproto(NODEINST*, PORTPROTO*);
 void           us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np);
+char          *us_uniqueobjectname(char *name, NODEPROTO *facet, INTBIG type, void *exclude);
 char          *us_uniqueportname(char*, NODEPROTO*);
 void           us_unknowncommand(void);
 void           us_unqueueredraw(LIBRARY *lib);
@@ -989,7 +1009,7 @@ INTSML         ttynumstatuslines(void);
 /* popup and pulldown menus */
 INTSML         nativemenuload(INTSML, char*[]);
 void           nativemenurename(POPUPMENU*, INTSML);
-INTSML         nativepopupmenu(POPUPMENU *menu, INTSML header, INTSML left, INTSML top);
+INTSML         nativepopupmenu(POPUPMENU **menu, INTSML header, INTSML left, INTSML top);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
