@@ -43,7 +43,7 @@ INTSML us_arraydlog(char*[]);
 INTSML us_artlookdlog(void);
 INTSML us_attributesdlog(void);
 INTSML us_capacitancedlog(char*[], char*);
-INTSML us_colormixdlog(char *overlayernames[]);
+void us_colormixdlog(char *overlayernames[]);
 INTSML us_copyfacetdlog(char*);
 INTSML us_createtodlog(char*[]);
 INTSML us_defarcdlog(void);
@@ -53,7 +53,6 @@ INTSML us_dependentlibdlog(void);
 INTSML us_editfacetdlog(char*);
 INTSML us_facetdlog(void);
 INTSML us_facetlist(char*, char*[], INTSML);
-INTSML us_filedlog(COMCOMP*, char*[], char*, INTSML);
 INTSML us_findtextdlog(void);
 INTSML us_frameoptionsdlog(void);
 INTSML us_gaindlog(char*, char*[], char*);
@@ -62,12 +61,12 @@ INTSML us_helpdlog(char*);
 INTSML us_highlayerlog(void);
 INTSML us_iconstyledlog(void);
 INTSML us_inductancedlog(char*[], char*);
+INTSML us_javaoptionsdlog(void);
 INTSML us_lambdadlog(void);
 INTSML us_librarypathdlog(void);
 INTSML us_libtotechnologydlog(void);
 INTSML us_menudlog(char*[]);
 INTSML us_modtextsizedlog(void);
-INTSML us_newfacetdlog(char*[]);
 INTSML us_newviewdlog(char*[]);
 INTSML us_nodesizedlog(char*[]);
 INTSML us_noyesalwaysdlog(char*, char*[]);
@@ -88,7 +87,7 @@ INTSML us_resistancedlog(char*, char*[], char*);
 INTSML us_selectoptdlog(void);
 INTSML us_selectportnodenetdlog(INTSML);
 INTSML us_showdlog(INTSML);
-INTSML us_sourcedlog(char*[], NODEINST*, VARIABLE*);
+INTSML us_spicedlog(void);
 INTSML us_spreaddlog(void);
 INTSML us_technologydlog(char*, char*[]);
 INTSML us_techoptdlog(void);
@@ -98,7 +97,6 @@ INTSML us_variablesdlog(void);
 INTSML us_vccsdlog(char*[], char*);
 INTSML us_viewdlog(INTBIG);
 INTSML us_visiblelayersdlog(char*);
-INTSML us_widlendlog(char*[], char*);
 INTSML us_windowviewdlog(void);
 INTSML us_yesnodlog(char*, char*[]);
 
