@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrtrack.h
- * User interface aid: cursor tracking headers
+ * User interface tool: cursor tracking headers
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -39,10 +39,7 @@ INTSML us_distancedown(INTBIG, INTBIG);
 INTSML us_distancechar(INTBIG x, INTBIG y, INTSML chr);
 void us_distanceup(void);
 INTSML us_distanceaborted(void);
-void us_textmoveinit(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, GEOM*);
-void us_textmovebegin(void);
-INTSML us_textmovedown(INTBIG, INTBIG);
-void us_textgrabinit(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, GEOM*);
+void us_textgrabinit(UINTBIG*, INTBIG, INTBIG, INTBIG, INTBIG, GEOM*);
 void us_textgrabbegin(void);
 INTSML us_textgrabdown(INTBIG, INTBIG);
 void us_sizeainit(ARCINST*);
@@ -61,7 +58,7 @@ INTSML us_tracedown(INTBIG, INTBIG);
 void us_traceup(void);
 void us_pointbegin(void);
 INTSML us_addpdown(INTBIG, INTBIG);
-void us_createinit(INTBIG, INTBIG, NODEPROTO*, INTSML, INTSML);
+void us_createinit(INTBIG, INTBIG, NODEPROTO*, INTSML, INTSML, GEOM*, PORTPROTO*);
 INTSML us_ignoreup(INTBIG, INTBIG);
 void us_createbegin(void);
 INTSML us_dragdown(INTBIG, INTBIG);
@@ -93,21 +90,15 @@ void us_findsbegin(void);
 INTSML us_stretchdown(INTBIG, INTBIG);
 void us_finddbegin(void);
 void us_finddterm(INTBIG*, INTBIG*);
-void us_hthumbbegin(INTBIG x, WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx);
+void us_hthumbbegin(INTBIG x, WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx, void (*callback)(INTBIG));
+void us_hthumbtrackingcallback(INTBIG delta);
 INTSML us_hthumbdown(INTBIG x, INTBIG y);
 void us_hthumbdone(void);
 void us_vthumbbegin(INTBIG y, WINDOWPART *w, INTBIG hx, INTBIG ly, INTBIG hy,
-		INTBIG totallines, INTSML onleft);
-void us_evthumbdone(void);
-INTBIG us_evthumbend(void);
-void us_svthumbdone(void);
-void us_shthumbdone(void);
-void us_ehthumbdone(void);
-INTBIG us_ehthumbend(void);
+		INTSML onleft, void (*callback)(INTBIG));
+void us_vthumbtrackingcallback(INTBIG delta);
 INTSML us_vthumbdown(INTBIG x, INTBIG y);
 void us_vthumbdone(void);
-INTBIG us_svthumbend(void);
-float us_shthumbend(void);
 void us_hpartdividerbegin(INTBIG y, INTBIG lx, INTBIG hx, WINDOWFRAME *wf);
 INTSML us_hpartdividerdown(INTBIG x, INTBIG y);
 void us_hpartdividerdone(void);
