@@ -39,7 +39,7 @@ extern "C"
 #define FALSE				0
 /* #define VHDL50           1 */			/* uncomment to enable VHDL 5.0 */
 #define FNAMESIZE			200				/* maximum size of file names */
-#define MAXVHDLLINE			256				/* maximum line length */
+#define MAXVHDLLINE			1000			/* maximum line length */
 #define NOTARGET			0				/* no output target, compile only */
 #define TARGET_ALS			1				/* output target is ALS file */
 #define TARGET_QUISC		2				/* output target is QUISC file */
@@ -47,7 +47,7 @@ extern "C"
 #define TARGET_RSIM			4				/* output target is NETLISP for RSIM */
 #define TARGET_SILOS		5				/* output target is SILOS  (V.01)*/
 
-extern AIDENTRY *vhdl_aid;
+extern TOOL *vhdl_tool;
 
 /********** Token Definitions ******************************************/
 
@@ -203,10 +203,11 @@ typedef struct Itokenlist
 
 /******** Identifier Table Structures **********************************/
 
-#define IDENT_TABLE_SIZE 10007				/* maximum number of identifiers */
+/* #define IDENT_TABLE_SIZE 10007 */		/* maximum number of identifiers */
+#define IDENT_TABLE_SIZE 80021				/* maximum number of identifiers */
 											/* this value should be prime */
 											/* for the HASH function */
-#define MAX_HASH_TRYS	  100
+#define MAX_HASH_TRYS	  1000
 
 typedef struct
 {
@@ -318,20 +319,20 @@ typedef struct Idbportlist
 {
 	IDENTTABLE				*name;			/* name of port */
 	INTBIG					mode;			/* mode of port */
-	struct Idbtype			*type;			/* type of port */
+	struct Idbltype			*type;			/* type of port */
 	INTBIG					flags;			/* general flags */
 	struct Idbportlist		*next;			/* next in port list */
 } DBPORTLIST;
 
 #define DBTYPE_SINGLE		1
 #define DBTYPE_ARRAY		2
-typedef struct Idbtype
+typedef struct Idbltype
 {
 	IDENTTABLE				*name;			/* name of type */
 	INTBIG					type;			/* type of type */
 	char					*pointer;		/* pointer to info */
-	struct Idbtype			*subtype;		/* possible subtype */
-} DBTYPE;
+	struct Idbltype			*subtype;		/* possible subtype */
+} DBLTYPE;
 
 /********** Bodies *****************************************************/
 
@@ -365,7 +366,7 @@ typedef struct Idbcomponents
 typedef struct Idbsignals
 {
 	IDENTTABLE				*name;			/* name of signal */
-	struct Idbtype			*type;			/* type of signal */
+	struct Idbltype			*type;			/* type of signal */
 	struct Idbsignals		*next;			/* next signal */
 } DBSIGNALS;
 
@@ -404,7 +405,7 @@ typedef struct Idbname
 	char					*pointer;		/* NULL if identifier */
 								 			/* pointer to DBEXPRLIST if indexed */
 								 			/* pointer to DBNAMELIST if concatenated */
-	struct Idbtype	*dbtype; 				/* pointer to type */
+	struct Idbltype	*dbtype; 				/* pointer to type */
 } DBNAME;
 
 typedef struct Idbexprlist
@@ -950,7 +951,7 @@ typedef struct Iliteral
 #define NONUMERICLITERAL	0
 
 /* prototypes for tool interface */
-void           vhdl_init(INTBIG*, char*[], AIDENTRY*);
+void           vhdl_init(INTBIG*, char*[], TOOL*);
 void           vhdl_done(void);
 INTSML         vhdl_set(INTSML, char*[]);
 INTBIG         vhdl_request(char*, va_list);
@@ -973,7 +974,7 @@ TOKENLIST     *vhdl_getnametoken(NAME*);
 void           vhdl_getnexttoken(void);
 IDENTTABLE    *vhdl_getprefixident(PREFIX*);
 TOKENLIST     *vhdl_getprefixtoken(PREFIX*);
-DBTYPE        *vhdl_gettype(IDENTTABLE*);
+DBLTYPE        *vhdl_gettype(IDENTTABLE*);
 INTSML         vhdl_keysame(TOKENLIST*, INTBIG);
 IDENTTABLE    *vhdl_makeidentkey(char*);
 DISCRETERANGE *vhdl_parsediscrete_range(void);
