@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iobinaryi.c
- * Input/output aid: binary format input
+ * Input/output tool: binary format input
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -33,17 +33,19 @@
 #include "eio.h"
 #include "tech.h"
 #include "tecgen.h"
+#include "tecart.h"
 #include "tecschem.h"
 #include "tecmocmos.h"
 #include "tecmocmossub.h"
 #include "edialogs.h"
+#include "usr.h"
 
 #define REPORTINC   2000			/* bytes between graphical updates */
 
 typedef struct
 {
-	INTSML       aidbitsmessed;		/* 0: aid order is correct */
-	INTBIG       aabcount;			/* number of aidbits for old files */
+	INTSML       toolbitsmessed;	/* 0: tool order is correct */
+	INTBIG       aabcount;			/* number of toolbits for old files */
 	INTBIG       bytecount;			/* position within input file */
 	char       **realname;			/* variable names */
 	INTBIG       namecount;			/* number of variable names */
@@ -54,7 +56,7 @@ typedef struct
 
 	/* totals of objects in the file */
 	INTBIG       magic;				/* file's magic number */
-	INTBIG       aacount;			/* number of aids */
+	INTBIG       aacount;			/* number of tools */
 	INTBIG       techcount;			/* number of technologies */
 	INTBIG       nodepprotoindex;	/* number of primitive node prototypes */
 	INTBIG       portpprotoindex;	/* number of primitive port prototypes */
@@ -70,13 +72,14 @@ typedef struct
 
 	/* input error message arrays */
 	char       **techerror;			/* name of unknown technologies */
-	char       **aiderror;			/* name of unknown aids */
+	char       **toolerror;			/* name of unknown tools */
 	INTSML      *nodepprotoerror;	/* flag for unknown prim. NODEPROTOs */
 	char       **nodepprotoorig;	/* name of unknown prim. NODEPROTOs */
 	INTBIG      *nodepprototech;	/* tech. assoc. with prim. NODEPROTOs */
 	char       **portpprotoerror;	/* name of unknown PORTPROTOs */
 	char       **arcprotoerror;		/* name of unknown ARCPROTOs */
 	INTSML       swap_bytes;		/* are the bytes swapped? 1 if so */
+	INTSML       converttextdescriptors;	/* convert textdescript fields? */
 	INTBIG       swapped_floats;	/* number of swappped floating-point variables */
 	INTBIG       swapped_doubles;	/* number of swappped double-precision variables */
 	INTBIG       clipped_integers;	/* number of clipped integers */
@@ -91,7 +94,7 @@ typedef struct
 	NODEPROTO  **nodeprotolist;		/* list of facets for readin */
 	CELL       **celllist;			/* list of cells for readin */
 	TECHNOLOGY **techlist;			/* list of technologies for readin */
-	INTBIG      *aidlist;			/* list of aids for readin */
+	INTBIG      *toollist;			/* list of tools for readin */
 	PORTPROTO  **portprotolist;		/* list of portprotos for readin */
 	INTBIG      *portcount;			/* number of portprotos in each facet */
 	PORTPROTO  **portpprotolist;	/* list of primitive portprotos for readin */
@@ -104,34 +107,33 @@ static char        *io_tempstring;				/* for reading temporary strings */
 static INTSML       io_tempstringlength = 0;	/* length of temporary string */
 
 /* prototypes for local routines */
-char       *io_doreadlibrary(LIBRARY*);
-INTSML      io_readnodeproto(NODEPROTO*);
-INTSML      io_readnodeinst(NODEINST*);
-void        io_readgeom(INTBIG*, INTBIG*);
-INTSML      io_readarcinst(ARCINST*);
-INTSML      io_readnamespace(void);
-void        io_ignorevariables(void);
-INTSML      io_readvariables(INTBIG, INTBIG);
-INTSML      io_getinvar(INTBIG*, INTBIG);
-INTBIG      io_arrangeaidbits(INTBIG);
-char       *io_convertnodeproto(NODEPROTO**);
-void        io_convertportproto(PORTPROTO**);
-void        io_convertarcproto(ARCPROTO**);
-ARCPROTO   *io_getarcprotolist(INTSML);
-PORTPROTO  *io_getportpprotolist(INTBIG);
-NODEPROTO  *io_getnodepprotolist(INTBIG);
-TECHNOLOGY *io_gettechlist(INTSML);
-void        io_getin(void *, INTSML, INTSML, INTSML);
-char       *io_getstring(CLUSTER*);
-char       *io_gettempstring(void);
-void        io_getinbig(void *data);
-void        io_getinubig(void *data);
-void        io_getinsmall(void *data);
-void        io_getin1byte(void *data);
-void        io_readexternalnodeproto(LIBRARY *lib, INTBIG i);
-void        io_ensureallports(LIBRARY *lib);
-void        io_binfindallports(LIBRARY *lib, PORTPROTO *pp, INTBIG *lx, INTBIG *hx,
-				INTBIG *ly, INTBIG *hy, INTSML *first, ARCPROTO **onlyarc, XARRAY trans);
+static char       *io_doreadlibrary(LIBRARY*);
+static INTSML      io_readnodeproto(NODEPROTO*);
+static INTSML      io_readnodeinst(NODEINST*);
+static void        io_readgeom(INTBIG*, INTBIG*);
+static INTSML      io_readarcinst(ARCINST*);
+static INTSML      io_readnamespace(void);
+static void        io_ignorevariables(void);
+static INTSML      io_readvariables(INTBIG, INTBIG);
+static INTSML      io_getinvar(INTBIG*, INTBIG);
+static INTBIG      io_arrangetoolbits(INTBIG);
+static INTBIG      io_convertnodeproto(NODEPROTO**, char**);
+static void        io_convertportproto(PORTPROTO**);
+static void        io_convertarcproto(ARCPROTO**);
+static ARCPROTO   *io_getarcprotolist(INTSML);
+static PORTPROTO  *io_getportpprotolist(INTBIG);
+static NODEPROTO  *io_getnodepprotolist(INTBIG);
+static TECHNOLOGY *io_gettechlist(INTSML);
+static void        io_getin(void *, INTSML, INTSML, INTSML);
+static char       *io_getstring(CLUSTER*);
+static char       *io_gettempstring(void);
+static void        io_getinbig(void *data);
+static void        io_getinubig(void *data);
+static void        io_readexternalnodeproto(LIBRARY *lib, INTBIG i);
+static void        io_ensureallports(LIBRARY *lib);
+static void        io_binfindallports(LIBRARY *lib, PORTPROTO *pp, INTBIG *lx, INTBIG *hx,
+						INTBIG *ly, INTBIG *hy, INTSML *first, ARCPROTO **onlyarc, XARRAY trans);
+static void        io_fixexternalvariables(VARIABLE *firstvar, INTSML numvar);
 
 /*
  * Routine to free all memory associated with this module.
@@ -143,7 +145,19 @@ void io_freebininmemory(void)
 
 INTSML io_readbinlibrary(LIBRARY *lib)
 {
-	return(io_doreadbinlibrary(lib, 1));
+	REGISTER INTSML ret;
+
+	ret = io_doreadbinlibrary(lib, 1);
+	if (ret == 0 && (lib->userbits&HIDDENLIBRARY) == 0)
+	{
+		ttyputmsg(_("Read library %s on %s"), lib->libname,
+			timetostring(getcurrenttime()));
+#ifdef ONUNIX
+		printf(_("Read library %s on %s\n"), lib->libname,
+			timetostring(getcurrenttime()));
+#endif
+	}
+	return(ret);
 }
 
 INTSML io_doreadbinlibrary(LIBRARY *lib, INTSML newprogress)
@@ -161,6 +175,10 @@ INTSML io_doreadbinlibrary(LIBRARY *lib, INTSML newprogress)
 		return(1);
 	}
 
+	/* update the library file name if the true location is different */
+	if (strcmp(filename, lib->libfile) != 0)
+		(void)reallocstring(&lib->libfile, filename, lib->cluster);
+
 	/* prepare status dialog */
 	if (io_verbose < 0)
 	{
@@ -229,6 +247,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 	REGISTER TECHNOLOGY *tech;
 	REGISTER PORTEXPINST **portexpinstlist;
 	REGISTER PORTARCINST **portarcinstlist;
+	REGISTER TOOL *tool;
 	char *version, *errormsg;
 	unsigned char chmagic[4];
 	REGISTER VIEW *v;
@@ -307,7 +326,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 	io_getinbig(&io_binindata.curnodeproto);
 	if (io_verbose > 0)
 	{
-		ttyputmsg(M_("Reading %ld aids, %ld technologies"), io_binindata.aacount,
+		ttyputmsg(M_("Reading %ld tools, %ld technologies"), io_binindata.aacount,
 			io_binindata.techcount);
 		ttyputmsg(M_("        %ld prim nodes, %ld prim ports, %ld arc protos"),
 			io_binindata.nodepprotoindex, io_binindata.portpprotoindex,
@@ -333,6 +352,15 @@ char *io_doreadlibrary(LIBRARY *lib)
 			convertmosiscmostechnologies = 1;
 	}
 
+	/* for versions before 6.04c, convert text descriptor values */
+	io_binindata.converttextdescriptors = 0;
+	if (emajor < 6 ||
+		(emajor == 6 && eminor < 4) ||
+		(emajor == 6 && eminor == 4 && edetail < 3))
+	{
+		io_binindata.converttextdescriptors = 1;
+	}
+
 #ifdef REPORTCONVERSION
 	ttyputmsg("Library is version %s (%ld.%ld.%ld)", version, emajor, eminor, edetail);
 	if (convertmosiscmostechnologies != 0)
@@ -383,7 +411,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 		}
 	}
 
-	/* get the number of aidbits to ignore */
+	/* get the number of toolbits to ignore */
 	if (io_binindata.magic <= MAGIC3 && io_binindata.magic >= MAGIC6)
 	{
 		/* versions 3, 4, 5, and 6 find this in the file */
@@ -437,10 +465,10 @@ char *io_doreadlibrary(LIBRARY *lib)
 	if (io_binindata.techlist == 0) return(_("No memory"));
 	io_binindata.techerror = (char **)emalloc(((sizeof (char *)) * io_binindata.techcount), el_tempcluster);
 	if (io_binindata.techerror == 0) return(_("No memory"));
-	io_binindata.aidlist = emalloc((SIZEOFINTBIG * io_binindata.aacount), el_tempcluster);
-	if (io_binindata.aidlist == 0) return(_("No memory"));
-	io_binindata.aiderror = (char **)emalloc(((sizeof (char *)) * io_binindata.aacount), el_tempcluster);
-	if (io_binindata.aiderror == 0) return(_("No memory"));
+	io_binindata.toollist = emalloc((SIZEOFINTBIG * io_binindata.aacount), el_tempcluster);
+	if (io_binindata.toollist == 0) return(_("No memory"));
+	io_binindata.toolerror = (char **)emalloc(((sizeof (char *)) * io_binindata.aacount), el_tempcluster);
+	if (io_binindata.toolerror == 0) return(_("No memory"));
 
 	/* versions 9 and later allocate cell pointers */
 	if (io_binindata.magic <= MAGIC9)
@@ -531,7 +559,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 		if (io_binindata.arccount[i] < 0 && io_binindata.nodecount[i] < 0)
 		{
 			/* this facet is from an external library */
-			io_binindata.nodeprotolist[i] = NONODEPROTO;
+			io_binindata.nodeprotolist[i] = 0;
 		} else
 		{
 			io_binindata.nodeprotolist[i] = allocnodeproto(lib->cluster);
@@ -560,7 +588,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 	for(i=0; i<io_binindata.nodeprotoindex; i++)
 	{
 		np = io_binindata.nodeprotolist[i];
-		if (np == NONODEPROTO)
+		if (np == 0)
 		{
 			/* for external references, clear the port proto list */
 			for(j=0; j<io_binindata.portcount[i]; j++)
@@ -803,6 +831,15 @@ char *io_doreadlibrary(LIBRARY *lib)
 			for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 				if (strcmp(ap->protoname, name) == 0) break;
 			if (ap == NOARCPROTO)
+			{
+				if (tech == art_tech)
+				{
+					if (strcmp(name, "Dash-1") == 0) ap = art_dottedarc; else
+					if (strcmp(name, "Dash-2") == 0) ap = art_dashedarc; else
+					if (strcmp(name, "Dash-3") == 0) ap = art_thickerarc;
+				}
+			}
+			if (ap == NOARCPROTO)
 			{
 				ap = tech->firstarcproto;
 				(void)initinfstr();
@@ -818,25 +855,25 @@ char *io_doreadlibrary(LIBRARY *lib)
 	}
 
 	/* setup pointers for tools */
-	io_binindata.aidbitsmessed = 0;
+	io_binindata.toolbitsmessed = 0;
 	for(i=0; i<io_binindata.aacount; i++)
 	{
 		name = io_gettempstring();
 		if (name == 0) return(_("No memory"));
-		io_binindata.aiderror[i] = 0;
-		for(j=0; j<el_maxaid; j++)
-			if (strcmp(name, el_aids[j].aidname) == 0) break;
-		if (j >= el_maxaid)
+		io_binindata.toolerror[i] = 0;
+		for(j=0; j<el_maxtools; j++)
+			if (strcmp(name, el_tools[j].toolname) == 0) break;
+		if (j >= el_maxtools)
 		{
-			(void)allocstring(&io_binindata.aiderror[i], name, el_tempcluster);
+			(void)allocstring(&io_binindata.toolerror[i], name, el_tempcluster);
 			j = -1;
 		}
-		if (i != j) io_binindata.aidbitsmessed++;
-		io_binindata.aidlist[i] = j;
+		if (i != j) io_binindata.toolbitsmessed++;
+		io_binindata.toollist[i] = j;
 	}
 	if (io_binindata.magic <= MAGIC3 && io_binindata.magic >= MAGIC6)
 	{
-		/* versions 3, 4, 5, and 6 must ignore aidbits associations */
+		/* versions 3, 4, 5, and 6 must ignore toolbits associations */
 		for(i=0; i<io_binindata.aabcount; i++) (void)io_gettempstring();
 	}
 
@@ -889,13 +926,13 @@ char *io_doreadlibrary(LIBRARY *lib)
 	if (io_verbose > 0) ttyputmsg(M_("Reading library variables"));
 	if (io_readvariables((INTBIG)lib, VLIBRARY) < 0) return(_("No memory"));
 
-	/* read the aid variables */
-	if (io_verbose > 0) ttyputmsg(M_("Reading aid variables"));
+	/* read the tool variables */
+	if (io_verbose > 0) ttyputmsg(M_("Reading tool variables"));
 	for(i=0; i<io_binindata.aacount; i++)
 	{
-		j = io_binindata.aidlist[i];
+		j = io_binindata.toollist[i];
 		if (j < 0) io_ignorevariables(); else
-			if (io_readvariables((INTBIG)&el_aids[j], VAID) < 0)
+			if (io_readvariables((INTBIG)&el_tools[j], VTOOL) < 0)
 				return(_("No memory"));
 	}
 
@@ -980,7 +1017,7 @@ char *io_doreadlibrary(LIBRARY *lib)
 	for(i=0; i<io_binindata.nodeprotoindex; i++)
 	{
 		np = io_binindata.nodeprotolist[i];
-		if (np == NONODEPROTO) continue;
+		if (np == 0) continue;
 		if (io_readnodeproto(np) != 0) return(_("No memory"));
 		if (lastnp == NONODEPROTO)
 		{
@@ -1000,10 +1037,51 @@ char *io_doreadlibrary(LIBRARY *lib)
 	for(i=0; i<io_binindata.nodeprotoindex; i++)
 	{
 		np = io_binindata.nodeprotolist[i];
-		if (np != NONODEPROTO) continue;
+		if (np != 0) continue;
 		io_readexternalnodeproto(lib, i);
 	}
 
+	/* now that external facets are resolved, fix all variables that may have used them */
+	io_fixexternalvariables(lib->firstvar, lib->numvar);
+	for(i=0; i<io_binindata.aacount; i++)
+	{
+		j = io_binindata.toollist[i];
+		tool = &el_tools[j];
+		io_fixexternalvariables(tool->firstvar, tool->numvar);
+	}
+	for(te=0; te<io_binindata.techcount; te++)
+	{
+		tech = io_binindata.techlist[te];
+		io_fixexternalvariables(tech->firstvar, tech->numvar);
+	}
+	for(i=0; i<io_binindata.arcprotoindex; i++)
+	{
+		ap = io_binindata.arcprotolist[i];
+		io_fixexternalvariables(ap->firstvar, ap->numvar);
+	}
+	for(i=0; i<io_binindata.nodepprotoindex; i++)
+	{
+		np = io_binindata.nodepprotolist[i];
+		io_fixexternalvariables(np->firstvar, np->numvar);
+	}
+	for(i=0; i<io_binindata.portpprotoindex; i++)
+	{
+		pp = io_binindata.portpprotolist[i];
+		io_fixexternalvariables(pp->firstvar, pp->numvar);
+	}
+	for(v = el_views; v != NOVIEW; v = v->nextview)
+		io_fixexternalvariables(v->firstvar, v->numvar);
+	for(i=0; i<io_binindata.cellindex; i++)
+	{
+		c = io_binindata.celllist[i];
+		io_fixexternalvariables(c->firstvar, c->numvar);
+	}
+	for(i=0; i<io_binindata.nodeprotoindex; i++)
+	{
+		np = io_binindata.nodeprotolist[i];
+		io_fixexternalvariables(np->firstvar, np->numvar);
+	}
+
 	/* convert port references in external facets */
 	for(i=0; i<io_binindata.nodeprotoindex; i++)
 	{
@@ -1204,12 +1282,12 @@ char *io_doreadlibrary(LIBRARY *lib)
 		efree(io_binindata.techerror[te]);
 	}
 	for(i=0; i<io_binindata.aacount; i++)
-		if (io_binindata.aiderror[i] != 0)
+		if (io_binindata.toolerror[i] != 0)
 	{
 		if (io_verbose > 0)
-			ttyputmsg(M_("Unknown aid %s not used so all is well"),
-				io_binindata.aiderror[i]);
-		efree(io_binindata.aiderror[i]);
+			ttyputmsg(M_("Unknown tool %s not used so all is well"),
+				io_binindata.toolerror[i]);
+		efree(io_binindata.toolerror[i]);
 	}
 	for(i=0; i<io_binindata.nodepprotoindex; i++)
 		if (io_binindata.nodepprotoorig[i] != 0)
@@ -1277,9 +1355,9 @@ char *io_doreadlibrary(LIBRARY *lib)
 	efree((char *)io_binindata.portpprotolist);
 	efree((char *)io_binindata.arcprotolist);
 	efree((char *)io_binindata.techlist);
-	efree((char *)io_binindata.aidlist);
+	efree((char *)io_binindata.toollist);
 	efree((char *)io_binindata.techerror);
-	efree((char *)io_binindata.aiderror);
+	efree((char *)io_binindata.toolerror);
 	efree((char *)io_binindata.nodepprotoerror);
 	efree((char *)io_binindata.nodepprotoorig);
 	efree((char *)io_binindata.portpprotoerror);
@@ -1342,9 +1420,11 @@ INTSML io_readnodeproto(NODEPROTO *np)
 	if (io_binindata.magic >= MAGIC5)
 	{
 		io_getinbig(&np->lastnodeproto);
-		(void)io_convertnodeproto(&np->lastnodeproto);
+		if (io_convertnodeproto(&np->lastnodeproto, 0) != 0)
+			ttyputmsg(_("...while reading cell %s"), np->cell->cellname);
 		io_getinbig(&np->nextnodeproto);
-		(void)io_convertnodeproto(&np->nextnodeproto);
+		if (io_convertnodeproto(&np->nextnodeproto, 0) != 0)
+			ttyputmsg(_("...while reading cell %s"), np->cell->cellname);
 	}
 
 	/* read the number of portprotos on this nodeproto */
@@ -1387,12 +1467,24 @@ INTSML io_readnodeproto(NODEPROTO *np)
 		/* read the portproto name and text descriptor */
 		pp->protoname = io_getstring(np->cell->lib->cluster);
 		if (pp->protoname == 0) return(1);
-		if (io_binindata.magic <= MAGIC9) io_getinubig(&pp->textdescript);
+		if (io_binindata.magic <= MAGIC9)
+		{
+			if (io_binindata.converttextdescriptors != 0)
+			{
+				/* conversion is done later */
+				io_getinubig(&pp->textdescript[0]);
+				pp->textdescript[1] = 0;
+			} else
+			{
+				io_getinubig(&pp->textdescript[0]);
+				io_getinubig(&pp->textdescript[1]);
+			}
+		}
 
 		/* ignore the "seen" bits (versions 8 and older) */
 		if (io_binindata.magic > MAGIC9) io_getinubig(&k);
 
-		/* read the portproto aid information */
+		/* read the portproto tool information */
 		if (io_binindata.magic <= MAGIC7)
 		{
 			/* version 7 and later simply read the relevant data */
@@ -1426,9 +1518,9 @@ INTSML io_readnodeproto(NODEPROTO *np)
 		io_getinbig(&i);
 	}
 
-	/* read aid information */
+	/* read tool information */
 	io_getinubig(&np->adirty);
-	np->adirty = io_arrangeaidbits((INTBIG)np->adirty);
+	np->adirty = io_arrangetoolbits((INTBIG)np->adirty);
 	if (io_binindata.magic <= MAGIC7)
 	{
 		/* version 7 and later simply read the relevant data */
@@ -1523,7 +1615,12 @@ void io_readexternalnodeproto(LIBRARY *lib, INTBIG i)
 		if (io != 0)
 		{
 			xclose(io);
-			ttyputmsg(_("Reading referenced library %s"), filename);
+			ttyputmsg(_("Reading referenced library %s on %s"), filename,
+				timetostring(getcurrenttime()));
+#ifdef ONUNIX
+			printf(_("Reading referenced library %s on %s\n"), filename,
+				timetostring(getcurrenttime()));
+#endif
 		} else
 		{
 			(void)initinfstr();
@@ -1543,6 +1640,7 @@ void io_readexternalnodeproto(LIBRARY *lib, INTBIG i)
 		}
 
 		len = strlen(libfile);
+		io_libinputrecursivedepth++;
 		if (len > 4 && namesame(&libfile[len-4], ".txt") == 0)
 		{
 			/* ends in ".txt", presume text file */
@@ -1552,9 +1650,10 @@ void io_readexternalnodeproto(LIBRARY *lib, INTBIG i)
 			/* all other endings: presume binary file */
 			k = io_doreadbinlibrary(elib, 0);
 		}
-		for(k=0; k<el_maxaid; k++)
-			if (el_aids[k].readlibrary != 0)
-				(*el_aids[k].readlibrary)(elib);
+		io_libinputrecursivedepth--;
+		for(k=0; k<el_maxtools; k++)
+			if (el_tools[k].readlibrary != 0)
+				(*el_tools[k].readlibrary)(elib);
 		io_binindata = savebinindata;
 		if (io_verbose < 0 && io_binindata.filelength > 0)
 		{
@@ -1702,6 +1801,8 @@ void io_readexternalnodeproto(LIBRARY *lib, INTBIG i)
 		np->cellview = v;
 		np->creationdate = creation;
 		np->revisiondate = revision;
+		setval((INTBIG)np, VNODEPROTO, "IO_true_library", (INTBIG)elib->libname, VSTRING);
+		setval((INTBIG)np, VNODEPROTO, "IO_true_cell", (INTBIG)c->cellname, VSTRING);
 
 		/* rename the cell */
 		if (c->temp1 == 0)
@@ -1795,7 +1896,7 @@ INTSML io_readnodeinst(NODEINST *ni)
 {
 	INTBIG i, k;
 	REGISTER INTSML j;
-	REGISTER char *inst;
+	char *inst;
 	REGISTER PORTARCINST *pi, *lpo;
 	REGISTER PORTEXPINST *pe, *lpe;
 	PORTPROTO *pp;
@@ -1804,7 +1905,8 @@ INTSML io_readnodeinst(NODEINST *ni)
 
 	/* read the nodeproto index */
 	io_getinbig(&ni->proto);
-	inst = io_convertnodeproto(&ni->proto);
+	if (io_convertnodeproto(&ni->proto, &inst) != 0)
+		ttyputmsg(_("...while reading node instance"));
 	if (inst != 0)
 	{
 		if (orignodename == 0) orignodename = makekey("NODE_original_name");
@@ -1823,7 +1925,19 @@ INTSML io_readnodeinst(NODEINST *ni)
 	ni->rotation = (INTSML)i;
 
 	/* versions 9 and later get text descriptor for facet name */
-	if (io_binindata.magic <= MAGIC9) io_getinubig(&ni->textdescript);
+	if (io_binindata.magic <= MAGIC9)
+	{
+		if (io_binindata.converttextdescriptors != 0)
+		{
+			/* conversion is done later */
+			io_getinubig(&ni->textdescript[0]);
+			ni->textdescript[1] = 0;
+		} else
+		{
+			io_getinubig(&ni->textdescript[0]);
+			io_getinubig(&ni->textdescript[1]);
+		}
+	}
 
 	/* read the nodeinst name (versions 1, 2, or 3 only) */
 	if (io_binindata.magic >= MAGIC3)
@@ -1898,7 +2012,7 @@ INTSML io_readnodeinst(NODEINST *ni)
 	/* ignore the "seen" bits (versions 8 and older) */
 	if (io_binindata.magic > MAGIC9) io_getinubig(&k);
 
-	/* read the aid information */
+	/* read the tool information */
 	if (io_binindata.magic <= MAGIC7)
 	{
 		/* version 7 and later simply read the relevant data */
@@ -1998,7 +2112,7 @@ INTSML io_readarcinst(ARCINST *ai)
 	/* ignore the "seen" bits (versions 8 and older) */
 	if (io_binindata.magic > MAGIC9) io_getinubig(&i);
 
-	/* read the arcinst's aid information */
+	/* read the arcinst's tool information */
 	if (io_binindata.magic <= MAGIC7)
 	{
 		/* version 7 and later simply read the relevant data */
@@ -2064,8 +2178,10 @@ void io_ignorevariables(void)
 INTSML io_readvariables(INTBIG addr, INTBIG type)
 {
 	REGISTER INTBIG i, j, datasize, ty, keyval;
+	REGISTER INTSML ret;
 	REGISTER VARIABLE *var;
-	INTBIG count, newtype, len, newaddr, cou, newdescript;
+	INTBIG count, newtype, len, newaddr, cou;
+	UINTBIG newdescript[TEXTDESCRIPTSIZE];
 	INTSML key;
 
 	io_getinbig(&count);
@@ -2079,8 +2195,22 @@ INTSML io_readvariables(INTBIG addr, INTBIG type)
 
 		/* version 9 and later reads text description on displayable variables */
 		if ((ty&VDISPLAY) != 0 && io_binindata.magic <= MAGIC9)
-			io_getinubig(&newdescript); else
-				newdescript = defaulttextdescript(NOGEOM);
+		{
+			if (io_binindata.converttextdescriptors != 0)
+			{
+				/* conversion is done later */
+				io_getinubig(&newdescript[0]);
+				newdescript[1] = 0;
+			} else
+			{
+				io_getinubig(&newdescript[0]);
+				io_getinubig(&newdescript[1]);
+			}
+		} else
+		{
+			TDCLEAR(newdescript);
+			defaulttextdescript(newdescript, NOGEOM);
+		}
 		if ((ty&VISARRAY) != 0)
 		{
 			io_getinbig(&len);
@@ -2097,18 +2227,41 @@ INTSML io_readvariables(INTBIG addr, INTBIG type)
 				for(j=0; j<len; j += 2)
 				{
 					io_getinbig((INTBIG *)(newaddr + (j+1)*datasize));
-					if (io_getinvar((INTBIG *)(newaddr + j*datasize),
-						*(INTBIG *)(newaddr + (j+1)*datasize)) != 0) return(-1);
+					ret = io_getinvar((INTBIG *)(newaddr + j*datasize),
+						*(INTBIG *)(newaddr + (j+1)*datasize));
+					if (ret < 0) return(-1);
+					if (ret > 0)
+					{
+						ttyputmsg(_("...while reading variable '%s' on %s object"),
+							io_binindata.realname[key], us_variabletypename(type));
+					}
 				}
 			} else
 			{
 				for(j=0; j<len; j++)
-					if (io_getinvar((INTBIG *)(newaddr + j*datasize), ty) != 0) return(-1);
+				{
+					ret = io_getinvar((INTBIG *)(newaddr + j*datasize), ty);
+					if (ret < 0) return(-1);
+					if (ret > 0)
+					{
+						ttyputmsg(_("...while reading variable '%s' on %s object"),
+							io_binindata.realname[key], us_variabletypename(type));
+					}
+				}
 			}
 			if ((ty&VLENGTH) == 0)
 				for(j=0; j<datasize; j++)
 					((char *)newaddr)[len*datasize+j] = -1;
-		} else if (io_getinvar(&newaddr, ty) != 0) return(-1);
+		} else
+		{
+			ret = io_getinvar(&newaddr, ty);
+			if (ret < 0) return(-1);
+			if (ret > 0)
+			{
+				ttyputmsg(_("...while reading variable '%s' on %s object"),
+					io_binindata.realname[key], us_variabletypename(type));
+			}
+		}
 
 		/* copy this variable into database */
 		if (io_binindata.newnames[key] == 0) io_binindata.newnames[key] = makekey(io_binindata.realname[key]);
@@ -2116,7 +2269,7 @@ INTSML io_readvariables(INTBIG addr, INTBIG type)
 		nextchangequiet();
 		var = setvalkey(addr, type, keyval, newaddr, newtype);
 		if (var == NOVARIABLE) return(-1);
-		var->textdescript = newdescript;
+		TDCOPY(var->textdescript, newdescript);
 
 		/* handle updating of technology caches */
 		if (type == VTECHNOLOGY)
@@ -2133,6 +2286,11 @@ INTSML io_readvariables(INTBIG addr, INTBIG type)
 	return((INTSML)count);
 }
 
+/*
+ * Helper routine to read a variable at address "addr" of type "ty".
+ * Returns zero if OK, negative on memory error, positive if there were
+ * correctable problems in the read.
+ */
 INTSML io_getinvar(INTBIG *addr, INTBIG ty)
 {
 	INTBIG i;
@@ -2168,7 +2326,7 @@ INTSML io_getinvar(INTBIG *addr, INTBIG ty)
 			break;
 		case VSTRING:
 			pp = io_getstring(el_tempcluster);
-			if (pp == 0) return(1);
+			if (pp == 0) return(-1);
 			*addr = (INTBIG)pp;
 			break;
 		case VNODEINST:
@@ -2178,7 +2336,7 @@ INTSML io_getinvar(INTBIG *addr, INTBIG ty)
 			break;
 		case VNODEPROTO:
 			io_getinbig(addr);
-			(void)io_convertnodeproto((NODEPROTO **)addr);
+			if (io_convertnodeproto((NODEPROTO **)addr, 0) != 0) return(1);
 			break;
 		case VARCPROTO:
 			io_getinbig(addr);
@@ -2236,26 +2394,26 @@ INTSML io_getinvar(INTBIG *addr, INTBIG ty)
 			break;
 		case VLIBRARY:
 			pp = io_getstring(el_tempcluster);
-			if (pp == 0) return(1);
+			if (pp == 0) return(-1);
 			*addr = (INTBIG)getlibrary(pp);
 			break;
-		case VAID:
+		case VTOOL:
 			io_getinbig(addr);
 			if (*addr < 0 || *addr >= io_binindata.aacount) *addr = -1; else
 			{
-				i = io_binindata.aidlist[*addr];
-				if (i < 0 || i >= el_maxaid)
+				i = io_binindata.toollist[*addr];
+				if (i < 0 || i >= el_maxtools)
 				{
 					i = 0;
-					if (io_binindata.aiderror[*addr] != 0)
+					if (io_binindata.toolerror[*addr] != 0)
 					{
-						ttyputerr(_("WARNING: no aid called '%s', using 'user'"),
-							io_binindata.aiderror[*addr]);
-						efree(io_binindata.aiderror[*addr]);
-						io_binindata.aiderror[*addr] = 0;
+						ttyputerr(_("WARNING: no tool called '%s', using 'user'"),
+							io_binindata.toolerror[*addr]);
+						efree(io_binindata.toolerror[*addr]);
+						io_binindata.toolerror[*addr] = 0;
 					}
 				}
-				*addr = (INTBIG)&el_aids[i];
+				*addr = (INTBIG)&el_tools[i];
 			}
 			break;
 		case VRTNODE:
@@ -2265,25 +2423,67 @@ INTSML io_getinvar(INTBIG *addr, INTBIG ty)
    return(0);
 }
 
+/*
+ * routine to fix variables that make reference to external facets.
+ */
+void io_fixexternalvariables(VARIABLE *firstvar, INTSML numvar)
+{
+	REGISTER INTSML i;
+	REGISTER INTBIG j, k, type, len;
+	REGISTER VARIABLE *var;
+	REGISTER NODEPROTO *np, **nparray;
+
+	for(i=0; i<numvar; i++)
+	{
+		var = &firstvar[i];
+		type = var->type;
+		if ((type&VDONTSAVE) != 0) continue;
+		if ((type&VTYPE) != VNODEPROTO) continue;
+		if ((type&VISARRAY) != 0)
+		{
+			len = (type&VLENGTH) >> VLENGTHSH;
+			nparray = (NODEPROTO **)var->addr;
+			if (len == 0) for(len=0; nparray[len] != NONODEPROTO; len++) ;
+			for(j=0; j<len; j++)
+			{
+				np = nparray[j];
+				if ((INTBIG)np >= 0 && (INTBIG)np < io_binindata.nodeprotoindex)
+				{
+					k = (INTBIG)np;
+					nparray[j] = io_binindata.nodeprotolist[k];
+				}
+			}
+		} else
+		{
+			np = (NODEPROTO *)var->addr;
+			if ((INTBIG)np >= 0 && (INTBIG)np < io_binindata.nodeprotoindex)
+			{
+				k = (INTBIG)np;
+				var->addr = (INTBIG)io_binindata.nodeprotolist[k];
+			}
+		}
+	}
+}
+
 /******************** INPUT HELPER ROUTINES ********************/
 
 /*
- * routine to return the proper aid bits word given the arrangement
- * of aids.  These words have one bit per aid according to
- * the aid's position which may get re-arranged.
+ * routine to return the proper tool bits word given the arrangement
+ * of tools.  These words have one bit per tool according to
+ * the tool's position which may get re-arranged.
  */
-INTBIG io_arrangeaidbits(INTBIG val)
+INTBIG io_arrangetoolbits(INTBIG val)
 {
 	REGISTER INTBIG out, i, j;
 
 	/* if the bits are not re-arranged, result is simple */
-	if (io_binindata.aidbitsmessed == 0) return(val);
+	if (io_binindata.toolbitsmessed == 0) return(val);
 
 	/* re-arrange the bits in the word */
 	out = 0;
 	for(i=0; i<io_binindata.aacount; i++)
 	{
-		j = io_binindata.aidlist[i];
+		j = io_binindata.toollist[i];
 		if (j < 0) continue;
 		if ((val & (1 << i)) != 0) out |= 1 << j;
 	}
@@ -2292,17 +2492,17 @@ INTBIG io_arrangeaidbits(INTBIG val)
 
 /*
  * routine to convert the nodeproto index at "np" to a true nodeproto pointer.
- * returns a string with the original name of this prototype (if there were
- * conversion problems in the file).  Returns zero if the pointer is fine.
+ * Sets "origname" to a string with the original name of this prototype (if there were
+ * conversion problems in the file).  Sets "origname" to zero if the pointer is fine.
  */
-char *io_convertnodeproto(NODEPROTO **np)
+INTBIG io_convertnodeproto(NODEPROTO **np, char **origname)
 {
-	REGISTER INTBIG i, nindex;
-	REGISTER char *origname;
+	REGISTER INTBIG i, nindex, error;
 
 	if (*np == NONODEPROTO) return(0);
 	i = (INTBIG)*np;
-	origname = 0;
+	if (origname != 0) *origname = 0;
+	error = 0;
 	if (i < 0)
 	{
 		nindex = -i - 2;
@@ -2311,9 +2511,10 @@ char *io_convertnodeproto(NODEPROTO **np)
 			ttyputerr(_("Error: want primitive node index %ld when limit is %ld"),
 				nindex, io_binindata.nodepprotoindex);
 			nindex = 0;
+			error = 1;
 		}
 		*np = io_getnodepprotolist(nindex);
-		origname = io_binindata.nodepprotoorig[nindex];
+		if (origname != 0) *origname = io_binindata.nodepprotoorig[nindex];
 	} else
 	{
 		if (i >= io_binindata.nodeprotoindex)
@@ -2321,12 +2522,18 @@ char *io_convertnodeproto(NODEPROTO **np)
 			ttyputerr(_("Error: want facet index %ld when limit is %ld"),
 				i, io_binindata.nodeprotoindex);
 			*np = io_getnodepprotolist(0);
+			error = 1;
 		} else
 		{
 			*np = io_binindata.nodeprotolist[i];
+			if (*np == 0)
+			{
+				/* reference to facet in another library: unresolved now */
+				*np = (NODEPROTO *)i;
+			}
 		}
 	}
-	return(origname);
+	return(error);
 }
 
 void io_convertportproto(PORTPROTO **pp)
@@ -2484,9 +2691,9 @@ void io_ensureallports(LIBRARY *lib)
 			pp->connects = pe->proto->connects;
 			pp->subportproto = pe->proto;
 			pp->userbits = pe->proto->userbits;
-			pp->textdescript = defaulttextdescript(NOGEOM);
-			pp->textdescript = (pp->textdescript & ~VTSIZE) |
-				(defaulttextsize(1) << VTSIZESH);
+			TDCLEAR(pp->textdescript);
+			defaulttextsize(1, pp->textdescript);
+			defaulttextdescript(pp->textdescript, NOGEOM);
 		}
 	}
 }
@@ -2762,7 +2969,7 @@ char *io_gettempstring(void)
 	{
 		if (io_tempstringlength != 0) efree(io_tempstring);
 		io_tempstringlength = len+1;
-		io_tempstring = (char *)emalloc(io_tempstringlength, io_aid->cluster);
+		io_tempstring = (char *)emalloc(io_tempstringlength, io_tool->cluster);
 		if (io_tempstring == 0) { io_tempstringlength = 0; return(0); }
 	}
 	if (io_binindata.swap_bytes != 0 && len != 0) io_binindata.swap_bytes = -1;
