@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iobinaryo.c
- * Input/output aid: binary format output
+ * Input/output tool: binary format output
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -38,17 +38,18 @@ static char   *io_namesave;			/* for saving the global namespace */
 static char   *io_outfilename = 0;	/* the name of the file being written */
 
 /* prototypes for local routines */
-void io_cleanup(void);
-void io_writenodeproto(NODEPROTO*, INTSML);
-void io_writenodeinst(NODEINST*);
-void io_writearcinst(ARCINST*);
-void io_writenamespace(void);
-void io_restorenamespace(void);
-void io_writevariables(VARIABLE*, INTSML);
-void io_putoutvar(INTBIG*, INTBIG);
-void io_putout(void*, INTSML);
-void io_putoutbig(void*);
-void io_putstring(char*);
+static void io_cleanup(void);
+static void io_writenodeproto(NODEPROTO*, INTSML);
+static void io_writenodeinst(NODEINST*);
+static void io_writearcinst(ARCINST*);
+static void io_writenamespace(void);
+static void io_restorenamespace(void);
+static void io_writevariables(VARIABLE*, INTSML);
+static void io_findxlibvariables(VARIABLE*, INTSML);
+static void io_putoutvar(INTBIG*, INTBIG);
+static void io_putout(void*, INTSML);
+static void io_putoutbig(void*);
+static void io_putstring(char*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -70,6 +71,8 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	REGISTER ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
 	REGISTER NODEINST *ni;
+	REGISTER PORTARCINST *pi;
+	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai;
 	REGISTER LIBRARY *olib;
 	REGISTER TECHNOLOGY *tech;
@@ -92,10 +95,10 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	i += addstringtoinfstr(".elib");
 	if (io_outfilename == 0) 
 	{
-		i += allocstring(&io_outfilename, returninfstr(), io_aid->cluster);
+		i += allocstring(&io_outfilename, returninfstr(), io_tool->cluster);
 	} else
 	{
-		i += reallocstring(&io_outfilename, returninfstr(), io_aid->cluster);
+		i += reallocstring(&io_outfilename, returninfstr(), io_tool->cluster);
 	}
 	if (dotaddr != 0) *dotaddr = '.';
 	if (i != 0)
@@ -151,7 +154,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 					for(i=0; i<1000; i++)
 					{
 						if (i == 0) sprintf(datesuffix, "-%d-%d-%d", year, month+1, mday); else
-							sprintf(datesuffix, "-%d-%d-%d--%d", year, month+1, mday, i);
+							sprintf(datesuffix, "-%d-%d-%d--%ld", year, month+1, mday, i);
 						(void)strcpy(rename, name);
 						rename[strlen(rename)-5] = 0;
 						(void)strcat(rename, datesuffix);
@@ -184,10 +187,10 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 		us_rename(3, arg);
 		if (io_outfilename == 0) 
 		{
-			(void)allocstring(&io_outfilename, truename, io_aid->cluster);
+			(void)allocstring(&io_outfilename, truename, io_tool->cluster);
 		} else
 		{
-			(void)reallocstring(&io_outfilename, truename, io_aid->cluster);
+			(void)reallocstring(&io_outfilename, truename, io_tool->cluster);
 		}
 		name = io_outfilename;
 	}
@@ -213,33 +216,15 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	io_putout(&magic, 4);
 	wordsize = SIZEOFINTSML;   io_putout(&wordsize, 1);
 	wordsize = SIZEOFINTBIG;   io_putout(&wordsize, 1);
-	aacount = el_maxaid;
+	aacount = el_maxtools;
 	io_putoutbig(&aacount);
 	techcount = el_maxtech;
 	io_putoutbig(&techcount);
 
-	/* count the number of objects in the database */
+	/* initialize the number of objects in the database */
 	nodeindex = portprotoindex = nodeprotoindex = arcindex = nodepprotoindex =
 		portpprotoindex = arcprotoindex = cellindex = 0;
 
-	/* prepare to locate references to facets in other libraries */
-	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
-	{
-		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			np->temp2 = 0;
-		for(c = olib->firstcell; c != NOCELL; c = c->nextcell)
-			c->temp2 = 0;
-	}
-	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-	{
-		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-		{
-			if (ni->proto->primindex != 0) continue;
-			ni->proto->temp2 = 1;
-			ni->proto->cell->temp2 = 1;
-		}
-	}
-
 	/* count and number the cells, facets, nodes, arcs, and ports in this library */
 	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 		c->temp1 = cellindex++;
@@ -255,6 +240,57 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	}
 	facetshere = nodeprotoindex;
 
+	/* prepare to locate references to facets in other libraries */
+	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
+	{
+		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			np->temp2 = 0;
+		for(c = olib->firstcell; c != NOCELL; c = c->nextcell)
+			c->temp2 = 0;
+	}
+
+	/* scan for all cross-library references */
+	io_findxlibvariables(lib->firstvar, lib->numvar);
+	for(i=0; i<el_maxtools; i++)
+		io_findxlibvariables(el_tools[i].firstvar, el_tools[i].numvar);
+	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
+	{
+		io_findxlibvariables(tech->firstvar, tech->numvar);
+		for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
+			io_findxlibvariables(ap->firstvar, ap->numvar);
+		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			io_findxlibvariables(np->firstvar, np->numvar);
+			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				io_findxlibvariables(pp->firstvar, pp->numvar);
+		}
+	}
+	for(v = el_views; v != NOVIEW; v = v->nextview)
+		io_findxlibvariables(v->firstvar, v->numvar);
+	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
+		io_findxlibvariables(c->firstvar, c->numvar);
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	{
+		io_findxlibvariables(np->firstvar, np->numvar);
+		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			io_findxlibvariables(pp->firstvar, pp->numvar);
+		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		{
+			io_findxlibvariables(ni->firstvar, ni->numvar);
+			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+				io_findxlibvariables(pi->firstvar, pi->numvar);
+			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+				io_findxlibvariables(pe->firstvar, pe->numvar);
+			if (ni->proto->primindex == 0)
+			{
+				ni->proto->temp2 = 1;
+				ni->proto->cell->temp2 = 1;
+			}
+		}
+		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			io_findxlibvariables(ai->firstvar, ai->numvar);
+	}
+
 	/* count and number the facets and cells in other libraries */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 	{
@@ -303,7 +339,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 
 	if (io_verbose > 0)
 	{
-		ttyputmsg(M_("Writing %ld aids, %ld technologies"), aacount, techcount);
+		ttyputmsg(M_("Writing %ld tools, %ld technologies"), aacount, techcount);
 		ttyputmsg(M_("        %ld prim nodes, %ld prim ports, %ld arc protos"),
 			nodepprotoindex, portpprotoindex, arcprotoindex);
 		ttyputmsg(M_("        %ld cells %ld facets, %ld ports, %ld nodes, %ld arcs"),
@@ -399,13 +435,13 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 			io_putstring(ap->protoname);
 	}
 
-	/* write the names of the aids */
-	for(i=0; i<el_maxaid; i++) io_putstring(el_aids[i].aidname);
+	/* write the names of the tools */
+	for(i=0; i<el_maxtools; i++) io_putstring(el_tools[i].toolname);
 
 	/* write the userbits for the library */
 	io_putoutbig(&lib->userbits);
 
-	/* write the aid lambda values */
+	/* write the tool lambda values */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		io_putoutbig(&lib->lambda[tech->techindex]);
 
@@ -416,9 +452,9 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	/* write the library variables */
 	io_writevariables(lib->firstvar, lib->numvar);
 
-	/* write the aid variables */
-	for(i=0; i<el_maxaid; i++)
-		io_writevariables(el_aids[i].firstvar, el_aids[i].numvar);
+	/* write the tool variables */
+	for(i=0; i<el_maxtools; i++)
+		io_writevariables(el_tools[i].firstvar, el_tools[i].numvar);
 
 	/* write the variables on technologies */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -532,8 +568,17 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 		efree(rename);
 	}
 
-	ttyputmsg(_("%s written (%ld %s)"), name, facetshere,
-		makeplural(_("facet"), nodeprotoindex));
+	if ((lib->userbits&HIDDENLIBRARY) == 0)
+	{
+		ttyputmsg(_("%s written on %s (%ld %s)"), name,
+			timetostring(getcurrenttime()), facetshere,
+				makeplural(_("facet"), nodeprotoindex));
+#ifdef ONUNIX
+		printf(_("%s written on %s (%ld %s)\n"), name,
+			timetostring(getcurrenttime()), facetshere,
+				makeplural(_("facet"), nodeprotoindex));
+#endif
+	}
 	lib->userbits = (lib->userbits & ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) | READFROMDISK;
 	return(0);
 }
@@ -605,9 +650,10 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 		if (thislib != 0)
 		{
 			/* write the text descriptor */
-			io_putoutbig(&pp->textdescript);
+			io_putoutbig(&pp->textdescript[0]);
+			io_putoutbig(&pp->textdescript[1]);
 
-			/* write the portproto aid information */
+			/* write the portproto tool information */
 			io_putoutbig(&pp->userbits);
 
 			/* write variable information */
@@ -617,7 +663,7 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 
 	if (thislib != 0)
 	{
-		/* write aid information */
+		/* write tool information */
 		io_putoutbig(&np->adirty);
 		io_putoutbig(&np->userbits);
 
@@ -645,7 +691,9 @@ void io_writenodeinst(NODEINST *ni)
 	io_putoutbig(&ni->highy);
 	i = ni->transpose;   io_putoutbig(&i);
 	i = ni->rotation;    io_putoutbig(&i);
-	io_putoutbig(&ni->textdescript);
+
+	io_putoutbig(&ni->textdescript[0]);
+	io_putoutbig(&ni->textdescript[1]);
 
 	/* count the arc ports */
 	i = 0;
@@ -685,7 +733,7 @@ void io_writenodeinst(NODEINST *ni)
 		io_writevariables(pe->firstvar, pe->numvar);
 	}
 
-	/* write the aid information */
+	/* write the tool information */
 	io_putoutbig(&ni->userbits);
 
 	/* write variable information */
@@ -712,7 +760,7 @@ void io_writearcinst(ARCINST *arcinst)
 		io_putoutbig(&arcinst->end[i].nodeinst->temp1);
 	}
 
-	/* write the arcinst's aid information */
+	/* write the arcinst's tool information */
 	io_putoutbig(&arcinst->userbits);
 
 	/* write variable information */
@@ -760,10 +808,54 @@ void io_restorenamespace(void)
 	efree(io_namesave);
 }
 
+/*
+ * Routine to scan the variables on an object (which are in "firstvar" and "numvar")
+ * for NODEPROTO references.  Any found are marked (by setting "temp2" to 1).
+ * This is used to gather cross-library references.
+ */
+void io_findxlibvariables(VARIABLE *firstvar, INTSML numvar)
+{
+	REGISTER INTSML i;
+	REGISTER INTBIG len, type, j;
+	REGISTER VARIABLE *var;
+	REGISTER NODEPROTO *np, **nparray;
+
+	for(i=0; i<numvar; i++)
+	{
+		var = &firstvar[i];
+		type = var->type;
+		if ((type&VDONTSAVE) != 0) continue;
+		if ((type&VTYPE) != VNODEPROTO) continue;
+		if ((type&VISARRAY) != 0)
+		{
+			len = (type&VLENGTH) >> VLENGTHSH;
+			nparray = (NODEPROTO **)var->addr;
+			if (len == 0) for(len=0; nparray[len] != NONODEPROTO; len++) ;
+			for(j=0; j<len; j++)
+			{
+				np = nparray[j];
+				if (np != NONODEPROTO && np->primindex == 0)
+				{
+					np->temp2 = 1;
+					np->cell->temp2 = 1;
+				}
+			}
+		} else
+		{
+			np = (NODEPROTO *)var->addr;
+			if (np != NONODEPROTO && np->primindex == 0)
+			{
+				np->temp2 = 1;
+				np->cell->temp2 = 1;
+			}
+		}
+	}
+}
+
 void io_writevariables(VARIABLE *firstvar, INTSML numvar)
 {
-	REGISTER INTSML i, j, datasize;
-	INTBIG num, len, addr, ty;
+	REGISTER INTBIG i, j, datasize;
+	INTBIG num, ty, len, addr;
 
 	for(num=i=0; i<numvar; i++)
 		if ((firstvar[i].type&VDONTSAVE) == 0) num++;
@@ -774,7 +866,11 @@ void io_writevariables(VARIABLE *firstvar, INTSML numvar)
 		io_putout((void *)firstvar[i].key, SIZEOFINTSML);
 		ty = firstvar[i].type;
 		io_putoutbig(&ty);
-		if ((ty&VDISPLAY) != 0) io_putoutbig(&firstvar[i].textdescript);
+		if ((ty&VDISPLAY) != 0)
+		{
+			io_putoutbig(&firstvar[i].textdescript[0]);
+			io_putoutbig(&firstvar[i].textdescript[1]);
+		}
 		addr = firstvar[i].addr;
 		if ((ty&VISARRAY) != 0)
 		{
@@ -825,6 +921,7 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER GEOM *geom;
+	REGISTER NODEPROTO *np;
 	INTBIG j;
 	static INTBIG nullptr = -1;
 
@@ -861,9 +958,9 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 					io_putoutbig(&nullptr);
 			break;
 		case VNODEPROTO:
-			if ((NODEPROTO *)*addr != NONODEPROTO)
-				io_putoutbig(&((NODEPROTO *)*addr)->temp1); else
-					io_putoutbig(&nullptr);
+			np = (NODEPROTO *)*addr;
+			if (np != NONODEPROTO) io_putoutbig(&np->temp1); else
+				io_putoutbig(&nullptr);
 			break;
 		case VARCPROTO:
 			if ((ARCPROTO *)*addr != NOARCPROTO)
@@ -910,9 +1007,9 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 				io_putstring(((LIBRARY *)*addr)->libname); else
 					io_putstring("noname");
 			break;
-		case VAID:
-			if ((AIDENTRY *)*addr != NOAID)
-				io_putoutbig(&((AIDENTRY *)*addr)->aidindex); else
+		case VTOOL:
+			if ((TOOL *)*addr != NOTOOL)
+				io_putoutbig(&((TOOL *)*addr)->toolindex); else
 					io_putoutbig(&nullptr);
 			break;
 		case VSHORT:
