@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iocifin.c
- * Input/output aid: CIF input
+ * Input/output tool: CIF input
  * Written by: Robert Winstanley, University of Calgary
  *
  * Copyright (c) 2000 Static Free Software.
@@ -52,11 +52,11 @@ typedef struct Icifcell
 	struct Icifcell *nextcell;		/* the next cif cell in the list */
 } CIFCELL;
 
-CIFCELL **io_cifcells = (CIFCELL **)NOSTRING; /* hash table of 'cifcells' */
-static INTBIG io_cifcells_size = 0; 	/* allocated size of io_cifcells */
-static INTBIG io_cifcells_num = 0;	/* number of used entries in io_cifcells */
-CIFCELL *io_curcell;				/* the current cell */
-static INTSML io_cifroundwires;		/* nonzero if wires should be rounded */
+static CIFCELL **io_cifcells = (CIFCELL **)NOSTRING; /* hash table of 'cifcells' */
+static INTBIG    io_cifcells_size = 0; 	/* allocated size of io_cifcells */
+static INTBIG    io_cifcells_num = 0;	/* number of used entries in io_cifcells */
+static CIFCELL  *io_curcell;			/* the current cell */
+static INTSML    io_cifroundwires;		/* nonzero if wires should be rounded */
 
 /**************************** CIF LISTS ****************************/
 
@@ -81,8 +81,8 @@ typedef struct Iciflist
 	struct Iciflist *next;			/* next entry in list */
 } CIFLIST;
 
-CIFLIST *io_ciflist = NOCIFLIST;	/* head of the list */
-CIFLIST *io_curlist;				/* current location in list */
+static CIFLIST *io_ciflist = NOCIFLIST;	/* head of the list */
+static CIFLIST *io_curlist;				/* current location in list */
 
 /**************************** MEMBER STRUCTURES ****************************/
 
@@ -143,37 +143,37 @@ typedef struct Ictrans
 	struct Ictrans *next;			/* next element in list */
 } CTRANS;
 
-CTRANS *io_curctrans;				/* current transformation description */
+static CTRANS *io_curctrans;				/* current transformation description */
 
 /**************************** MISCELLANEOUS ****************************/
 
-char       *io_curnodeprotoname;		/* name of the current cell */
-NODEPROTO  *io_incell;					/* address of facet being defined */
-NODEPROTO **io_cifnodes = 0;			/* nodeprotos associated with CIF names */
-INTSML      io_varlength;				/* the length of all attribute arrays */
-VARIABLE   *io_cifnames;				/* cif names for the current technology */
-INTBIG      io_cifnotfoundcount;		/* number of unknown layer names */
-char      **io_cifnotfoundlist;			/* unknown layer name list */
-INTBIG      io_cifnotfoundlimit = 0;	/* size of unknown layer name list */
+static char       *io_curnodeprotoname;		/* name of the current cell */
+static NODEPROTO  *io_incell;				/* address of facet being defined */
+static NODEPROTO **io_cifnodes = 0;			/* nodeprotos associated with CIF names */
+static INTSML      io_varlength;			/* the length of all attribute arrays */
+static VARIABLE   *io_cifnames;				/* cif names for the current technology */
+static INTBIG      io_cifnotfoundcount;		/* number of unknown layer names */
+static char      **io_cifnotfoundlist;		/* unknown layer name list */
+static INTBIG      io_cifnotfoundlimit = 0;	/* size of unknown layer name list */
 
 /* prototypes for local routines */
-INTSML     io_interpret(FILE*);
-INTSML     io_listtonodes(LIBRARY*);
-NODEPROTO *io_nodes_start(LIBRARY*);
-INTSML     io_nodes_box(void);
-INTSML     io_nodes_poly(void);
-INTSML     io_nodes_call(void);
-void       io_rotatelayer(INTBIG*, INTBIG*, INTSML);
-INTSML     io_initfind(void);
-NODEPROTO *io_findprotonode(INTSML);
-CIFCELL   *io_findcifcell(INTBIG);
-void       io_insertcifcell(CIFCELL *cifcell);
-CIFCELL   *io_newcifcell(INTBIG);
-CIFLIST   *io_newciflist(INTSML);
-void       io_placeciflist(INTSML);
-CTRANS    *io_newctrans(void);
-void       io_ciffreeciflist(void);
-void       io_ciffreecifcells(void);
+static INTSML     io_interpret(FILE*);
+static INTSML     io_listtonodes(LIBRARY*);
+static NODEPROTO *io_nodes_start(LIBRARY*);
+static INTSML     io_nodes_box(void);
+static INTSML     io_nodes_poly(void);
+static INTSML     io_nodes_call(void);
+static void       io_rotatelayer(INTBIG*, INTBIG*, INTSML);
+static INTSML     io_initfind(void);
+static NODEPROTO *io_findprotonode(INTSML);
+static CIFCELL   *io_findcifcell(INTBIG);
+static void       io_insertcifcell(CIFCELL *cifcell);
+static CIFCELL   *io_newcifcell(INTBIG);
+static CIFLIST   *io_newciflist(INTSML);
+static void       io_placeciflist(INTSML);
+static CTRANS    *io_newctrans(void);
+static void       io_ciffreeciflist(void);
+static void       io_ciffreecifcells(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -227,6 +227,7 @@ INTSML io_readciflibrary(LIBRARY *lib)
 	/* clean up */
 	(void)io_doneinterpreter();
 	for(i=0; i<io_cifnotfoundcount; i++) efree((char *)io_cifnotfoundlist[i]);
+
 	return(0);
 }
 
@@ -291,12 +292,8 @@ INTSML io_listtonodes(LIBRARY *lib)
 				break;
 			case C_END:
 				/* make cell size right */
-#if 0
-				(*el_curconstraint->solve)(io_incell);
-#else
 				db_boundfacet(io_incell, &io_incell->lowx, &io_incell->highx,
 					&io_incell->lowy, &io_incell->highy);
-#endif
 				lib->curnodeproto = io_incell;
 				io_incell = NONODEPROTO;
 				break;
@@ -420,7 +417,7 @@ INTSML io_nodes_poly(void)
 	}
 
 	/* store the trace information */
-	pt = trace = emalloc((cp->lim*2*SIZEOFINTBIG), io_aid->cluster);
+	pt = trace = emalloc((cp->lim*2*SIZEOFINTBIG), io_tool->cluster);
 	if (trace == 0) return(1);
 	cx = (hx + lx) / 2;   cy = (hy + ly) / 2;
 	for(i=0; i<cp->lim; i++)
@@ -562,12 +559,12 @@ INTSML io_initfind(void)
 	/* create the array of nodes associated with the array of CIF names */
 	total = el_curtech->layercount;
 	if (io_cifnodes != 0) efree((char *)io_cifnodes);
-	io_cifnodes = (NODEPROTO **)emalloc((total * (sizeof (NODEPROTO *))), io_aid->cluster);
+	io_cifnodes = (NODEPROTO **)emalloc((total * (sizeof (NODEPROTO *))), io_tool->cluster);
 	if (io_cifnodes == 0) return(-1);
 	for(i=0; i<total; i++) io_cifnodes[i] = NONODEPROTO;
 
 	/* create the polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* run through the node prototypes in this technology */
 	for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -655,7 +652,7 @@ INTBIG io_findlayernum(char *name)
 		newlimit = io_cifnotfoundlimit * 2;
 		if (newlimit <= 0) newlimit = 10;
 		if (newlimit < io_cifnotfoundcount) newlimit = io_cifnotfoundcount;
-		newlist = (char **)emalloc(newlimit * (sizeof (char *)), io_aid->cluster);
+		newlist = (char **)emalloc(newlimit * (sizeof (char *)), io_tool->cluster);
 		if (newlist == 0) return(-1);
 		for(i=0; i<io_cifnotfoundcount; i++)
 			newlist[i] = io_cifnotfoundlist[i];
@@ -663,7 +660,7 @@ INTBIG io_findlayernum(char *name)
 		io_cifnotfoundlist = newlist;
 		io_cifnotfoundlimit = newlimit;
 	}
-	(void)allocstring(&io_cifnotfoundlist[io_cifnotfoundcount], name, io_aid->cluster);
+	(void)allocstring(&io_cifnotfoundlist[io_cifnotfoundcount], name, io_tool->cluster);
 	io_cifnotfoundcount++;
 	ttyputmsg(_("Layer %s not found"), name);
 	return(-1);
@@ -716,7 +713,7 @@ CIFCELL *io_newcifcell(INTBIG cindex)
 	INTBIG new_cifcells_size;
 	INTBIG i;
 
-	newcc = (CIFCELL *)emalloc((sizeof (CIFCELL)), io_aid->cluster);
+	newcc = (CIFCELL *)emalloc((sizeof (CIFCELL)), io_tool->cluster);
 	if (newcc == (CIFCELL *) 0)
 	{
 		ttyputerr(_("Not enough memory allocated for CIFCELL"));
@@ -728,7 +725,7 @@ CIFCELL *io_newcifcell(INTBIG cindex)
 		old_cifcells = io_cifcells;
 		old_cifcells_size = io_cifcells_size;
 		new_cifcells_size = pickprime(io_cifcells_num * 4);
-		io_cifcells = (CIFCELL **)emalloc(new_cifcells_size * (sizeof (CIFCELL *)), io_aid->cluster);
+		io_cifcells = (CIFCELL **)emalloc(new_cifcells_size * (sizeof (CIFCELL *)), io_tool->cluster);
 		if (io_cifcells == (CIFCELL **) 0)
 		{
 			ttyputerr(_("Not enough memory allocated for CIFCELL"));
@@ -774,7 +771,7 @@ CIFLIST *io_newciflist(INTSML id)
 	CCALL *cc;
 	CFSTART *cs;
 
-	newcl = (CIFLIST *)emalloc((sizeof (CIFLIST)), io_aid->cluster);
+	newcl = (CIFLIST *)emalloc((sizeof (CIFLIST)), io_tool->cluster);
 	if (newcl == (CIFLIST *) 0)
 	{
 		ttyputerr(_("Not enough memory allocated for CIFLIST"));
@@ -785,29 +782,29 @@ CIFLIST *io_newciflist(INTSML id)
 	switch (id)
 	{
 		case C_START:
-			cs = (CFSTART *)emalloc((sizeof (CFSTART)), io_aid->cluster);
+			cs = (CFSTART *)emalloc((sizeof (CFSTART)), io_tool->cluster);
 			if (cs == 0) return(NOCIFLIST);
 			newcl->member = (char *)cs;
 			cs->name = 0;
 			break;
 		case C_BOX:
-			newcl->member = (char *)emalloc((sizeof (CBOX)), io_aid->cluster);
+			newcl->member = (char *)emalloc((sizeof (CBOX)), io_tool->cluster);
 			if (newcl->member == (char *) 0) return(NOCIFLIST);
 			break;
 		case C_POLY:
-			newcl->member = (char *)emalloc((sizeof (CPOLY)), io_aid->cluster);
+			newcl->member = (char *)emalloc((sizeof (CPOLY)), io_tool->cluster);
 			if (newcl->member == (char *) 0) return(NOCIFLIST);
 			break;
 		case C_GNAME:
-			newcl->member = (char *)emalloc((sizeof (CGNAME)), io_aid->cluster);
+			newcl->member = (char *)emalloc((sizeof (CGNAME)), io_tool->cluster);
 			if (newcl->member == (char *) 0) return(NOCIFLIST);
 			break;
 		case C_LABEL:
-			newcl->member = (char *)emalloc((sizeof (CLABEL)), io_aid->cluster);
+			newcl->member = (char *)emalloc((sizeof (CLABEL)), io_tool->cluster);
 			if (newcl->member == (char *) 0) return(NOCIFLIST);
 			break;
 		case C_CALL:
-			cc = (CCALL *)emalloc((sizeof (CCALL)), io_aid->cluster);
+			cc = (CCALL *)emalloc((sizeof (CCALL)), io_tool->cluster);
 			if (cc == 0) return(NOCIFLIST);
 			newcl->member = (char *)cc;
 			cc->name = 0;
@@ -875,7 +872,7 @@ CTRANS *io_newctrans(void)
 	CTRANS *newct;
 	CCALL *cc;
 
-	newct = (CTRANS *)emalloc((sizeof (CTRANS)), io_aid->cluster);
+	newct = (CTRANS *)emalloc((sizeof (CTRANS)), io_tool->cluster);
 	if (newct == (CTRANS *) 0)
 	{
 		ttyputerr(_("Not enough memory allocated for CTRANS"));
@@ -991,14 +988,14 @@ void io_outputpolygon(INTSML lay, char *ppath)
 	io_placeciflist(C_POLY);
 	cp = (CPOLY *)io_curlist->member;
 	cp->lay = lay;
-	cp->x = emalloc((lim * SIZEOFINTBIG), io_aid->cluster);
+	cp->x = emalloc((lim * SIZEOFINTBIG), io_tool->cluster);
 	if (cp->x == 0)
 	{
 		ttyputnomemory();
 		cp->lim = 0;
 		return;
 	}
-	cp->y = emalloc((lim * SIZEOFINTBIG), io_aid->cluster);
+	cp->y = emalloc((lim * SIZEOFINTBIG), io_tool->cluster);
 	if (cp->y == 0)
 	{
 		ttyputnomemory();
@@ -1026,7 +1023,7 @@ void io_outputgeoname(char *name, point pt, INTSML lay)
 	io_placeciflist(C_GNAME);
 	cg = (CGNAME *)io_curlist->member;
 	cg->lay = lay;
-	(void)allocstring(&cg->geoname, name, io_aid->cluster);
+	(void)allocstring(&cg->geoname, name, io_tool->cluster);
 	cg->x = pt.x;   cg->y = pt.y;
 }
 
@@ -1036,7 +1033,7 @@ void io_outputlabel(char *name, point pt)
 
 	io_placeciflist(C_LABEL);
 	cl = (CLABEL *)io_curlist->member;
-	(void)allocstring(&cl->label, name, io_aid->cluster);
+	(void)allocstring(&cl->label, name, io_tool->cluster);
 	cl->x = pt.x;   cl->y = pt.y;
 }
 
@@ -1049,7 +1046,7 @@ void io_outputcall(INTBIG number, char *name, char *list)
 	io_placeciflist(C_CALL);
 	cc = (CCALL *)io_curlist->member;
 	cc->cindex = number;
-	(void)allocstring(&cc->name, name, io_aid->cluster);
+	(void)allocstring(&cc->name, name, io_tool->cluster);
 	cc->list = io_curctrans = NOCTRANS;
 	for(i = io_tlistlength((tlist)list); i>0; i--)
 	{
@@ -1082,7 +1079,7 @@ void io_outputds(INTBIG number, char *name, INTBIG l, INTBIG r, INTBIG b, INTBIG
 	io_placeciflist(C_START);
 	cs = (CFSTART *)io_curlist->member;
 	cs->cindex = number;
-	(void)allocstring(&cs->name, name, io_aid->cluster);
+	(void)allocstring(&cs->name, name, io_tool->cluster);
 	cs->l = l;   cs->r = r;
 	cs->b = b;   cs->t = t;
 }
