@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iocifout.c
- * Input/output aid: CIF output
+ * Input/output tool: CIF output
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -69,22 +69,26 @@ typedef struct Ilayerreq
 	struct Ilayerreq *nextlayerreq;
 } LAYERREQ;
 
-LAYERREQ *io_ciflayerreq = NOLAYERREQ;
-LAYERREQ *io_ciflayerreqfree = NOLAYERREQ;
+static LAYERREQ  *io_ciflayerreq = NOLAYERREQ;
+static LAYERREQ  *io_ciflayerreqfree = NOLAYERREQ;
+static LAYERREQ **io_ciflayerreqlist;
+static INTBIG     io_ciflayerreqlisttotal = 0;
 
-void io_cifwritefacet(NODEPROTO*, INTSML);
-void io_outputcifpoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY, GEOM*);
-void io_cifprintf(char *msg, ...);
-void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG);
-void io_cif_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
-void io_cif_show_reserror(INTBIG, INTBIG, INTBIG, INTBIG);
-INTBIG io_cif_outscale(INTBIG value);
-LAYERREQ *io_alloclayerreq(void);
-void io_freelayerreq(LAYERREQ *req);
-void io_includeciflayer(TECHNOLOGY *tech, INTBIG layer);
-void io_writeciflayer(char *layername);
-void io_cifoptionsdlog(void);
-INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y);
+/* prototypes for local routines */
+static void io_cifwritefacet(NODEPROTO*, INTSML);
+static void io_outputcifpoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY, GEOM*);
+static void io_cifprintf(char *msg, ...);
+static void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG);
+static void io_cif_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
+static void io_cif_show_reserror(INTBIG, INTBIG, INTBIG, INTBIG);
+static INTBIG io_cif_outscale(INTBIG value);
+static LAYERREQ *io_alloclayerreq(void);
+static void io_freelayerreq(LAYERREQ *req);
+static void io_includeciflayer(TECHNOLOGY *tech, INTBIG layer);
+static void io_writeciflayer(char *layername);
+static void io_cifoptionsdlog(void);
+static INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y);
+static int io_ciflayerreqascending(const void *e1, const void *e2);
 
 /*
  * Routine to free all memory associated with this module.
@@ -105,6 +109,7 @@ void io_freecifoutmemory(void)
 		io_ciflayerreqfree = req->nextlayerreq;
 		efree((char *)req);
 	}
+	if (io_ciflayerreqlisttotal > 0) efree((char *)io_ciflayerreqlist);
 }
 
 /*
@@ -161,7 +166,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	{
 		io_cif_resolution = (INTSML)var->addr;
 		if (io_cif_resolution != 0 && io_cif_highlightreserr != 0)
-			(void)askaid(us_aid, "clear");
+			(void)asktool(us_tool, "clear");
 	}
 
 	/* get the number of allowable points on a polygon */
@@ -284,16 +289,15 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	REGISTER NODEPROTO *subnt, *bodysubnt, *onp;
 	REGISTER PORTPROTO *pp, *subpp;
 	REGISTER PORTARCINST *pi;
-	REGISTER INTBIG i, j, sorted, total, validport, toplayer, toplayerfound;
-	REGISTER char *rname, *nname;
+	REGISTER INTBIG i, j, total, validport, toplayer, toplayerfound;
 	REGISTER INTBIG offx, offy, fun;
-	REGISTER LAYERREQ *req, *lastreq, *nextreq;
+	REGISTER LAYERREQ *req;
 	XARRAY trans, localtran, temp2, subrot;
 	INTBIG rx, ry, xpos, ypos, bx, by, cx, cy;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	io_cifoutfacetnumber++;
 	if (fake == 0)
@@ -313,6 +317,10 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	{
 		subnt = subni->proto;
 		if (subnt->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (subnt->cell == np->cell) continue;
+
 		if ((subni->userbits & NEXPAND) == 0 && (io_cifoutputstate[0]&CIFOUTEXACT) != 0) continue;
 
 		/* convert body facets to contents facets */
@@ -379,31 +387,29 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 		}
 
 		/* sort the requests by layer name */
-		sorted = 0;
-		while (sorted == 0)
+		total = 0;
+		for(req = io_ciflayerreq; req != NOLAYERREQ; req = req->nextlayerreq)
+			total++;
+		if (total > io_ciflayerreqlisttotal)
 		{
-			sorted = 1;
-			lastreq = NOLAYERREQ;
-			for(req = io_ciflayerreq; req != NOLAYERREQ; req = req->nextlayerreq)
-			{
-				nextreq = req->nextlayerreq;
-				if (nextreq == NOLAYERREQ) break;
-				rname = req->layername;
-				if (rname == 0) rname = "";
-				nname = nextreq->layername;
-				if (nname == 0) nname = "";
-				if (namesame(rname, nname) > 0)
-				{
-					/* swap them */
-					if (lastreq == NOLAYERREQ) io_ciflayerreq = nextreq; else
-						lastreq->nextlayerreq = nextreq;
-					req->nextlayerreq = nextreq->nextlayerreq;
-					nextreq->nextlayerreq = req;
-					req = nextreq;
-					sorted = 0;
-				}
-				lastreq = req;
-			}
+			if (io_ciflayerreqlisttotal > 0)
+				efree((char *)io_ciflayerreqlist);
+			io_ciflayerreqlisttotal = 0;
+			io_ciflayerreqlist = (LAYERREQ **)emalloc(total * (sizeof (LAYERREQ *)),
+				io_tool->cluster);
+			if (io_ciflayerreqlist == 0) return;
+			io_ciflayerreqlisttotal = total;
+		}
+		total = 0;
+		for(req = io_ciflayerreq; req != NOLAYERREQ; req = req->nextlayerreq)
+			io_ciflayerreqlist[total++] = req;
+		esort(io_ciflayerreqlist, total, sizeof (LAYERREQ *), io_ciflayerreqascending);
+		for(i=0; i<total-1; i++)
+			io_ciflayerreqlist[i]->nextlayerreq = io_ciflayerreqlist[i+1];
+		if (total == 0) io_ciflayerreq = NOLAYERREQ; else
+		{
+			io_ciflayerreq = io_ciflayerreqlist[0];
+			io_ciflayerreqlist[total-1]->nextlayerreq = NOLAYERREQ;
 		}
 
 		/* now write geometry by layer */
@@ -505,6 +511,10 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	{
 		subnt = subni->proto;
 		if (subnt->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (subnt->cell == np->cell) continue;
+
 		i = subni->rotation;
 		if (subni->transpose != 0) i = (i + 900) % 3600;
 		rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
@@ -697,6 +707,20 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	io_cifprintf("DF;\n");
 }
 
+int io_ciflayerreqascending(const void *e1, const void *e2)
+{
+	REGISTER LAYERREQ *lr1, *lr2;
+	REGISTER char *lrname1, *lrname2;
+
+	lr1 = *((LAYERREQ **)e1);
+	lr2 = *((LAYERREQ **)e2);
+	lrname1 = lr1->layername;
+	if (lrname1 == 0) lrname1 = "";
+	lrname2 = lr2->layername;
+	if (lrname2 == 0) lrname2 = "";
+	return(namesame(lrname1, lrname2));
+}
+
 INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 {
 	REGISTER INTBIG sea, i, tot, first, bestheight, bestlayer;
@@ -706,7 +730,7 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 	REGISTER ARCINST *ai;
 	static POLYGON *poly = NOPOLYGON;
 
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	sea = initsearch(x, x, y, y, np);
 	first = 1;
 	for(;;)
@@ -724,6 +748,8 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 				if (isinside(x, y, poly) == 0) continue;
 				if (get3dfactors(poly->tech, poly->layer, &height, &thickness) != 0)
 					continue;
+
+				/* LINTED "bestheight" used in proper order */
 				if (first != 0 || height > bestheight)
 				{
 					bestheight = height;
@@ -949,7 +975,7 @@ void io_cifprintf(char *msg, ...)
 	unsigned char c;
 
 	var_start(ap, msg);
-	(void)vsprintf(temp, msg, ap);
+	evsnprintf(temp, 200, msg, ap);
 	va_end(ap);
 
 	/* accumulate CRC */
@@ -993,7 +1019,7 @@ void io_cifreserror(GEOM *pos, INTBIG length, INTBIG width, INTBIG xc, INTBIG yc
 		{
 			/* highlight the object */
 			if (io_cif_highlightreserr != 0)
-				(void)askaid(us_aid, "show-object", (INTBIG)pos);
+				(void)asktool(us_tool, "show-object", (INTBIG)pos);
 			io_reserr_count++;
 		}
 	}
@@ -1093,7 +1119,7 @@ void io_cif_show_reserror(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 	/* show resolution error if it is in the current window */
 	np = getcurfacet();
 	if (np == io_cifoutcurnp)
-		(void)askaid(us_aid, "show-line", x1, y1, x2, y2, np); else
+		(void)asktool(us_tool, "show-line", x1, y1, x2, y2, np); else
 			ttyputmsg(_("Resolution error in subfacet %s"),
 				describenodeproto(io_cifoutcurnp));
 }
@@ -1131,7 +1157,7 @@ LAYERREQ *io_alloclayerreq(void)
 
 	if (io_ciflayerreqfree == NOLAYERREQ)
 	{
-		req = (LAYERREQ *)emalloc(sizeof (LAYERREQ), io_aid->cluster);
+		req = (LAYERREQ *)emalloc(sizeof (LAYERREQ), io_tool->cluster);
 		if (req == 0) return(NOLAYERREQ);
 	} else
 	{
@@ -1148,7 +1174,7 @@ void io_freelayerreq(LAYERREQ *req)
 }
 
 /* CIF Options */
-DIALOGITEM io_cifoptionsdialogitems[] =
+static DIALOGITEM io_cifoptionsdialogitems[] =
 {
  /*  1 */ {0, {180,380,204,452}, BUTTON, N_("OK")},
  /*  2 */ {0, {180,240,204,312}, BUTTON, N_("Cancel")},
@@ -1163,7 +1189,7 @@ DIALOGITEM io_cifoptionsdialogitems[] =
  /* 11 */ {0, {148,388,164,454}, EDITTEXT, ""},
  /* 12 */ {0, {128,232,144,436}, POPUP, ""}
 };
-DIALOG io_cifoptionsdialog = {{50,75,263,538}, N_("CIF Options"), 0, 12, io_cifoptionsdialogitems};
+static DIALOG io_cifoptionsdialog = {{50,75,263,538}, N_("CIF Options"), 0, 12, io_cifoptionsdialogitems};
 
 /* special items for the "CIF Options" dialog: */
 #define DCFO_LAYERLIST         3		/* Layer list (scroll list) */
