@@ -83,73 +83,73 @@ static linkedpoint  *io_cifpfree;
 static linkedtentry *io_ciftfree = NIL;
 
 /* prototypes for local routines */
-char io_endseen(void);
-void io_idefstart(INTBIG, INTBIG, INTBIG);
-void io_idefend(void);
-void io_ideletedef(INTBIG);
-void io_ilayer(char*);
-void io_icomment(char*);
-void io_iusercommand(INTBIG, char*);
-void io_iend(void);
-void io_iwire(INTBIG, char*);
-void io_iwire(INTBIG, char*);
-void io_iflash(INTBIG, point);
-void io_ipolygon(char*);
+static char io_endseen(void);
+static void io_idefstart(INTBIG, INTBIG, INTBIG);
+static void io_idefend(void);
+static void io_ideletedef(INTBIG);
+static void io_ilayer(char*);
+static void io_icomment(char*);
+static void io_iusercommand(INTBIG, char*);
+static void io_iend(void);
+static void io_iwire(INTBIG, char*);
+static void io_iwire(INTBIG, char*);
+static void io_iflash(INTBIG, point);
+static void io_ipolygon(char*);
 static void io_scalepath(char*, char*);
-void io_ibox(INTBIG, INTBIG, point, INTBIG, INTBIG);
-void io_icall(INTBIG, char*);
-void io_isymname(char*);
-void io_iinstname(char*);
-void io_igeoname(char*, point, INTBIG);
-void io_ilabel(char*, point);
-void io_makesymname(char*, INTBIG);
-void io_makeinstname(char*, INTBIG);
+static void io_ibox(INTBIG, INTBIG, point, INTBIG, INTBIG);
+static void io_icall(INTBIG, char*);
+static void io_isymname(char*);
+static void io_iinstname(char*);
+static void io_igeoname(char*, point, INTBIG);
+static void io_ilabel(char*, point);
+static void io_makesymname(char*, INTBIG);
+static void io_makeinstname(char*, INTBIG);
 static void io_newstentry(stentry*, INTBIG);
-stentry *io_lookupsym(INTBIG);
-void io_freesymbols(void);
-void io_initmm(point);
-void io_donemm(void);
-void io_minmax(point);
-INTBIG io_minx(void);
-INTBIG io_miny(void);
-INTBIG io_maxx(void);
-INTBIG io_maxy(void);
-void io_findcallbb(symcall*);
+static stentry *io_lookupsym(INTBIG);
+static void io_freesymbols(void);
+static void io_initmm(point);
+static void io_donemm(void);
+static void io_minmax(point);
+static INTBIG io_minx(void);
+static INTBIG io_miny(void);
+static INTBIG io_maxx(void);
+static INTBIG io_maxy(void);
+static void io_findcallbb(symcall*);
 static void io_findbb(stentry*);
-char io_initutil(void);
-void io_freestorage(void);
-void io_freedef(objectptr);
+static char io_initutil(void);
+static void io_freestorage(void);
+static void io_freedef(objectptr);
 static void io_clear(transform);
-INTSML io_swapcontext(INTBIG);
-INTSML io_increfcount(INTBIG);
-INTSML io_decrefcount(INTBIG);
-void io_pushtrans(void);
-void io_poptrans(void);
+static INTSML io_swapcontext(INTBIG);
+static INTSML io_increfcount(INTBIG);
+static INTSML io_decrefcount(INTBIG);
+static void io_pushtrans(void);
+static void io_poptrans(void);
 static void io_matmult(transform, transform, transform);
 static void io_mmult(transform, transform, transform);
-void io_applylocal(transform);
+static void io_applylocal(transform);
 static void io_assign(transform, transform);
-void io_rotate(INTBIG, INTBIG);
-void io_translate(INTBIG, INTBIG);
-void io_mirror(char);
-void io_dumpstack(void);
+static void io_rotate(INTBIG, INTBIG);
+static void io_translate(INTBIG, INTBIG);
+static void io_mirror(char);
+static void io_dumpstack(void);
 static void io_printmat(transform);
-void io_bbpolygon(INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-void io_bbwire(INTBIG, INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-char io_inititems(void);
-INTSML io_doneitems(void);
+static void io_bbpolygon(INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
+static void io_bbwire(INTBIG, INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
+static char io_inititems(void);
+static INTSML io_doneitems(void);
 static itementry *io_newnode(void);
 static void io_freenode(itementry*);
 static void io_sendlist(itementry*);
 static void io_dumpdef(stentry*);
 static void io_shipcontents(stentry*);
 static void io_outitem(itementry*);
-void io_item(objectptr);
+static void io_item(objectptr);
 static char io_initinput(void);
 static char io_doneinput(void);
 static char io_getch(void);
 static char io_peek(void);
-char io_endoffile(void);
+static char io_endoffile(void);
 static INTBIG io_flush(char);
 static void io_identify(void);
 static char io_inittypes(void);
@@ -157,15 +157,15 @@ static void io_freeciftfree(void);
 static char io_donetypes(void);
 static linkedpoint *io_getpnode(void);
 static void io_freepnode(linkedpoint*);
-void io_copypath(path, path);
-void io_freetlist(tlist);
-void io_dupetlist(tlist, tlist);
+static void io_copypath(path, path);
+static void io_freetlist(tlist);
+static void io_dupetlist(tlist, tlist);
 static linkedtentry *io_gettnode(void);
 static void io_freetnode(linkedtentry*);
-void io_appendtentry(tlist, tentry);
+static void io_appendtentry(tlist, tentry);
 static char io_initerror(void);
 static char io_doneerror(void);
-void io_report(char*, INTBIG);
+static void io_report(char*, INTBIG);
 static void io_blank(void);
 static void io_sep(void);
 static char io_semi(void);
@@ -177,11 +177,13 @@ static INTBIG io_signed(void);
 static void io_logit(INTBIG);
 static point io_getpoint(void);
 static void io_getpath(path);
-char io_inittrans(void);
-char io_donetrans(void);
-tmatrix io_getlocal(void);
-point io_transpoint(point);
-void io_freeonedef(struct kludge *cur);
+static char io_inittrans(void);
+static char io_donetrans(void);
+static tmatrix io_getlocal(void);
+static point io_transpoint(point);
+static void io_freeonedef(struct kludge *cur);
+static char *io_maketlist(void);
+static INTBIG io_parsestatement(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -262,7 +264,7 @@ void io_idefend(void)
 	if (!io_cifnamed)
 	{
 		io_makesymname(s, io_cifcurrent->st_symnumber);
-		(void)allocstring(&io_cifcurrent->st_name, s, io_aid->cluster);
+		(void)allocstring(&io_cifcurrent->st_name, s, io_tool->cluster);
 	}
 	io_cifcurrent->st_defined = 1;
 }
@@ -358,7 +360,7 @@ void io_iwire(INTBIG width, char *a)
 		io_nulllayererrors++;
 		return;
 	}
-	obj = (wire *)emalloc((length-1)*sizeof(point)+sizeof(wire), io_aid->cluster);
+	obj = (wire *)emalloc((length-1)*sizeof(point)+sizeof(wire), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_iwire"), FATALINTERNAL);
@@ -416,7 +418,7 @@ void io_iflash(INTBIG diameter,point center)
 		return;
 	}
 
-	obj = (flash *)emalloc(sizeof(flash), io_aid->cluster);
+	obj = (flash *)emalloc(sizeof(flash), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_iflash"), FATALINTERNAL);
@@ -464,7 +466,7 @@ void io_ipolygon(char *a)
 		return;
 	}
 
-	obj = (polygon *)emalloc((length-1)*sizeof(point)+sizeof(polygon), io_aid->cluster);
+	obj = (polygon *)emalloc((length-1)*sizeof(point)+sizeof(polygon), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_ipolygon"), FATALINTERNAL);
@@ -557,7 +559,7 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 	)
 	{
 		mbox *obj;
-		obj = (mbox *)emalloc(sizeof(mbox), io_aid->cluster);
+		obj = (mbox *)emalloc(sizeof(mbox), io_tool->cluster);
 		if (obj == NIL)
 		{
 			io_report(_("no space: io_ibox"), FATALINTERNAL);
@@ -589,7 +591,7 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 	{
 		box *obj;
 
-		obj = (box *)emalloc(sizeof(box), io_aid->cluster);
+		obj = (box *)emalloc(sizeof(box), io_tool->cluster);
 		if (obj == NIL)
 		{
 			io_report(_("no space: io_ibox"), FATALINTERNAL);
@@ -653,7 +655,7 @@ void io_icall(INTBIG symbol, char *list)
 		io_appendtentry((tlist)newtlist, temp);	/* copy the list */
 	}
 
-	obj = (symcall *)emalloc(sizeof(symcall), io_aid->cluster);
+	obj = (symcall *)emalloc(sizeof(symcall), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_icall"), FATALINTERNAL);
@@ -679,7 +681,7 @@ void io_icall(INTBIG symbol, char *list)
 	{
 		char s[50];
 		io_makeinstname(s, io_cifinstance);
-		(void)allocstring(&obj->sy_name, s, io_aid->cluster);
+		(void)allocstring(&obj->sy_name, s, io_tool->cluster);
 	}
 	if (io_cifdefinprog)
 	{
@@ -710,7 +712,7 @@ void io_isymname(char *name)
 		return;
 	}
 	io_cifnamed = 1;
-	(void)allocstring(&io_cifcurrent->st_name, name, io_aid->cluster);
+	(void)allocstring(&io_cifcurrent->st_name, name, io_tool->cluster);
 }
 
 void io_iinstname(char *name)
@@ -728,7 +730,7 @@ void io_iinstname(char *name)
 	}
 	io_cifnamepending = 1;
 	io_cifstatesince = 0;
-	(void)allocstring(&io_cifnstored, name, io_aid->cluster);
+	(void)allocstring(&io_cifnstored, name, io_tool->cluster);
 }
 
 void io_igeoname(char *name, point pt, INTBIG lay)
@@ -743,7 +745,7 @@ void io_igeoname(char *name, point pt, INTBIG lay)
 		io_report(_("null geometry name ignored"), ADVISORY);
 		return;
 	}
-	obj = (gname *)emalloc(sizeof(gname), io_aid->cluster);
+	obj = (gname *)emalloc(sizeof(gname), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_igeoname"), FATALINTERNAL);
@@ -758,7 +760,7 @@ void io_igeoname(char *name, point pt, INTBIG lay)
 		pt.y = (INTBIG)(io_cifscalefactor * (float)pt.y);
 	}
 	obj->gn_pos = pt;
-	(void)allocstring(&obj->gn_name, name, io_aid->cluster);
+	(void)allocstring(&obj->gn_name, name, io_tool->cluster);
 
 	io_pushtrans();
 	temp = io_transpoint(pt);
@@ -788,7 +790,7 @@ void io_ilabel(char *name, point pt)
 		io_report(_("null label ignored"), ADVISORY);
 		return;
 	}
-	obj = (label *)emalloc(sizeof(label), io_aid->cluster);
+	obj = (label *)emalloc(sizeof(label), io_tool->cluster);
 	if (obj == NIL)
 	{
 		io_report(_("no space: io_ilabel"), FATALINTERNAL);
@@ -802,7 +804,7 @@ void io_ilabel(char *name, point pt)
 		pt.y = (INTBIG)(io_cifscalefactor * (float)pt.y);
 	}
 	obj->la_pos = pt;
-	(void)allocstring(&obj->la_name, name, io_aid->cluster);
+	(void)allocstring(&obj->la_name, name, io_tool->cluster);
 
 	io_pushtrans();
 	temp = io_transpoint(pt);
@@ -864,7 +866,7 @@ stentry *io_lookupsym(INTBIG sym)
 	if (io_cifstable[hadd] == NIL)
 	{
 		/* create a new entry */
-		io_cifstable[hadd] = (stentry *)emalloc(sizeof(stentry), io_aid->cluster);
+		io_cifstable[hadd] = (stentry *)emalloc(sizeof(stentry), io_tool->cluster);
 		if (io_cifstable[hadd] == NIL)
 		{
 			io_report(_("no space: io_lookupsym"), FATALINTERNAL);
@@ -882,7 +884,7 @@ stentry *io_lookupsym(INTBIG sym)
 				else {old = cur; cur = cur->st_overflow;}
 
 	/* no matching symbol numbers, so create a new one */
-	old->st_overflow = (stentry *)emalloc(sizeof(stentry), io_aid->cluster);
+	old->st_overflow = (stentry *)emalloc(sizeof(stentry), io_tool->cluster);
 	if (old->st_overflow == NIL)
 	{
 		io_report(_("no space: io_lookupsym"), FATALINTERNAL);
@@ -1142,7 +1144,7 @@ char io_inittrans(void)
 {
 	INTBIG i;
 
-	io_cifstacktop = (transform)emalloc(sizeof(tmatrix), io_aid->cluster);
+	io_cifstacktop = (transform)emalloc(sizeof(tmatrix), io_tool->cluster);
 	if (io_cifstacktop == NIL)
 	{
 		io_report(_("no space: io_inittrans"), FATALINTERNAL);
@@ -1153,7 +1155,7 @@ char io_inittrans(void)
 	io_cifstacktop->prev = NIL;
 	io_cifstacktop->multiplied = 1;
 
-	io_cifcarray = (context *)emalloc((CONTSIZE*sizeof(context)), io_aid->cluster);
+	io_cifcarray = (context *)emalloc((CONTSIZE*sizeof(context)), io_tool->cluster);
 	if (io_cifcarray == NIL)
 	{
 		io_report(_("no space: intitrans"), FATALINTERNAL);
@@ -1247,7 +1249,7 @@ void io_pushtrans(void)
 {
 	if (io_cifstacktop->next == NIL)
 	{
-		io_cifstacktop->next = (transform)emalloc(sizeof(tmatrix), io_aid->cluster);
+		io_cifstacktop->next = (transform)emalloc(sizeof(tmatrix), io_tool->cluster);
 		if (io_cifstacktop->next == NIL)
 			io_report(_("no space: io_pushtrans"), FATALINTERNAL);
 		io_clear(io_cifstacktop->next);
@@ -1581,7 +1583,7 @@ static itementry *io_newnode(void)		/* return a new itementry */
 
 	if (io_cifittop == NIL)
 	{
-		ans = (itementry *)emalloc(sizeof(itementry), io_aid->cluster);
+		ans = (itementry *)emalloc(sizeof(itementry), io_tool->cluster);
 		if (ans == NIL)
 		{
 			io_report(_("io_newnode: no space"), FATALINTERNAL);
@@ -2104,7 +2106,7 @@ char *io_makepath(void)
 {
 	path a;
 
-	a = (path)emalloc(sizeof(*a), io_aid->cluster);
+	a = (path)emalloc(sizeof(*a), io_tool->cluster);
 	if (a == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
@@ -2137,7 +2139,7 @@ static linkedpoint *io_getpnode(void)
 
 	if (io_cifpfree == NIL)
 	{
-		return((linkedpoint *)emalloc(sizeof(linkedpoint), io_aid->cluster));
+		return((linkedpoint *)emalloc(sizeof(linkedpoint), io_tool->cluster));
 	}
 	ans = io_cifpfree;
 	io_cifpfree = io_cifpfree->pnext;
@@ -2208,7 +2210,7 @@ char *io_maketlist(void)
 {
 	tlist a;
 
-	a = (tlist)emalloc(sizeof(*a), io_aid->cluster);
+	a = (tlist)emalloc(sizeof(*a), io_tool->cluster);
 	if (a == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
@@ -2254,7 +2256,7 @@ static linkedtentry *io_gettnode(void)
 
 	if (io_ciftfree == NIL)
 	{
-		ans = (linkedtentry *)emalloc(sizeof(linkedtentry), io_aid->cluster);
+		ans = (linkedtentry *)emalloc(sizeof(linkedtentry), io_tool->cluster);
 		if (ans == 0) return(0);
 		return(ans);
 	}
@@ -2409,17 +2411,20 @@ static void io_blank(void)
 {
 	REGISTER char c;
 
-	while (1) switch (c = io_peek())
+	for(;;)
 	{
-		case '(':
-		case ')':
-		case ';':
-		case '-':
-		case EOF:
-			return;
-		default:
-			if (isdigit(c) || isupper(c)) return;
-				else (void) io_getch();
+		switch (c = io_peek())
+		{
+			case '(':
+			case ')':
+			case ';':
+			case '-':
+			case EOF:
+				return;
+			default:
+				if (isdigit(c) || isupper(c)) return;
+					else (void) io_getch();
+		}
 	}
 }
 
@@ -2427,17 +2432,20 @@ static void io_sep(void)
 {
 	REGISTER char c;
 
-	while (1) switch (c = io_peek())
+	for(;;)
 	{
-		case '(':
-		case ')':
-		case ';':
-		case '-':
-		case EOF:
-			return;
-		default:
-			if (isdigit(c)) return;
-				else (void) io_getch();
+		switch (c = io_peek())
+		{
+			case '(':
+			case ')':
+			case ';':
+			case '-':
+			case EOF:
+				return;
+			default:
+				if (isdigit(c)) return;
+					else (void) io_getch();
+		}
 	}
 }
 
@@ -2468,7 +2476,7 @@ static char *io_utext(void)
 	INTBIG maxsize = 80;
 	INTBIG size = 0;
 
-	if ((user = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
+	if ((user = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return((char *)0);
@@ -2482,7 +2490,7 @@ static char *io_utext(void)
 			INTBIG i;
 			maxsize += 80;
 			olduser = user;
-			user = (char *)emalloc(maxsize, io_aid->cluster);
+			user = (char *)emalloc(maxsize, io_tool->cluster);
 			if (user == NIL)
 				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) user[i] = olduser[i];
@@ -2500,7 +2508,7 @@ static char *io_name(void)
 	INTBIG size = 0;
 	char c; char nochar = 1;
 
-	if ((ntext = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
+	if ((ntext = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return((char *) 0);
@@ -2519,7 +2527,7 @@ static char *io_name(void)
 			INTBIG i;
 			maxsize += 80;
 			oldntext = ntext;
-			if ((ntext = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
+			if ((ntext = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
 				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) ntext[i] = oldntext[i];
 			efree(oldntext);
@@ -2735,7 +2743,7 @@ INTBIG io_parsestatement(void)
 			symbolnumber = io_cardinal(); ERRORCHECK;
 			io_blank();
 			curtlist = io_maketlist();
-			while (1)
+			for(;;)
 			{
 				switch (io_peek())
 				{
@@ -2787,7 +2795,7 @@ INTBIG io_parsestatement(void)
 				INTBIG size = 0;
 
 				command = COMMENT;
-				if ((comment = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
+				if ((comment = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
 				{
 					io_report(_("free storage exhausted"), FATALINTERNAL);
 					break;
@@ -2817,7 +2825,7 @@ INTBIG io_parsestatement(void)
 
 						maxsize += 80;
 						oldcomment = comment;
-						comment = (char *)emalloc(maxsize, io_aid->cluster);
+						comment = (char *)emalloc(maxsize, io_tool->cluster);
 						if (comment == NIL)
 						{
 							io_report(_("free storage exhausted"), FATALINTERNAL);
