@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iodefi.c
- * Input/output aid: DEF (Design Exchange Format) reader
+ * Input/output tool: DEF (Design Exchange Format) reader
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -54,38 +54,39 @@
 static COMCOMP iodefop = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
 	INPUTOPT, " \t", M_("DEF options"), 0};
 
-INTBIG  io_deffilesize;
-INTBIG  io_deflineno;
-char    io_defline[MAXLINE];
-char    io_deffilename[300];
-INTBIG  io_deflinepos;
-INTBIG  io_defunits;
-VIADEF *io_deffirstviadef;
+static INTBIG  io_deffilesize;
+static INTBIG  io_deflineno;
+static char    io_defline[MAXLINE];
+static char    io_deffilename[300];
+static INTBIG  io_deflinepos;
+static INTBIG  io_defunits;
+static VIADEF *io_deffirstviadef;
 
-char      *io_defgetkeyword(FILE *f);
-INTSML     io_defignoretosemicolon(FILE *f, char *command);
-INTSML     io_defreadfile(FILE *f, LIBRARY *lib);
-INTSML     io_defreadpropertydefinitions(FILE *f);
-INTSML     io_defreadnets(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options);
-INTSML     io_defreadpins(FILE *f, NODEPROTO *facet);
-INTSML     io_defreadcomponents(FILE *f, NODEPROTO *facet);
-INTSML     io_defreadvias(FILE *f, NODEPROTO *facet);
-INTSML     io_defreadcomponent(FILE *f, NODEPROTO *facet);
-INTSML     io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y);
-NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib);
-INTSML     io_defreadpin(FILE *f, NODEPROTO *facet);
-INTSML     io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans);
-void       io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc);
-INTSML     io_defreadunits(FILE *f);
-char      *io_defmustgetkeyword(FILE *f, char *where);
-INTSML     io_defreadvia(FILE *f);
-INTSML     io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options);
-void       io_definerror(char *command, ...);
-INTSML     io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
-				NODEINST **theni, PORTPROTO **thepp);
-void       io_defoptionsdlog(void);
-INTSML     io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
-				NODEINST *not, NODEINST **theni, PORTPROTO **thepp);
+/* prototypes for local routines */
+static char      *io_defgetkeyword(FILE *f);
+static INTSML     io_defignoretosemicolon(FILE *f, char *command);
+static INTSML     io_defreadfile(FILE *f, LIBRARY *lib);
+static INTSML     io_defreadpropertydefinitions(FILE *f);
+static INTSML     io_defreadnets(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options);
+static INTSML     io_defreadpins(FILE *f, NODEPROTO *facet);
+static INTSML     io_defreadcomponents(FILE *f, NODEPROTO *facet);
+static INTSML     io_defreadvias(FILE *f, NODEPROTO *facet);
+static INTSML     io_defreadcomponent(FILE *f, NODEPROTO *facet);
+static INTSML     io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y);
+static NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib);
+static INTSML     io_defreadpin(FILE *f, NODEPROTO *facet);
+static INTSML     io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans);
+static void       io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc);
+static INTSML     io_defreadunits(FILE *f);
+static char      *io_defmustgetkeyword(FILE *f, char *where);
+static INTSML     io_defreadvia(FILE *f);
+static INTSML     io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options);
+static void       io_definerror(char *command, ...);
+static INTSML     io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
+					NODEINST **theni, PORTPROTO **thepp);
+static void       io_defoptionsdlog(void);
+static INTSML     io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
+					NODEINST *not, NODEINST **theni, PORTPROTO **thepp);
 
 /*
  * Routine to free all memory associated with this module.
@@ -281,9 +282,9 @@ INTSML io_defreadvia(FILE *f)
 	if (key == 0) return(1);
 
 	/* create a new via definition */
-	vd = (VIADEF *)emalloc(sizeof (VIADEF), io_aid->cluster);
+	vd = (VIADEF *)emalloc(sizeof (VIADEF), io_tool->cluster);
 	if (vd == 0) return(1);
-	(void)allocstring(&vd->vianame, key, io_aid->cluster);
+	(void)allocstring(&vd->vianame, key, io_tool->cluster);
 	vd->sx = vd->sy = 0;
 	vd->via = NONODEPROTO;
 	vd->lay1 = vd->lay2 = NOARCPROTO;
@@ -433,8 +434,7 @@ INTSML io_defreadcomponent(FILE *f, NODEPROTO *facet)
 				var = setvalkey((INTBIG)ni, VNODEINST, el_node_name,
 					(INTBIG)compname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
-					var->textdescript = (var->textdescript & ~VTSIZE) |
-						(defaulttextsize(3) << VTSIZESH);
+					defaulttextsize(3, var->textdescript);
 				continue;
 			}
 			continue;
@@ -793,6 +793,8 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			if (lastlogni != NONODEINST && (options&DEFNOLOGICAL) == 0)
 			{
 				portposition(ni, pp, &fx, &fy);
+
+				/* LINTED "lastlogpp" used in proper order */
 				portposition(lastlogni, lastlogpp, &tx, &ty);
 				bits = us_makearcuserbits(gen_unroutedarc);
 				ai = newarcinst(gen_unroutedarc, defaultarcwidth(gen_unroutedarc), bits,
@@ -1064,7 +1066,7 @@ INTSML io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygons */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	sea = initsearch(x, x, y, y, facet);
 	for(;;)
@@ -1223,7 +1225,7 @@ void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO
 	static POLYGON *poly = NOPOLYGON;
 
 	/* initialize */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	*pin = NONODEPROTO;
 	*pure = NONODEPROTO;
 	*arc = NOARCPROTO;
@@ -1447,20 +1449,20 @@ void io_definerror(char *command, ...)
 	char line[500];
 
 	var_start(ap, command);
-	(void)vsprintf(line, command, ap);
+	evsnprintf(line, 500, command, ap);
 	va_end(ap);
 	ttyputerr(_("File %s, line %ld: %s"), io_deffilename, io_deflineno, line);
 }
 
 /* DEF Options */
-DIALOGITEM io_defoptionsdialogitems[] =
+static DIALOGITEM io_defoptionsdialogitems[] =
 {
  /*  1 */ {0, {64,156,88,228}, BUTTON, N_("OK")},
  /*  2 */ {0, {64,16,88,88}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {32,8,48,230}, CHECK, N_("Place logical interconnect")},
  /*  4 */ {0, {8,8,24,230}, CHECK, N_("Place physical interconnect")}
 };
-DIALOG io_defoptionsdialog = {{50,75,147,314}, N_("DEF Options"), 0, 4, io_defoptionsdialogitems};
+static DIALOG io_defoptionsdialog = {{50,75,147,314}, N_("DEF Options"), 0, 4, io_defoptionsdialogitems};
 
 /* special items for the "DEF Options" dialog: */
 #define DDFO_PLACELOGICAL    3	/* Place logical interconnect (check) */
