@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iodxf.c
- * Input/output aid: DXF input
+ * Input/output tool: DXF input
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -65,70 +65,70 @@ typedef struct Iforwardref
 	struct Iforwardref  *nextforwardref;
 } FORWARDREF;
 
-INTSML            io_dxfreadalllayers;
-INTSML            io_dxfflatteninput;
-INTBIG            io_dxfcurline, io_dxflength;
-INTBIG            io_dxfentityhandle;
-INTSML            io_dxfgroupid, io_dxfpairvalid, io_dxfignoredpoints, io_dxfignoredattribdefs,
-				  io_dxfignoredattributes;
-INTSML            io_dxfreadpolylines, io_dxfreadlines, io_dxfreadcircles, io_dxfreadsolids,
-				  io_dxfread3dfaces, io_dxfreadarcs, io_dxfreadinserts, io_dxfreadtexts;
-char              io_dxfline[MAXCHARSPERLINE];
-DXFLAYER         *io_dxffirstlayer = 0;
-FORWARDREF       *io_dxffirstforwardref;
-NODEPROTO        *io_dxfmainfacet;
-NODEPROTO        *io_dxfcurfacet;
-char            **io_dxfheadertext;
-INTSML           *io_dxfheaderid;
-INTSML            io_dxfinputmode;			/* 0: pairs not read, 1: normal pairs, 2: blank lines */
-INTSML            io_dxfheadertotal = 0;
-INTSML            io_dxfheadercount = 0;
-INTSML            io_dxfvalidlayercount = 0;
-char            **io_dxfvalidlayernames;
-INTSML           *io_dxfvalidlayernumbers;
-void             *io_dxfignoredlayerstringarray = 0;
-INTBIG            io_dxfscalefactor;
-INTBIG            io_dxflayerkey = 0;
+static INTSML            io_dxfreadalllayers;
+static INTSML            io_dxfflatteninput;
+static INTBIG            io_dxfcurline, io_dxflength;
+static INTBIG            io_dxfentityhandle;
+static INTSML            io_dxfgroupid, io_dxfpairvalid, io_dxfignoredpoints, io_dxfignoredattribdefs,
+						 io_dxfignoredattributes;
+static INTSML            io_dxfreadpolylines, io_dxfreadlines, io_dxfreadcircles, io_dxfreadsolids,
+						 io_dxfread3dfaces, io_dxfreadarcs, io_dxfreadinserts, io_dxfreadtexts;
+static char              io_dxfline[MAXCHARSPERLINE];
+static DXFLAYER         *io_dxffirstlayer = 0;
+static FORWARDREF       *io_dxffirstforwardref;
+static NODEPROTO        *io_dxfmainfacet;
+static NODEPROTO        *io_dxfcurfacet;
+static char            **io_dxfheadertext;
+static INTSML           *io_dxfheaderid;
+static INTSML            io_dxfinputmode;			/* 0: pairs not read, 1: normal pairs, 2: blank lines */
+static INTSML            io_dxfheadertotal = 0;
+static INTSML            io_dxfheadercount = 0;
+static INTSML            io_dxfvalidlayercount = 0;
+static char            **io_dxfvalidlayernames;
+static INTSML           *io_dxfvalidlayernumbers;
+static void             *io_dxfignoredlayerstringarray = 0;
+static INTBIG            io_dxflayerkey = 0;
 
 /* prototypes for local routines */
-INTSML     io_dxfgetacceptablelayers(void);
-INTSML     io_dxfacceptablelayer(DXFLAYER *layer);
-char      *io_dxfblockname(char *name);
-void       io_dxfclearacceptablelayers(void);
-void       io_dxfclearlayers(void);
-INTSML     io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float ysca, INTSML rot, NODEPROTO *np);
-NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca);
-DXFLAYER  *io_dxfgetlayer(char *name);
-INTSML     io_dxfgetnextline(FILE *io, char *text, INTSML canBeBlank);
-INTSML     io_dxfgetnextpair(FILE *io, INTSML *groupID, char **text);
-INTSML     io_dxfignoreentity(FILE *io);
-void       io_dxfoptionsdlog(void);
-void       io_dxfpushpair(INTSML groupID, char *text);
-INTSML     io_dxfreadcircleentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG *rad, DXFLAYER **layer);
-INTSML     io_dxfreadentities(FILE *io, LIBRARY *lib);
-INTSML     io_dxfignoresection(FILE *io);
-INTSML     io_dxfreadblock(FILE *io, char **name);
-INTSML     io_dxfreadarcentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG *rad, double *sangle,
-			double *eangle, DXFLAYER **retLayer);
-INTSML     io_dxfreadheadersection(FILE *io);
-INTSML     io_dxfreadinsertentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, char **name, INTSML *rot,
-			float *xsca, float *ysca, INTSML *xrep, INTSML *yrep, INTBIG *xspa, INTBIG *yspa, DXFLAYER **retLayer);
-INTSML     io_dxfreadlineentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2, INTBIG *z2,
-			INTSML *lineType, DXFLAYER **retLayer);
-INTSML     io_dxfreadpolylineentity(FILE *io, INTBIG **xp, INTBIG **yp, INTBIG **zp, double **bulge,
-			INTSML *count, INTSML *closed, INTSML *lineType, DXFLAYER **layer);
-INTSML     io_dxfreadsolidentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2, INTBIG *z2,
-			INTBIG *x3, INTBIG *y3, INTBIG *z3, INTBIG *x4, INTBIG *y4, INTBIG *z4, DXFLAYER **retLayer);
-INTSML     io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, char **msg, INTBIG *descript, DXFLAYER **retLayer);
-INTSML     io_dxfreadtablessection(FILE *io);
-INTSML     io_dxfread3dfaceentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2,
-			INTBIG *z2, INTBIG *x3, INTBIG *y3, INTBIG *z3, INTBIG *x4, INTBIG *y4, INTBIG *z4, DXFLAYER **layer);
-void       io_dxfwritefacet(NODEPROTO *np, INTSML subfacets);
-char      *io_dxffacetname(NODEPROTO *np);
+static INTSML     io_dxfgetacceptablelayers(void);
+static INTSML     io_dxfacceptablelayer(DXFLAYER *layer);
+static char      *io_dxfblockname(char *name);
+static void       io_dxfclearacceptablelayers(void);
+static void       io_dxfclearlayers(void);
+static INTSML     io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float ysca, INTSML rot, NODEPROTO *np);
+static NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca);
+static DXFLAYER  *io_dxfgetlayer(char *name);
+static INTSML     io_dxfgetnextline(FILE *io, char *text, INTSML canBeBlank);
+static INTSML     io_dxfgetnextpair(FILE *io, INTSML *groupID, char **text);
+static INTSML     io_dxfignoreentity(FILE *io);
+static void       io_dxfoptionsdlog(void);
+static void       io_dxfpushpair(INTSML groupID, char *text);
+static INTSML     io_dxfreadcircleentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG *rad, DXFLAYER **layer);
+static INTSML     io_dxfreadentities(FILE *io, LIBRARY *lib);
+static INTSML     io_dxfignoresection(FILE *io);
+static INTSML     io_dxfreadblock(FILE *io, char **name);
+static INTSML     io_dxfreadarcentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG *rad, double *sangle,
+					double *eangle, DXFLAYER **retLayer);
+static INTSML     io_dxfreadheadersection(FILE *io);
+static INTSML     io_dxfreadinsertentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, char **name, INTSML *rot,
+					float *xsca, float *ysca, INTSML *xrep, INTSML *yrep, INTBIG *xspa, INTBIG *yspa, DXFLAYER **retLayer);
+static INTSML     io_dxfreadlineentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2, INTBIG *z2,
+					INTSML *lineType, DXFLAYER **retLayer);
+static INTSML     io_dxfreadpolylineentity(FILE *io, INTBIG **xp, INTBIG **yp, INTBIG **zp, double **bulge,
+					INTSML *count, INTSML *closed, INTSML *lineType, DXFLAYER **layer);
+static INTSML     io_dxfreadsolidentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2, INTBIG *z2,
+					INTBIG *x3, INTBIG *y3, INTBIG *z3, INTBIG *x4, INTBIG *y4, INTBIG *z4, DXFLAYER **retLayer);
+static INTSML     io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, char **msg,
+					UINTBIG *descript, DXFLAYER **retLayer);
+static INTSML     io_dxfreadtablessection(FILE *io);
+static INTSML     io_dxfread3dfaceentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2,
+					INTBIG *z2, INTBIG *x3, INTBIG *y3, INTBIG *z3, INTBIG *x4, INTBIG *y4, INTBIG *z4, DXFLAYER **layer);
+static void       io_dxfwritefacet(NODEPROTO *np, INTSML subfacets);
+static char      *io_dxffacetname(NODEPROTO *np);
 #ifdef PRESERVEDXF
   static void  *io_dxfpreservestringarray = 0;
-  void io_dxfstartgathering(void);
-  void io_dxfstoredxf(NODEINST *ni);
+  static void io_dxfstartgathering(void);
+  static void io_dxfstoredxf(NODEINST *ni);
 #endif
 
 /****************************************** WRITING DXF ******************************************/
@@ -322,7 +322,7 @@ void io_dxfwritefacet(NODEPROTO *np, INTSML subfacets)
 				if (var != NOVARIABLE)
 				{
 					/* get polygon */
-					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 					i = nodepolys(ni, 0, NOWINDOWPART);
 					for(j=0; j<i; j++)
 					{
@@ -437,7 +437,7 @@ char *io_dxffacetname(NODEPROTO *np)
 	if (namesame(np->cell->cellname, np->cell->lib->libname) == 0)
 	{
 		/* use another name */
-		buf = (char *)emalloc(strlen(np->cell->cellname)+4, io_aid->cluster);
+		buf = (char *)emalloc(strlen(np->cell->cellname)+4, io_tool->cluster);
 		if (buf == 0) return(np->cell->cellname);
 		for(i=1; i<1000; i++)
 		{
@@ -508,7 +508,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 	io_dxfheadercount = 0;
 	if (io_dxfignoredlayerstringarray == 0)
 	{
-		io_dxfignoredlayerstringarray = newstringarray(io_aid->cluster);
+		io_dxfignoredlayerstringarray = newstringarray(io_tool->cluster);
 		if (io_dxfignoredlayerstringarray == 0) return(1);
 	}
 	clearstrings(io_dxfignoredlayerstringarray);
@@ -725,7 +725,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 		for(i=0; i<len; i++)
 		{
 			if (i > 0) (void)addstringtoinfstr(", ");
-			(void)addstringtoinfstr(list[i]);
+			(void)formatinfstr("'%s'", list[i]);
 		}
 		ttyputmsg("%s", returninfstr());
 	}
@@ -750,9 +750,9 @@ INTSML io_dxfreadheadersection(FILE *io)
 		if (io_dxfheadercount >= io_dxfheadertotal)
 		{
 			newtotal = io_dxfheadercount + 25;
-			newtext = (char **)emalloc(newtotal * (sizeof (char *)), io_aid->cluster);
+			newtext = (char **)emalloc(newtotal * (sizeof (char *)), io_tool->cluster);
 			if (newtext == 0) return(1);
-			newid = (INTSML *)emalloc(newtotal * SIZEOFINTSML, io_aid->cluster);
+			newid = (INTSML *)emalloc(newtotal * SIZEOFINTSML, io_tool->cluster);
 			if (newid == 0) return(1);
 			for(i=0; i<io_dxfheadercount; i++)
 			{
@@ -770,7 +770,7 @@ INTSML io_dxfreadheadersection(FILE *io)
 			io_dxfheadertotal = newtotal;
 		}
 		if (io_dxfheadertext[io_dxfheadercount] == 0)
-			allocstring(&io_dxfheadertext[io_dxfheadercount], text, io_aid->cluster);
+			allocstring(&io_dxfheadertext[io_dxfheadercount], text, io_tool->cluster);
 		io_dxfheaderid[io_dxfheadercount] = groupID;
 		io_dxfheadercount++;
 	}
@@ -813,7 +813,7 @@ INTSML io_dxfreadtablessection(FILE *io)
 			if (groupID == 0 && strcmp(text, "LAYER") == 0)
 			{
 				/* make a new layer */
-				layer = (DXFLAYER *)emalloc(sizeof (DXFLAYER), io_aid->cluster);
+				layer = (DXFLAYER *)emalloc(sizeof (DXFLAYER), io_tool->cluster);
 				if (layer == 0) return(1);
 				layer->layerName = 0;
 				layer->layerColor = -1;
@@ -825,7 +825,7 @@ INTSML io_dxfreadtablessection(FILE *io)
 			}
 			if (groupID == 2 && layer != 0)
 			{
-				layer->layerName = (char *)emalloc(strlen(text)+1, io_aid->cluster);
+				layer->layerName = (char *)emalloc(strlen(text)+1, io_tool->cluster);
 				if (layer->layerName == 0) return(1);
 				strcpy(layer->layerName, text);
 			}
@@ -902,7 +902,8 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 	float xsca, ysca;
 	INTSML groupID, count, i, closed, xrep, yrep, rot, lineType, start, last;
 	INTBIG x1,y1,z1, x2,y2,z2, x3,y3,z3, x4,y4,z4, rad, *xp,*yp,*zp, coord[8], *coords, lx, hx, ly, hy,
-		xc, yc, xspa, yspa, descript, iangle;
+		xc, yc, xspa, yspa, iangle;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	double sangle, eangle, startoffset, bulgesign;
 	double *bulge;
 	DXFLAYER *layer;
@@ -1010,9 +1011,9 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 					if (strcmp(np->cell->cellname, pt) == 0) break;
 				if (np == NONODEPROTO)
 				{
-					fr = (FORWARDREF *)emalloc(sizeof (FORWARDREF), io_aid->cluster);
+					fr = (FORWARDREF *)emalloc(sizeof (FORWARDREF), io_tool->cluster);
 					if (fr == 0) return(1);
-					(void)allocstring(&fr->refname, pt, io_aid->cluster);
+					(void)allocstring(&fr->refname, pt, io_tool->cluster);
 					fr->parent = io_dxfcurfacet;
 					fr->x = x1;		fr->y = y1;
 					fr->rot = rot;
@@ -1103,8 +1104,8 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 									ttyputerr(_("Domain error in polyline bulge computation"));
 									continue;
 								}
-								sa = atan2(y1-yc, x1-xc);
-								ea = atan2(y2-yc, x2-xc);
+								sa = atan2((double)(y1-yc), (double)(x1-xc));
+								ea = atan2((double)(y2-yc), (double)(x2-xc));
 								if (bulge[last] < 0.0)
 								{
 									r2 = sa;   sa = ea;   ea = r2;
@@ -1275,7 +1276,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 		}
 		if (strcmp(text, "TEXT") == 0)
 		{
-			if (io_dxfreadtextentity(io, &lx, &hx, &ly, &hy, &msg, &descript, &layer) != 0) return(1);
+			if (io_dxfreadtextentity(io, &lx, &hx, &ly, &hy, &msg, descript, &layer) != 0) return(1);
 			/* if (io_dxfreadalllayers == 0) continue; */
 			if (io_dxfacceptablelayer(layer) == 0)
 			{
@@ -1294,7 +1295,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 #endif
 					var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)msg,
 						VSTRING|VDISPLAY);
-					if (var != NOVARIABLE) var->textdescript = descript;
+					if (var != NOVARIABLE) TDCOPY(var->textdescript, descript);
 					setvalkey((INTBIG)ni, VNODEINST, io_dxflayerkey, (INTBIG)layer->layerName, VSTRING);
 				}
 				efree(msg);
@@ -1522,9 +1523,17 @@ INTSML io_dxfreadpolylineentity(FILE *io, INTBIG **xp, INTBIG **yp, INTBIG **zp,
 				if (inEnd != 0)
 				{
 					io_dxfpushpair(groupID, text);
+
+					/* LINTED "x" used in proper order */
 					*xp = x;
+
+					/* LINTED "y" used in proper order */
 					*yp = y;
+
+					/* LINTED "z" used in proper order */
 					*zp = z;
+
+					/* LINTED "bulge" used in proper order */
 					*bulgep = bulge;
 					*count = vertCount;
 					return(0);
@@ -1635,7 +1644,8 @@ INTSML io_dxfreadsolidentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBI
 	return(0);
 }
 
-INTSML io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, char **msg, INTBIG *descript, DXFLAYER **retLayer)
+INTSML io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy,
+	char **msg, UINTBIG *descript, DXFLAYER **retLayer)
 {
 	char *text, *saveMsg;
 	INTSML groupID, gotxa, px, py;
@@ -1670,8 +1680,7 @@ INTSML io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 	if (gotxa != 0)
 	{
 		*lx = mini(x, xalign);	*hx = *lx + abs(xalign-x) * 2;
-		*ly = y;		*hy = y + height;
-		*descript = VTPOSBOXED | (defaulttextsize(2) << VTSIZESH);
+		*ly = y;                *hy = y + height;
 	} else
 	{
 		if (*saveMsg == 0)
@@ -1684,8 +1693,9 @@ INTSML io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 			*lx = x;	*hx = x + height*px/py;
 			*ly = y;	*hy = y + height;
 		}
-		*descript = VTPOSBOXED | (defaulttextsize(2) << VTSIZESH);
 	}
+	defaulttextsize(2, descript);
+	TDSETPOS(descript, VTPOSBOXED);
 	*msg = saveMsg;
 	return(0);
 }
@@ -1923,9 +1933,9 @@ DXFLAYER *io_dxfgetlayer(char *name)
 		if (strcmp(name, layer->layerName) == 0) return(layer);
 
 	/* create a new one */
-	layer = (DXFLAYER *)emalloc(sizeof (DXFLAYER), io_aid->cluster);
+	layer = (DXFLAYER *)emalloc(sizeof (DXFLAYER), io_tool->cluster);
 	if (layer == 0) return(0);
-	layer->layerName = (char *)emalloc(strlen(name)+1, io_aid->cluster);
+	layer->layerName = (char *)emalloc(strlen(name)+1, io_tool->cluster);
 	if (layer->layerName == 0) return(0);
 	strcpy(layer->layerName, name);
 	layer->layerColor = -1;
@@ -2032,7 +2042,7 @@ void io_dxfstartgathering(void)
 {
 	if (io_dxfpreservestringarray == 0)
 	{
-		io_dxfpreservestringarray = newstringarray(io_aid->cluster);
+		io_dxfpreservestringarray = newstringarray(io_tool->cluster);
 		if (io_dxfpreservestringarray == 0) return;
 	}
 	clearstrings(io_dxfpreservestringarray);
@@ -2120,10 +2130,10 @@ INTSML io_dxfgetacceptablelayers(void)
 
 	/* make space for these values */
 	io_dxfvalidlayernames = (char **)emalloc((io_dxfvalidlayercount * sizeof(char *)),
-		io_aid->cluster);
+		io_tool->cluster);
 	if (io_dxfvalidlayernames == 0) return(1);
 	io_dxfvalidlayernumbers = (INTSML *)emalloc((io_dxfvalidlayercount * SIZEOFINTSML),
-		io_aid->cluster);
+		io_tool->cluster);
 	if (io_dxfvalidlayernumbers == 0) return(1);
 
 	/* set DXF layer names */
@@ -2137,7 +2147,7 @@ INTSML io_dxfgetacceptablelayers(void)
 			while(*pt != 0 && *pt != ',') pt++;
 			save = *pt;
 			*pt = 0;
-			if (allocstring(&io_dxfvalidlayernames[k], start, io_aid->cluster) != 0)
+			if (allocstring(&io_dxfvalidlayernames[k], start, io_tool->cluster) != 0)
 				return(1);
 			io_dxfvalidlayernumbers[k] = (INTSML)i;
 			k++;
@@ -2181,7 +2191,7 @@ char *io_dxfblockname(char *name)
 }
 
 /* DXF Options */
-DIALOGITEM io_dxfoptionsdialogitems[] =
+static DIALOGITEM io_dxfoptionsdialogitems[] =
 {
  /*  1 */ {0, {144,344,168,416}, BUTTON, N_("OK")},
  /*  2 */ {0, {144,248,168,320}, BUTTON, N_("Cancel")},
@@ -2190,7 +2200,7 @@ DIALOGITEM io_dxfoptionsdialogitems[] =
  /*  5 */ {0, {8,324,24,430}, EDITTEXT, ""},
  /*  6 */ {0, {32,240,48,430}, CHECK, N_("Input flattens hierarchy")}
 };
-DIALOG io_dxfoptionsdialog = {{50,75,228,514}, N_("DXF Options"), 0, 6, io_dxfoptionsdialogitems};
+static DIALOG io_dxfoptionsdialog = {{50,75,228,514}, N_("DXF Options"), 0, 6, io_dxfoptionsdialogitems};
 
 /* special items for the "DXF Options" dialog: */
 #define DDXO_LAYERLIST    3		/* Layer list (scroll) */
