@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: ioedifo.c
- * Input/output aid: EDIF netlist generator
+ * Input/output tool: EDIF netlist generator
  * Written by: Steven M. Rubin, Static Free Software
  * Modifications and extensions by B G West and G. Lawson
  *
@@ -38,6 +38,7 @@
 #include "egraphics.h"
 #include "tech.h"
 #include "tecgen.h"
+#include "tecschem.h"
 #include "network.h"
 #include "edialogs.h"
 #include <math.h>
@@ -64,12 +65,10 @@ typedef struct _eo_stream
 	INTBIG             compress;			/* the compress flag */
 } EO_STREAM, *EO_STREAM_PTR;
 
-char *io_edifoextlibname[WORD+1];
-INTSML io_edifoextlibcount;
-static INTBIG io_edifospice_model = 0;
-INTSML io_edifo_gateindex;
-INTBIG io_ediforev;
-static char io_edifo_blanks[] = "                                                  ";
+static char  *io_edifoextlibname[WORD+1];
+static INTSML io_edifoextlibcount;
+static INTSML io_edifo_gateindex;
+static char   io_edifo_blanks[] = "                                                  ";
 
 /* globals for SCHEMATIC View */
 static INTBIG schematic_view = 0;
@@ -87,55 +86,54 @@ static _egraphic egraphic_override = EGUNKNOWN;
 static char *egraphic_text[5] = {"UNKNOWN", "ARTWORK", "TEXT", "WIRE", "BUS"};
 static EO_STREAM_PTR edif_stream;
 
-/* prototypes */
-INTBIG io_edif_scale(INTBIG val);
-INTBIG io_edifsearch(NODEPROTO *np);
-void io_edifextsearch(NODEPROTO *np);
-char *io_ediffind_path(NODEPROTO *np);
-void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun);
-char *io_edif_orientation(NODEINST *ni);
-char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTSML serindex);
-void io_edif_pt(INTBIG x, INTBIG y);
-INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external);
-char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun);
-INTSML io_edifisglobal(PORTPROTO *pp);
-INTSML io_edifmarknetports(NODEPROTO *np);
-INTSML io_edifwritelibext(NODEPROTO *np);
-char *io_ediftoken(char *str);
-char io_edifnotwhitespace(char ch);
-INTSML io_edifvalid(char ch);
-char *io_edifvalidname(VARIABLE *var);
-INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid);
-INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
+/* prototypes for local routines */
+static INTBIG io_edif_scale(INTBIG val);
+static INTBIG io_edifsearch(NODEPROTO *np);
+static void io_edifextsearch(NODEPROTO *np);
+static char *io_ediffind_path(NODEPROTO *np);
+static void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun);
+static char *io_edif_orientation(NODEINST *ni);
+static char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTSML serindex);
+static void io_edif_pt(INTBIG x, INTBIG y);
+static INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external);
+static char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun);
+static INTSML io_edifisglobal(PORTPROTO *pp);
+static INTSML io_edifmarknetports(NODEPROTO *np);
+static INTSML io_edifwritelibext(NODEPROTO *np);
+static char *io_ediftoken(char *str);
+static char io_edifnotwhitespace(char ch);
+static INTSML io_edifvalid(char ch);
+static char *io_edifvalidname(VARIABLE *var);
+static INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid);
+static INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	char *accessrules, INTBIG routegrid);
-char *io_ediflowerstring(char *str);
-char *io_edifupperstring(char *str);
-void io_edifsymbol(NODEPROTO *np);
-void io_edifsymbol_facet(NODEINST *ni, XARRAY prevtrans);
-void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans);
-void io_edifsymbol_arcinst(ARCINST *ai, XARRAY trans);
+static char *io_ediflowerstring(char *str);
+static char *io_edifupperstring(char *str);
+static void io_edifsymbol(NODEPROTO *np);
+static void io_edifsymbol_facet(NODEINST *ni, XARRAY prevtrans);
+static void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans);
+static void io_edifsymbol_arcinst(ARCINST *ai, XARRAY trans);
+static void io_edifsetgraphic(_egraphic type);
+static INTBIG io_edifsymbol_showpoly(POLYGON *obj);
+static EO_STREAM_PTR EO_open_stream(char *, INTBIG);
+static INTBIG EO_close_stream(EO_STREAM_PTR);
+static INTBIG EO_open_block(EO_STREAM_PTR, char *);
+static INTBIG EO_put_block(EO_STREAM_PTR, char *, char *);
+static INTBIG EO_put_identifier(EO_STREAM_PTR, char *);
+static INTBIG EO_put_string(EO_STREAM_PTR, char *);
+static INTBIG EO_put_integer(EO_STREAM_PTR, INTBIG);
+static INTBIG EO_put_float(EO_STREAM_PTR, double);
+static INTBIG EO_put_header(EO_STREAM_PTR, char *, char *, char *);
+static INTBIG EO_close_block(EO_STREAM_PTR, char *);
+static EO_STREAM_PTR EO_alloc_stream(void);
+static INTBIG EO_free_stream(EO_STREAM_PTR);
+static char *EO_get_timestamp(char *);
+static char *EO_make_string(char *);
+static char *EO_get_exp(double);
+static void io_edifoptionsdlog(void);
+
 void io_compute_center(INTBIG xc, INTBIG yc, INTBIG x1, INTBIG y1,
 	INTBIG x2, INTBIG y2, INTBIG *cx, INTBIG *cy);
-void io_edifsetgraphic(_egraphic type);
-INTBIG io_edifsymbol_showpoly(POLYGON *obj);
-EO_STREAM_PTR EO_open_stream(char *, INTBIG);
-INTBIG EO_close_stream(EO_STREAM_PTR);
-INTBIG EO_open_block(EO_STREAM_PTR, char *);
-INTBIG EO_put_block(EO_STREAM_PTR, char *, char *);
-INTBIG EO_put_comment(EO_STREAM_PTR, char *);
-INTBIG EO_put_identifier(EO_STREAM_PTR, char *);
-INTBIG EO_put_string(EO_STREAM_PTR, char *);
-INTBIG EO_put_integer(EO_STREAM_PTR, INTBIG);
-INTBIG EO_put_float(EO_STREAM_PTR, double);
-INTBIG EO_put_date(EO_STREAM_PTR);
-INTBIG EO_put_header(EO_STREAM_PTR, char *, char *, char *);
-INTBIG EO_close_block(EO_STREAM_PTR, char *);
-EO_STREAM_PTR EO_alloc_stream(void);
-INTBIG EO_free_stream(EO_STREAM_PTR);
-char *EO_get_timestamp(char *);
-char *EO_make_string(char *);
-char *EO_get_exp(double);
-void io_edifoptionsdlog(void);
 
 /*
  * Routine to initialize EDIF I/O.
@@ -164,10 +162,10 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	double meters_to_lambda;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate & AIDON) == 0)
+	if ((net_tool->toolstate & TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the EDIF I/O command"));
 		return(1);
 	}
@@ -183,9 +181,6 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 		return(1);
 	}
 
-	/* get some keys */
-	io_edifospice_model = makekey("SIM_spice_model");
-
 	/* See if schematic view is requested */
 	lambda = lib->lambda[el_curtech->techindex];
 	curstate = io_getstatebits();
@@ -308,11 +303,6 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 		EO_close_block(edif_stream, "external");
 	}
 
-	/* establish the resistor model revision level */
-	io_ediforev = 1;
-	var = getval((INTBIG) np, VNODEPROTO, VINTEGER, "EDIF_resistor_rev");
-	if (var != NOVARIABLE) io_ediforev = var->addr;
-
 	/* now recursively write the facets expanded within the library */
 	EO_open_block(edif_stream, "library");
 	EO_put_identifier(edif_stream, io_ediftoken(lib->libname));
@@ -367,7 +357,7 @@ INTBIG io_edifsearch(NODEPROTO *np)
 	{
 		if (ni->proto->primindex != 0)
 		{
-			fun = nodefunction(ni, 0);
+			fun = nodefunction(ni);
 			i = 1;
 			if (fun == NPGATEAND || fun == NPGATEOR || fun == NPGATEXOR)
 			{
@@ -385,6 +375,9 @@ INTBIG io_edifsearch(NODEPROTO *np)
 			continue;
 		}
 
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
+
 		/* get actual subfacet (including contents/body distinction) */
 		onp = contentsview(ni->proto);
 		if (onp == NONODEPROTO) onp = ni->proto;
@@ -405,7 +398,7 @@ INTBIG io_edifsearch(NODEPROTO *np)
 void io_edifextsearch(NODEPROTO *np)
 {
 	REGISTER NODEINST *ni;
-	REGISTER NODEPROTO *onp;
+	REGISTER NODEPROTO *onp, *subnp;
 	REGISTER INTSML i;
 	char *libname;
 
@@ -430,7 +423,7 @@ void io_edifextsearch(NODEPROTO *np)
 			io_edifoextlibcount = i;
 			(void)initinfstr();
 			(void)addstringtoinfstr(libname);
-			(void)allocstring(&io_edifoextlibname[i], returninfstr(), io_aid->cluster);
+			(void)allocstring(&io_edifoextlibname[i], returninfstr(), io_tool->cluster);
 			ttyputmsg(_("External library %s, lib number %d"), io_edifoextlibname[i], i);
 		}
 		np->temp2 = i;
@@ -439,7 +432,14 @@ void io_edifextsearch(NODEPROTO *np)
 	}
 	if (onp == NONODEPROTO) onp = np;
 	for (ni = onp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-		if (ni->proto->temp1 == 0) io_edifextsearch(ni->proto);
+	{
+		subnp = ni->proto;
+		if (subnp->temp1 != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (subnp->cell == onp->cell) continue;
+		io_edifextsearch(subnp);
+	}
 
 	np->temp1++;
 }
@@ -489,7 +489,7 @@ char *io_ediffind_path(NODEPROTO *np)
 		xclose(f);
 	} else (void)strcpy(libpath, "unknown");
 
-	(void)allocstring(&path, libpath, io_aid->cluster);
+	(void)allocstring(&path, libpath, io_tool->cluster);
 	return(path);
 }
 
@@ -557,7 +557,7 @@ void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun)
 	}
 	if (schematic_view)
 	{
-
+		/* EMPTY */ 
 	}
 	EO_close_block(edif_stream, "cell");
 }
@@ -691,7 +691,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	}
 
 	/* get polygon */
-	if (schematic_view && poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (schematic_view && poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* recurse on sub-facets first */
 	backannotate = 0;
@@ -702,6 +702,9 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 			ni->temp1 = 0;
 			if (ni->proto->primindex != 0) continue;
 
+			/* ignore recursive references (showing icon in contents) */
+			if (ni->proto->cell == np->cell) continue;
+
 			/* do not expand "monitor_probe" construct (icon) */
 			if (namesame(ni->proto->cell->cellname, "monitor_probe") == 0) continue;
 
@@ -724,8 +727,8 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	if (external > 0 && np->temp2 != external) return(backannotate);
 
 	/* make sure that all nodes and networks have names on them */
-	if (askaid(net_aid, "name-nodes", (INTBIG)np) != 0) backannotate++;
-	if (askaid(net_aid, "name-nets", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nets", (INTBIG)np) != 0) backannotate++;
 
 	/* mark this facet as written */
 	np->temp1++;
@@ -809,7 +812,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 		{
 			/* set beginning page */
 			pageindex = 1;
-			(void)sprintf(page, "P%d", pageindex);
+			(void)sprintf(page, "P%ld", pageindex);
 
 			/* locate the next like in cell */
 			for (np = np->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
@@ -835,13 +838,16 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 				}
 				for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 				{
-					fun = nodefunction(ni, 0);
+					fun = nodefunction(ni);
 					if (ni->proto->primindex != 0)
 					{
 						if (fun == NPUNKNOWN || fun == NPPIN || fun == NPCONTACT ||
 							fun == NPNODE || fun == NPCONNECT || fun == NPART) continue;
 					} else if (namesame(ni->proto->cell->cellname, "monitor_probe") == 0)
-					continue;
+						continue;
+
+					/* ignore recursive references (showing icon in contents) */
+					if (ni->proto->cell == np->cell) continue;
 
 					EO_open_block(edif_stream, "instance");
 					iname = io_edifwritecompname(ni, fun, 0);
@@ -888,7 +894,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 							i = 0;
 							for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 								if (pi->proto == ni->proto->firstportproto) i++;
-							(void)sprintf(name, "%s%d", io_ediftoken(ni->proto->primname), i);
+							(void)sprintf(name, "%s%ld", io_ediftoken(ni->proto->primname), i);
 							EO_put_identifier(edif_stream, name);
 						} else EO_put_identifier(edif_stream, io_edifdescribepriminst(ni, fun));
 						EO_put_block(edif_stream, "libraryRef", "lib0");
@@ -981,11 +987,14 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 				{
 					if (ni->proto->primindex != 0)
 					{
-						fun = nodefunction(ni, 0);
+						fun = nodefunction(ni);
 						if (fun != NPUNKNOWN && fun != NPPIN && fun != NPCONTACT &&
 							fun != NPNODE && fun != NPCONNECT && fun != NPART) continue;
 					} else if (namesame(ni->proto->cell->cellname, "monitor_probe") == 0) continue;
 
+					/* ignore recursive references (showing icon in contents) */
+					if (ni->proto->cell == np->cell) continue;
+
 					for (pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					{
 						if ((pp->userbits & STATEBITS) == INPORT || (pp->userbits & STATEBITS) == REFINPORT)
@@ -1029,6 +1038,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 						/* evaluate the bus name, look for net arrays */
 						if (net->namecount > 0)
 						{
+							/* EMPTY */ 
 						}
 						EO_open_block(edif_stream, "netBundle");
 						if (net->namecount > 0)
@@ -1115,7 +1125,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 							}
 							if (ni->proto->primindex == 0) break;
 
-							fun = nodefunction(ni, 0);
+							fun = nodefunction(ni);
 							if (fun != NPUNKNOWN && fun != NPPIN && fun != NPCONTACT &&
 								fun != NPNODE && fun != NPCONNECT && fun != NPART) break;
 						}
@@ -1172,12 +1182,15 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 						if (ni->proto->primindex != 0)
 						{
 							/* ignore passive components */
-							fun = nodefunction(ni, 0);
+							fun = nodefunction(ni);
 							if (fun == NPUNKNOWN || fun == NPPIN || fun == NPCONTACT ||
 								fun == NPNODE || fun == NPCONNECT || fun == NPART) continue;
 							cnp = ni->proto;
 						} else
 						{
+							/* ignore recursive references (showing icon in contents) */
+							if (ni->proto->cell == np->cell) continue;
+
 							if (namesame(ni->proto->cell->cellname, "monitor_probe") == 0)
 								continue;
 							fun = NPUNKNOWN;
@@ -1357,7 +1370,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 			{
 				/* get next schematic */
 				pageindex++;
-				(void)sprintf(page, "P%d", pageindex);
+				(void)sprintf(page, "P%ld", pageindex);
 				for (np = np->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
 					if (!namesame(np->cellview->sviewname, page))
 				{
@@ -1387,7 +1400,7 @@ char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun)
 	switch (fun)
 	{
 		case NPRESIST:
-			var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, io_edifospice_model);
+			var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, sch_spicemodelkey);
 			if (var == NOVARIABLE) return("Resistor");
 
 			model = (char *) var->addr;
@@ -1405,7 +1418,7 @@ char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun)
 		case NPSUBSTRATE:
 			return("gtap");
 		case NPDIODE:
-			var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, io_edifospice_model);
+			var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, sch_spicemodelkey);
 			if (var != NOVARIABLE && namesamen("subtap", (char *) var->addr, 6) == 0)
 				return("gtap");
 	}
@@ -1726,7 +1739,7 @@ INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	}
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* get this port geometry */
 	shapeportpoly(ni, ppt, poly, 0);
@@ -1825,7 +1838,7 @@ void io_edifsymbol(NODEPROTO *np)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	EO_open_block(edif_stream, "symbol");
 	egraphic_override = EGWIRE;
@@ -1899,7 +1912,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 	VARIABLE *var;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	np = ni->proto;
 
@@ -1981,6 +1994,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 			{
 				if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
 				{
+					/* EMPTY */ 
 					/* us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colfacettxt, w,
 					portcliplx, portcliphx, portcliply, portcliphy); */
 				} else
@@ -2043,7 +2057,7 @@ void io_edifsymbol_arcinst(ARCINST *ai, XARRAY trans)
 
 	/* ask the technology how to draw the arcinst */
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	i = arcpolys(ai, NOWINDOWPART);
 
@@ -2210,7 +2224,7 @@ INTBIG io_edifsymbol_showpoly(POLYGON *obj)
 			EO_open_block(edif_stream, "stringDisplay");
 			EO_put_string(edif_stream, obj->string);
 			EO_open_block(edif_stream, "display");
-			if (obj->font >= TXT4P && obj->font <= TXT20P)
+			if (TXTGETPOINTS(TDGETSIZE(obj->textdescript)) != 0)
 			{
 				EO_open_block(edif_stream, "figureGroupOverride");
 				EO_put_identifier(edif_stream, egraphic_text[EGART]);
@@ -2219,7 +2233,8 @@ INTBIG io_edifsymbol_showpoly(POLYGON *obj)
 				EO_open_block(edif_stream, "textHeight");
 
 				/* 2 pixels = 0.0278 in or 36 double pixels per inch */
-				height = muldiv((el_curlib->lambda[el_curtech->techindex] * 10), (obj->font + 2), 36);
+				height = muldiv((el_curlib->lambda[el_curtech->techindex] * 10),
+					TXTGETPOINTS(TDGETSIZE(obj->textdescript)), 36);
 				EO_put_integer(edif_stream, io_edif_scale(height));
 				EO_close_block(edif_stream, "figureGroupOverride");
 			} else EO_put_identifier(edif_stream, egraphic_text[EGART]);
@@ -2360,7 +2375,7 @@ EO_STREAM_PTR EO_open_stream(char *filename, INTBIG compress)
 	}
 
 	/* update filename - allocate name and initialize the structure */
-	if (allocstring(&stream->filename, truename, io_aid->cluster) != 0)
+	if (allocstring(&stream->filename, truename, io_tool->cluster) != 0)
 	{
 		ttyputnomemory();
 		return(NOEO_STREAM);
@@ -2411,7 +2426,7 @@ INTBIG EO_open_block(EO_STREAM_PTR stream, char *keyword)
 			xprintf(stream->file, "\n");
 		}
 		if (allocstring(&stream->blkstack[stream->blkstack_ptr++], keyword,
-			io_aid->cluster) != 0)
+			io_tool->cluster) != 0)
 		{
 			ttyputnomemory();
 			return(1);
@@ -2448,29 +2463,6 @@ INTBIG EO_put_block(EO_STREAM_PTR stream, char *keyword, char *identifier)
 	return(1);
 }
 
-/* module: EO_put_comment
-   function:  Will output a quoted comment
-   returns: 0 on success, 1 on error
- */
-INTBIG EO_put_comment(EO_STREAM_PTR stream, char *comment)
-{
-	if (stream != NOEO_STREAM)
-	{
-		/* output the new block */
-		if (stream->blkstack_ptr)
-		{
-			xprintf(stream->file, "\n");
-		}
-
-		/* output the comment */
-		xprintf(stream->file, "%s(%scomment %s%s)",
-			GETBLANKS(stream->compress, stream->blkstack_ptr),
-				DOSPACE, EO_make_string(comment), DOSPACE);
-		return(0);
-	}
-	return(1);
-}
-
 /* module: EO_put_identifier
    function:  Will output a string identifier to the stream file
    returns: 0 on success, 1 on error
@@ -2527,20 +2519,6 @@ INTBIG EO_put_float(EO_STREAM_PTR stream, double val)
 	return(1);
 }
 
-/* module: EO_put_date
-   function:  Will output the current date to the stream edif file
-   returns: 0 on success, 1 on error
- */
-INTBIG EO_put_date(EO_STREAM_PTR stream)
-{
-	if (stream != NOEO_STREAM)
-	{
-		xprintf(stream->file, " %s", EO_get_timestamp((char *)0));
-		return(0);
-	}
-	return(1);
-}
-
 INTBIG EO_put_header(EO_STREAM_PTR stream, char *program, char *comment, char *origin)
 {
 	char name[WORD+1];
@@ -2607,7 +2585,7 @@ EO_STREAM_PTR EO_alloc_stream(void)
 {
 	EO_STREAM_PTR stream;
 
-	if ((stream = (EO_STREAM_PTR)emalloc(sizeof (EO_STREAM), io_aid->cluster)) == NOEO_STREAM)
+	if ((stream = (EO_STREAM_PTR)emalloc(sizeof (EO_STREAM), io_tool->cluster)) == NOEO_STREAM)
 	{
 		ttyputnomemory();
 		return(NOEO_STREAM);
@@ -2738,12 +2716,12 @@ char *EO_get_exp(double val)
 
 	/* now convert the exponent */
 	exp = atoi(++pp);
-	(void)sprintf(rp, "%d", exp-nonzero);
+	(void)sprintf(rp, "%ld", exp-nonzero);
 	return(result);
 }
 
 /* EDIF Options */
-DIALOGITEM io_edifoptionsdialogitems[] =
+static DIALOGITEM io_edifoptionsdialogitems[] =
 {
  /*  1 */ {0, {68,120,92,192}, BUTTON, N_("OK")},
  /*  2 */ {0, {68,16,92,88}, BUTTON, N_("Cancel")},
@@ -2751,7 +2729,7 @@ DIALOGITEM io_edifoptionsdialogitems[] =
  /*  4 */ {0, {36,8,52,96}, MESSAGE, N_("Input scale:")},
  /*  5 */ {0, {36,100,52,188}, EDITTEXT, ""}
 };
-DIALOG io_edifoptionsdialog = {{50,75,151,284}, N_("EDIF Options"), 0, 5, io_edifoptionsdialogitems};
+static DIALOG io_edifoptionsdialog = {{50,75,151,284}, N_("EDIF Options"), 0, 5, io_edifoptionsdialogitems};
 
 /* special items for the "EDIF Options" dialog: */
 #define DEDO_USESCHEMATIC  3		/* Use Schematic View (check) */
@@ -2769,7 +2747,7 @@ void io_edifoptionsdlog(void)
 	curstate = io_getstatebits();
 	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
 	if ((curstate[0]&EDIFSCHEMATIC) != 0) DiaSetControl(DEDO_USESCHEMATIC, 1);
-	var = getval((INTBIG)io_aid, VAID, VFLOAT, "IO_edif_input_scale");
+	var = getval((INTBIG)io_tool, VTOOL, VFLOAT, "IO_edif_input_scale");
 	if (var == NOVARIABLE) inputscale = 1.0; else
 		inputscale = castfloat(var->addr);
 	sprintf(line, "%g", inputscale);
@@ -2795,7 +2773,7 @@ void io_edifoptionsdlog(void)
 		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
 		newscale = (float)atof(DiaGetText(DEDO_INPUTSCALE));
 		if (newscale != inputscale)
-			setval((INTBIG)io_aid, VAID, "IO_edif_input_scale", castint(newscale), VFLOAT);
+			setval((INTBIG)io_tool, VTOOL, "IO_edif_input_scale", castint(newscale), VFLOAT);
 	}
 	DiaDoneDialog();
 }
