@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iogdsi.c
- * Input/output aid: GDSII stream input
+ * Input/output tool: GDSII stream input
  * Written by: Glen Lawson, S-MOS Systems, Inc.
  *
  * Copyright (c) 2000 Static Free Software.
@@ -153,7 +153,7 @@ static char *io_gdsIerror_string[] =
 	N_("Array orientation oblique")							/* 30 */
 };
 
-gsymbol io_gdsIoption_set[] =
+static gsymbol io_gdsIoption_set[] =
 {
 	GDS_ATTRTABLE,
 	GDS_REFLIBS,
@@ -162,7 +162,7 @@ gsymbol io_gdsIoption_set[] =
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsIshape_set[] =
+static gsymbol io_gdsIshape_set[] =
 {
 	GDS_AREF,
 	GDS_SREF,
@@ -174,7 +174,7 @@ gsymbol io_gdsIshape_set[] =
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsIgood_op_set[] =
+static gsymbol io_gdsIgood_op_set[] =
 {
 	GDS_HEADER,
 	GDS_BGNLIB,
@@ -220,7 +220,7 @@ gsymbol io_gdsIgood_op_set[] =
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsIbackup_set[] =
+static gsymbol io_gdsIbackup_set[] =
 {
 	GDS_UNITS,
 	GDS_REFLIBS,
@@ -229,7 +229,7 @@ gsymbol io_gdsIbackup_set[] =
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsImask_set[] =
+static gsymbol io_gdsImask_set[] =
 {
 	GDS_DATATYPSYM,
 	GDS_TEXTTYPE,
@@ -238,70 +238,69 @@ gsymbol io_gdsImask_set[] =
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsIunsupported_set[] =
+static gsymbol io_gdsIunsupported_set[] =
 {
 	GDS_ELFLAGS,
 	GDS_PLEX,
 	GDS_BADFIELD
 };
 
-gsymbol io_gdsIrecovery_set[100];
+static gsymbol io_gdsIrecovery_set[100];
 
 /* prototypes for local routines */
-void            io_gdsIappendset(gsymbol[], gsymbol);
-void            io_gdsIattrtable(void);
-void            io_gdsIbackup(void);
-void            io_gdsIbeginstructure(void);
-void            io_gdsIbox(INTBIG*);
-void            io_gdsIcompute_size(NODEPROTO*);
-void            io_gdsIcopyset(gsymbol[], gsymbol[]);
-void            io_gdsIdetermine_aref(void);
-void            io_gdsIdetermine_boundary(INTBIG, shape_type*, shape_type*);
-void            io_gdsIdetermine_box(void);
-void            io_gdsIdetermine_justification(INTBIG*, INTBIG*);
-void            io_gdsIdetermine_layer(INTBIG*, INTBIG*);
-void            io_gdsIdetermine_node(void);
-void            io_gdsIdetermine_orientation(INTBIG*, INTBIG*, double*);
-void            io_gdsIdetermine_path(void);
-void            io_gdsIdetermine_points(INTBIG, INTBIG, INTBIG*);
-void            io_gdsIdetermine_property(void);
-void            io_gdsIdetermine_shape(void);
-void            io_gdsIdetermine_sref(void);
-void            io_gdsIdetermine_text(void);
-void            io_gdsIdetermine_time(char*);
-void            io_gdsIelement(INTSML*);
-void            io_gdsIerror(INTBIG);
-NODEPROTO      *io_gdsIfindproto(char *name);
-void            io_gdsIfonts(void);
-void            io_gdsIgetdouble(double*);
-void            io_gdsIgetfloat(float*);
-void            io_gdsIgetinteger(INTBIG*);
-void            io_gdsIgetproto(char*);
-unsigned char   io_gdsIgetrawbyte(void);
-gsymbol         io_gdsIgetrecord(datatype_symbol*);
-datatype_symbol io_gdsIgetrecordtype(void);
-void            io_gdsIgetstring(char*);
-void            io_gdsIgettoken(void);
-void            io_gdsIgetword(UINTSML*);
-void            io_gdsIheader(void);
-void            io_gdsIinit(void);
-void            io_gdsIitoa(char*, INTBIG);
-void            io_gdsIlibrary(void);
-INTSML          io_gdsIload(FILE*);
-INTSML          io_gdsImember(gsymbol, gsymbol[]);
-void            io_gdsIOnceinit(void);
-void            io_gdsIonlyone(gsymbol[], gsymbol);
-double          io_gdsIpower(INTBIG, INTBIG);
-void            io_gdsIrecompute(NODEPROTO*, INTBIG);
-void            io_gdsIreflibs(void);
-void            io_gdsIshape(INTBIG, shape_type, shape_type);
-void            io_gdsIstep(INTBIG, INTBIG, INTBIG, INTBIG);
-void            io_gdsIstructure(void);
-void            io_gdsItext(char*, INTBIG, INTBIG, INTBIG, INTBIG, double);
-void            io_gdsItransform(point_type, INTBIG, INTBIG);
-void            io_gdsItranslate(INTBIG*, INTBIG*, double, INTSML);
-void            io_gdsIunits(void);
-void            io_gdsIunsupported(gsymbol[]);
+static void            io_gdsIappendset(gsymbol[], gsymbol);
+static void            io_gdsIattrtable(void);
+static void            io_gdsIbackup(void);
+static void            io_gdsIbeginstructure(void);
+static void            io_gdsIbox(INTBIG*);
+static void            io_gdsIcopyset(gsymbol[], gsymbol[]);
+static void            io_gdsIdetermine_aref(void);
+static void            io_gdsIdetermine_boundary(INTBIG, shape_type*, shape_type*);
+static void            io_gdsIdetermine_box(void);
+static void            io_gdsIdetermine_justification(INTBIG*, INTBIG*);
+static void            io_gdsIdetermine_layer(INTBIG*, INTBIG*);
+static void            io_gdsIdetermine_node(void);
+static void            io_gdsIdetermine_orientation(INTBIG*, INTBIG*, double*);
+static void            io_gdsIdetermine_path(void);
+static void            io_gdsIdetermine_points(INTBIG, INTBIG, INTBIG*);
+static void            io_gdsIdetermine_property(void);
+static void            io_gdsIdetermine_shape(void);
+static void            io_gdsIdetermine_sref(void);
+static void            io_gdsIdetermine_text(void);
+static void            io_gdsIdetermine_time(char*);
+static void            io_gdsIelement(INTSML*);
+static void            io_gdsIerror(INTBIG);
+static NODEPROTO      *io_gdsIfindproto(char *name);
+static void            io_gdsIfonts(void);
+static void            io_gdsIgetdouble(double*);
+static void            io_gdsIgetfloat(float*);
+static void            io_gdsIgetinteger(INTBIG*);
+static void            io_gdsIgetproto(char*);
+static unsigned char   io_gdsIgetrawbyte(void);
+static gsymbol         io_gdsIgetrecord(datatype_symbol*);
+static datatype_symbol io_gdsIgetrecordtype(void);
+static void            io_gdsIgetstring(char*);
+static void            io_gdsIgettoken(void);
+static void            io_gdsIgetword(UINTSML*);
+static void            io_gdsIheader(void);
+static void            io_gdsIinit(void);
+static void            io_gdsIitoa(char*, INTBIG);
+static void            io_gdsIlibrary(void);
+static INTSML          io_gdsIload(FILE*);
+static INTSML          io_gdsImember(gsymbol, gsymbol[]);
+static void            io_gdsIOnceinit(void);
+static void            io_gdsIonlyone(gsymbol[], gsymbol);
+static double          io_gdsIpower(INTBIG, INTBIG);
+static void            io_gdsIrecompute(NODEPROTO*, INTBIG);
+static void            io_gdsIreflibs(void);
+static void            io_gdsIshape(INTBIG, shape_type, shape_type);
+static void            io_gdsIstep(INTBIG, INTBIG, INTBIG, INTBIG);
+static void            io_gdsIstructure(void);
+static void            io_gdsItext(char*, INTBIG, INTBIG, INTBIG, INTBIG, double);
+static void            io_gdsItransform(point_type, INTBIG, INTBIG);
+static void            io_gdsItranslate(INTBIG*, INTBIG*, double, INTSML);
+static void            io_gdsIunits(void);
+static void            io_gdsIunsupported(gsymbol[]);
 
 /* modules */
 
@@ -887,38 +886,38 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 
 	/* set the text size and orientation */
 	size = rounddouble(scale);
-	if (size < TXT4P) size = TXT4P;
-	if (size > TXT20P) size = TXT20P;
-	var->textdescript = (size << VTSIZESH);
+	if (size <= 0) size = 8;
+	if (size > TXTMAXPOINTS) size = TXTMAXPOINTS;
+	TDSETSIZE(var->textdescript, size);
 
 	/* determine the presentation */
-	var->textdescript = (var->textdescript & ~VTPOSITION);
+	TDSETPOS(var->textdescript, VTPOSCENT);
 	switch (vjust)
 	{
 		case 1:		/* top */
 			switch (hjust)
 			{
-				case 1:  var->textdescript |= VTPOSUPRIGHT; break;
-				case 2:  var->textdescript |= VTPOSUPLEFT;  break;
-				default: var->textdescript |= VTPOSUP;      break;
+				case 1:  TDSETPOS(var->textdescript, VTPOSUPRIGHT); break;
+				case 2:  TDSETPOS(var->textdescript, VTPOSUPLEFT);  break;
+				default: TDSETPOS(var->textdescript, VTPOSUP);      break;
 			}
 			break;
 
 		case 2:		/* bottom */
 			switch (hjust)
 			{
-				case 1:  var->textdescript |= VTPOSDOWNRIGHT; break;
-				case 2:  var->textdescript |= VTPOSDOWNLEFT;  break;
-				default: var->textdescript |= VTPOSDOWN;      break;
+				case 1:  TDSETPOS(var->textdescript, VTPOSDOWNRIGHT); break;
+				case 2:  TDSETPOS(var->textdescript, VTPOSDOWNLEFT);  break;
+				default: TDSETPOS(var->textdescript, VTPOSDOWN);      break;
 			}
 			break;
 
 		default:	/* centered */
 			switch (hjust)
 			{
-				case 1:  var->textdescript |= VTPOSRIGHT; break;
-				case 2:  var->textdescript |= VTPOSLEFT;  break;
-				default: var->textdescript |= VTPOSCENT;  break;
+				case 1:  TDSETPOS(var->textdescript, VTPOSRIGHT); break;
+				case 2:  TDSETPOS(var->textdescript, VTPOSLEFT);  break;
+				default: TDSETPOS(var->textdescript, VTPOSCENT);  break;
 			}
 	}
 }
@@ -936,7 +935,7 @@ void io_gdsIOnceinit(void)
 	REGISTER NODEPROTO *np;
 
 	/* create the polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* run through the node prototypes in this technology */
 	ni = dummynode();
@@ -1590,7 +1589,7 @@ void io_gdsIdetermine_path(void)
 				io_gdslayerpoly[io_gdslayerwhich]++;
 
 				/* get polygon */
-				if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+				if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 				/* determine shape of segment */
 				length = computedistance(fx, fy, tx, ty);
@@ -1947,7 +1946,7 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 
 	io_gdslibrary = lib;
 
-	/* get current state of I/O aid */
+	/* get current state of I/O tool */
 	io_gdscurstate = io_getstatebits();
 
 	/* get the gds file */
@@ -2090,7 +2089,7 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 		io_gdsrecomputed++;
 		if ((io_gdsrecomputed%1000) == 0 && io_verbose < 0 && io_gdsfilesize > 0)
 		{
-			(void)sprintf(numsofar, _("Cleaned up %d instances..."), io_gdsrecomputed);
+			(void)sprintf(numsofar, _("Cleaned up %ld instances..."), io_gdsrecomputed);
 			DiaSetText(2, numsofar);
 			if (count > 0)
 				DiaPercent(1, (io_gdsrecomputed*100)/count);
