@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iogdso.c
- * Input/output aid: GDS-II output
+ * Input/output tool: GDS-II output
  * Written by: Sid Penstone, Queens University
  *
  * Copyright (c) 2000 Static Free Software.
@@ -106,30 +106,29 @@ static double  io_gds_scale;				/* constant */
 static INTBIG  io_gds_layerkey;				/* key for "IO_gds_layer" */
 
 /* prototypes for local routines */
-void io_gdswritecell(NODEPROTO*);
-void io_outputgdspoly(TECHNOLOGY*, POLYGON*, INTSML, INTBIG, INTBIG, XARRAY, VARIABLE*);
-void io_gds_set_layer(INTSML);
-void io_gds_initialize(void);
-void io_gds_closefile(void);
-void io_gds_bgnlib(NODEPROTO*);
-void io_gds_bgnstr(NODEPROTO*);
-void io_gds_date(UINTBIG*);
-void io_gds_header(INTSML, INTSML);
-void io_gds_name(INTSML, char*, INTSML);
-void io_gds_angle(INTSML);
-void io_gds_boundary(POLYGON*);
-void io_gds_path(POLYGON*);
-void io_gds_byte(char);
-void io_gds_int2(INTSML);
-void io_gds_int4(INTBIG);
-void io_gds_int2_arr(INTSML*, INTSML);
-void io_gds_int4_arr(INTBIG*, INTSML);
-void io_gds_string(char*, INTSML);
-UINTBIG io_gds_floatint(INTBIG);
-void io_gds_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
-char *io_gds_makename(char*);
-void io_gds_cvfloat8(double*, UINTBIG*, UINTBIG*);
-void io_gdsoptionsdlog(void);
+static void io_gdswritecell(NODEPROTO*);
+static void io_outputgdspoly(TECHNOLOGY*, POLYGON*, INTSML, INTBIG, INTBIG, XARRAY, VARIABLE*);
+static void io_gds_set_layer(INTSML);
+static void io_gds_initialize(void);
+static void io_gds_closefile(void);
+static void io_gds_bgnlib(NODEPROTO*);
+static void io_gds_bgnstr(NODEPROTO*);
+static void io_gds_date(UINTBIG*);
+static void io_gds_header(INTSML, INTSML);
+static void io_gds_name(INTSML, char*, INTSML);
+static void io_gds_angle(INTSML);
+static void io_gds_boundary(POLYGON*);
+static void io_gds_path(POLYGON*);
+static void io_gds_byte(char);
+static void io_gds_int2(INTSML);
+static void io_gds_int4(INTBIG);
+static void io_gds_int2_arr(INTSML*, INTSML);
+static void io_gds_int4_arr(INTBIG*, INTSML);
+static void io_gds_string(char*, INTSML);
+static void io_gds_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
+static char *io_gds_makename(char*);
+static void io_gds_cvfloat8(double*, UINTBIG*, UINTBIG*);
+static void io_gdsoptionsdlog(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -259,6 +258,9 @@ void io_gdswritecell(NODEPROTO *np)
 		subnt = subno->proto;
 		if (subnt->primindex != 0) continue;
 
+		/* ignore recursive references (showing icon in contents) */
+		if (subnt->cell == np->cell) continue;
+
 		/* convert body cells to contents cells */
 		onp = contentsview(subnt);
 		if (onp != NONODEPROTO) subnt = onp;
@@ -271,7 +273,7 @@ void io_gdswritecell(NODEPROTO *np)
 	}
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* write this cell */
 	io_gds_set_layer(0);
@@ -452,6 +454,9 @@ void io_gdswritecell(NODEPROTO *np)
 			}
 		} else
 		{
+			/* ignore recursive references (showing icon in contents) */
+			if (subno->proto->cell == np->cell) continue;
+
 			/* write a call to a cell */
 #ifndef OLDGDS
 			var = getvalkey((INTBIG)subno->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
@@ -549,7 +554,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 	INTBIG xl, xh, yl, yh, xpos, ypos, laynum;
 	static POLYGON *poly2 = NOPOLYGON;
 
-	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, io_aid->cluster);
+	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, io_tool->cluster);
 
 	/* determine the layer name for this polygon */
 	if (layervar != NOVARIABLE) laynum = (INTBIG)layervar->addr; else
@@ -669,8 +674,8 @@ void io_gds_initialize(void)
 	io_gds_set_layer(0);
 	if (io_dbuffer == 0)
 	{
-		io_dbuffer = (char *)emalloc(DSIZE, io_aid->cluster);
-		io_empty = (char *)emalloc(DSIZE, io_aid->cluster);
+		io_dbuffer = (char *)emalloc(DSIZE, io_tool->cluster);
+		io_empty = (char *)emalloc(DSIZE, io_tool->cluster);
 
 		/* all zeroes, even if malloc() did it  */
 		for (i=0; i<DSIZE;i++) io_empty[i] = 0;
@@ -965,28 +970,6 @@ void io_gds_string(char *ptr, INTSML n)
 		io_gds_byte((char)(islower(ptr[i]) ? toupper(ptr[i]):ptr[i]));
 }
 
-UINTBIG io_gds_floatint(INTBIG val)       /* Convert integer to gds float */
-{
-	UINTBIG exp, val1, sign;
-
-	if (val == 0) return(0);
-	if (val < 0)
-	{
-		sign = 0x80;
-		val = -val;
-	} else sign = 0;
-	exp = 8 + 64;
-	val1 = val;
-	while ((val1 & 0xF0000000) == 0)
-	{
-		val1 = val1 << 4;
-		exp --;
-	}
-	exp = ((exp & 0x7FFF) | sign) << 24;
-	val1 = (val1 >> 8) | exp;
-	return(val1);
-}
-
 /*
  * Write out a merged polygon created by the merging algorithm
  * we have to scan it to make sure that it is closed
@@ -1002,7 +985,7 @@ void io_gds_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 	if (count > io_gds_polypoints)
 		ttyputerr(_("WARNING: Polygon has too many points (%d)"), count);
 
-	if (gds_poly == NOPOLYGON) gds_poly = allocstaticpolygon(4, io_aid->cluster);
+	if (gds_poly == NOPOLYGON) gds_poly = allocstaticpolygon(4, io_tool->cluster);
 	if (count > gds_poly->limit) (void)extendpolygon(gds_poly, count);
 	gds_poly->count = count;
 	for (i = 0; i < count; i++)
@@ -1092,7 +1075,7 @@ void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 }
 
 /* GDS Options */
-DIALOGITEM io_gdsoptionsdialogitems[] =
+static DIALOGITEM io_gdsoptionsdialogitems[] =
 {
  /*  1 */ {0, {224,344,248,416}, BUTTON, N_("OK")},
  /*  2 */ {0, {224,248,248,320}, BUTTON, N_("Cancel")},
@@ -1110,7 +1093,7 @@ DIALOGITEM io_gdsoptionsdialogitems[] =
  /* 14 */ {0, {200,396,216,464}, EDITTEXT, ""},
  /* 15 */ {0, {104,240,120,464}, CHECK, N_("Input Ignores Unknown Layers")}
 };
-DIALOG io_gdsoptionsdialog = {{50,75,307,548}, N_("GDS Options"), 0, 15, io_gdsoptionsdialogitems};
+static DIALOG io_gdsoptionsdialog = {{50,75,307,548}, N_("GDS Options"), 0, 15, io_gdsoptionsdialogitems};
 
 /* special items for the "GDS Options" dialog: */
 #define DGDO_LAYERLIST       3		/* Layer list (scroll list) */
