@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iohpglout.c
- * Input/output analysis aid: HPGL generation
+ * Input/output analysis tool: HPGL generation
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -53,23 +53,23 @@ typedef struct
 	INTSML fangle;		/* fill angle (ftype 3 or 4 only) */
 } PENCOLOR;
 
-PENCOLOR pen_color_table[256];
+static PENCOLOR pen_color_table[256];
 
 /* prototypes for local routines */
-void io_hpwritepolygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
-INTSML io_hppoly(POLYGON*, WINDOWPART*);
-void io_hpline(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void io_hparc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void io_hpcircle(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void io_hpdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
-void io_hpfilledpolygon(INTBIG*, INTBIG*, INTSML, INTSML);
-void io_hptext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, INTSML);
-void io_hpparsepenfile(void);
-INTSML io_hpchoosecolorentry(INTSML);
-void io_hppenselect(INTSML);
-void io_hpmove(INTBIG, INTBIG);
-void io_hpdraw(INTBIG, INTBIG);
-void io_hpcmd(char[]);
+static void io_hpwritepolygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
+static INTSML io_hppoly(POLYGON*, WINDOWPART*);
+static void io_hpline(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void io_hparc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void io_hpcircle(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void io_hpdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
+static void io_hpfilledpolygon(INTBIG*, INTBIG*, INTSML, INTSML);
+static void io_hptext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, INTSML);
+static void io_hpparsepenfile(void);
+static INTSML io_hpchoosecolorentry(INTSML);
+static void io_hppenselect(INTSML);
+static void io_hpmove(INTBIG, INTBIG);
+static void io_hpdraw(INTBIG, INTBIG);
+static void io_hpcmd(char[]);
 
 void io_hpwritepolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count)
 {
@@ -138,9 +138,9 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 
 		/* setup pens */
 		io_hpcmd("NP256");
-		varred = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_red");
-		vargreen = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_green");
-		varblue = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_blue");
+		varred = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_red");
+		vargreen = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_green");
+		varblue = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_blue");
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputmsg(_("Cannot get colors!"));
@@ -179,7 +179,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	io_hpcmd("IP;");
 
 	/* see if fixed scale specification has been made */
-	varscale = getval((INTBIG)io_aid, VAID, VINTEGER, "IO_hpgl2_scale");
+	varscale = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_hpgl2_scale");
 	if (io_hpgl2 != 0 && varscale != NOVARIABLE)
 	{
 		/* in HPGL/2, can handle fixed scale specification in internal units per pixel */
@@ -210,7 +210,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	el_curwindowpart->screenly = io_hpwindow.screenly;
 	el_curwindowpart->screenhy = io_hpwindow.screenhy;
 	computewindowscale(el_curwindowpart);
-	(void)askaid(us_aid, "display-to-routine", io_hppoly);
+	(void)asktool(us_tool, "display-to-routine", io_hppoly);
 	el_curwindowpart->uselx = (INTSML)sulx;      el_curwindowpart->usehx = (INTSML)suhx;
 	el_curwindowpart->usely = (INTSML)suly;      el_curwindowpart->usehy = (INTSML)suhy;
 	el_curwindowpart->screenlx = sslx;   el_curwindowpart->screenhx = sshx;
@@ -244,7 +244,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 {
 	REGISTER INTSML k;
-	INTBIG xl, xh, yl, yh, x, y, font;
+	INTBIG xl, xh, yl, yh, x, y, size;
 	INTSML color;
 	REGISTER TECHNOLOGY *tech;
 
@@ -334,6 +334,7 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 		case DISC:
 			/* filled disc: plot it and its outline */
 			io_hpdisc(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1], poly->desc);
+			/* FALLTHROUGH */ 
 
 		case CIRCLE:
 			io_hpcircle(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1], color);
@@ -355,9 +356,9 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 		case TEXTBOTRIGHT:
 		case TEXTBOX:
 			tech = win->curnodeproto->tech;
-			font = truefontsize(poly->font, win, tech);
+			size = truefontsize(TDGETSIZE(poly->textdescript), win, tech);
 			getbbox(poly, &xl, &xh, &yl, &yh);
-			io_hptext(poly->style, xl, xh, yl, yh, font, poly->string, color);
+			io_hptext(poly->style, xl, xh, yl, yh, size, poly->string, color);
 			break;
 	}
 	return(0);
@@ -458,12 +459,12 @@ void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTSML count, INTSML color
 	if (ftype != 1) io_hpcmd("EP;");
 }
 
-void io_hptext(INTSML type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG font,
+void io_hptext(INTSML type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG size,
 	char *text, INTSML color)
 {
 	char s[MAXSTR];
 
-	(void)sprintf(s, "SI %f,%f;", font*0.02f/1.3f, font*0.02f);
+	(void)sprintf(s, "SI %f,%f;", size*0.02f/1.3f, size*0.02f);
 	io_hpcmd(s);
 	io_hppenselect(color);
 
@@ -548,7 +549,7 @@ void io_hptext(INTSML type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG f
  *
  *   Color	Pen#	Line	Fill	Dist	Angle
  */
-char *io_hppendata[] =
+static char *io_hppendata[] =
 {
 	"0000	0	0	0	0	0	no color ",
 	"0010	4	0	3	500	0	transparent color 1 (blue)",
