@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iolefi.c
- * Input/output aid: LEF (Library Exchange Format) reader
+ * Input/output tool: LEF (Library Exchange Format) reader
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -66,29 +66,30 @@ LEFPATH *io_leffreepath = NOLEFPATH;
 
 #define MAXLINE 2500
 
-INTBIG  io_leffilesize;
-INTBIG  io_leflineno;
-char    io_lefline[MAXLINE];
-INTBIG  io_leflinepos;
-VIADEF *io_leffirstviadef = NOVIADEF;
+static INTBIG  io_leffilesize;
+static INTBIG  io_leflineno;
+static char    io_lefline[MAXLINE];
+static INTBIG  io_leflinepos;
+       VIADEF *io_leffirstviadef = NOVIADEF;
 
-void       io_leffreepaths(LEFPATH *firstlp);
-ARCPROTO  *io_lefgetarc(INTBIG afunc);
-char      *io_lefgetkeyword(FILE *f);
-NODEPROTO *io_lefgetnode(INTBIG lfunc);
-INTSML     io_lefignoretosemicolon(FILE *f, char *command);
-void       io_lefkillpath(LEFPATH *lp);
-LEFPATH   *io_lefnewpath(void);
-PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
-void       io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc);
-INTSML     io_lefreadfile(FILE *f, LIBRARY *lib);
-INTSML     io_lefreadlayer(FILE *f, LIBRARY *lib);
-INTSML     io_lefreadmacro(FILE *f, LIBRARY *lib);
-INTSML     io_lefreadvia(FILE *f, LIBRARY *lib);
-INTSML     io_lefreadobs(FILE *f, NODEPROTO *facet);
-INTSML     io_lefreadpin(FILE *f, NODEPROTO *facet);
-INTSML     io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits);
-void       io_leffreevias(void);
+/* prototypes for local routines */
+static void       io_leffreepaths(LEFPATH *firstlp);
+static ARCPROTO  *io_lefgetarc(INTBIG afunc);
+static char      *io_lefgetkeyword(FILE *f);
+static NODEPROTO *io_lefgetnode(INTBIG lfunc);
+static INTSML     io_lefignoretosemicolon(FILE *f, char *command);
+static void       io_lefkillpath(LEFPATH *lp);
+static LEFPATH   *io_lefnewpath(void);
+static PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
+static void       io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc);
+static INTSML     io_lefreadfile(FILE *f, LIBRARY *lib);
+static INTSML     io_lefreadlayer(FILE *f, LIBRARY *lib);
+static INTSML     io_lefreadmacro(FILE *f, LIBRARY *lib);
+static INTSML     io_lefreadvia(FILE *f, LIBRARY *lib);
+static INTSML     io_lefreadobs(FILE *f, NODEPROTO *facet);
+static INTSML     io_lefreadpin(FILE *f, NODEPROTO *facet);
+static INTSML     io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits);
+static void       io_leffreevias(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -488,9 +489,9 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 	if (vianame == 0) return(1);
 
 	/* create a new via definition */
-	vd = (VIADEF *)emalloc(sizeof (VIADEF), io_aid->cluster);
+	vd = (VIADEF *)emalloc(sizeof (VIADEF), io_tool->cluster);
 	if (vd == 0) return(1);
-	(void)allocstring(&vd->vianame, vianame, io_aid->cluster);
+	(void)allocstring(&vd->vianame, vianame, io_tool->cluster);
 	vd->sx = vd->sy = 0;
 	vd->via = NONODEPROTO;
 	vd->lay1 = vd->lay2 = NOARCPROTO;
@@ -844,7 +845,11 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 					/* queue path */
 					lp = io_lefnewpath();
 					if (lp == NOLEFPATH) return(1);
+
+					/* LINTED "lastintx" used in proper order */
 					lp->x[0] = lastintx;     lp->x[1] = intx;
+
+					/* LINTED "lastinty" used in proper order */
 					lp->y[0] = lastinty;     lp->y[1] = inty;
 					lp->ni[0] = NONODEINST;  lp->ni[1] = NONODEINST;
 					lp->width = intwidth;
@@ -1052,7 +1057,7 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *th
 
 		/* make space for modified name */
 		if (newname == 0) newname = (char *)emalloc(strlen(thename)+10, el_tempcluster);
-		sprintf(newname, "%s-%d", thename, i);
+		sprintf(newname, "%s-%ld", thename, i);
 		portname = newname;
 	}
 	if (newname != 0) efree(newname);
@@ -1263,7 +1268,7 @@ LEFPATH *io_lefnewpath(void)
 		io_leffreepath = lp->nextlefpath;
 	} else
 	{
-		lp = (LEFPATH *)emalloc(sizeof(LEFPATH), io_aid->cluster);
+		lp = (LEFPATH *)emalloc(sizeof(LEFPATH), io_tool->cluster);
 		if (lp == 0) lp = NOLEFPATH;
 	}
 	return(lp);
