@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iolefo.c
- * Input/output aid: LEF output
+ * Input/output tool: LEF output
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -41,12 +41,13 @@
 #include "eio.h"
 #include "efunction.h"
 
-void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans);
-char *io_lefoutlayername(TECHNOLOGY *tech, INTSML layer);
-void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore);
-void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech);
+/* prototypes for local routines */
+static void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans);
+static char *io_lefoutlayername(TECHNOLOGY *tech, INTSML layer);
+static void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore);
+static void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech);
 
-char io_lefoutcurlayer[200];
+static char io_lefoutcurlayer[200];
 
 INTSML io_writeleflibrary(LIBRARY *lib)
 {
@@ -62,7 +63,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* create the proper disk file for the LEF */
 	np = lib->curnodeproto;
@@ -192,12 +193,12 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex == 0) continue;
 		if (ni == ignore) continue;
-		fun = nodefunction(ni, 0);
+		fun = nodefunction(ni);
 		if (fun != NPPIN && fun != NPCONTACT && fun != NPNODE && fun != NPCONNECT)
 			continue;
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -242,7 +243,7 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (top != 0 && ni->temp1 != 0) continue;
