@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iolout.c
- * Input/output aid: L output
+ * Input/output tool: L output
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -42,7 +42,7 @@
 #define OTHERNODE  4
 
 /* table that associates arc functionality with port types */
-struct
+static struct
 {
 	INTBIG arcfunct;
 	char *portname;
@@ -59,7 +59,7 @@ struct
 };
 
 /* table that associates arc functionality with contact types */
-struct
+static struct
 {
 	INTBIG arcfunct[3];
 	char *contactname;
@@ -73,10 +73,10 @@ struct
 };
 
 /* prototypes for local routines */
-INTBIG io_l_writefacet(NODEPROTO*);
-char *io_l_name(NODEINST*);
-char *io_l_fixname(char*);
-INTSML io_l_nodetype(NODEINST*);
+static INTBIG io_l_writefacet(NODEPROTO*);
+static char *io_l_name(NODEINST*);
+static char *io_l_fixname(char*);
+static INTSML io_l_nodetype(NODEINST*);
 
 INTSML io_writellibrary(LIBRARY *lib)
 {
@@ -144,6 +144,9 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		subnt = subno->proto;
 		if (subnt->primindex != 0) continue;
 
+		/* ignore recursive references (showing icon in contents) */
+		if (subnt->cell == np->cell) continue;
+
 		/* convert body facets to contents facets */
 		onp = contentsview(subnt);
 		if (onp != NONODEPROTO) subnt = onp;
@@ -157,7 +160,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	np->temp1 = 1;
 
 	/* make sure that all nodes have names on them */
-	if (askaid(net_aid, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
 
 	/* write the facet header */
 	xprintf(io_fileout, "\n");
@@ -197,7 +200,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 
 	/* number all components in the facet */
 	i = 1;
-	for(subno=np->firstnodeinst; subno!=NONODEINST; subno=subno->nextnodeinst)
+	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 		subno->temp1 = i++;
 
 	/* write the components */
@@ -210,6 +213,9 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		type = subnt->primname;
 		if (subnt->primindex == 0)
 		{
+			/* ignore recursive references (showing icon in contents) */
+			if (subnt->cell == np->cell) continue;
+
 			/* convert body facets to contents facets */
 			onp = contentsview(subnt);
 			if (onp != NONODEPROTO) subnt = onp;
@@ -217,7 +223,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			xprintf(io_fileout, "\tINST %s %s", type, io_l_name(subno));
 		} else
 		{
-			i = nodefunction(subno, 0);
+			i = nodefunction(subno);
 			if (i == NPPIN)
 			{
 				/* if pin is an export, don't write separate node statement */
@@ -305,7 +311,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	xprintf(io_fileout, "\n");
 
 	/* write all arcs connected to nodes */
-	for(subar=np->firstarcinst; subar!=NOARCINST; subar=subar->nextarcinst)
+	for(subar = np->firstarcinst; subar != NOARCINST; subar = subar->nextarcinst)
 		subar->temp1 = 0;
 	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 	{
@@ -328,7 +334,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 				xprintf(io_fileout, " W=%s", latoa(subar->width-arcwidthoffset(subar)));
 
 			/* write the starting node name (use port name if pin is an export) */
-			if (subno->firstportexpinst != NOPORTEXPINST && nodefunction(subno, 0) == NPPIN)
+			if (subno->firstportexpinst != NOPORTEXPINST && nodefunction(subno) == NPPIN)
 				xprintf(io_fileout, " %s",
 						io_l_fixname(subno->firstportexpinst->exportproto->protoname)); else
 							xprintf(io_fileout, " %s", io_l_name(subno));
@@ -407,7 +413,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			} else xprintf(io_fileout, " TO");
 
 			/* write the terminating node name (use port name if pin is an export) */
-			if (oni->firstportexpinst != NOPORTEXPINST && nodefunction(oni, 0) == NPPIN)
+			if (oni->firstportexpinst != NOPORTEXPINST && nodefunction(oni) == NPPIN)
 				xprintf(io_fileout, " %s",
 					io_l_fixname(oni->firstportexpinst->exportproto->protoname)); else
 						xprintf(io_fileout, " %s", io_l_name(oni));
@@ -428,7 +434,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	}
 
 	/* write any unmentioned wires (shouldn't be any) */
-	for(subar=np->firstarcinst; subar!=NOARCINST; subar=subar->nextarcinst)
+	for(subar = np->firstarcinst; subar != NOARCINST; subar = subar->nextarcinst)
 	{
 		if (subar->temp1 != 0) continue;
 		xprintf(io_fileout, "# WIRE %s not described!!\n", describearcinst(subar));
@@ -494,7 +500,7 @@ INTSML io_l_nodetype(NODEINST *ni)
 	REGISTER PORTARCINST *pi;
 
 	if (ni->proto->primindex == 0) return(INSTANCE);
-	i = nodefunction(ni, 0);
+	i = nodefunction(ni);
 	if (i == NPTRANMOS || i == NPTRADMOS || i == NPTRAPMOS) return(TRANSISTOR);
 	if (i != NPPIN) return(OTHERNODE);
 	i = 0;
