@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iopadso.c
- * Input/output aid: PADS output
+ * Input/output tool: PADS output
  * Written by: Neil Levine, NAL Consulting for Intel Corp.
  *
  * Copyright (c) 2001 Static Free Software.
@@ -28,12 +28,6 @@
  * info@staticfreesoft.com
  */
 
-/*
- * Modified 8/21/00 NL so that electric does not crash when a net has no name.
- * Modified 10/9/00 NL to not print out netname more than once for multiple parts for EAGLE netlist.
- * Modified 12/1/00 NL to work with release 6.02.
- */
-
 /*
  * ----------------- PADS NETLIST FORMAT ----------------------
         PADS-POWERPCB-V2
@@ -41,16 +35,31 @@
         *PART*
         LED1 LED@LED
         R1 RES100@RES100
-        
+
         *NET*
         *SIGNAL* A0 12,00 0 0 0 -2
         LED1.1 R1.2
         *SIGNAL* A1 12.00 0 0 0 -2
         LED1.2 R1.1
-        
+
         *END*
 */
 
+/*
+ * ----------------- ECAD NETLIST FORMAT ----------------------
+
+ .cmp (t=pkg_type) ref_des (x=0, y=0)
+
+  	.cmp (t=LED) LED1
+ 	.cmp (t=RES100) R1
+
+Net_name : ref_des pad; \
+           ref_des pad;
+
+ 	A0 : LED1 1; R1 2;
+ 	A1 : LED1 2; R1 1;
+
+*/
 
 #include "config.h"
 #if IOPADS
@@ -68,51 +77,48 @@ typedef struct Inextpadsnet
 	struct Inextpadsnet *nextpadsnet;
 } PADSNET;
 
-PADSNET *io_padsfirstnet;
+static PADSNET *io_padsfirstnet;
 
 /* prototypes for local routines */
-void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix);
-void io_padsmarkfacets(NODEPROTO *curfacet);
+static void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix);
+static void io_padsmarkfacets(NODEPROTO *curfacet);
 
 INTSML io_writepadslibrary(LIBRARY *lib)
 {
-#define MAX_SIGNAL_LINE_LENGTH  75
-
 	char file[100], *truename;
-	REGISTER INTBIG sorted, SignalLineLength;
+	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
 	REGISTER char *name;
 	REGISTER NODEPROTO *curfacet;
 	REGISTER PADSNET *en, *lasten, *nexten;
 	REGISTER PORTPROTO *pp;
 
-	/* create the proper disk file for the PADS netlist */
+	/* create the proper disk file for the PADS */
 	curfacet = lib->curnodeproto;
 	if (curfacet == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate PADS output");
+		ttyputerr(_("Must be editing a facet to generate PADS output"));
 		return(1);
 	}
-
 	(void)strcpy(file, curfacet->cell->cellname);
 	(void)strcat(file, ".asc");
 	name = truepath(file);
-	io_fileout = xcreate(name, io_filetypepads, "PADS File", &truename);
+	io_fileout = xcreate(name, io_filetypepads, _("PADS File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
-	xprintf(io_fileout, "!PADS-POWERPCB-V2\n\n*CLUSTER* ITEM\n\n\n*PART*\n");
+   	xprintf(io_fileout, "!PADS-POWERPCB-V2\n\n*CLUSTER* ITEM\n\n\n*PART*\n");
 
 	/* recurse through the circuit, gathering network connections */
 	io_padsfirstnet = NOPADSNET;
 	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
 
-	io_padsdumpfacet(curfacet, "");  /* crashes in here somewhere if not net name NL */
+	io_padsdumpfacet(curfacet, "");		/* assemble parts list */
 
-	xprintf(io_fileout, "\n*NET*\n");
+	xprintf(io_fileout, "\n*NET* \n");	/* cm - removed before netlist */
 
 	/* sort the signals */
 	sorted = 0;
@@ -137,45 +143,71 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 		}
 	}
 
+	/* determine longest name */
+	maxnetname = maxpackagename = 0;
+	for(en = io_padsfirstnet; en != NOPADSNET; en = en->nextpadsnet)
+	{
+		i = strlen(en->netname);
+		if (i > maxnetname) maxnetname = i;
+		i = strlen(en->packagename);
+		if (i > maxpackagename) maxpackagename = i;
+	}
+	maxnetname += 4;
+	maxpackagename += 4;
+
 	/* write networks */
 	lasten = NOPADSNET;
 	for(en = io_padsfirstnet; en != NOPADSNET; en = en->nextpadsnet)
-	{       
+	{
 		if (lasten == NOPADSNET || namesame(lasten->netname, en->netname) != 0)
 		{
-			if (lasten != NOPADSNET) xprintf(io_fileout, "\n");
-			xprintf(io_fileout, "*SIGNAL* %s 12.00 0 0 0 -2\n", en->netname);
-			SignalLineLength = 0;			/* used to track length of line for multi pin nets */
+			if (lasten != NOPADSNET)
+				xprintf(io_fileout, "\n");
+			xprintf(io_fileout, _("*SIGNAL* %s\n"), en->netname);	/* cm - write netname on first line of net */
 		}
-
-		/* write "Part" */
-		xprintf(io_fileout, "%s.", en->packagename);
-		SignalLineLength += strlen(en->packagename) + 1;
-
-		/* write "Pad" (an attribute with a number) */
-		xprintf(io_fileout, "%s ", en->pinname);
-		SignalLineLength += strlen(en->pinname) + 1;
-
-		if(SignalLineLength > MAX_SIGNAL_LINE_LENGTH)           /* start next line */
+#if 0
+		else
 		{
-			xprintf(io_fileout, "\n");
-			SignalLineLength = 0;
+			xprintf(io_fileout, "      ");							/* cm - was net name on each line */
 		}
+		for(i=strlen(en->netname); i<maxnetname; i++)
+			xprintf(io_fileout, " ");
+#endif
+
+		/* write "Part" column */
+		xprintf(io_fileout, "%s.%s\n", en->packagename,en->pinname);	/* cm - removed single quotes */
+#if 0
+		for(i=strlen(en->packagename); i<maxpackagename; i++)
+			xprintf(io_fileout, " ");
+#endif
+
+		/* write "Pad" column (an attribute with a number) */
+#if 0
+		xprintf(io_fileout, "%s \\\n", en->pinname);					/* cm - removed single quotes */
+		if (lasten == NOPADSNET || namesame(lasten->netname, en->netname) != 0)
+		{
+			if (lasten != NOPADSNET)
+				xprintf(io_fileout, ";\n");
+			else
+				xprintf(io_fileout, "\\\n");
+		}
+#endif
+
 		lasten = en;
 	}
 
-	if (lasten != NOPADSNET) xprintf(io_fileout, "\n\n*END*\n");
+	if (lasten != NOPADSNET) xprintf(io_fileout, "\n*END*\n"); /* cm - end of net section */
 
 	/* free memory */
 	while (io_padsfirstnet != NOPADSNET)
-	{
+	   {
 		en = io_padsfirstnet;
 		io_padsfirstnet = en->nextpadsnet;
 		efree(en->netname);
 		efree(en->packagename);
 		efree(en->pinname);
 		efree((char *)en);
-	}
+	   }
 
 	/* clean up */
 	xclose(io_fileout);
@@ -185,12 +217,13 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 	return(0);
 }
 
+
 /*
  * Routine to write out all facets in the current library that are marked (temp1 != 0).
  */
 void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 {
-	REGISTER char *name;
+	char *name;
 	char line[50], *newprefix, *tempname;
 	REGISTER NODEPROTO *np, *subnp, *subcnp;
 	REGISTER NETWORK *net;
@@ -199,14 +232,6 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
 	REGISTER PADSNET *en;
-	char CurRefDes[128], CurPackage[128];
-	char LastRefDes[128], LastPackage[128];
-	int RefDesSame, PackageSame;
-
-	CurRefDes[0] = 0;			/* Current reference designator string empty */                                                         
-	CurPackage[0] = 0;			/* Current package string empty */
-	LastRefDes[0] = 0;			/* Last reference designator string empty */
-	LastPackage[0] = 0;			/* Last  package string empty */
 
 	/* mark those facets that will be included in this dump */
 	io_padsmarkfacets(curfacet);
@@ -228,15 +253,19 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 			}
 		}
 
-		/* dump symbols in this facet */
+		/* dump symbols in this facet */ 
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			/* see if this node has a part name */
 			if (ni->proto->primindex != 0) continue;
-			varpart = getval((INTBIG)ni, VNODEINST, -1, "ATTR_PART");	/* cm - changed case on attribute */
+			subnp = ni->proto;
+
+			/* ignore recursive references (showing icon in contents) */
+			if (subnp->cell == np->cell) continue;
+
+			varpart = getval((INTBIG)ni, VNODEINST, -1, "ATTR_ref_des");   /* cm - changed for pads */
 			if (varpart == NOVARIABLE)
 			{
-				subnp = ni->proto;
 				subcnp = contentsview(subnp);
 				if (subcnp != NONODEPROTO) subnp = subcnp;
 
@@ -266,7 +295,7 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
 					(void)addstringtoinfstr(net->netname);
-					allocstring(&tempname, returninfstr(), io_aid->cluster);
+					allocstring(&tempname, returninfstr(), io_tool->cluster);
 					pp->temp1 = (INTBIG)tempname;
 				}
 
@@ -281,71 +310,66 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 			} else
 			{
 				/* found package at bottom of hierarchy */
+				(void)allocstring(&name, describevariable(varpart, -1, -1), el_tempcluster);
 				varpackagetype = getval((INTBIG)ni, VNODEINST, -1, "ATTR_pkg_type");
-
-				sprintf(CurRefDes, "%s%s", prefix, describevariable(varpart, -1, -1));	/* format current ref des to string */
 				if (varpackagetype == NOVARIABLE)
 				{
-					sprintf(CurPackage, "%s", ni->proto->cell->cellname);		/* current package to string */
+#if 0
+					xprintf(io_fileout, ".cmp_t %s '%s%s'", ni->proto->cell->cellname,		/* cm - changed */
+						prefix, name);
+#endif
+					xprintf(io_fileout, "Error no pkg_type attribute for %s%s", prefix, name);
 				} else
 				{
-					sprintf(CurPackage, "%s", describevariable(varpackagetype, -1, -1));	/* current package to string */
-				}
-				RefDesSame = (strcmp(CurRefDes, LastRefDes) == 0);				/* convert to booleans */
-				PackageSame = (strcmp(CurPackage, LastPackage) == 0);
-
-				if(RefDesSame && PackageSame)
-				{
-					/* don't need to write the line, warning or exchange current and last values */
-				} else
-				{
-					xprintf(io_fileout, "%s %s@%s\n", CurRefDes, CurPackage, CurPackage);	/* write the line */
-					if(RefDesSame && !PackageSame)
-						ttyputerr(_("Possible hetero error, RefDes same, package different"));	/* warning */
-					strcpy(LastRefDes, CurRefDes);                                                                                         /* save current values to last */
-					strcpy(LastPackage, CurPackage);
+					/* prefix seems to have no effect */
+					xprintf(io_fileout, "%s%s  %s@%s", prefix, name, describevariable(varpackagetype, -1, -1), describevariable(varpackagetype, -1, -1));
 				}
+				xprintf(io_fileout, "\n");
 
 				/* record all networks */
-				name = describevariable(varpart, -1, -1);
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				{
 					/* get "Pad" information */
 					(void)initinfstr();
 					(void)addstringtoinfstr("ATTRP_");
 					(void)addstringtoinfstr(pi->proto->protoname);
-					(void)addstringtoinfstr("_pad");
-
+					(void)addstringtoinfstr("_pin");
 					var = getval((INTBIG)ni, VNODEINST, -1, returninfstr());
-					if (var == NOVARIABLE) continue;
+					if (var == NOVARIABLE)
+					{
+						/* "Pad" not found on instance: look for it inside of prototype */
+						var = getval((INTBIG)pi->proto, VPORTPROTO, -1, "ATTR_pin");
+						if (var == NOVARIABLE) continue;
+					}
 
 					/* create a new net connection */
-					en = (PADSNET *)emalloc(sizeof (PADSNET), io_aid->cluster);
+					en = (PADSNET *)emalloc(sizeof (PADSNET), io_tool->cluster);
 					if (en == 0) return;
 					net = pi->conarcinst->network;
 					if (net->temp1 != 0)
 					{
-						(void)allocstring(&en->netname, (char *)net->temp1, io_aid->cluster);
-					} else
+						(void)allocstring(&en->netname, (char *)net->temp1, io_tool->cluster);
+					} else if (net->namecount > 0)
 					{
 						(void)initinfstr();
 						(void)addstringtoinfstr(prefix);
-
-						/* test for existence of at least one netname */
-						if (net->namecount)(void)addstringtoinfstr(net->netname); else	/* @@@ Modified 8/21/00 NL */
-							(void)addstringtoinfstr("**NO NET NAME**");					/* @@@ Added 8/21/00 NL */
-
-						(void)allocstring(&en->netname, returninfstr(), io_aid->cluster);
+						(void)addstringtoinfstr(net->netname);
+						(void)allocstring(&en->netname, returninfstr(), io_tool->cluster);
+					} else
+					{
+						(void)initinfstr();
+						(void)formatinfstr("%sNET%ld added here", prefix, (INTBIG)net);
+						(void)allocstring(&en->netname, returninfstr(), io_tool->cluster);
 					}
-
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
 					(void)addstringtoinfstr(name);
-					(void)allocstring(&en->packagename, returninfstr(), io_aid->cluster);
-					(void)allocstring(&en->pinname, describevariable(var, -1, -1), io_aid->cluster);
+					(void)allocstring(&en->packagename, returninfstr(), io_tool->cluster);
+					(void)allocstring(&en->pinname, describevariable(var, -1, -1), io_tool->cluster);
 					en->nextpadsnet = io_padsfirstnet;
 					io_padsfirstnet = en;
 				}
+				efree((char *)name);
 			}
 		}
 	}
