@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iopsout.c
- * Input/output analysis aid: PostScript generation
+ * Input/output analysis tool: PostScript generation
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -51,7 +51,7 @@
 #include "edialogs.h"
 
 /* #define CLIP 1 */		/* set if the bounding box is used as the clip path, for EPS only */
-/* #define DEBUGHIERPS 1	/* uncomment to debug hierarchical PostScript (shows memory usage) */
+/* #define DEBUGHIERPS 1 */	/* uncomment to debug hierarchical PostScript (shows memory usage) */
 
 #define PSSCALE             4
 #define CORNERDATESIZE     14			/* size of date information in corner */
@@ -84,28 +84,29 @@ static INTBIG     io_pspolygontotal;		/* number of polygons in job */
 static INTBIG     io_psopcount;				/* chunks of code */
 static char       io_psprefix[10];			/* indentation for PostScript */
 
-GRAPHICS io_psblack = {LAYERO, BLACK, SOLIDC, SOLIDC,
+static GRAPHICS io_psblack = {LAYERO, BLACK, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* prototypes for local routines */
-void   io_psarc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void   io_pscircle(INTBIG, INTBIG, INTBIG, INTBIG);
-void   io_psdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
-void   io_psdot(INTBIG, INTBIG);
-void   io_psdumpcontents(NODEPROTO *np);
-void   io_psdumpfacets(NODEPROTO *np);
-char  *io_psfacetname(NODEPROTO *np);
-void   io_psline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML io_pspattern(GRAPHICS*);
-INTSML io_pspoly(POLYGON*, WINDOWPART*);
-INTSML io_pspolycount(POLYGON*, WINDOWPART*);
-void   io_pspolygon(INTBIG*, INTBIG*, INTSML, GRAPHICS*);
-void   io_psputheader(INTBIG which);
-void   io_pstext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*);
-void   io_pswrite(char *s, ...);
-INTSML io_pswritefacet(NODEPROTO*, char*, INTBIG);
-void   io_pswritestring(char*);
-void   io_psxform(INTBIG, INTBIG, INTBIG*, INTBIG*);
+static void   io_psarc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void   io_pscircle(INTBIG, INTBIG, INTBIG, INTBIG);
+static void   io_psdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
+static void   io_psdot(INTBIG, INTBIG);
+static void   io_psdumpcontents(NODEPROTO *np);
+static void   io_psdumpfacets(NODEPROTO *np);
+static char  *io_psfacetname(NODEPROTO *np);
+static void   io_psline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static INTSML io_pspattern(GRAPHICS*);
+static INTSML io_pspoly(POLYGON*, WINDOWPART*);
+static INTSML io_pspolycount(POLYGON*, WINDOWPART*);
+static void   io_pspolygon(INTBIG*, INTBIG*, INTSML, GRAPHICS*);
+static void   io_psputheader(INTBIG which);
+static void   io_pstext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, char*,
+				 INTBIG, INTBIG, INTBIG);
+static void   io_pswrite(char *s, ...);
+static INTSML io_pswritefacet(NODEPROTO*, char*, INTBIG);
+static void   io_pswritestring(char*);
+static void   io_psxform(INTBIG, INTBIG, INTBIG*, INTBIG*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -242,14 +243,15 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	if ((curstate[0]&PSPLOTTER) != 0) useplotter = 1;
 	if ((curstate[0]&PSROTATE) != 0) rotateplot = 1;
 	if ((curstate[0]&PLOTDATES) != 0) plotdates = 1;
+	if (printit != 0) epsformat = 0;
 
-	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_width");
+	var = getval((INTBIG)io_tool, VTOOL, VFRACT, "IO_postscript_width");
 	if (var == NOVARIABLE) pagewid = DEFAULTPSWIDTH; else
 		pagewid = muldiv(var->addr, 75, WHOLE);
-	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_height");
+	var = getval((INTBIG)io_tool, VTOOL, VFRACT, "IO_postscript_height");
 	if (var == NOVARIABLE) pagehei = DEFAULTPSHEIGHT; else
 		pagehei = muldiv(var->addr, 75, WHOLE);
-	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_margin");
+	var = getval((INTBIG)io_tool, VTOOL, VFRACT, "IO_postscript_margin");
 	if (var == NOVARIABLE)
 	{
 		pagemarginps = DEFAULTPSMARGIN;
@@ -263,9 +265,9 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	/* cache color maps if using color */
 	if (io_psusecolor != 0)
 	{
-		varred = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_red");
-		vargreen = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_green");
-		varblue = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_blue");
+		varred = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_red");
+		vargreen = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_green");
+		varblue = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_blue");
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputmsg(_("Cannot get colors!"));
@@ -279,6 +281,18 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	/* determine the area of interest */
 	if (io_getareatoprint(np, &lx, &hx, &ly, &hy, 0) != 0) return(1);
 
+	/* if plotting, compute height from width */
+	if (useplotter != 0)
+	{
+		if (rotateplot != 0)
+		{
+			pagehei = muldiv(pagewid, hx-lx, hy-ly);
+		} else
+		{
+			pagehei = muldiv(pagewid, hy-ly, hx-lx);
+		}
+	}
+
 	/* create the PostScript file */
 	if (printit != 0)
 	{
@@ -441,17 +455,17 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	/* set the page size if this is a plotter */
 	if (useplotter != 0)
 	{
-		t1 = bbhx - bblx + pagemarginps * 2;
-		t2 = bbhy - bbly + pagemarginps * 2;
-		io_pswrite("<< /PageSize [%ld %ld] >> setpagedevice\n", t1, t2);
+		io_pswrite("<< /PageSize [%ld %ld] >> setpagedevice\n",
+			muldiv(pagewid, 72, 75), muldiv(pagehei, 72, 75));
 	}
 
 	/* make the scale be exactly equal to one page pixel */
 	io_pswrite("72 %ld div 72 %ld div scale\n", PSSCALE*75, PSSCALE*75);
 
 	/* PostScript: set the proper typeface */
+	io_pswrite("/DefaultFont /Times-Roman def\n");
 	io_pswrite("/scaleFont {\n");
-	io_pswrite("    /Times-Roman findfont\n");
+	io_pswrite("    /DefaultFont findfont\n");
 	io_pswrite("    exch scalefont setfont} def\n");
 
 	/* PostScript: make the line width proper */
@@ -462,6 +476,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 
 	if (epsformat)
 	{
+		/* EMPTY */
 		/* EPS: set the clip path to be equal to the bounding box */
 #ifdef CLIP
 		io_pswrite("gsave\n");
@@ -477,10 +492,16 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 		/* PostScript: rotate the image if requested */
 		if (rotateplot != 0)
 		{
+#if 0
 			io_pswrite("%s %s add 300 mul %s 300 mul translate 90 rotate\n",
 				frtoa(muldiv(pagewid, WHOLE, 75)),
 				frtoa(muldiv((pagehei-pagewid)/2, WHOLE, 75)),
 				frtoa(muldiv((pagehei-pagewid)/2, WHOLE, 75)));
+#else
+			io_pswrite("%s 300 mul %s 300 mul translate 90 rotate\n",
+				frtoa(muldiv(pagewid+pagemarginps, WHOLE, 75)),
+				frtoa(muldiv((pagehei-pagewid)/2, WHOLE, 75)));
+#endif
 		}
 	}
 
@@ -513,7 +534,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 		io_pspolygoncount = 0;
 		if (io_verbose < 0)
 		{
-			(void)askaid(us_aid, "display-to-routine", io_pspolycount);
+			(void)asktool(us_tool, "display-to-routine", io_pspolycount);
 			io_pspolygontotal = io_pspolygoncount;
 			if (io_pspolygontotal == 0) io_pspolygontotal = 1;
 			DiaSetText(2, _("Writing PostScript..."));
@@ -530,7 +551,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 			{
 				if (stopping(STOPREASONDECK)) break;
 				io_whichlayer = io_nextplotlayer(i) + 1;
-				(void)askaid(us_aid, "display-to-routine", io_pspoly);
+				(void)asktool(us_tool, "display-to-routine", io_pspoly);
 			}
 			if (stopping(STOPREASONDECK))
 			{
@@ -538,12 +559,12 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 				return(0);
 			}
 			io_whichlayer = 0;
-			(void)askaid(us_aid, "display-to-routine", io_pspoly);
+			(void)asktool(us_tool, "display-to-routine", io_pspoly);
 		} else
 		{
 			/* gray-scale: just plot it once */
 			io_whichlayer = -1;
-			(void)askaid(us_aid, "display-to-routine", io_pspoly);
+			(void)asktool(us_tool, "display-to-routine", io_pspoly);
 		}
 
 		/* restore "tiny facet" removal option */
@@ -562,7 +583,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 				{
 					onp->temp1 = 0;
 					layarr = (INTSML *)emalloc((io_maxpslayer+1) * SIZEOFINTSML,
-						io_aid->cluster);
+						io_tool->cluster);
 					if (layarr == 0) return(1);
 					for(i=0; i<=io_maxpslayer; i++) layarr[i] = 0;
 					onp->temp2 = (INTBIG)layarr;
@@ -616,7 +637,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 
 		/* dump the current facet */
 		io_pswrite("\n%% Invocation of top-level facet\n");
-#ifndef DEBUGHIERPS
+#ifdef DEBUGHIERPS
 		io_pswrite("(FINISHED) dovmstats\n");
 #else
 		if (io_psusecolor != 0)
@@ -651,7 +672,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	{
 		gridx = el_curwindowpart->gridx;
 		gridy = el_curwindowpart->gridy;
-		var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_gridfloats);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloats);
 		if (var == NOVARIABLE || var->addr == 0)
 		{
 			gridlx = lx  / gridx * gridx;
@@ -659,7 +680,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 		} else
 		{
 			grabpoint(np, &gridlx, &gridly);
-			var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_alignment_obj");
+			var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_alignment_obj");
 			if (var != NOVARIABLE) gridalign(&gridlx, &gridly, var->addr);
 			gridlx += gridlx / gridx * gridx;
 			gridly += gridly / gridy * gridy;
@@ -692,7 +713,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	j = framepolys(np);
 	if (j != 0)
 	{
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 		io_whichlayer = -1;
 		for(i=0; i<j; i++)
 		{
@@ -748,7 +769,7 @@ INTSML io_pswritefacet(NODEPROTO *np, char *synchronize, INTBIG printit)
 	{
 		/* determine printer to use */
 		defprinter = 0;
-		var = getval((INTBIG)io_aid, VAID, VSTRING, "IO_default_printer");
+		var = getval((INTBIG)io_tool, VTOOL, VSTRING, "IO_default_printer");
 		if (var != NOVARIABLE) defprinter = (char *)var->addr; else
 		{
 			printer = egetenv("PRINTER");
@@ -880,7 +901,7 @@ void io_psdumpcontents(NODEPROTO *np)
 	if (stopping(STOPREASONDECK)) return;
 	if (io_psfake != 0) io_psopcount += 2; else
 		io_pswrite("/%s {\n", io_psfacetname(np));
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	io_lastred = io_lastgreen = io_lastblue = -1;
 
 	/* first write calls to subfacets */
@@ -953,7 +974,8 @@ void io_psdumpcontents(NODEPROTO *np)
 				io_pspoly(poly, el_curwindowpart);
 
 				poly->style = TEXTCENT;
-				poly->font = TXT4L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 				poly->string = describenodeproto(ni->proto);
 				io_pspoly(poly, el_curwindowpart);
 			}
@@ -1004,7 +1026,7 @@ void io_psdumpcontents(NODEPROTO *np)
 		us_displayroutine = io_pspoly;
 
 		/* write facet text */
-		us_drawnodeprotovariables(np, el_matid, el_curwindowpart);
+		us_drawnodeprotovariables(np, el_matid, el_curwindowpart, 0);
 
 		/* write port text */
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -1013,7 +1035,7 @@ void io_psdumpcontents(NODEPROTO *np)
 			us_writeprotoname(pp, LAYERA, trans, LAYERO,
 				el_colfacettxt, el_curwindowpart, 0, 0, 0, 0,
 					(us_useroptions&PORTLABELS) >> PORTLABELSSH);
-			us_drawportprotovariables(pp, 1, trans, el_curwindowpart);
+			us_drawportprotovariables(pp, 1, trans, el_curwindowpart, 0);
 		}
 
 		/* restore graphics state */
@@ -1039,7 +1061,9 @@ INTSML io_pspolycount(POLYGON *poly, WINDOWPART *win)
  */
 INTSML io_pspoly(POLYGON *poly, WINDOWPART *win)
 {
-	REGISTER INTBIG red, green, blue, k, type, font;
+	REGISTER INTBIG red, green, blue, k, type, size, face;
+	REGISTER char *facename;
+	char **facelist;
 	REGISTER float r, g, b;
 	INTBIG xl, xh, yl, yh, x, y, listx[4], listy[4];
 	REGISTER TECHNOLOGY *tech;
@@ -1087,7 +1111,7 @@ INTSML io_pspoly(POLYGON *poly, WINDOWPART *win)
 				r = (float)red / 255.0f;
 				g = (float)green / 255.0f;
 				b = (float)blue / 255.0f;
-				io_pswrite("%s%f %f %f setrgbcolor\n", io_psprefix, r, g, b);
+				io_pswrite("%s%g %g %g setrgbcolor\n", io_psprefix, r, g, b);
 			}
 		}
 	}
@@ -1139,6 +1163,7 @@ INTSML io_pspoly(POLYGON *poly, WINDOWPART *win)
 				io_psline(xh, yl, xl, yl, 0);
 				break;
 			}
+			/* FALLTHROUGH */ 
 
 		case OPENED:
 		case OPENEDT1:
@@ -1184,6 +1209,7 @@ INTSML io_pspoly(POLYGON *poly, WINDOWPART *win)
 
 		case DISC:
 			io_psdisc(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1], poly->desc);
+			/* FALLTHROUGH */ 
 
 		case CIRCLE:
 			io_pscircle(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1]);
@@ -1204,10 +1230,18 @@ INTSML io_pspoly(POLYGON *poly, WINDOWPART *win)
 		case TEXTTOPRIGHT:
 		case TEXTBOTRIGHT:
 		case TEXTBOX:
-			tech = win->curnodeproto->tech;
-			font = truefontsize(poly->font, win, tech);
+			tech = poly->tech;
+			size = truefontsize(TDGETSIZE(poly->textdescript), win, tech);
 			getbbox(poly, &xl, &xh, &yl, &yh);
-			io_pstext(poly->style, xl, xh, yl, yh, font, poly->string);
+			face = TDGETFACE(poly->textdescript);
+			if (face == 0) facename = 0; else
+			{
+				(void)screengetfacelist(&facelist);
+				facename = facelist[face];
+			}
+			io_pstext(poly->style, xl, xh, yl, yh, size, poly->string, facename,
+				TDGETITALIC(poly->textdescript), TDGETBOLD(poly->textdescript),
+					TDGETUNDERLINE(poly->textdescript));
 			break;
 	}
 	return(0);
@@ -1398,18 +1432,18 @@ void io_psputheader(INTBIG which)
 		"/Centerstring {",								/* x y str sca */
 		"    dup /TSize exch def",						/* save size */
 		"    dup scaleFont exch dup TSize StringLength", /* x y sca str xw yw */
-		"    pop 3 -1 roll .8 mul",						/* x y str xw sca*.8 */
-		"    exch 5 -1 roll exch 2 div sub",			/* y str sca*.8 x-xw/2 */
-		"    exch 4 -1 roll exch 2 div sub",			/* str x-xw/2 y-sca*.8/2 */
+		"    pop 3 -1 roll .5 mul",						/* x y str xw sca*.5 (was .8) */
+		"    exch 5 -1 roll exch 2 div sub",			/* y str sca*.5 x-xw/2 */
+		"    exch 4 -1 roll exch 2 div sub",			/* str x-xw/2 y-sca*.5/2 */
 		"    moveto TSize StringShow",
 		"} def",
 
 		"/Topstring {",									/* x y str sca */
 		"    dup /TSize exch def",						/* save size */
 		"    dup scaleFont exch dup TSize StringLength", /* x y sca str xw yw */
-		"    pop 3 -1 roll .8 mul",						/* x y str xw sca*.8 */
-		"    exch 5 -1 roll exch 2 div sub",			/* y str sca*.8 x-xw/2 */
-		"    exch 4 -1 roll exch sub",					/* str x-xw/2 y-sca*.8 */
+		"    pop 3 -1 roll .5 mul",						/* x y str xw sca*.5 (was .8) */
+		"    exch 5 -1 roll exch 2 div sub",			/* y str sca*.5 x-xw/2 */
+		"    exch 4 -1 roll exch sub",					/* str x-xw/2 y-sca*.5 */
 		"    moveto TSize StringShow",
 		"} def",
 
@@ -1439,18 +1473,18 @@ void io_psputheader(INTBIG which)
 
 		"/Topleftstring {",								/* x y str sca */
 		"    dup /TSize exch def",						/* save size */
-		"    dup scaleFont .8 mul",						/* x y str sca*.8 */
-		"    3 -1 roll exch sub",						/* x str y-sca*.8 */
-		"    3 -1 roll exch",							/* str x y-sca*.8 */
+		"    dup scaleFont .5 mul",						/* x y str sca*.5 (was .8) */
+		"    3 -1 roll exch sub",						/* x str y-sca*.5 */
+		"    3 -1 roll exch",							/* str x y-sca*.5 */
 		"    moveto TSize StringShow",
 		"} def",
 
 		"/Toprightstring {",							/* x y str sca */
 		"    dup /TSize exch def",						/* save size */
 		"    dup scaleFont exch dup TSize StringLength", /* x y sca str xw yw */
-		"    pop 3 -1 roll .8 mul",						/* x y str xw sca*.8 */
-		"    exch 5 -1 roll exch sub",					/* y str sca*.8 x-xw */
-		"    exch 4 -1 roll exch sub",					/* str x-xw y-sca*.8 */
+		"    pop 3 -1 roll .5 mul",						/* x y str xw sca*.5 (was .8) */
+		"    exch 5 -1 roll exch sub",					/* y str sca*.5 x-xw */
+		"    exch 4 -1 roll exch sub",					/* str x-xw y-sca*.5 */
 		"    moveto TSize StringShow",
 		"} def",
 
@@ -1721,7 +1755,7 @@ INTSML io_pspattern(GRAPHICS *col)
 	if (io_psgraphicsseencount >= io_psgraphicsseenlimit)
 	{
 		newgraphicsseen = (GRAPHICS **)emalloc((io_psgraphicsseenlimit + 50) *
-			(sizeof (GRAPHICS *)), io_aid->cluster);
+			(sizeof (GRAPHICS *)), io_tool->cluster);
 		if (newgraphicsseen == 0) return(0);
 		for(i=0; i<io_psgraphicsseencount; i++)
 			newgraphicsseen[i] = io_psgraphicsseen[i];
@@ -1787,13 +1821,16 @@ INTSML io_pspattern(GRAPHICS *col)
 }
 
 /* draw text */
-void io_pstext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG fnt,
-	char *text)
+void io_pstext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG size,
+	char *text, char *face, INTBIG italic, INTBIG bold, INTBIG underline)
 {
-	char *pt;
-	INTBIG pslx, pshx, psly, pshy, fontsize;
+	char *pt, psfontname[300];
+	INTBIG pslx, pshx, psly, pshy, fontsize, changedfont;
+	static char defaultfontname[200];
+	static INTBIG defaultfontnameknown = 0;
 
-	fontsize = fnt * PSSCALE;
+	/* get the font size */
+	fontsize = size * PSSCALE/2;
 	if (fontsize <= 0) return;
 
 	if (io_psfake != 0)
@@ -1807,10 +1844,50 @@ void io_pstext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG f
 	for(pt = text; *pt != 0; pt++) if (*pt != ' ' && *pt != '\t') break;
 	if (*pt == 0) return;
 
+	/* get the default font name */
+	if (defaultfontnameknown == 0)
+	{
+		defaultfontnameknown = 1;
+		strcpy(defaultfontname, screengetdefaultfacename());
+	}
+
 	io_psxform(lx, ly, &pslx, &psly);
 	io_psxform(ux, uy, &pshx, &pshy);
 
 	io_psputheader(PSHEADERSTRING);
+	changedfont = 0;
+	if (face != 0)
+	{
+		(void)initinfstr();
+		for(pt = face; *pt != 0; pt++)
+		{
+			if (*pt == ' ') (void)addtoinfstr('-'); else
+				(void)addtoinfstr(*pt);
+		}
+		io_pswrite("/DefaultFont /%s def\n", returninfstr());
+		changedfont = 1;
+	} else
+	{
+		if (italic != 0)
+		{
+			if (bold != 0)
+			{
+				sprintf(psfontname, "/DefaultFont /%s-BoldItalic def\n", defaultfontname);
+				io_pswrite(psfontname);
+				changedfont = 1;
+			} else
+			{
+				sprintf(psfontname, "/DefaultFont /%s-Italic def\n", defaultfontname);
+				io_pswrite(psfontname);
+				changedfont = 1;
+			}
+		} else if (bold != 0)
+		{
+			sprintf(psfontname, "/DefaultFont /%s-Bold def\n", defaultfontname);
+			io_pswrite(psfontname);
+			changedfont = 1;
+		}
+	}
 	switch (type)
 	{
 		case TEXTCENT:
@@ -1865,6 +1942,11 @@ void io_pstext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG f
 			io_pswrite(" %ld Boxstring\n", fontsize);
 			break;
 	}
+	if (changedfont != 0)
+	{
+		sprintf(psfontname, "/DefaultFont /%s def\n", defaultfontname);
+		io_pswrite(psfontname);
+	}
 }
 
 /*
@@ -1895,7 +1977,7 @@ void io_pswrite(char *s, ...)
 	va_list ap;
 
 	var_start(ap, s);
-	(void)vsprintf(theline, s, ap);
+	evsnprintf(theline, 100, s, ap);
 	va_end(ap);
 
 	xprintf(io_psout, "%s", theline);
