@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: ioquickdraw.c
- * Input/output analysis aid: plotter output on Macintosh
+ * Input/output analysis tool: plotter output on Macintosh
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -157,9 +157,9 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	SetPort((WindowPtr)plotwin);
 
 	/* save background color and make it white */
-	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE) return(1);
 	saver = ((INTBIG *)varred->addr)[0];
 	saveg = ((INTBIG *)vargreen->addr)[0];
@@ -273,7 +273,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	{
 		gridx = el_curwindowpart->gridx;
 		gridy = el_curwindowpart->gridy;
-		var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_gridfloats);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloats);
 		if (var == NOVARIABLE || var->addr == 0)
 		{
 			gridlx = np->lowx  / gridx * gridx;
@@ -281,7 +281,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		} else
 		{
 			grabpoint(np, &gridlx, &gridly);
-			var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_alignment_obj");
+			var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_alignment_obj");
 			if (var != NOVARIABLE) gridalign(&gridlx, &gridly, var->addr);
 			gridlx += gridlx / gridx * gridx;
 			gridly += gridly / gridy * gridy;
@@ -302,22 +302,22 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	{
 		/* first plot outlines around stipple layers */
 		io_setplotlayer(-(io_nextplotlayer(ix) + 1));
-		(void)askaid(us_aid, "display-to-routine", io_plotpoly);
+		(void)asktool(us_tool, "display-to-routine", io_plotpoly);
 
 		/* next plot layers */
 		io_setplotlayer(io_nextplotlayer(ix) + 1);
-		(void)askaid(us_aid, "display-to-routine", io_plotpoly);
+		(void)asktool(us_tool, "display-to-routine", io_plotpoly);
 	}
 
 	/* finally plot layers not in the technology */
 	io_setplotlayer(0);
-	(void)askaid(us_aid, "display-to-routine", io_plotpoly);
+	(void)asktool(us_tool, "display-to-routine", io_plotpoly);
 
 	/* put out dates if requested */
 	if ((curstate[0]&PLOTDATES) != 0)
 	{
 		/* create the polygon if it doesn't exist */
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(1, io_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(1, io_tool->cluster);
 
 		/* plot facet name */
 		(void)initinfstr();
@@ -327,7 +327,8 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		poly->yv[0] = np->lowy;
 		poly->count = 1;
 		poly->style = TEXTBOTRIGHT;
-		poly->font = TXT1L;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(4));
 		poly->tech = el_curtech;
 		poly->desc = &io_black;
 		(void)io_plotpoly(poly, el_curwindowpart);
@@ -401,7 +402,7 @@ void io_setbounds(INTBIG slx, INTBIG shx, INTBIG sly, INTBIG shy, INTBIG ulx, IN
 INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 {
 	REGISTER INTSML k, type;
-	INTBIG xl, xh, yl, yh, x, y, listx[4], listy[4], font,
+	INTBIG xl, xh, yl, yh, x, y, listx[4], listy[4], size,
 		centerx, centery, x1p, y1p, x2p, y2p, xa, ya, xb, yb, radius;
 	INTSML startangle, endangle, amt, style;
 	unsigned char pat[8];
@@ -660,9 +661,9 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 		case TEXTBOTRIGHT:
 		case TEXTBOX:
 			tech = win->curnodeproto->tech;
-			font = truefontsize(poly->font, io_plotwindow, tech);
+			size = truefontsize(TDGETSIZE(poly->textdescript), io_plotwindow, tech);
 			getbbox(poly, &xl, &xh, &yl, &yh);
-			io_plottext(poly->style, xl, xh, yl, yh, font, poly->string);
+			io_plottext(poly->style, xl, xh, yl, yh, size, poly->string);
 			break;
 	}
 	return(0);
@@ -746,11 +747,11 @@ void io_plotpolygon(INTBIG *x, INTBIG *y, INTSML count, INTSML style, GRAPHICS *
 	KillPoly(polyhandle);
 }
 
-void io_plottext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG fnt,
+void io_plottext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG size,
 	char *text)
 {
 	char localstring[256];
-	INTBIG len, i, tsx, tsy, px, py, font;
+	INTBIG len, i, tsx, tsy, px, py, truesize;
 	FontInfo fontinfo;
 
 	io_xform(&lx, &ly);
@@ -762,9 +763,9 @@ void io_plottext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG
 	if (type == TEXTBOX)
 	{
 		/* scan for a font that fits */
-		for(font = fnt; font >= 4; font--)
+		for(truesize = size; truesize >= 4; truesize--)
 		{
-			TextSize(font);
+			TextSize(truesize);
 			GetFontInfo(&fontinfo);
 			tsx = TextWidth(localstring, 0, len);
 			tsy = fontinfo.ascent + fontinfo.descent + fontinfo.leading;
@@ -792,7 +793,7 @@ void io_plottext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG
 		}
 	} else
 	{
-		TextSize(fnt);
+		TextSize(size);
 		GetFontInfo(&fontinfo);
 		tsx = TextWidth(localstring, 0, len);
 		tsy = fontinfo.ascent + fontinfo.descent + fontinfo.leading;
@@ -921,16 +922,16 @@ void io_maccopyhighlighted(void)
 	{
 		/* first plot outlines around stipple layers */
 		io_setplotlayer(-(io_nextplotlayer(ix) + 1));
-		(void)askaid(us_aid, "display-highlighted-to-routine", io_plotpoly);
+		(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
 
 		/* next plot layers */
 		io_setplotlayer(io_nextplotlayer(ix) + 1);
-		(void)askaid(us_aid, "display-highlighted-to-routine", io_plotpoly);
+		(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
 	}
 
 	/* finally plot layers not in the technology */
 	io_setplotlayer(0);
-	(void)askaid(us_aid, "display-highlighted-to-routine", io_plotpoly);
+	(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
 
 	ClosePicture();
 	HLock((Handle)picture);
