@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iosdfi.c
- * Input/output aid: SDF (Standard Delay Format) 2.1 reader
+ * Input/output tool: SDF (Standard Delay Format) 2.1 reader
  * Written by: Russell L. Wright
  *
  * Copyright (c) 2000 Static Free Software.
@@ -60,53 +60,53 @@ typedef struct
 	void  **paramvalue;
 } LISPTREE;
 
-LISPTREE *sdfi_treestack[MAXDEPTH];
-INTSML    sdfi_treedepth;
-LISPTREE *sdfi_treepos;
-LISPTREE *sdfi_freelisptree = 0;
+static LISPTREE *sdfi_treestack[MAXDEPTH];
+static INTSML    sdfi_treedepth;
+static LISPTREE *sdfi_treepos;
+static LISPTREE *sdfi_freelisptree = 0;
 
-INTBIG sdfi_filesize;
-INTBIG sdfi_lineno;
-char *sdfi_design = NULL;		/* DESIGN keyword */
-char *sdfi_sdfversion = NULL;	/* SDFVERSION keyword */
-char *sdfi_date = NULL;			/* DATE keyword */
-char *sdfi_vendor = NULL;		/* VENDOR keyword */
-char *sdfi_program = NULL;		/* PROGRAM keyword */
-char *sdfi_version = NULL;		/* VERSION keyword */
-char *sdfi_voltage = NULL;		/* VOLTAGE keyword */
-char *sdfi_process = NULL;		/* PROCESS keyword */
-char *sdfi_temperature = NULL;	/* TEMPERATURE keyword */
-char *sdfi_timescale = NULL;	/* TIMESCALE keyword */
-char *sdfi_hiername = NULL;		/* current cell instance hierarchy name */
-char *sdfi_celltype = NULL;		/* current CELLTYPE */
-char *sdfi_instance = NULL;		/* current INSTANCE */
-char *sdfi_divider = NULL;		/* hierarchy divider - if DIVIDER keyword not in SDF file defaults to . */
-INTBIG sdfi_timeconvert = 1000; /* multiplier to convert time values to picoseconds */
+static INTBIG sdfi_filesize;
+static INTBIG sdfi_lineno;
+static char *sdfi_design = NULL;		/* DESIGN keyword */
+static char *sdfi_sdfversion = NULL;	/* SDFVERSION keyword */
+static char *sdfi_date = NULL;			/* DATE keyword */
+static char *sdfi_vendor = NULL;		/* VENDOR keyword */
+static char *sdfi_program = NULL;		/* PROGRAM keyword */
+static char *sdfi_version = NULL;		/* VERSION keyword */
+static char *sdfi_voltage = NULL;		/* VOLTAGE keyword */
+static char *sdfi_process = NULL;		/* PROCESS keyword */
+static char *sdfi_temperature = NULL;	/* TEMPERATURE keyword */
+static char *sdfi_timescale = NULL;	/* TIMESCALE keyword */
+static char *sdfi_hiername = NULL;		/* current cell instance hierarchy name */
+static char *sdfi_celltype = NULL;		/* current CELLTYPE */
+static char *sdfi_instance = NULL;		/* current INSTANCE */
+static char *sdfi_divider = NULL;		/* hierarchy divider - if DIVIDER keyword not in SDF file defaults to . */
+static INTBIG sdfi_timeconvert = 1000; /* multiplier to convert time values to picoseconds */
 								/* if TIMESCALE keyword not in SDF file default time unit is 1ns */
-INTBIG SDF_instance_key = 0;
-INTBIG SDF_absolute_port_delay_key = 0;
-INTBIG SDF_absolute_iopath_delay_key = 0;
-NODEPROTO *sdfi_curfacet = NONODEPROTO;
+static INTBIG SDF_instance_key = 0;
+static INTBIG SDF_absolute_port_delay_key = 0;
+static INTBIG SDF_absolute_iopath_delay_key = 0;
+static NODEPROTO *sdfi_curfacet = NONODEPROTO;
 
 /* prototypes for local routines */
-INTSML     sdfi_addparameter(LISPTREE *tree, INTSML type, void *value);
-LISPTREE  *sdfi_alloclisptree(void);
-void       sdfi_killptree(LISPTREE *lt);
-INTSML     sdfi_pushkeyword(char *pt);
-LISPTREE  *sdfi_readfile(FILE *fp);
-INTSML     sdfi_parsetree(LISPTREE *lt);
-INTSML     sdfi_parsedelayfile(LISPTREE *lt);
-INTSML     sdfi_parsecell(LISPTREE *lt);
-INTSML     sdfi_parsedelay(LISPTREE *lt, NODEINST *ni);
-INTSML     sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni);
-INTSML     sdfi_parseincrement(LISPTREE *lt, NODEINST *ni);
-INTSML     sdfi_parseport(LISPTREE *lt, NODEINST *ni);
-INTSML     sdfi_parseiopath(LISPTREE *lt, NODEINST *ni);
-INTSML     sdfi_parsetimescale(LISPTREE *lt);
-NODEINST  *sdfi_getcellinstance(char *celltype, char *instance);
-char      *sdfi_converttops(char *tstring);
-void       sdfi_setstring(char **string, char *value);
-void       sdfi_clearglobals(void);
+static INTSML     sdfi_addparameter(LISPTREE *tree, INTSML type, void *value);
+static LISPTREE  *sdfi_alloclisptree(void);
+static void       sdfi_killptree(LISPTREE *lt);
+static INTSML     sdfi_pushkeyword(char *pt);
+static LISPTREE  *sdfi_readfile(FILE *fp);
+static INTSML     sdfi_parsetree(LISPTREE *lt);
+static INTSML     sdfi_parsedelayfile(LISPTREE *lt);
+static INTSML     sdfi_parsecell(LISPTREE *lt);
+static INTSML     sdfi_parsedelay(LISPTREE *lt, NODEINST *ni);
+static INTSML     sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni);
+static INTSML     sdfi_parseincrement(LISPTREE *lt, NODEINST *ni);
+static INTSML     sdfi_parseport(LISPTREE *lt, NODEINST *ni);
+static INTSML     sdfi_parseiopath(LISPTREE *lt, NODEINST *ni);
+static INTSML     sdfi_parsetimescale(LISPTREE *lt);
+static NODEINST  *sdfi_getcellinstance(char *celltype, char *instance);
+static char      *sdfi_converttops(char *tstring);
+static void       sdfi_setstring(char **string, char *value);
+static void       sdfi_clearglobals(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -242,9 +242,9 @@ LISPTREE *sdfi_readfile(FILE *f)
 	LISPTREE *treetop;
 
 	/* make the tree top */
-	treetop = (LISPTREE *)emalloc((sizeof (LISPTREE)), io_aid->cluster);
+	treetop = (LISPTREE *)emalloc((sizeof (LISPTREE)), io_tool->cluster);
 	if (treetop == 0) return(0);
-	if (allocstring(&treetop->keyword, "TOP", io_aid->cluster) != 0) return(0);
+	if (allocstring(&treetop->keyword, "TOP", io_tool->cluster) != 0) return(0);
 	treetop->paramtotal = 0;
 	treetop->parameters = 0;
 
@@ -351,7 +351,7 @@ INTSML sdfi_pushkeyword(char *keyword)
 		/* add keyword */
 		pt = &keyword[1];
 		while (*pt == ' ' && *pt == '\t') pt++;
-		if (allocstring(&newtree->keyword, pt, io_aid->cluster) != 0) return(1);
+		if (allocstring(&newtree->keyword, pt, io_tool->cluster) != 0) return(1);
 
 		/* push tree onto stack */
 		sdfi_treestack[sdfi_treedepth] = sdfi_treepos;
@@ -379,7 +379,7 @@ INTSML sdfi_pushkeyword(char *keyword)
 		keyword++;
 		keyword[strlen(keyword)-1] = 0;
 	}
-	if (allocstring(&savekey, keyword, io_aid->cluster) != 0) return(1);
+	if (allocstring(&savekey, keyword, io_tool->cluster) != 0) return(1);
 	if (sdfi_addparameter(sdfi_treepos, PARAMATOM, savekey) != 0) return(1);
 	return(0);
 }
@@ -402,9 +402,9 @@ INTSML sdfi_addparameter(LISPTREE *tree, INTSML type, void *value)
 			/* intelligent determination of parameter needs */
 			newlimit = 3;
 		}
-		newparamtypes = (INTSML *)emalloc(newlimit * SIZEOFINTSML, io_aid->cluster);
+		newparamtypes = (INTSML *)emalloc(newlimit * SIZEOFINTSML, io_tool->cluster);
 		if (newparamtypes == 0) return(1);
-		newparamvalues = (void **)emalloc(newlimit * (sizeof (void *)), io_aid->cluster);
+		newparamvalues = (void **)emalloc(newlimit * (sizeof (void *)), io_tool->cluster);
 		if (newparamvalues == 0) return(1);
 		for(i=0; i<tree->parameters; i++)
 		{
@@ -437,7 +437,7 @@ LISPTREE *sdfi_alloclisptree(void)
 		sdfi_freelisptree = (LISPTREE *)lt->paramvalue;
 	} else
 	{
-		lt = (LISPTREE *)emalloc(sizeof (LISPTREE), io_aid->cluster);
+		lt = (LISPTREE *)emalloc(sizeof (LISPTREE), io_tool->cluster);
 		if (lt == 0) return(0);
 	}
 	return(lt);
@@ -768,7 +768,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 			/* store SDF instance name on node */
 			if (ni != NONODEINST)
 			{
-				sa = newstringarray(io_aid->cluster);
+				sa = newstringarray(io_tool->cluster);
 				if (sa == 0) return(1);
 				(void)initinfstr();
 				(void)addstringtoinfstr(sdfi_instance);
@@ -986,7 +986,7 @@ INTSML sdfi_parseport(LISPTREE *lt, NODEINST *ni)
 		}
 	}
 
-	sa = newstringarray(io_aid->cluster);
+	sa = newstringarray(io_tool->cluster);
 	if (sa == 0) return(1);
 
 	/* create string of transition delay values */
@@ -1135,7 +1135,7 @@ INTSML sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
 		}
 	}
 
-	sa = newstringarray(io_aid->cluster);
+	sa = newstringarray(io_tool->cluster);
 	if (sa == 0) return(1);
 
 	/* create string of transition delay values */
@@ -1191,7 +1191,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	/* at top level of hierarchy */
 	if (strstr(instance, sdfi_divider) == NULL)
 	{
-		for (ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 			if (var != NOVARIABLE)
@@ -1221,18 +1221,18 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	if (namesame(sdfi_divider, "/") == 0) for (pt = tmp; *pt != 0; pt++) if (*pt == '/') count++;
 
 	/* separate out each hiearchy level */
-	instlist = (char **)emalloc(count * (sizeof(char *)), io_aid->cluster);
+	instlist = (char **)emalloc(count * (sizeof(char *)), io_tool->cluster);
 	pt = instance;
 	for (i=0; i<count; i++)
 	{
 		str = getkeyword(&pt, sdfi_divider);
-		if (allocstring(&instlist[i], str, io_aid->cluster) != 0) return(NONODEINST);
+		if (allocstring(&instlist[i], str, io_tool->cluster) != 0) return(NONODEINST);
 		(void)tonextchar(&pt);
 	}
 
 	/* find the NODEINST corresponding to bottom level of hierarchy */
 	i = 0;
-	for (ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 		if (var != NOVARIABLE)
@@ -1318,8 +1318,8 @@ char *sdfi_converttops(char *tstring)
 void sdfi_setstring(char **string, char *value)
 {
 	if (*string == 0)
-		(void)allocstring(string, value, io_aid->cluster); else
-			(void)reallocstring(string, value, io_aid->cluster);
+		(void)allocstring(string, value, io_tool->cluster); else
+			(void)reallocstring(string, value, io_tool->cluster);
 }
 
 void sdfi_clearglobals(void)
