@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iosuei.c
- * Input/output aid: SUE (Schematic User Environment) reader
+ * Input/output tool: SUE (Schematic User Environment) reader
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -161,43 +161,44 @@ SUENET *io_suefreenet = NOSUENET;
 #define MAXKEYWORDS    50			/* maximum keywords on an input line */
 #define MAXICONPOINTS  25			/* maximum coordinates on an "icon_line" line */
 
-INTBIG io_suelineno;
-INTBIG io_suefilesize;
-char   io_suelastline[MAXLINE];
-char   io_sueorigline[MAXLINE];
-char   io_suecurline[MAXLINE];
-char **io_suedirectories;
-INTBIG io_suenumdirectories = 0;
-FILE  *io_suefilein;
+static INTBIG io_suelineno;
+static INTBIG io_suefilesize;
+static char   io_suelastline[MAXLINE];
+static char   io_sueorigline[MAXLINE];
+static char   io_suecurline[MAXLINE];
+static char **io_suedirectories;
+       INTBIG io_suenumdirectories = 0;
+static FILE  *io_suefilein;
 
-INTSML     io_sueadddirectory(char *directory);
-INTBIG     io_suearraylength(char *name);
-void       io_suecleardirectories(void);
-NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count);
-char      *io_sueexpandname(char *portname, INTBIG count, INTBIG which);
-char      *io_suefindbusname(ARCINST *ai);
-INTSML     io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy, NODEPROTO *np,
-			NODEINST **ni, PORTPROTO **pp, NODEINST *notthisnode, INTBIG lambda);
-NODEINST  *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp);
-void       io_suefreenets(SUENET *firstsn);
-void       io_suefreewires(SUEWIRE *firstsw);
-INTSML     io_suegetnextline(char **keywords, INTSML curlydepth);
-NODEPROTO *io_suegetnodeproto(LIBRARY *lib, char *protoname);
-void       io_suekillnet(SUENET *sn);
-void       io_suekillwire(SUEWIRE *sw);
-INTBIG     io_suemakex(INTBIG x, INTBIG lambda);
-INTBIG     io_suemakey(INTBIG y, INTBIG lambda);
-PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
-SUENET    *io_suenewnet(void);
-SUEWIRE   *io_suenewwire(void);
-void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet);
-void       io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
-			INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext);
-void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda);
-NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname);
-NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name);
-char      *io_suesearchbusname(ARCINST *ai);
-PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy);
+/* prototypes for local routines */
+static INTSML     io_sueadddirectory(char *directory);
+static INTBIG     io_suearraylength(char *name);
+static void       io_suecleardirectories(void);
+static NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count);
+static char      *io_sueexpandname(char *portname, INTBIG count, INTBIG which);
+static char      *io_suefindbusname(ARCINST *ai);
+static INTSML     io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy, NODEPROTO *np,
+					NODEINST **ni, PORTPROTO **pp, NODEINST *notthisnode, INTBIG lambda);
+static NODEINST  *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp);
+static void       io_suefreenets(SUENET *firstsn);
+static void       io_suefreewires(SUEWIRE *firstsw);
+static INTSML     io_suegetnextline(char **keywords, INTSML curlydepth);
+static NODEPROTO *io_suegetnodeproto(LIBRARY *lib, char *protoname);
+static void       io_suekillnet(SUENET *sn);
+static void       io_suekillwire(SUEWIRE *sw);
+static INTBIG     io_suemakex(INTBIG x, INTBIG lambda);
+static INTBIG     io_suemakey(INTBIG y, INTBIG lambda);
+static PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
+static SUENET    *io_suenewnet(void);
+static SUEWIRE   *io_suenewwire(void);
+static void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet);
+static void       io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
+					INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext);
+static void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda);
+static NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname);
+static NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name);
+static char      *io_suesearchbusname(ARCINST *ai);
+static PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy);
 
 /*
  * Routine to free all memory associated with this module.
@@ -311,6 +312,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 	topfacet = io_suereadfile(lib, facetname);
 	if (topfacet != NONODEPROTO)
 		lib->curnodeproto = topfacet;
+	(void)asktool(net_tool, "total-re-number");
 
 	/* clean up */
 	DiaDoneDialog();
@@ -332,7 +334,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		numargs, namestrlen;
 	REGISTER INTBIG count, i, lx, hx, ly, hy, curly, xshrink, yshrink,
 		varcount, varindex, varoffset, pos, invertoutput, lambda, detailbits,
-		keycount, cx, cy, p1x, p1y, p2x, p2y, start, extent, numextrawires, len;
+		keycount, cx, cy, p1x, p1y, p2x, p2y, start, extent, numextrawires, len,
+		iconx, icony, placeicon, newaddr, newtype, varissize;
 	INTSML rot, trn, rotation;
 	XARRAY trans;
 	double rextent, rstart;
@@ -391,6 +394,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 						(void)addstringtoinfstr(&keywords[1][10]);
 				(void)addstringtoinfstr("{sch}");
 				schemfacet = facet = newnodeproto(returninfstr(), lib);
+				placeicon = 0;
 			} else if (namesamen(keywords[1], "ICON_", 5) == 0)
 			{
 				/* create the icon facet */
@@ -428,6 +432,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				len = strlen(thename) + 1;
 				if (len > namestrlen)
 				{
+					/* LINTED "namestring" used in proper order */
 					if (namestrlen > 0) efree(namestring);
 					namestring = (char *)emalloc(len, el_tempcluster);
 					namestrlen = len;
@@ -441,7 +446,9 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			{
 				if (x != 0 || y != 0)
 				{
-					/* place facet-center? */
+					/* queue icon placement */
+					iconx = x;   icony = y;
+					placeicon = 1;
 				}
 				continue;
 			}
@@ -454,7 +461,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				sn = io_suenewnet();
 				sn->x = x;
 				sn->y = y;
-				(void)allocstring(&sn->label, thename, io_aid->cluster);
+				(void)allocstring(&sn->label, thename, io_tool->cluster);
 				sn->nextsuenet = firstsuenet;
 				firstsuenet = sn;
 				continue;
@@ -469,6 +476,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			detailbits = 0;
 			numextrawires = 0;
 			extrawires = 0;
+			type = 0;
 			if (namesame(keywords[1], "inout") == 0)
 			{
 				proto = sch_offpageprim;
@@ -476,6 +484,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				xform(K2, 0, &xoff, &yoff, trans);
 				xoff = muldiv(xoff, lambda, WHOLE);
 				yoff = muldiv(yoff, lambda, WHOLE);
+				type = BIDIRPORT;
 			} else if (namesame(keywords[1], "input") == 0)
 			{
 				proto = sch_offpageprim;
@@ -483,6 +492,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				xform(-K2, 0, &xoff, &yoff, trans);
 				xoff = muldiv(xoff, lambda, WHOLE);
 				yoff = muldiv(yoff, lambda, WHOLE);
+				type = INPORT;
 			} else if (namesame(keywords[1], "output") == 0)
 			{
 				proto = sch_offpageprim;
@@ -490,6 +500,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				xform(K2, 0, &xoff, &yoff, trans);
 				xoff = muldiv(xoff, lambda, WHOLE);
 				yoff = muldiv(yoff, lambda, WHOLE);
+				type = OUTPORT;
 			} else if (namesame(keywords[1], "rename_net") == 0)
 			{
 				proto = sch_wirepinprim;
@@ -505,9 +516,13 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 						xoff = muldiv(xoff, lambda, WHOLE);
 						yoff = muldiv(yoff, lambda, WHOLE);
 						proto = sch_gndprim;
+						type = GNDPORT;
 					}
 					if (namesame(thename, "vdd") == 0)
+					{
 						proto = sch_pwrprim;
+						type = PWRPORT;
+					}
 				}
 			} else if (namesame(keywords[1], "join_net") == 0)
 			{
@@ -668,10 +683,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 							facetname, io_suelineno, thename);
 					} else
 					{
+						defaulttextdescript(ppt->textdescript, NOGEOM);
+						defaulttextsize(1, ppt->textdescript);
+						ppt->userbits = (ppt->userbits & ~STATEBITS) | type;
 						endobjectchange((INTBIG)ppt, VPORTPROTO);
-						ppt->textdescript = defaulttextdescript(NOGEOM);
-						ppt->textdescript = (ppt->textdescript & ~VTSIZE) |
-							(defaulttextsize(1) << VTSIZESH);
 					}
 				} else
 				{
@@ -679,8 +694,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)thename,
 						VSTRING|VDISPLAY);
 					if (var != NOVARIABLE)
-						var->textdescript = (var->textdescript & ~VTSIZE) |
-							(defaulttextsize(3) << VTSIZESH);
+						defaulttextsize(3, var->textdescript);
 				}
 			}
 
@@ -705,34 +719,51 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					namesame(keywords[i], "-orient") == 0 ||
 					namesame(keywords[i], "-type") == 0 ||
 					namesame(keywords[i], "-name") == 0) continue;
-				sprintf(suevarname, "SUE_%s", &keywords[i][1]);
-				for(pt = suevarname; *pt != 0; pt++) if (*pt == ' ')
+				varissize = 0;
+				if (namesame(&keywords[i][1], "w") == 0)
 				{
-					ttyputmsg(_("Facet %s, line %d, bad variable name (%s)"), 
-						facetname, io_suelineno, suevarname);
-					break;
-				}
-				(void)initinfstr();
-				if (keywords[i][1] == 'W' && keywords[i][2] != 0)
+					strcpy(suevarname, "ATTR_width");
+					varissize = 1;
+				} else if (namesame(&keywords[i][1], "l") == 0)
 				{
-					(void)addstringtoinfstr(&keywords[i][2]);
-					(void)addstringtoinfstr(":");
+					strcpy(suevarname, "ATTR_length");
+					varissize = 1;
+				} else
+				{
+					sprintf(suevarname, "SUE_%s", &keywords[i][1]);
+					for(pt = suevarname; *pt != 0; pt++) if (*pt == ' ')
+					{
+						ttyputmsg(_("Facet %s, line %d, bad variable name (%s)"), 
+							facetname, io_suelineno, suevarname);
+						break;
+					}
 				}
-				(void)addstringtoinfstr(keywords[i+1]);
-				var = setval((INTBIG)ni, VNODEINST, suevarname, (INTBIG)returninfstr(),
-					VSTRING|VDISPLAY);
+				newtype = VSTRING;
+				if (varissize != 0)
+				{
+					newaddr = atola(keywords[i+1]) * WHOLE / lib->lambda[el_curtech->techindex];
+					if (newaddr != 0) newtype = VFRACT; else
+						newaddr = (INTBIG)keywords[i+1];
+				} else
+				{
+					(void)initinfstr();
+					if (keywords[i][1] == 'W' && keywords[i][2] != 0)
+					{
+						(void)addstringtoinfstr(&keywords[i][2]);
+						(void)addstringtoinfstr(":");
+					}
+					(void)addstringtoinfstr(keywords[i+1]);
+					newaddr = (INTBIG)returninfstr();
+				}
+				var = setval((INTBIG)ni, VNODEINST, suevarname, newaddr,
+					newtype|VDISPLAY);
 				if (var != NOVARIABLE)
 				{
-					var->textdescript = defaulttextdescript(ni->geom);
+					defaulttextdescript(var->textdescript, ni->geom);
 					varoffset = (ni->highy - ni->lowy) / (varcount+1);
 					pos = (ni->highy - ni->lowy) / 2 - varindex * varoffset;
 					varindex++;
-					if (pos < 0)
-					{
-						pos = -pos;
-						var->textdescript |= VTYOFFNEG;
-					}
-					var->textdescript |= (pos * 4 / lambda) << VTYOFFSH;
+					TDSETOFF(var->textdescript, TDGETXOFF(var->textdescript), pos * 4 / lambda);
 				}
 			}
 			continue;
@@ -774,9 +805,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					facetname, io_suelineno, suevarname);
 			} else
 			{
-				ppt->textdescript = defaulttextdescript(NOGEOM);
-				ppt->textdescript = (ppt->textdescript & ~VTSIZE) |
-					(defaulttextsize(1) << VTSIZESH);
+				defaulttextdescript(ppt->textdescript, NOGEOM);
+				defaulttextsize(1, ppt->textdescript);
 				ppt->userbits = (ppt->userbits & ~STATEBITS) | type;
 				endobjectchange((INTBIG)ppt, VPORTPROTO);
 			}
@@ -892,7 +922,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				newargvalues = (char **)emalloc(i * (sizeof (char *)), el_tempcluster);
 				for(i=0; i<numargs; i++)
 				{
+					/* LINTED "argnames" used in proper order */
 					newargnames[i] = argnames[i];
+
+					/* LINTED "argvalues" used in proper order */
 					newargvalues[i] = argvalues[i];
 				}
 				if (numargs > 0)
@@ -949,7 +982,11 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, facet);
 			if (ni == NONODEINST) continue;
 			var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)thelabel, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = (defaulttextsize(2) << VTSIZESH) | VTPOSCENT;
+			if (var != NOVARIABLE)
+			{
+				defaulttextsize(2, var->textdescript);
+				TDSETPOS(var->textdescript, VTPOSCENT);
+			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
@@ -965,7 +1002,11 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, facet);
 			if (ni == NONODEINST) continue;
 			var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)thetext, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = (defaulttextsize(2) << VTSIZESH) | VTPOSCENT;
+			if (var != NOVARIABLE)
+			{
+				defaulttextsize(2, var->textdescript);
+				TDSETPOS(var->textdescript, VTPOSCENT);
+			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
@@ -981,6 +1022,21 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		ttyputerr(_("Facet %s, line %d: unknown keyword (%s): %s"), facetname,
 			io_suelineno, keywords[0], io_sueorigline);
 	}
+	/* place an icon instance in the schematic if requested */
+	if (placeicon != 0 && schemfacet != NONODEPROTO &&
+		iconfacet != NONODEPROTO)
+	{
+		px = iconfacet->highx - iconfacet->lowx;
+		py = iconfacet->highy - iconfacet->lowy;
+		lx = iconx - px/2;   hx = lx + px;
+		ly = icony - py/2;   hy = ly + py;
+		ni = newnodeinst(iconfacet, lx, hx, ly, hy, 0, 0, schemfacet);
+		if (ni != NONODEINST)
+		{
+			ni->userbits |= NEXPAND;
+			endobjectchange((INTBIG)ni, VNODEINST);
+		}
+	}
 
 	for(i=0; i<numargs; i++)
 	{
@@ -1146,7 +1202,7 @@ PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *
 		(void)initinfstr();
 		for(pt = thename; *pt != 0 && *pt != '['; pt++)
 			(void)addtoinfstr(*pt);
-		sprintf(numbuf, "-%d", i);
+		sprintf(numbuf, "-%ld", i);
 		(void)addstringtoinfstr(numbuf);
 		for( ; *pt != 0; pt++)
 			(void)addtoinfstr(*pt);
@@ -1217,6 +1273,8 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 				cx = (ai->end[0].xpos + ai->end[1].xpos) / 2;
 				cy = (ai->end[0].ypos + ai->end[1].ypos) / 2;
 				dist = computedistance(cx, cy, sn->x, sn->y);
+
+				/* LINTED "bestdist" used in proper order */
 				if (bestai == NOARCINST || dist < bestdist)
 				{
 					bestai = ai;
@@ -1610,7 +1668,7 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 {
 	REGISTER NODEPROTO *iconnp, *contentsnp, *newnp, *type, *pinproto;
 	REGISTER NODEINST *ni, *newni, *end0, *end1, *pinni;
-	REGISTER PORTPROTO *port0, *port1, *pp, *newpp;
+	REGISTER PORTPROTO *port0, *port1, *pp;
 	REGISTER ARCPROTO *conproto;
 	REGISTER ARCINST *ai, *newai;
 	REGISTER VARIABLE *var;
@@ -1690,18 +1748,17 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 				(INTBIG)expandedname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 			{
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(4) << VTSIZESH);
+				defaulttextsize(4, var->textdescript);
 				switch (side)
 				{
 					case 0:		/* left side */
-						var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSUPLEFT;   break;
+						TDSETPOS(var->textdescript, VTPOSUPLEFT);   break;
 					case 1:		/* right side */
-						var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSUPRIGHT;  break;
+						TDSETPOS(var->textdescript, VTPOSUPRIGHT);  break;
 					case 2:		/* bottom side */
-						var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSRIGHT;    break;
+						TDSETPOS(var->textdescript, VTPOSRIGHT);    break;
 					case 3:		/* top side */
-						var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSRIGHT;    break;
+						TDSETPOS(var->textdescript, VTPOSRIGHT);    break;
 				}
 			}
 			endobjectchange((INTBIG)newai, VARCINST);
@@ -1751,7 +1808,7 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 		ly = oy - pinsizey/2;   hy = ly + pinsizey;
 		newni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, newnp);
 		if (newni == NONODEINST) continue;
-		newpp = newportproto(newnp, newni, sch_buspinprim->firstportproto, expandedname);
+		(void)newportproto(newnp, newni, sch_buspinprim->firstportproto, expandedname);
 		endobjectchange((INTBIG)newni, VNODEINST);
 		newai = newarcinst(sch_busarc, sch_busarc->nominalwidth, us_makearcuserbits(sch_busarc),
 			pinni, sch_buspinprim->firstportproto, x, y, newni, sch_buspinprim->firstportproto, ox, oy, newnp);
@@ -1801,7 +1858,7 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 		if (end0->proto == pp->subnodeinst->proto) port0 = pp->subportproto; else
 			port0 = sch_buspinprim->firstportproto;
 		expandedname = io_sueexpandname(pp->protoname, count, -1);
-		newpp = newportproto(newnp, end0, port0, expandedname);
+		(void)newportproto(newnp, end0, port0, expandedname);
 	}
 	return(newnp);
 }
@@ -1905,7 +1962,7 @@ PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG
 	static POLYGON *poly = NOPOLYGON;
 
 	/* make sure there is a polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		shapeportpoly(ni, pp, poly, 0);
@@ -2024,7 +2081,7 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			/* make sure there is a polygon */
-			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 			/* get the polygon describing the port */
 			shapeportpoly(ni, pp, poly, 0);
@@ -2051,6 +2108,8 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 			}
 
 			dist = computedistance(ox, oy, thisx, thisy);
+
+			/* LINTED "bestdist" used in proper order */
 			if (bestpp == NOPORTPROTO || dist < bestdist)
 			{
 				bestpp = pp;
@@ -2195,11 +2254,11 @@ INTSML io_sueadddirectory(char *directory)
 	char **newdir;
 
 	newnumdir = io_suenumdirectories + 1;
-	newdir = (char **)emalloc(newnumdir * (sizeof (char *)), io_aid->cluster);
+	newdir = (char **)emalloc(newnumdir * (sizeof (char *)), io_tool->cluster);
 	if (newdir == 0) return(1);
 	for(i=0; i<io_suenumdirectories; i++)
 		newdir[i] = io_suedirectories[i];
-	newdir[io_suenumdirectories] = (char *)emalloc(strlen(directory)+1, io_aid->cluster);
+	newdir[io_suenumdirectories] = (char *)emalloc(strlen(directory)+1, io_tool->cluster);
 	if (newdir[io_suenumdirectories] == 0) return(1);
 	strcpy(newdir[io_suenumdirectories], directory);
 	if (io_suenumdirectories > 0) efree((char *)io_suedirectories);
@@ -2230,7 +2289,7 @@ SUEWIRE *io_suenewwire(void)
 		io_suefreewire = sw->nextsuewire;
 	} else
 	{
-		sw = (SUEWIRE *)emalloc(sizeof(SUEWIRE), io_aid->cluster);
+		sw = (SUEWIRE *)emalloc(sizeof(SUEWIRE), io_tool->cluster);
 	}
 	return(sw);
 }
@@ -2262,7 +2321,7 @@ SUENET *io_suenewnet(void)
 		io_suefreenet = sn->nextsuenet;
 	} else
 	{
-		sn = (SUENET *)emalloc(sizeof(SUENET), io_aid->cluster);
+		sn = (SUENET *)emalloc(sizeof(SUENET), io_tool->cluster);
 	}
 	sn->label = 0;
 	return(sn);
