@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iotexti.c
- * Input/output aid: textual format input
+ * Input/output tool: textual format input
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -32,6 +32,7 @@
 #include "database.h"
 #include "eio.h"
 #include "tecgen.h"
+#include "tecart.h"
 #include "tecschem.h"
 #include "tecmocmos.h"
 #include "tecmocmossub.h"
@@ -49,7 +50,7 @@
 #define INARCEND    7
 
 /* state of variable reading (value of "io_txtindata.varpos") */
-#define INVAID         1
+#define INVTOOL        1
 #define INVTECHNOLOGY  2
 #define INVLIBRARY     3
 #define INVNODEPROTO   4
@@ -106,87 +107,87 @@ static INTBIG io_maxinputline = 0;
 static char *io_keyword;
 
 /* prototypes for local routines */
-void io_newlib(void);
-INTSML io_getkeyword(void);
-INTSML io_grabbuffers(INTBIG);
-PORTPROTO *io_getport(char*, NODEPROTO*);
-void io_null(void);
-void io_newlib(void);
-void io_versn(void);
-void io_libkno(void);
-void io_libain(void);
-void io_libaib(void);
-void io_libbit(void);
-void io_libusb(void);
-void io_libte(void);
-void io_libten(void);
-void io_lambda(void);
-void io_getvar(void);
-INTBIG io_decode(char*, INTBIG);
-void io_libcc(void);
-void io_libms(void);
-void io_libvie(void);
-void io_newcel(void);
-void io_celnam(void);
-void io_celver(void);
-void io_celcre(void);
-void io_celrev(void);
-void io_celext(void);
-void io_cellx(void);
-void io_celhx(void);
-void io_celly(void);
-void io_celhy(void);
-void io_tech(void);
-void io_celaad(void);
-void io_celbit(void);
-void io_celusb(void);
-void io_celnet(void);
-void io_celnoc(void);
-void io_celarc(void);
-void io_celptc(void);
-void io_celdon(void);
-void io_newno(void);
-void io_nodtyp(void);
-void io_nodlx(void);
-void io_nodhx(void);
-void io_nodly(void);
-void io_nodhy(void);
-void io_nodnam(void);
-void io_noddes(void);
-void io_nodrot(void);
-void io_nodtra(void);
-void io_nodkse(void);
-void io_nodpoc(void);
-void io_nodbit(void);
-void io_nodusb(void);
-void io_newpor(void);
-void io_porarc(void);
-void io_porexp(void);
-void io_newar(void);
-void io_arctyp(void);
-void io_arcnam(void);
-void io_arcwid(void);
-void io_arclen(void);
-void io_arcsig(void);
-void io_newend(void);
-void io_endnod(void);
-void io_endpt(void);
-void io_endxp(void);
-void io_endyp(void);
-void io_arckse(void);
-void io_arcbit(void);
-void io_arcusb(void);
-void io_arcnet(void);
-void io_newpt(void);
-void io_ptnam(void);
-void io_ptdes(void);
-void io_ptsno(void);
-void io_ptspt(void);
-void io_ptkse(void);
-void io_ptbit(void);
-void io_ptusb(void);
-void io_ptnet(void);
-TECHNOLOGY *io_gettechnology(char*);
+static void io_newlib(void);
+static INTSML io_getkeyword(void);
+static INTSML io_grabbuffers(INTBIG);
+static PORTPROTO *io_getport(char*, NODEPROTO*);
+static void io_null(void);
+static void io_newlib(void);
+static void io_versn(void);
+static void io_libkno(void);
+static void io_libain(void);
+static void io_libaib(void);
+static void io_libbit(void);
+static void io_libusb(void);
+static void io_libte(void);
+static void io_libten(void);
+static void io_lambda(void);
+static void io_getvar(void);
+static INTBIG io_decode(char*, INTBIG);
+static void io_libcc(void);
+static void io_libms(void);
+static void io_libvie(void);
+static void io_newcel(void);
+static void io_celnam(void);
+static void io_celver(void);
+static void io_celcre(void);
+static void io_celrev(void);
+static void io_celext(void);
+static void io_cellx(void);
+static void io_celhx(void);
+static void io_celly(void);
+static void io_celhy(void);
+static void io_tech(void);
+static void io_celaad(void);
+static void io_celbit(void);
+static void io_celusb(void);
+static void io_celnet(void);
+static void io_celnoc(void);
+static void io_celarc(void);
+static void io_celptc(void);
+static void io_celdon(void);
+static void io_newno(void);
+static void io_nodtyp(void);
+static void io_nodlx(void);
+static void io_nodhx(void);
+static void io_nodly(void);
+static void io_nodhy(void);
+static void io_nodnam(void);
+static void io_noddes(void);
+static void io_nodrot(void);
+static void io_nodtra(void);
+static void io_nodkse(void);
+static void io_nodpoc(void);
+static void io_nodbit(void);
+static void io_nodusb(void);
+static void io_newpor(void);
+static void io_porarc(void);
+static void io_porexp(void);
+static void io_newar(void);
+static void io_arctyp(void);
+static void io_arcnam(void);
+static void io_arcwid(void);
+static void io_arclen(void);
+static void io_arcsig(void);
+static void io_newend(void);
+static void io_endnod(void);
+static void io_endpt(void);
+static void io_endxp(void);
+static void io_endyp(void);
+static void io_arckse(void);
+static void io_arcbit(void);
+static void io_arcusb(void);
+static void io_arcnet(void);
+static void io_newpt(void);
+static void io_ptnam(void);
+static void io_ptdes(void);
+static void io_ptsno(void);
+static void io_ptspt(void);
+static void io_ptkse(void);
+static void io_ptbit(void);
+static void io_ptusb(void);
+static void io_ptnet(void);
+static TECHNOLOGY *io_gettechnology(char*);
 
 struct keyroutine
 {
@@ -195,7 +196,7 @@ struct keyroutine
 };
 
 /* possible keywords while reading libraries */
-struct keyroutine io_libraryroutines[] =
+static struct keyroutine io_libraryroutines[] =
 {
 	{"****library",     io_newlib},
 	{"bits",            io_libbit},
@@ -216,7 +217,7 @@ struct keyroutine io_libraryroutines[] =
 };
 
 /* possible keywords while reading facets */
-struct keyroutine io_facetroutines[] =
+static struct keyroutine io_facetroutines[] =
 {
 	{"bits",            io_celbit},
 	{"userbits",        io_celusb},
@@ -244,7 +245,7 @@ struct keyroutine io_facetroutines[] =
 };
 
 /* possible keywords while reading ports */
-struct keyroutine io_portroutines[] =
+static struct keyroutine io_portroutines[] =
 {
 	{"bits",            io_ptbit},
 	{"userbits",        io_ptusb},
@@ -265,7 +266,7 @@ struct keyroutine io_portroutines[] =
 };
 
 /* possible keywords while reading nodes */
-struct keyroutine io_noderoutines[] =
+static struct keyroutine io_noderoutines[] =
 {
 	{"bits",            io_nodbit},
 	{"userbits",        io_nodusb},
@@ -292,7 +293,7 @@ struct keyroutine io_noderoutines[] =
 };
 
 /* possible keywords while reading portinsts */
-struct keyroutine io_portinstroutines[] =
+static struct keyroutine io_portinstroutines[] =
 {
 	{"arc",             io_porarc},
 	{"exported",        io_porexp},
@@ -307,7 +308,7 @@ struct keyroutine io_portinstroutines[] =
 };
 
 /* possible keywords while reading arcs */
-struct keyroutine io_arcroutines[] =
+static struct keyroutine io_arcroutines[] =
 {
 	{"bits",            io_arcbit},
 	{"userbits",        io_arcusb},
@@ -328,7 +329,7 @@ struct keyroutine io_arcroutines[] =
 };
 
 /* possible keywords while reading arc ends */
-struct keyroutine io_arcendroutines[] =
+static struct keyroutine io_arcendroutines[] =
 {
 	{"node",            io_endnod},
 	{"nodeport",        io_endpt},
@@ -352,11 +353,10 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 {
 	struct keyroutine *table;
 	REGISTER char *pp;
-	REGISTER INTBIG i, j, version, total, clustersize, largestcluster, assoc,
-		reportcount, lambda;
+	REGISTER INTBIG i, j, reportcount, lambda;
 	INTBIG num, den;
 	REGISTER INTBIG oldunit;
-	REGISTER NODEPROTO *np, **list, *onp;
+	REGISTER NODEPROTO *np;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -376,6 +376,10 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 		return(1);
 	}
 
+	/* update the library file name if the true location is different */
+	if (strcmp(filename, lib->libfile) != 0)
+		(void)reallocstring(&lib->libfile, filename, lib->cluster);
+
 	reportcount = io_txtindata.fileposition = 0;
 	if (io_verbose < 0)
 	{
@@ -476,7 +480,6 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	}
 
 	/* set the former version number on the library */
-	version = atoi(io_txtindata.version);
 	nextchangequiet();
 	(void)setvalkey((INTBIG)io_txtindata.curlib, VLIBRARY, makekey("LIB_former_version"),
 		(INTBIG)io_txtindata.version, VSTRING|VDONTSAVE);
@@ -515,70 +518,6 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 			longjmp(io_filerror, (INTBIG)_("No cluster memory"));
 	}
 
-	/* handle recent libraries version 4 or later */
-	if (version >= 4)
-	{
-		/* coalesce similar cell names */
-		for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			np->temp1 = 0;
-
-		/* associate cell names that are the same */
-		assoc = 1;
-		largestcluster = 0;
-		for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-		{
-			if (np->temp1 != 0) continue;
-			np->temp1 = assoc;
-			clustersize = 1;
-			for(onp = np->nextnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
-				if (namesame(onp->cell->cellname, np->cell->cellname) == 0)
-			{
-				onp->temp1 = assoc;
-				clustersize++;
-			}
-			if (clustersize > largestcluster) largestcluster = clustersize;
-			assoc++;
-		}
-
-		/* get memory for groups of cells */
-		list = (NODEPROTO **)emalloc(((sizeof (NODEPROTO *)) * largestcluster), el_tempcluster);
-		if (list == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
-
-		/* combine names that are the same */
-		for(i=1; i<assoc; i++)
-		{
-			/* see how many have this name */
-			total = 0;
-			for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-				if (np->temp1 == i) list[total++] = np;
-			if (total <= 1) continue;
-
-			/* move all but the first */
-			for(j=1; j<total; j++)
-			{
-				np = list[j];
-
-				/* remove the facet from the cell list */
-				db_retractnodeproto(np);
-
-				/* delete the cell */
-				if (np->cell->firstincell == NONODEPROTO)
-				{
-					efree(np->cell->cellname);
-					freecell(np->cell);
-				} else ttyputmsg(_("Facet %s did not stand alone!"), np->cell->cellname);
-
-				/* set the cell pointer correctly */
-				np->cell = list[0]->cell;
-
-				/* insert the facet into the new cell list */
-				db_insertnodeproto(np);
-			}
-		}
-
-		efree((char *)list);
-	}
-
 	/* warn if the MOSIS CMOS technologies were converted */
 	if (io_txtindata.convertmosiscmostechnologies != 0)
 	{
@@ -616,7 +555,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	if (io_txtindata.rtnodeerror != 0)
 		ttyputmsg(_("Warning: %ld RTNODE pointers not restored"), io_txtindata.rtnodeerror);
 	if (io_txtindata.libraryerror != 0)
-		ttyputmsg(_("Warning: LIBRARY pointers not restored"), io_txtindata.libraryerror);
+		ttyputmsg(_("Warning: %ld LIBRARY pointers not restored"), io_txtindata.libraryerror);
 
 	if (io_txtindata.mainfacet != -1 && io_txtindata.mainfacet < io_txtindata.facetcount)
 		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.mainfacet]; else
@@ -630,7 +569,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 
 INTSML io_getkeyword(void)
 {
-	REGISTER INTSML c, cindex, inquote;
+	REGISTER INTBIG c, cindex, inquote;
 
 	/* skip leading blanks */
 	for(;;)
@@ -688,7 +627,7 @@ INTSML io_grabbuffers(INTBIG size)
 	REGISTER INTBIG i;
 
 	/* first get the new buffer */
-	p = (char *)emalloc((size+1), io_aid->cluster);
+	p = (char *)emalloc((size+1), io_tool->cluster);
 	if (p == 0)
 	{
 		ttyputnomemory();
@@ -767,7 +706,7 @@ void io_newlib(void)
 	/* set defaults */
 	io_txtindata.mainfacet = -1;
 	(void)allocstring(&io_txtindata.version, "1.00", el_tempcluster);
-	io_txtindata.varpos = INVAID;
+	io_txtindata.varpos = INVTOOL;
 	io_txtindata.curtech = NOTECHNOLOGY;
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		io_txtindata.curlib->lambda[tech->techindex] = 0;
@@ -801,7 +740,7 @@ void io_versn(void)
 }
 
 /*
- * get the number of aids (keyword "aids")
+ * get the number of tools (keyword "aids")
  */
 void io_libkno(void)
 {
@@ -809,19 +748,19 @@ void io_libkno(void)
 }
 
 /*
- * get the name of the aid (keyword "aidname")
+ * get the name of the tool (keyword "aidname")
  */
 void io_libain(void)
 {
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
-	aid = getaid(io_keyword);
-	if (aid == NOAID) io_txtindata.bitcount = -1; else
-		io_txtindata.bitcount = aid->aidindex + 1;
+	tool = gettool(io_keyword);
+	if (tool == NOTOOL) io_txtindata.bitcount = -1; else
+		io_txtindata.bitcount = tool->toolindex + 1;
 }
 
 /*
- * get the number of aidbits (keyword "aidbits")
+ * get the number of toolbits (keyword "aidbits")
  */
 void io_libaib(void)
 {
@@ -829,7 +768,7 @@ void io_libaib(void)
 }
 
 /*
- * get aid information for the library (keyword "bits")
+ * get tool information for the library (keyword "bits")
  */
 void io_libbit(void)
 {
@@ -839,11 +778,14 @@ void io_libbit(void)
 }
 
 /*
- * get the number of aidbits (keyword "userbits")
+ * get the number of toolbits (keyword "userbits")
  */
 void io_libusb(void)
 {
 	io_txtindata.curlib->userbits = atoi(io_keyword);
+
+	/* this library came as readable dump, so don't automatically save it to disk */
+	io_txtindata.curlib->userbits &= ~READFROMDISK;
 }
 
 /*
@@ -888,8 +830,8 @@ void io_lambda(void)
  */
 void io_getvar(void)
 {
-	REGISTER INTBIG i, j, count, type, len, naddr, ntype, *store, key, ret,
-		descript;
+	REGISTER INTBIG i, j, count, type, len, naddr, ntype, *store, key, ret;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER char *pt, *start;
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *t;
@@ -897,10 +839,10 @@ void io_getvar(void)
 	naddr = -1;
 	switch (io_txtindata.varpos)
 	{
-		case INVAID:				/* keyword applies to aids */
+		case INVTOOL:				/* keyword applies to tools */
 			if (io_txtindata.bitcount < 0) break;
-			naddr = (INTBIG)&el_aids[io_txtindata.bitcount-1];
-			ntype = VAID;
+			naddr = (INTBIG)&el_tools[io_txtindata.bitcount-1];
+			ntype = VTOOL;
 			break;
 		case INVTECHNOLOGY:			/* keyword applies to technologies */
 			if (io_txtindata.bitcount < 0) break;
@@ -970,7 +912,14 @@ void io_getvar(void)
 
 		/* get the descriptor */
 		while (*pt != ',' && *pt != ':' && *pt != 0) pt++;
-		if (*pt == ',') descript = myatoi(&pt[1]); else descript = 0;
+		TDCLEAR(descript);
+		if (*pt == ',')
+		{
+			descript[0] = myatoi(&pt[1]);
+			for(pt++; *pt != 0 && *pt != '/' && *pt != ']'; pt++) ;
+			if (*pt == '/')
+				descript[1] = myatoi(pt+1);
+		}
 
 		/* get value */
 		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)_("EOF in variables"));
@@ -1038,7 +987,7 @@ void io_getvar(void)
 				nextchangequiet();
 				var = setvalkey(naddr, ntype, key, (INTBIG)store, type);
 				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)_("No memory"));
-				var->textdescript = descript;
+				TDCOPY(var->textdescript, descript);
 
 				/* handle updating of technology caches */
 				if (ntype == VTECHNOLOGY)
@@ -1053,7 +1002,7 @@ void io_getvar(void)
 				nextchangequiet();
 				var = setvalkey(naddr, ntype, key, ret, type);
 				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)_("No memory"));
-				var->textdescript = descript;
+				TDCOPY(var->textdescript, descript);
 
 				/* handle updating of technology caches */
 				if (ntype == VTECHNOLOGY)
@@ -1149,8 +1098,8 @@ INTBIG io_decode(char *name, INTBIG type)
 			io_txtindata.libraryerror++;   break;
 		case VTECHNOLOGY:
 			return((INTBIG)io_gettechnology(name));
-		case VAID:
-			return((INTBIG)getaid(name));
+		case VTOOL:
+			return((INTBIG)gettool(name));
 		case VRTNODE:
 			io_txtindata.rtnodeerror++;   break;
 	}
@@ -1163,7 +1112,6 @@ INTBIG io_decode(char *name, INTBIG type)
 void io_libcc(void)
 {
 	REGISTER INTBIG i;
-	REGISTER CELL *c;
 
 	io_txtindata.varpos = INVLIBRARY;
 
@@ -1184,48 +1132,16 @@ void io_libcc(void)
 	if (io_txtindata.nodeprotolist == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 	for(i=0; i<io_txtindata.facetcount; i++)
 	{
-		c = alloccell(io_txtindata.curlib->cluster);
-		if (c == NOCELL) longjmp(io_filerror, (INTBIG)_("No memory for facets"));
 		io_txtindata.nodeprotolist[i] = allocnodeproto(io_txtindata.curlib->cluster);
 		if (io_txtindata.nodeprotolist[i] == NONODEPROTO)
 			longjmp(io_filerror, (INTBIG)_("No memory for facets"));
-		io_txtindata.nodeprotolist[i]->cell = c;
-		c->firstincell = io_txtindata.nodeprotolist[i];
-		c->nextcell = NOCELL;
-		if (i > 0) io_txtindata.nodeprotolist[i-1]->cell->nextcell = c;
-		c->lib = io_txtindata.curlib;
 		io_txtindata.nodeprotolist[i]->cellview = el_unknownview;
 		io_txtindata.nodeprotolist[i]->newestversion = io_txtindata.nodeprotolist[i];
 		io_txtindata.nodeprotolist[i]->primindex = 0;
 		io_txtindata.nodeprotolist[i]->firstportproto = NOPORTPROTO;
 		io_txtindata.nodeprotolist[i]->firstnodeinst = NONODEINST;
 		io_txtindata.nodeprotolist[i]->firstarcinst = NOARCINST;
-
-		/* create geometry structure in the facet */
-		if (geomstructure(io_txtindata.nodeprotolist[i]) != 0)
-			longjmp(io_filerror, (INTBIG)_("No memory for geometry structure"));
 	}
-	if (io_txtindata.facetcount == 0)
-	{
-		io_txtindata.curlib->firstcell = NOCELL;
-	} else
-	{
-		io_txtindata.curlib->firstcell = io_txtindata.nodeprotolist[0]->cell;
-		io_txtindata.curlib->tailcell = io_txtindata.nodeprotolist[io_txtindata.facetcount-1]->cell;
-	}
-	io_txtindata.curlib->numcells = io_txtindata.facetcount;
-
-	/* create the linked list of node prototypes in this library */
-	for(i=0; i<io_txtindata.facetcount; i++)
-	{
-		if (i != 0) io_txtindata.nodeprotolist[i]->lastnodeproto = io_txtindata.nodeprotolist[i-1]; else
-			io_txtindata.nodeprotolist[i]->lastnodeproto = NONODEPROTO;
-		if (i != io_txtindata.facetcount-1)
-			io_txtindata.nodeprotolist[i]->nextnodeproto = io_txtindata.nodeprotolist[i+1]; else
-				io_txtindata.nodeprotolist[i]->nextnodeproto = NONODEPROTO;
-	}
-	io_txtindata.curlib->firstnodeproto = io_txtindata.nodeprotolist[0];
-	io_txtindata.curlib->tailnodeproto = io_txtindata.nodeprotolist[io_txtindata.facetcount-1];
 }
 
 /*
@@ -1291,7 +1207,11 @@ void io_celnam(void)
 {
 	REGISTER char *pt;
 	REGISTER VIEW *v;
+	char *cellname;
+	REGISTER CELL *cell;
 
+	if (io_txtindata.curnodeproto->cell != NOCELL)
+		longjmp(io_filerror, (INTBIG)_("Second facet name"));
 	if (io_verbose != 0)
 	{
 		if (io_verbose < 0 && io_txtindata.filelength > 0)
@@ -1307,7 +1227,7 @@ void io_celnam(void)
 	if (*pt == '{')
 	{
 		*pt = 0;
-		if (allocstring(&io_txtindata.curnodeproto->cell->cellname, io_keyword,
+		if (allocstring(&cellname, io_keyword,
 			io_txtindata.curlib->cluster) != 0)
 				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 		pt++;
@@ -1317,10 +1237,21 @@ void io_celnam(void)
 		if (v != NOVIEW) io_txtindata.curnodeproto->cellview = v;
 	} else
 	{
-		if (allocstring(&io_txtindata.curnodeproto->cell->cellname, io_keyword,
+		if (allocstring(&cellname, io_keyword,
 			io_txtindata.curlib->cluster) != 0)
 				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 	}
+	cell = db_findcellname(cellname, io_txtindata.curlib);
+	if (cell == NOCELL)
+	{
+		cell = alloccell(io_txtindata.curlib->cluster);
+		if (cell == NOCELL) longjmp(io_filerror, (INTBIG)_("No memory for facets"));
+		cell->lib = io_txtindata.curlib;
+		cell->cellname = cellname;
+	} else
+		efree(cellname);
+	io_txtindata.curnodeproto->cell = cell;
+	db_insertnodeproto(io_txtindata.curnodeproto);
 }
 
 /*
@@ -1357,8 +1288,9 @@ void io_celext(void)
 	REGISTER char *libname, *pt;
 	char *filename, *libfile, *oldline2, *oldline3;
 	FILE *io;
-	REGISTER CELL *cell, *lastcell, *c;
-	REGISTER NODEPROTO *np, *onp, *lastnp, *nnp;
+	REGISTER CELL *cell;
+	char *cellname;
+	REGISTER NODEPROTO *np, *onp;
 	REGISTER NODEINST *ni;
 	TXTINPUTDATA savetxtindata;
 
@@ -1413,6 +1345,7 @@ void io_celext(void)
 		}
 
 		len = strlen(libfile);
+		io_libinputrecursivedepth++;
 		if (len > 4 && namesame(&libfile[len-4], ".txt") == 0)
 		{
 			/* ends in ".txt", presume text file */
@@ -1422,9 +1355,10 @@ void io_celext(void)
 			/* all other endings: presume binary file */
 			k = io_doreadbinlibrary(elib, 0);
 		}
-		for(k=0; k<el_maxaid; k++)
-			if (el_aids[k].readlibrary != 0)
-				(*el_aids[k].readlibrary)(elib);
+		io_libinputrecursivedepth--;
+		for(k=0; k<el_maxtools; k++)
+			if (el_tools[k].readlibrary != 0)
+				(*el_tools[k].readlibrary)(elib);
 		io_txtindata = savetxtindata;
 		if (io_verbose < 0 && io_txtindata.filelength > 0)
 		{
@@ -1476,39 +1410,13 @@ void io_celext(void)
 		/* get rid of existing facet/cell and plug in the external reference */
 		onp = io_txtindata.nodeprotolist[io_txtindata.curfacetnumber];
 		cell = onp->cell;
-
-		lastnp = NONODEPROTO;
-		for(nnp = io_txtindata.curlib->firstnodeproto; nnp != NONODEPROTO; nnp = nnp->nextnodeproto)
+		db_retractnodeproto(onp);
+		if (cell->firstincell == NONODEPROTO)
 		{
-			if (nnp == onp) break;
-			lastnp = nnp;
+			efree(cell->cellname);
+			efree((char *)cell);
 		}
-		if (nnp != NONODEPROTO)
-		{
-			if (lastnp == NONODEPROTO) io_txtindata.curlib->firstnodeproto = onp->nextnodeproto; else
-				lastnp->nextnodeproto = onp->nextnodeproto;
-			if (io_txtindata.curlib->tailnodeproto == onp)
-				io_txtindata.curlib->tailnodeproto = lastnp;
-		}
-		db_freertree(onp->rtree);
 		freenodeproto(onp);
-
-		lastcell = NOCELL;
-		for(c = io_txtindata.curlib->firstcell; c != NOCELL; c = c->nextcell)
-		{
-			if (c == cell) break;
-			lastcell = c;
-		}
-		if (c != NOCELL)
-		{
-			if (lastcell == NOCELL) io_txtindata.curlib->firstcell = cell->nextcell; else
-				lastcell->nextcell = cell->nextcell;
-			if (c == io_txtindata.curlib->tailcell) io_txtindata.curlib->tailcell = lastcell;
-			io_txtindata.curlib->numcells--;
-		}
-		efree(cell->cellname);
-		efree((char *)cell);
-
 		io_txtindata.nodeprotolist[io_txtindata.curfacetnumber] = np;
 	} else
 	{
@@ -1518,8 +1426,25 @@ void io_celext(void)
 		(void)addstringtoinfstr(np->cell->cellname);
 		(void)addstringtoinfstr("FROM");
 		(void)addstringtoinfstr(elib->libname);
-		(void)reallocstring(&np->cell->cellname, returninfstr(),
-			io_txtindata.curlib->cluster);
+		cell = np->cell;
+		db_retractnodeproto(np);
+		if (cell->firstincell == NONODEPROTO)
+		{
+			efree(cell->cellname);
+			efree((char *)cell);
+		}
+
+		cellname = returninfstr();
+		cell = db_findcellname(cellname, io_txtindata.curlib);
+		if (cell == NOCELL)
+		{
+			cell = alloccell(io_txtindata.curlib->cluster);
+			if (cell == NOCELL) longjmp(io_filerror, (INTBIG)_("No memory for facets"));
+			cell->lib = io_txtindata.curlib;
+			(void)allocstring(&cell->cellname, cellname, io_txtindata.curlib->cluster);
+		}
+		np->cell = cell;
+		db_insertnodeproto(np);
 
 		/* create two Invisible Pins to define the facet size */
 		insx = gen_invispinprim->highx - gen_invispinprim->lowx;
@@ -1584,7 +1509,7 @@ void io_tech(void)
 }
 
 /*
- * get the aid dirty word for the current facet (keyword "aadirty")
+ * get the tool dirty word for the current facet (keyword "aadirty")
  */
 void io_celaad(void)
 {
@@ -1593,7 +1518,7 @@ void io_celaad(void)
 }
 
 /*
- * get aid information for current facet (keyword "bits")
+ * get tool information for current facet (keyword "bits")
  */
 void io_celbit(void)
 {
@@ -1602,7 +1527,7 @@ void io_celbit(void)
 }
 
 /*
- * get aid information for current facet (keyword "userbits")
+ * get tool information for current facet (keyword "userbits")
  */
 void io_celusb(void)
 {
@@ -1610,7 +1535,7 @@ void io_celusb(void)
 }
 
 /*
- * get aid information for current facet (keyword "netnum")
+ * get tool information for current facet (keyword "netnum")
  */
 void io_celnet(void) {}
 
@@ -1753,6 +1678,10 @@ void io_celdon(void)
 		}
 	}
 
+	/* create geometry structure in the facet */
+	if (geomstructure(io_txtindata.curnodeproto) != 0)
+		longjmp(io_filerror, (INTBIG)_("No memory for geometry structure"));
+
 	/* fill geometry module for each nodeinst */
 	for(i=0; i<io_txtindata.nodeinstcount; i++)
 	{
@@ -1890,7 +1819,17 @@ void io_nodnam(void)
  */
 void io_noddes(void)
 {
-	io_txtindata.curnodeinst->textdescript = atoi(io_keyword);
+	REGISTER char *pt;
+
+	io_txtindata.curnodeinst->textdescript[0] = atoi(io_keyword);
+	for(pt = io_keyword; *pt != 0 && *pt != '/'; pt++) ;
+	if (*pt == 0)
+	{
+		io_txtindata.curnodeinst->textdescript[1] = 0;
+	} else
+	{
+		io_txtindata.curnodeinst->textdescript[1] = atoi(pt+1);
+	}
 }
 
 /*
@@ -1910,7 +1849,7 @@ void io_nodtra(void)
 }
 
 /*
- * get the aid seen bits for the current nodeinst (keyword "aseen")
+ * get the tool seen bits for the current nodeinst (keyword "aseen")
  */
 void io_nodkse(void)
 {
@@ -1926,7 +1865,7 @@ void io_nodpoc(void)
 }
 
 /*
- * get aid information for current nodeinst (keyword "bits")
+ * get tool information for current nodeinst (keyword "bits")
  */
 void io_nodbit(void)
 {
@@ -1935,7 +1874,7 @@ void io_nodbit(void)
 }
 
 /*
- * get aid information for current nodeinst (keyword "userbits")
+ * get tool information for current nodeinst (keyword "userbits")
  */
 void io_nodusb(void)
 {
@@ -2050,6 +1989,26 @@ void io_arctyp(void)
 		return;
 	}
 
+	/* convert old Artwork names */
+	if (tech == art_tech)
+	{
+		if (strcmp(line, "Dash-1") == 0)
+		{
+			io_txtindata.curarcinst->proto = art_dottedarc;
+			return;
+		}
+		if (strcmp(line, "Dash-2") == 0)
+		{
+			io_txtindata.curarcinst->proto = art_dashedarc;
+			return;
+		}
+		if (strcmp(line, "Dash-3") == 0)
+		{
+			io_txtindata.curarcinst->proto = art_thickerarc;
+			return;
+		}
+	}
+
 	/* special hack: try the generic technology if name is not found */
 	for(ap = gen_tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		if (namesame(line, ap->protoname) == 0)
@@ -2135,7 +2094,7 @@ void io_endyp(void)
 }
 
 /*
- * get the aid information for the current arcinst (keyword "aseen")
+ * get the tool information for the current arcinst (keyword "aseen")
  */
 void io_arckse(void)
 {
@@ -2143,7 +2102,7 @@ void io_arckse(void)
 }
 
 /*
- * get aid information for current arcinst (keyword "bits")
+ * get tool information for current arcinst (keyword "bits")
  */
 void io_arcbit(void)
 {
@@ -2152,7 +2111,7 @@ void io_arcbit(void)
 }
 
 /*
- * get aid information for current arcinst (keyword "userbits")
+ * get tool information for current arcinst (keyword "userbits")
  */
 void io_arcusb(void)
 {
@@ -2160,7 +2119,7 @@ void io_arcusb(void)
 }
 
 /*
- * get aid information for current arcinst (keyword "netnum")
+ * get tool information for current arcinst (keyword "netnum")
  */
 void io_arcnet(void) {}
 
@@ -2190,7 +2149,17 @@ void io_ptnam(void)
  */
 void io_ptdes(void)
 {
-	io_txtindata.curportproto->textdescript = atoi(io_keyword);
+	REGISTER char *pt;
+
+	io_txtindata.curportproto->textdescript[0] = atoi(io_keyword);
+	for(pt = io_keyword; *pt != 0 && *pt != '/'; pt++) ;
+	if (*pt == 0)
+	{
+		io_txtindata.curportproto->textdescript[1] = 0;
+	} else
+	{
+		io_txtindata.curportproto->textdescript[1] = atoi(pt+1);
+	}
 }
 
 /*
@@ -2214,7 +2183,7 @@ void io_ptspt(void)
 }
 
 /*
- * get the aid seen for the current port prototype (keyword "aseen")
+ * get the tool seen for the current port prototype (keyword "aseen")
  */
 void io_ptkse(void)
 {
@@ -2222,7 +2191,7 @@ void io_ptkse(void)
 }
 
 /*
- * get the aid data for the current port prototype (keyword "bits")
+ * get the tool data for the current port prototype (keyword "bits")
  */
 void io_ptbit(void)
 {
@@ -2231,7 +2200,7 @@ void io_ptbit(void)
 }
 
 /*
- * get the aid data for the current port prototype (keyword "userbits")
+ * get the tool data for the current port prototype (keyword "userbits")
  */
 void io_ptusb(void)
 {
@@ -2239,7 +2208,7 @@ void io_ptusb(void)
 }
 
 /*
- * get the aid data for the current port prototype (keyword "netnum")
+ * get the tool data for the current port prototype (keyword "netnum")
  */
 void io_ptnet(void) {}
 
