@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: iotexto.c
- * Input/output aid: textual format output
+ * Input/output tool: textual format output
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -31,17 +31,17 @@
 #include "global.h"
 #include "eio.h"
 
-INTBIG io_facetnumber, io_nodeinsterror, io_portarcinsterror, io_portexpinsterror,
+static INTBIG io_facetnumber, io_nodeinsterror, io_portarcinsterror, io_portexpinsterror,
 	  io_portprotoerror, io_arcinsterror, io_geomerror, io_rtnodeerror, io_libraryerror;
 
 /* prototypes for local routines */
-void io_textrecurse(NODEPROTO*);
-INTSML io_countvars(INTSML, VARIABLE*);
-void io_writevars(INTSML, VARIABLE*, NODEPROTO*);
-char *io_makestring(VARIABLE*, NODEPROTO*);
-INTSML io_makestringvar(INTBIG, INTBIG, NODEPROTO*);
-INTSML io_addstring(char*);
-void io_printname(char*, FILE*);
+static void io_textrecurse(NODEPROTO*);
+static INTSML io_countvars(INTSML, VARIABLE*);
+static void io_writevars(INTSML, VARIABLE*, NODEPROTO*);
+static char *io_makestring(VARIABLE*, NODEPROTO*);
+static INTSML io_makestringvar(INTBIG, INTBIG, NODEPROTO*);
+static INTSML io_addstring(char*);
+static void io_printname(char*, FILE*);
 
 INTSML io_writetextlibrary(LIBRARY *lib)
 {
@@ -57,6 +57,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	REGISTER ARCINST *ai;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VIEW *v;
+	REGISTER NODEPROTO **facets;
 
 	(void)strcpy(file, lib->libfile);
 	name = &file[strlen(file)-5];
@@ -82,16 +83,34 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	io_facetnumber = 0;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->firstinst == NONODEINST) io_textrecurse(np);
+	if (io_facetnumber > 0)
+	{
+		facets = (NODEPROTO **)emalloc((io_facetnumber * sizeof(NODEPROTO *)),
+			io_tool->cluster);
+		if (facets == 0)
+		{
+			ttyputnomemory();
+			return(1);
+		}
+		for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
+		{
+			for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			{
+				if (np->temp1 >= 0 && np->temp1 < io_facetnumber)
+					facets[np->temp1] = np;
+			}
+		}
+	}
 
 	/* write header information */
 	xprintf(io_fileout, "****library: \"%s\"\n", lib->libname);
 	xprintf(io_fileout, "version: %s\n", el_version);
-	xprintf(io_fileout, "aids: %d\n", el_maxaid);
-	for(i=0; i<el_maxaid; i++)
+	xprintf(io_fileout, "aids: %d\n", el_maxtools);
+	for(i=0; i<el_maxtools; i++)
 	{
-		xprintf(io_fileout, "aidname: %s\n", el_aids[i].aidname);
-		if (io_countvars(el_aids[i].numvar, el_aids[i].firstvar) != 0)
-			io_writevars(el_aids[i].numvar, el_aids[i].firstvar, NONODEPROTO);
+		xprintf(io_fileout, "aidname: %s\n", el_tools[i].toolname);
+		if (io_countvars(el_tools[i].numvar, el_tools[i].firstvar) != 0)
+			io_writevars(el_tools[i].numvar, el_tools[i].firstvar, NONODEPROTO);
 	}
 	xprintf(io_fileout, "userbits: %ld\n", lib->userbits);
 	xprintf(io_fileout, "techcount: %d\n", el_maxtech);
@@ -113,14 +132,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	for(facet = 0; facet < io_facetnumber; facet++)
 	{
 		/* write the nodeproto name */
-		for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
-		{
-			for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			{
-				if (np->temp1 == facet) break;
-			}
-			if (np != NONODEPROTO) break;
-		}
+		np = facets[facet];
 		xprintf(io_fileout, "***cell: %ld\n", np->temp1);
 		xprintf(io_fileout, "name: %s", np->cell->cellname);
 		if (*np->cellview->sviewname != 0)
@@ -135,13 +147,14 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 			np->lowx, np->highx, np->lowy, np->highy);
 
 		/* facets in external libraries mention the library and stop */
-		if (olib != lib)
+		if (np->cell->lib != lib)
 		{
-			xprintf(io_fileout, "externallibrary: \"%s\"\n", olib->libfile);
+			xprintf(io_fileout, "externallibrary: \"%s\"\n",
+				np->cell->lib->libfile);
 			continue;
 		}
 
-		/* write aid information */
+		/* write tool information */
 		xprintf(io_fileout, "aadirty: %ld\n", np->adirty);
 		xprintf(io_fileout, "userbits: %ld\n", np->userbits);
 
@@ -170,7 +183,10 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 				ni->highx, ni->lowy, ni->highy);
 			xprintf(io_fileout, "rotation: %d transpose: %d\n", ni->rotation, ni->transpose);
 			if (ni->proto->primindex == 0)
-				xprintf(io_fileout, "descript: %ld\n", ni->textdescript);
+			{
+				xprintf(io_fileout, "descript: %ld/%ld\n", ni->textdescript[0],
+					ni->textdescript[1]);
+			}
 			xprintf(io_fileout, "userbits: %ld\n", ni->userbits);
 			io_writevars(ni->numvar, ni->firstvar, np);
 
@@ -205,7 +221,10 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 			xprintf(io_fileout, "subnode: %ld\n", pp->subnodeinst->temp1);
 			xprintf(io_fileout, "subport: %s\n", pp->subportproto->protoname);
 			xprintf(io_fileout, "name: %s\n", pp->protoname);
-			xprintf(io_fileout, "descript: %ld\n", pp->textdescript);
+
+			/* need to write both words */
+			xprintf(io_fileout, "descript: %ld/%ld\n", pp->textdescript[0],
+				pp->textdescript[1]);
 			xprintf(io_fileout, "userbits: %ld\n", pp->userbits);
 			io_writevars(pp->numvar, pp->firstvar, np);
 		}
@@ -251,6 +270,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	xclose(io_fileout);
 	ttyputmsg(_("%s written"), truename);
 	lib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
+	if (io_facetnumber > 0) efree((char *)facets);
 	return(0);
 }
 
@@ -308,8 +328,16 @@ void io_writevars(INTSML numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
 		if (pt == 0) return;
 		io_printname((char *)var->key, io_fileout);
 		if ((var->type&(VLENGTH|VISARRAY)) != VISARRAY)
-			xprintf(io_fileout, "[0%o,0%o]: ", var->type, var->textdescript); else
-				xprintf(io_fileout, "(%ld)[0%o,0%o]: ", getlength(var), var->type, var->textdescript);
+		{
+			/* need to write both words!!! */
+			xprintf(io_fileout, "[0%o,0%o/0%o]: ", var->type, var->textdescript[0],
+				var->textdescript[1]);
+		} else
+		{
+			/* need to write both words!!! */
+			xprintf(io_fileout, "(%ld)[0%o,0%o/0%o]: ", getlength(var), var->type,
+				var->textdescript[0], var->textdescript[1]);
+		}
 		xprintf(io_fileout, "%s\n", pt);
 	}
 }
@@ -392,7 +420,7 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 	REGISTER RTNODE *rtn;
 	REGISTER LIBRARY *lib;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	if ((type&(VCODE1|VCODE2)) != 0) type = VSTRING;
 	switch (type&VTYPE)
@@ -499,10 +527,10 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			tech = (TECHNOLOGY *)addr;
 			if (tech == NOTECHNOLOGY) return(addstringtoinfstr("NOTECHNOLOGY"));
 			return(io_addstring(tech->techname));
-		case VAID:
-			aid = (AIDENTRY *)addr;
-			if (aid == NOAID) return(addstringtoinfstr("NOAID"));
-			return(io_addstring(aid->aidname));
+		case VTOOL:
+			tool = (TOOL *)addr;
+			if (tool == NOTOOL) return(addstringtoinfstr("NOTOOL"));
+			return(io_addstring(tool->toolname));
 		case VRTNODE:
 			io_rtnodeerror++;
 			rtn = (RTNODE *)addr;
