@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: compact.c
- * One-dimensional compactor aid
+ * One-dimensional compactor tool
  * Written by: Nora Ryan, Schlumberger Palo Alto Research
  * Rewritten by: Steven M. Rubin, Schlumberger Palo Alto Research
  *
@@ -38,7 +38,7 @@
  */
 
 #include "config.h"
-#if COMAID
+#if COMTOOL
 
 #include "global.h"
 #include "compact.h"
@@ -99,44 +99,44 @@ typedef struct Itecharray
 	INTSML             taindex;
 	struct Itecharray *nexttecharray;
 } TECH_ARRAY;
-TECH_ARRAY *com_conv_layer;
+static TECH_ARRAY *com_conv_layer;
 
 /* prototypes for local routines */
-void com_buildtechnologies(void);
-OBJECT *com_make_ni_object(NODEINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
-void com_fillnode(NODEINST*);
-LINE *com_sort(LINE*, INTSML);
-void com_computeline_hi_and_low(LINE*, INTSML);
-INTSML com_lineup_firstrow(LINE*, LINE*, INTSML, INTBIG);
-INTSML com_findleastlow(LINE*, INTSML);
-INTSML com_compact(LINE*, LINE*, INTSML, INTSML, NODEPROTO*);
-INTBIG com_checkinst(OBJECT*, LINE*, INTSML, OBJECT**, POLYLIST **, POLYLIST **, NODEPROTO*);
-INTBIG com_minseparate(OBJECT*, INTSML, POLYLIST*, LINE*, INTSML, OBJECT**, POLYLIST **, NODEPROTO*);
-INTBIG com_check(INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-INTSML com_cropnodeinst(POLYLIST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML, INTSML);
-INTSML com_in_bound(INTBIG, INTBIG, INTBIG, INTBIG);
-void com_fixed_nonfixed(LINE*, LINE*);
-void com_undo_fixed_nonfixed(LINE*, LINE*);
-void com_noslide(LINE*);
-void com_slide(LINE*);
-INTSML com_move(LINE*, INTBIG, INTBIG, INTSML);
-INTSML com_convertpintonode_layer(INTSML, TECHNOLOGY*);
-void com_subsmash(NODEPROTO*);
-void com_add_poly_polylist(POLYGON*, OBJECT*, INTSML, TECHNOLOGY*);
-OBJECT *com_allocate_object(void);
-void com_add_object_to_object(OBJECT**, OBJECT*);
-LINE *com_make_object_line(LINE*, OBJECT*);
-void com_clearspace(LINE*);
-void com_freeobject(OBJECT*);
-char *com_describeline(LINE*);
-void com_addlinedescription(LINE*);
-char *com_describeobject(OBJECT*);
-void com_createobjects(NODEINST*, INTSML, OBJECT**, OBJECT**);
-OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML com_examineonefacet(NODEPROTO*, INTSML, INTSML);
-void comp_optionsdlog(void);
+static void com_buildtechnologies(void);
+static OBJECT *com_make_ni_object(NODEINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
+static void com_fillnode(NODEINST*);
+static LINE *com_sort(LINE*, INTSML);
+static void com_computeline_hi_and_low(LINE*, INTSML);
+static INTSML com_lineup_firstrow(LINE*, LINE*, INTSML, INTBIG);
+static INTSML com_findleastlow(LINE*, INTSML);
+static INTSML com_compact(LINE*, LINE*, INTSML, INTSML, NODEPROTO*);
+static INTBIG com_checkinst(OBJECT*, LINE*, INTSML, OBJECT**, POLYLIST **, POLYLIST **, NODEPROTO*);
+static INTBIG com_minseparate(OBJECT*, INTSML, POLYLIST*, LINE*, INTSML, OBJECT**, POLYLIST **, NODEPROTO*);
+static INTBIG com_check(INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static INTSML com_cropnodeinst(POLYLIST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML, INTSML);
+static INTSML com_in_bound(INTBIG, INTBIG, INTBIG, INTBIG);
+static void com_fixed_nonfixed(LINE*, LINE*);
+static void com_undo_fixed_nonfixed(LINE*, LINE*);
+static void com_noslide(LINE*);
+static void com_slide(LINE*);
+static INTSML com_move(LINE*, INTBIG, INTBIG, INTSML);
+static INTSML com_convertpintonode_layer(INTSML, TECHNOLOGY*);
+static void com_subsmash(NODEPROTO*);
+static void com_add_poly_polylist(POLYGON*, OBJECT*, INTSML, TECHNOLOGY*);
+static OBJECT *com_allocate_object(void);
+static void com_add_object_to_object(OBJECT**, OBJECT*);
+static LINE *com_make_object_line(LINE*, OBJECT*);
+static void com_clearspace(LINE*);
+static void com_freeobject(OBJECT*);
+static char *com_describeline(LINE*);
+static void com_addlinedescription(LINE*);
+static char *com_describeobject(OBJECT*);
+static void com_createobjects(NODEINST*, INTSML, OBJECT**, OBJECT**);
+static OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
+static INTSML com_examineonefacet(NODEPROTO*, INTSML, INTSML);
+static void comp_optionsdlog(void);
 
-/* the COMPACTOR aid table */
+/* the COMPACTOR tool table */
 static COMCOMP comcp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
 	NOBACKUP, 0, " \t", M_("facet to be rechecked"), M_("default is current facet")};
 static KEYWORD comnotopt[] =
@@ -165,26 +165,26 @@ static KEYWORD comopt[] =
 COMCOMP com_compactp = {comopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Compactor action"), M_("show defaults")};
 
-AIDENTRY *com_aid;
-INTBIG    com_spread;				/* cached key for "COM_spread" */
-INTSML    com_debug;
-INTBIG    com_maxboundary, com_lowbound;
-INTBIG    com_flatindex;			/* counter for unique network numbers */
-INTSML    com_do_axis;
+       TOOL     *com_tool;
+static INTBIG    com_spread;			/* cached key for "COM_spread" */
+static INTSML    com_debug;
+static INTBIG    com_maxboundary, com_lowbound;
+static INTBIG    com_flatindex;			/* counter for unique network numbers */
+static INTSML    com_do_axis;
 
 /************************ CONTROL ***********************/
 
-void com_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void com_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* ignore pass 3 initialization */
-	if (thisaid == 0) return;
+	if (thistool == 0) return;
 
 	/* miscellaneous initialization during pass 2 */
-	if (thisaid == NOAID)
+	if (thistool == NOTOOL)
 	{
 		com_spread = makekey("COM_spread");
 		nextchangequiet();
-		(void)setvalkey((INTBIG)com_aid, VAID, com_spread, 0, VINTEGER|VDONTSAVE);
+		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 0, VINTEGER|VDONTSAVE);
 		com_debug = 0;
 		com_do_axis = VERTICAL;
 		com_conv_layer = NOTECHARRAY;
@@ -193,8 +193,8 @@ void com_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		return;
 	}
 
-	/* copy aid pointer during pass 1 */
-	com_aid = thisaid;
+	/* copy tool pointer during pass 1 */
+	com_tool = thistool;
 }
 
 /*
@@ -221,14 +221,14 @@ void com_buildtechnologies(void)
 	/* initialize technology layer conversion array */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 	{
-		cur_tech_array = (TECH_ARRAY *)emalloc((sizeof(TECH_ARRAY)), com_aid->cluster);
+		cur_tech_array = (TECH_ARRAY *)emalloc((sizeof(TECH_ARRAY)), com_tool->cluster);
 		if (cur_tech_array == 0) return;
 		cur_tech_array->taindex = tech->techindex;
 		cur_tech_array->nexttecharray = com_conv_layer;
 		com_conv_layer = cur_tech_array;
 
 		cur_tech_array->layer = (INTSML *)emalloc((sizeof(INTSML) * tech->layercount),
-			com_aid->cluster);
+			com_tool->cluster);
 
 		/* define the layer translation for pseudo layers and regular layers */
 		for(j = 0; j < tech->layercount; j++)
@@ -252,6 +252,7 @@ void com_buildtechnologies(void)
 
 void com_done(void)
 {
+#ifdef DEBUGMEMORY
 	REGISTER TECH_ARRAY *cur_tech_array, *next_techarray;
 
 	/* first free the former list of layer conversions */
@@ -263,6 +264,7 @@ void com_done(void)
 		efree((char *)cur_tech_array);
 	}
 	com_conv_layer = NOTECHARRAY;
+#endif
 }
 
 void com_slice(void)
@@ -274,10 +276,10 @@ void com_slice(void)
 	if (np == NONODEPROTO) return;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		return;
 	}
 
@@ -290,7 +292,7 @@ void com_slice(void)
 	if (!change)
 	{
 		 ttyputmsg(_("No further change.  Compactor turned off"));
-		 aidturnoff(com_aid, 0);
+		 toolturnoff(com_tool, 0);
 	} else setactivity(_("Compaction"));
 }
 
@@ -303,7 +305,7 @@ INTSML com_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		var = getvalkey((INTBIG)com_aid, VAID, VINTEGER, com_spread);
+		var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread);
 		if (var != NOVARIABLE)
 		{
 			if (var->addr != 0) ttyputmsg(M_("Compactor will spread if necessary")); else
@@ -328,17 +330,17 @@ INTSML com_set(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "spread", l) == 0)
 		{
-			(void)setvalkey((INTBIG)com_aid, VAID, com_spread, 0, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 0, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Compactor will not spread designs"));
 			return(0);
 		}
-		ttyputbadusage("tellaid compaction not");
+		ttyputbadusage("telltool compaction not");
 		return(1);
 	}
 
 	if (namesamen(pp, "spread", l) == 0)
 	{
-		(void)setvalkey((INTBIG)com_aid, VAID, com_spread, 1, VINTEGER|VDONTSAVE);
+		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 1, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Compactor will spread if necessary"));
 		return(0);
 	}
@@ -346,10 +348,10 @@ INTSML com_set(INTSML count, char *par[])
 	if (namesamen(pp, "check", l) == 0)
 	{
 		/* make sure network tool is on */
-		if ((net_aid->aidstate&AIDON) == 0)
+		if ((net_tool->toolstate&TOOLON) == 0)
 		{
 			ttyputerr(M_("Network tool must be running...turning it on"));
-			aidturnon(net_aid, 0);
+			toolturnon(net_tool, 0);
 			ttyputerr(M_("...now reissue the compaction command"));
 			return(1);
 		}
@@ -370,7 +372,7 @@ INTSML com_set(INTSML count, char *par[])
 			if (namesamen(pp, "horizontal", l) == 0) com_do_axis = HORIZONTAL; else
 			if (namesamen(pp, "vertical", l) == 0) com_do_axis = VERTICAL; else
 			{
-				ttyputbadusage("tellaid compaction check");
+				ttyputbadusage("telltool compaction check");
 				return(1);
 			}
 		}
@@ -416,7 +418,7 @@ INTSML com_set(INTSML count, char *par[])
 		}
 		return(0);
 	}
-	ttyputbadusage("tellaid compaction");
+	ttyputbadusage("telltool compaction");
 	return(1);
 }
 
@@ -654,7 +656,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 	tot = arcpolys(ai, NOWINDOWPART);
 	for(j=0; j<tot; j++)
 	{
-		poly = allocpolygon(4, com_aid->cluster);
+		poly = allocpolygon(4, com_tool->cluster);
 		shapearcpoly(ai, j, poly);
 		if (poly->layer < 0)
 		{
@@ -778,7 +780,7 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 		tot = nodeEpolys(ni, 0, NOWINDOWPART);
 		for(j=0; j<tot; j++)
 		{
-			poly = allocpolygon(4, com_aid->cluster);
+			poly = allocpolygon(4, com_tool->cluster);
 			shapeEnodepoly(ni, j, poly);
 			xformpoly(poly, trans);
 
@@ -1011,6 +1013,8 @@ INTSML com_findleastlow(LINE *line, INTSML axis)
 		if (cur_object->insttype == OBJARCINST) continue;
 		if (axis == HORIZONTAL) thislow = cur_object->lowx; else
 			thislow = cur_object->lowy;
+
+		/* LINTED "low" used in proper order */
 		if (first_time == 0) low = mini(low, thislow); else
 		{
 			low = thislow;
@@ -1034,7 +1038,7 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
 	REGISTER VARIABLE *var;
 
 	spread = 0;
-	var = getvalkey((INTBIG)com_aid, VAID, VINTEGER, com_spread);
+	var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread);
 	if (var != NOVARIABLE && var->addr != 0) spread++;
 
 	/* loop through all lines that may compact */
@@ -1116,7 +1120,7 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
 INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **oreason,
 	POLYLIST **opreason, POLYLIST **preason, NODEPROTO *facet)
 {
-	REGISTER INTSML pindex, layer;
+	REGISTER INTSML layer;
 	REGISTER INTBIG this_motion, best_motion;
 	REGISTER POLYGON *poly;
 	REGISTER POLYLIST *polys;
@@ -1129,7 +1133,6 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **oreason,
 		polys = polys->nextpolylist)
 	{
 		poly = polys->poly;
-		pindex = polys->networknum;
 
 		/* translate any pseudo layers for this node */
 		layer = com_convertpintonode_layer(poly->layer, polys->tech);
@@ -1165,7 +1168,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 		best_motion, this_motion, fun, minsize, nminsize;
 	REGISTER INTSML pindex, nindex, layer;
 	REGISTER POLYGON *poly, *npoly;
-	INTBIG lx, hx, ly, hy, xl, xh, yl, yh;
+	INTBIG lx, hx, ly, hy, xl, xh, yl, yh, edge;
 	REGISTER OBJECT *cur_object;
 	REGISTER POLYLIST *polys;
 	REGISTER TECHNOLOGY *tech;
@@ -1233,7 +1236,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					/* see how close they can get */
 					minsize = polyminsize(poly);
 					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
-						layer, minsize, con, 0, 0);
+						layer, minsize, con, 0, &edge, 0);
 					if (dist < 0) continue;
 
 					/*
@@ -1316,7 +1319,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					/* see how close they can get */
 					minsize = polyminsize(poly);
 					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
-						poly->layer, minsize, con, 0, 0);
+						poly->layer, minsize, con, 0, &edge, 0);
 					if (dist < 0) continue;
 
 					/*
@@ -1532,7 +1535,7 @@ INTSML com_move(LINE *line, INTBIG movex, INTBIG movey, INTSML change)
 	if (line == NOLINE) return(0);
 	if (!change && move != 0)
 	{
-		(void)askaid(us_aid, "clear");
+		(void)asktool(us_tool, "clear");
 		change = 1;
 	}
 
@@ -1666,7 +1669,7 @@ void com_add_poly_polylist(POLYGON *poly, OBJECT *object, INTSML networknum,
 {
 	REGISTER POLYLIST *new_polys;
 
-	new_polys = (POLYLIST *)emalloc((sizeof(POLYLIST)), com_aid->cluster);
+	new_polys = (POLYLIST *)emalloc((sizeof(POLYLIST)), com_tool->cluster);
 	if (new_polys == 0) return;
 	new_polys->poly = poly;
 	new_polys->tech = tech;
@@ -1679,7 +1682,7 @@ OBJECT *com_allocate_object(void)
 {
 	REGISTER OBJECT *cur_object;
 
-	cur_object = (OBJECT *)emalloc((sizeof(OBJECT)), com_aid->cluster);
+	cur_object = (OBJECT *)emalloc((sizeof(OBJECT)), com_tool->cluster);
 	if (cur_object == 0) return(NOOBJECT);
 	cur_object->nextobject = NOOBJECT;
 	return(cur_object);
@@ -1702,7 +1705,7 @@ LINE *com_make_object_line(LINE *line, OBJECT *object)
 {
 	REGISTER LINE *new_line;
 
-	new_line = (LINE *)emalloc((sizeof(LINE)), com_aid->cluster);
+	new_line = (LINE *)emalloc((sizeof(LINE)), com_tool->cluster);
 	if (new_line == 0) return(NOLINE);
 	new_line->nextline = line;
 	new_line->prevline = NOLINE;
@@ -1786,14 +1789,14 @@ char *com_describeobject(OBJECT *cur_object)
 /****************************** DIALOG ******************************/
 
 /* Compaction Options */
-DIALOGITEM com_optionsdialogitems[] =
+static DIALOGITEM com_optionsdialogitems[] =
 {
  /*  1 */ {0, {64,92,88,156}, BUTTON, N_("OK")},
  /*  2 */ {0, {64,8,88,72}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,154}, CHECK, N_("Allow spreading")},
  /*  4 */ {0, {32,8,48,154}, CHECK, N_("Verbose")}
 };
-DIALOG com_optionsdialog = {{50,75,147,243}, N_("Compaction Options"), 0, 4, com_optionsdialogitems};
+static DIALOG com_optionsdialog = {{50,75,147,243}, N_("Compaction Options"), 0, 4, com_optionsdialogitems};
 
 /* special items for the "Compaction Options" dialog: */
 #define DCMO_CANSPREAD   3		/* Allow spreading (check) */
@@ -1805,7 +1808,7 @@ void comp_optionsdlog(void)
 	REGISTER VARIABLE *var;
 
 	if (DiaInitDialog(&com_optionsdialog) != 0) return;
-	var = getval((INTBIG)com_aid, VAID, VINTEGER, "COM_spread");
+	var = getval((INTBIG)com_tool, VTOOL, VINTEGER, "COM_spread");
 	if (var == NOVARIABLE) origspread = 0; else origspread = var->addr;
 	if (origspread != 0) DiaSetControl(DCMO_CANSPREAD, 1);
 	if (com_debug != 0) DiaSetControl(DCMO_VERBOSE, 1);
@@ -1827,11 +1830,11 @@ void comp_optionsdlog(void)
 		if (DiaGetControl(DCMO_CANSPREAD) != 0) spread = 1; else
 			spread = 0;
 		if (spread != origspread)
-			(void)setval((INTBIG)com_aid, VAID, "COM_spread", spread, VINTEGER);
+			(void)setval((INTBIG)com_tool, VTOOL, "COM_spread", spread, VINTEGER);
 		if (DiaGetControl(DCMO_VERBOSE) != 0) com_debug = 1; else
 			com_debug = 0;
 	}
 	DiaDoneDialog();
 }
 
-#endif  /* COMAID - at top */
+#endif  /* COMTOOL - at top */
