@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if ERCAID
+#if ERCTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -37,7 +37,7 @@
 #include "erc.h"
 #include "edialogs.h"
 
-/* the ERC aid table */
+/* the ERC tool table */
 static KEYWORD ercopt[] =
 {
 	{"analyze",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -58,14 +58,14 @@ typedef struct Iwellcon
 	struct Iwellcon *nextwellcon;
 } WELLCON;
 
-WELLCON    *erc_wellconfree = NOWELLCON;
-WELLCON    *erc_firstwellcon = NOWELLCON;
-INTBIG      erc_worstpwelldist;
-INTBIG      erc_worstpwellconx, erc_worstpwellcony;
-INTBIG      erc_worstpwelledgex, erc_worstpwelledgey;
-INTBIG      erc_worstnwelldist;
-INTBIG      erc_worstnwellconx, erc_worstnwellcony;
-INTBIG      erc_worstnwelledgex, erc_worstnwelledgey;
+static WELLCON    *erc_wellconfree = NOWELLCON;
+static WELLCON    *erc_firstwellcon = NOWELLCON;
+static INTBIG      erc_worstpwelldist;
+static INTBIG      erc_worstpwellconx, erc_worstpwellcony;
+static INTBIG      erc_worstpwelledgex, erc_worstpwelledgey;
+static INTBIG      erc_worstnwelldist;
+static INTBIG      erc_worstnwellconx, erc_worstnwellcony;
+static INTBIG      erc_worstnwelledgex, erc_worstnwelledgey;
 
 /* well areas */
 #define NOWELLAREA ((WELLAREA *)-1)
@@ -81,8 +81,8 @@ typedef struct Iwellarea
 	struct Iwellarea  *nextwellarea;
 } WELLAREA;
 
-WELLAREA *erc_wellareafree = NOWELLAREA;
-WELLAREA *erc_firstwellarea = NOWELLAREA;
+static WELLAREA *erc_wellareafree = NOWELLAREA;
+static WELLAREA *erc_firstwellarea = NOWELLAREA;
 
 /* miscellaneous */
 
@@ -96,49 +96,49 @@ WELLAREA *erc_firstwellarea = NOWELLAREA;
 #define NWELLCONONCE      04
 #define NWELLCONIGNORE   010
 
-AIDENTRY   *erc_aid;						/* this tool */
-NODEPROTO  *erc_facet;
-INTBIG      erc_globalnetnumber;			/* global network number */
-INTBIG      erc_attachednetnumber;			/* attached network number (above this floats) */
-INTBIG      erc_optionskey;					/* key for "ERC_options" */
-INTBIG      erc_options;					/* value of "ERC_options" */
-INTBIG      erc_jobsize;					/* number of polygons to analyze */
-INTBIG      erc_polyscrunched;				/* number of polygons analyzed */
-INTBIG      erc_realrun;					/* nonzero if this is the real analysis */
+       TOOL       *erc_tool;					/* this tool */
+static NODEPROTO  *erc_facet;
+static INTBIG      erc_globalnetnumber;			/* global network number */
+static INTBIG      erc_attachednetnumber;		/* attached network number (above this floats) */
+static INTBIG      erc_optionskey;				/* key for "ERC_options" */
+static INTBIG      erc_options;					/* value of "ERC_options" */
+static INTBIG      erc_jobsize;					/* number of polygons to analyze */
+static INTBIG      erc_polyscrunched;			/* number of polygons analyzed */
+static INTBIG      erc_realrun;					/* nonzero if this is the real analysis */
 
 /* prototypes for local routines */
-WELLAREA    *erc_allocwellarea(void);
-WELLCON     *erc_allocwellcon(void);
-void         erc_analyzefacet(NODEPROTO *facet);
-void         erc_freeallwellareas(void);
-void         erc_freeallwellcons(void);
-void         erc_freewellarea(WELLAREA *wa);
-void         erc_freewellcon(WELLCON *wc);
-void         erc_gatherwells(NODEPROTO *np, XARRAY trans);
-void         erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count);
-void         erc_optionsdlog(void);
-INTSML       erc_welllayer(TECHNOLOGY *tech, INTSML layer);
+static WELLAREA    *erc_allocwellarea(void);
+static WELLCON     *erc_allocwellcon(void);
+static void         erc_analyzefacet(NODEPROTO *facet);
+static void         erc_freeallwellareas(void);
+static void         erc_freeallwellcons(void);
+static void         erc_gatherwells(NODEPROTO *np, XARRAY trans);
+static void         erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count);
+static void         erc_optionsdlog(void);
+static INTSML       erc_welllayer(TECHNOLOGY *tech, INTSML layer);
 
 /************************ CONTROL ***********************/
 
 /*
  * tool initialization
  */
-void erc_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void erc_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* only initialize during pass 1 */
-	if (thisaid == NOAID || thisaid == 0) return;
+	if (thistool == NOTOOL || thistool == 0) return;
 
-	/* copy aid pointer during pass 1 */
-	erc_aid = thisaid;
+	/* copy tool pointer during pass 1 */
+	erc_tool = thistool;
 	erc_optionskey = makekey("ERC_options");
 	DiaDeclareHook("ercopt", &erc_tablep, erc_optionsdlog);
 }
 
 void erc_done(void)
 {
+#ifdef DEBUGMEMORY
 	erc_freeallwellcons();
 	erc_freeallwellareas();
+#endif
 }
 
 /*
@@ -152,7 +152,7 @@ INTSML erc_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputusage("tellaid erc analyze");
+		ttyputusage("telltool erc analyze");
 		return(0);
 	}
 
@@ -167,7 +167,7 @@ INTSML erc_set(INTSML count, char *par[])
 		return(0);
 	}
 
-	ttyputbadusage("tellaid erc");
+	ttyputbadusage("telltool erc");
 	return(1);
 }
 
@@ -188,13 +188,14 @@ void erc_analyzefacet(NODEPROTO *facet)
 	REGISTER PORTPROTO *pp, *opp;
 	REGISTER WELLAREA *wa, *owa;
 	REGISTER void *err;
+	INTBIG edge;
 	extern DIALOG us_progressdialog;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		return;
 	}
 
@@ -210,12 +211,12 @@ void erc_analyzefacet(NODEPROTO *facet)
 	DiaSetText(2, _("Preparing to analyze..."));
 
 	/* initialize to analyze facet */
-	initerrorlogging(_("ERC"));
+	initerrorlogging(_("ERC"), facet, NONODEPROTO);
 	erc_freeallwellcons();
 	erc_freeallwellareas();
 	erc_worstpwelldist = erc_worstnwelldist = 0;
 	erc_facet = facet;
-	var = getvalkey((INTBIG)erc_aid, VAID, VINTEGER, erc_optionskey);
+	var = getvalkey((INTBIG)erc_tool, VTOOL, VINTEGER, erc_optionskey);
 	if (var == NOVARIABLE) erc_options = 0; else
 		erc_options = var->addr;
 
@@ -254,19 +255,20 @@ void erc_analyzefacet(NODEPROTO *facet)
 	erc_gatherwells(facet, el_matid);
 
 	/* determine the number of polygon points in the analysis */
-	DiaSetText(2, _("Analyzing..."));
 	erc_polyscrunched = 0;
 	erc_realrun = 0;
 	mergedone(erc_getpolygon);
 	erc_jobsize = erc_polyscrunched;
 
 	/* do the analysis */
+	DiaSetText(2, _("Analyzing..."));
 	erc_realrun = 1;
 	erc_polyscrunched = 0;
 	mergedone(erc_getpolygon);
 	DiaPercent(1, 100);
 
 	/* make sure all of the contacts are on the same net */
+	DiaSetText(2, _("Reporting errors..."));
 	for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
 	{
 		if (wc->netnum == 0)
@@ -320,9 +322,11 @@ void erc_analyzefacet(NODEPROTO *facet)
 		{
 			if (wa->tech != owa->tech || wa->layer != owa->layer) continue;
 			if (wa->netnum == owa->netnum && wa->netnum >= 0)
-				minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 1, 0, 0); else
-					minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 0, 0, 0);
+				minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 1, 0, &edge, 0); else
+					minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 0, 0, &edge, 0);
 			if (minsep < 0) continue;
+			if (wa->lx > owa->hx+minsep || owa->lx > wa->hx+minsep ||
+				wa->ly > owa->hy+minsep || owa->ly > wa->hy+minsep) continue;
 			dist = polyseparation(wa->poly, owa->poly);
 			if (dist < minsep)
 			{
@@ -380,17 +384,17 @@ void erc_analyzefacet(NODEPROTO *facet)
 	/* show the farthest distance from a well contact */
 	if (erc_worstpwelldist > 0 || erc_worstnwelldist > 0)
 	{
-		(void)askaid(us_aid, "clear");
+		(void)asktool(us_tool, "clear");
 		if (erc_worstpwelldist > 0)
 		{
-			(void)askaid(us_aid, "show-line", erc_worstpwellconx, erc_worstpwellcony,
+			(void)asktool(us_tool, "show-line", erc_worstpwellconx, erc_worstpwellcony,
 				erc_worstpwelledgex, erc_worstpwelledgey, erc_facet);
 			ttyputmsg(_("Farthest distance from a P-Well contact is %s"),
 				latoa(erc_worstpwelldist));
 		}
 		if (erc_worstnwelldist > 0)
 		{
-			(void)askaid(us_aid, "show-line", erc_worstnwellconx, erc_worstnwellcony,
+			(void)asktool(us_tool, "show-line", erc_worstnwellconx, erc_worstnwellcony,
 				erc_worstnwelledgex, erc_worstnwelledgey, erc_facet);
 			ttyputmsg(_("Farthest distance from a N-Well contact is %s"),
 				latoa(erc_worstnwelldist));
@@ -453,7 +457,7 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans)
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER WELLCON *wc;
 
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, erc_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, erc_tool->cluster);
 
 	/* grab global network information from the ports */
 	if (erc_realrun != 0)
@@ -513,7 +517,7 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans)
 				{
 					if (stopping(STOPREASONERC)) return;
 				}
-				nfun = nodefunction(ni, 0);
+				nfun = nodefunction(ni);
 				ni->proto->temp1++;
 
 				if (nfun == NPWELL || nfun == NPSUBSTRATE)
@@ -602,7 +606,7 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 
 	/* save the polygon */
 	wa = erc_allocwellarea();
-	wa->poly = allocpolygon(count, erc_aid->cluster);
+	wa->poly = allocpolygon(count, erc_tool->cluster);
 	for(i=0; i<count; i++)
 	{
 		wa->poly->xv[i] = x[i];
@@ -638,6 +642,8 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 	for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
 	{
 		if (wc->fun != desiredcontact) continue;
+		if (wc->x < wa->lx || wc->x > wa->hx ||
+			wc->y < wa->ly || wc->y > wa->hy) continue;
 		if (isinside(wc->x, wc->y, wa->poly) == 0) continue;
 		wa->netnum = wc->netnum;
 		break;
@@ -675,6 +681,8 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 		for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
 		{
 			if (wc->fun != desiredcontact) continue;
+			if (wc->x < wa->lx || wc->x > wa->hx ||
+				wc->y < wa->ly || wc->y > wa->hy) continue;
 			if (isinside(wc->x, wc->y, wa->poly) == 0) continue;
 			dist = computedistance(wc->x, wc->y, xp, yp);
 			if (first != 0 || dist < bestdist)
@@ -760,18 +768,12 @@ WELLCON *erc_allocwellcon(void)
 		erc_wellconfree = wc->nextwellcon;
 	} else
 	{
-		wc = (WELLCON *)emalloc(sizeof (WELLCON), erc_aid->cluster);
+		wc = (WELLCON *)emalloc(sizeof (WELLCON), erc_tool->cluster);
 		if (wc == 0) return(NOWELLCON);
 	}
 	return(wc);
 }
 
-void erc_freewellcon(WELLCON *wc)
-{
-	wc->nextwellcon = erc_wellconfree;
-	erc_wellconfree = wc;
-}
-
 void erc_freeallwellareas(void)
 {
 	REGISTER WELLAREA *wa;
@@ -795,22 +797,16 @@ WELLAREA *erc_allocwellarea(void)
 		erc_wellareafree = wa->nextwellarea;
 	} else
 	{
-		wa = (WELLAREA *)emalloc(sizeof (WELLAREA), erc_aid->cluster);
+		wa = (WELLAREA *)emalloc(sizeof (WELLAREA), erc_tool->cluster);
 		if (wa == 0) return(NOWELLAREA);
 	}
 	return(wa);
 }
 
-void erc_freewellarea(WELLAREA *wa)
-{
-	wa->nextwellarea = erc_wellareafree;
-	erc_wellareafree = wa;
-}
-
 /******************** OPTIONS DIALOG ********************/
 
 /* ERC: Options Dialog */
-DIALOGITEM erc_optionsdialogitems[] =
+static DIALOGITEM erc_optionsdialogitems[] =
 {
  /*  1 */ {0, {108,396,132,460}, BUTTON, N_("OK")},
  /*  2 */ {0, {108,296,132,360}, BUTTON, N_("Cancel")},
@@ -823,7 +819,7 @@ DIALOGITEM erc_optionsdialogitems[] =
  /*  9 */ {0, {80,248,96,480}, RADIO, N_("Do not check for contacts")},
  /* 10 */ {0, {8,284,24,384}, MESSAGE, N_("For N-Well:")}
 };
-DIALOG erc_optionsdialog = {{50,75,191,564}, N_("ERC Options"), 0, 10, erc_optionsdialogitems};
+static DIALOG erc_optionsdialog = {{50,75,191,564}, N_("ERC Options"), 0, 10, erc_optionsdialogitems};
 
 /* special items for the "ERC Options" dialog: */
 #define DERO_PWELLEACH   3		/* PWell contact in each area (radio) */
@@ -839,7 +835,7 @@ void erc_optionsdlog(void)
 	REGISTER VARIABLE *var;
 
 	if (DiaInitDialog(&erc_optionsdialog) != 0) return;
-	var = getvalkey((INTBIG)erc_aid, VAID, VINTEGER, erc_optionskey);
+	var = getvalkey((INTBIG)erc_tool, VTOOL, VINTEGER, erc_optionskey);
 	if (var == NOVARIABLE) ercoptions = 0; else
 		ercoptions = var->addr;
 	oldoptions = ercoptions;
@@ -892,9 +888,9 @@ void erc_optionsdlog(void)
 			if (DiaGetControl(DERO_NWELLONCE) != 0) ercoptions |= NWELLCONONCE; else
 				ercoptions |= NWELLCONIGNORE;
 		if (ercoptions != oldoptions)
-			(void)setvalkey((INTBIG)erc_aid, VAID, erc_optionskey, ercoptions, VINTEGER);
+			(void)setvalkey((INTBIG)erc_tool, VTOOL, erc_optionskey, ercoptions, VINTEGER);
 	}
 	DiaDoneDialog();
 }
 
-#endif  /* ERCAID - at top */
+#endif  /* ERCTOOL - at top */
