@@ -33,7 +33,7 @@
  */
 
 #include "config.h"
-#if LOGEFFAID
+#if LOGEFFTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -43,7 +43,7 @@
 #include "usr.h"
 #include <math.h>
 
-/* the LOGICAL EFFORT aid table */
+/* the LOGICAL EFFORT tool table */
 static KEYWORD leopt[] =
 {
 	{"analyze-path",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -100,54 +100,54 @@ typedef struct Ilenode
 #define HIGHLIGHTCOMPONENTS 02
 #define DEFAULTSTATE        DISPLAYCAPACITANCE
 
-AIDENTRY *le_aid;						/* this tool */
-INTBIG    le_capacitance;				/* cached key for "LE_capacitance" */
-INTBIG    le_nodeeffort;				/* cached key for "LE_node_effort" */
-INTBIG    le_fanout;					/* cached key for "LE_fanout" */
-INTBIG    le_state;						/* cached key for "LE_state" */
-INTBIG    le_maximumstageeffort;		/* cached key for "LE_maximum_stage_effort" */
-LENODE   *le_lastlenode;				/* for propagating capacitance values */
-double    le_lastcapacitance;			/* for propagating capacitance values */
-LENODE   *le_firstlenode;				/* first in list of LE nodes in the path */
-LENODE   *le_lenodefree;				/* list of free LE nodes */
+       TOOL     *le_tool;					/* this tool */
+static INTBIG    le_capacitance;			/* cached key for "LE_capacitance" */
+static INTBIG    le_nodeeffort;				/* cached key for "LE_node_effort" */
+static INTBIG    le_fanout;					/* cached key for "LE_fanout" */
+static INTBIG    le_state;					/* cached key for "LE_state" */
+static INTBIG    le_maximumstageeffort;		/* cached key for "LE_maximum_stage_effort" */
+static LENODE   *le_lastlenode;				/* for propagating capacitance values */
+static double    le_lastcapacitance;		/* for propagating capacitance values */
+static LENODE   *le_firstlenode;			/* first in list of LE nodes in the path */
+static LENODE   *le_lenodefree;				/* list of free LE nodes */
 
 /* prototypes for local routines */
-void      le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inpi);
-LENODE   *le_alloclenode(void);
-void      le_analyzefacet(void);
-void      le_analyzepath(void);
-char     *le_describenode(LENODE *le);
-void      le_estimatedelay(NODEPROTO *facet);
-void      le_figurebranching(void);
-void      le_freealllenodes(void);
-void      le_freelenode(LENODE *le);
-void      le_gatherfacet(INTBIG show);
-void      le_gatherpath(INTBIG show);
-double    le_getcapacitance(ARCINST *ai);
-INTBIG    le_getgatetype(NODEINST *ni, INTBIG *inputs);
-double    le_getlogeffort(LENODE *le);
-double    le_getparasitics(LENODE *le);
-NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge);
-void      le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
-			double *onpath, double *offpath);
-void      le_setarccapacitance(ARCINST *ai, double c);
-void      le_setcapacitance(void);
-void      le_setlogicaleffort(void);
-void      le_setoptions(void);
-void      le_unwind(NODEINST *start, NODEINST *prev);
+static void      le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inpi);
+static LENODE   *le_alloclenode(void);
+static void      le_analyzefacet(void);
+static void      le_analyzepath(void);
+static char     *le_describenode(LENODE *le);
+static void      le_estimatedelay(NODEPROTO *facet);
+static void      le_figurebranching(void);
+static void      le_freealllenodes(void);
+static void      le_freelenode(LENODE *le);
+static void      le_gatherfacet(INTBIG show);
+static void      le_gatherpath(INTBIG show);
+static double    le_getcapacitance(ARCINST *ai);
+static INTBIG    le_getgatetype(NODEINST *ni, INTBIG *inputs);
+static double    le_getlogeffort(LENODE *le);
+static double    le_getparasitics(LENODE *le);
+static NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge);
+static void      le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
+					double *onpath, double *offpath);
+static void      le_setarccapacitance(ARCINST *ai, double c);
+static void      le_setcapacitance(void);
+static void      le_setlogicaleffort(void);
+static void      le_setoptions(void);
+static void      le_unwind(NODEINST *start, NODEINST *prev);
 
 /************************ CONTROL ***********************/
 
 /*
  * tool initialization
  */
-void le_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void le_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* ignore pass 3 initialization */
-	if (thisaid == 0) return;
+	if (thistool == 0) return;
 
 	/* ignore pass 2 initialization */
-	if (thisaid == NOAID)
+	if (thistool == NOTOOL)
 	{
 		le_capacitance = makekey("LE_capacitance");
 		le_nodeeffort = makekey("LE_node_effort");
@@ -159,12 +159,13 @@ void le_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		return;
 	}
 
-	/* copy aid pointer during pass 1 */
-	le_aid = thisaid;
+	/* copy tool pointer during pass 1 */
+	le_tool = thistool;
 }
 
 void le_done(void)
 {
+#ifdef DEBUGMEMORY
 	LENODE *le;
 
 	le_freealllenodes();
@@ -175,6 +176,7 @@ void le_done(void)
 		le_lenodefree = le_lenodefree->nextlenode;
 		efree((char *)le);
 	}
+#endif
 }
 
 /*
@@ -190,7 +192,7 @@ INTSML le_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputusage("tellaid logeffort (analyze-path | analyze-facet | set-options | set-capacitance | set-node-effort)");
+		ttyputusage("telltool logeffort (analyze-path | analyze-facet | set-options | set-capacitance | set-node-effort)");
 		return(0);
 	}
 
@@ -198,7 +200,7 @@ INTSML le_set(INTSML count, char *par[])
 
 	if (namesamen(pp, "analyze-facet", l) == 0 && l >= 9)
 	{
-		var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
+		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
 			state = var->addr;
 		le_gatherfacet(state & HIGHLIGHTCOMPONENTS);
@@ -209,7 +211,7 @@ INTSML le_set(INTSML count, char *par[])
 
 	if (namesamen(pp, "analyze-path", l) == 0 && l >= 9)
 	{
-		var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
+		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
 			state = var->addr;
 		le_gatherpath(state & HIGHLIGHTCOMPONENTS);
@@ -243,12 +245,12 @@ INTSML le_set(INTSML count, char *par[])
 		return(0);
 	}
 
-	ttyputbadusage("tellaid logeffort");
+	ttyputbadusage("telltool logeffort");
 	return(1);
 }
 
 /* Logical Effort Options dialog */
-DIALOGITEM le_leoptionsdialogitems[] =
+static DIALOGITEM le_leoptionsdialogitems[] =
 {
  /*  1 */ {0, {96,180,120,244}, BUTTON, N_("OK")},
  /*  2 */ {0, {96,12,120,76}, BUTTON, N_("Cancel")},
@@ -257,7 +259,7 @@ DIALOGITEM le_leoptionsdialogitems[] =
  /*  5 */ {0, {36,8,52,244}, CHECK, N_("Display intermediate capacitances")},
  /*  6 */ {0, {64,8,80,192}, CHECK, N_("Highlight components")}
 };
-DIALOG le_leoptionsdialog = {{75,75,206,329}, N_("Logical Effort Options"), 0, 6, le_leoptionsdialogitems};
+static DIALOG le_leoptionsdialog = {{75,75,206,329}, N_("Logical Effort Options"), 0, 6, le_leoptionsdialogitems};
 
 /* special items for the "Logical Effort Options" dialog: */
 #define DLEO_MAXGAIN    4		/* Maximum Stage Gain (edit text) */
@@ -276,12 +278,12 @@ void le_setoptions(void)
 	char line[50];
 
 	if (DiaInitDialog(&le_leoptionsdialog) != 0) return;
-	var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	if ((state&DISPLAYCAPACITANCE) != 0) DiaSetControl(DLEO_INTERCAP, 1);
 	if ((state&HIGHLIGHTCOMPONENTS) != 0) DiaSetControl(DLEO_HIGHCOMP, 1);
-	var = getvalkey((INTBIG)le_aid, VAID, VFLOAT, le_maximumstageeffort);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort);
 	if (var == NOVARIABLE) maxstageeffort = MAXSTAGEEFFORT; else
 		maxstageeffort = castfloat(var->addr);
 
@@ -303,24 +305,24 @@ void le_setoptions(void)
 		if (DiaGetControl(DLEO_INTERCAP) != 0) newstate |= DISPLAYCAPACITANCE;
 		if (DiaGetControl(DLEO_HIGHCOMP) != 0) newstate |= HIGHLIGHTCOMPONENTS;
 		if (newstate != state)
-			(void)setvalkey((INTBIG)le_aid, VAID, le_state, newstate, VINTEGER);
+			(void)setvalkey((INTBIG)le_tool, VTOOL, le_state, newstate, VINTEGER);
 		newmaxstageeffort = (float)atof(DiaGetText(DLEO_MAXGAIN));
 		if (newmaxstageeffort != maxstageeffort)
-			(void)setvalkey((INTBIG)le_aid, VAID, le_maximumstageeffort,
+			(void)setvalkey((INTBIG)le_tool, VTOOL, le_maximumstageeffort,
 				castint(newmaxstageeffort), VFLOAT);
 	}
 	DiaDoneDialog();
 }
 
 /* Logical Effort Capacitance dialog */
-DIALOGITEM le_capacitancedialogitems[] =
+static DIALOGITEM le_capacitancedialogitems[] =
 {
  /*  1 */ {0, {36,132,60,200}, BUTTON, N_("OK")},
  /*  2 */ {0, {36,8,60,76}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,100}, MESSAGE, N_("Capacitance:")},
  /*  4 */ {0, {8,108,24,200}, EDITTEXT, ""}
 };
-DIALOG le_capacitancedialog = {{75,75,146,286}, N_("Logical Effort Capacitance"), 0, 4, le_capacitancedialogitems};
+static DIALOG le_capacitancedialog = {{75,75,146,286}, N_("Logical Effort Capacitance"), 0, 4, le_capacitancedialogitems};
 
 /* special items for the "Logical Effort capacitance" dialog: */
 #define DLEC_CAPVALUE    4		/* Capacitance (edit text) */
@@ -336,7 +338,7 @@ void le_setcapacitance(void)
 	double c;
 	char line[50];
 
-	ai = (ARCINST *)askaid(us_aid, "get-arc");
+	ai = (ARCINST *)asktool(us_tool, "get-arc");
 	if (ai == NOARCINST)
 	{
 		ttyputerr(_("Select an arc first"));
@@ -375,14 +377,14 @@ void le_setcapacitance(void)
 }
 
 /* Logical Effort effort dialog */
-DIALOGITEM le_logeffortdialogitems[] =
+static DIALOGITEM le_logeffortdialogitems[] =
 {
  /*  1 */ {0, {40,128,64,192}, BUTTON, N_("OK")},
  /*  2 */ {0, {40,12,64,76}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,116}, MESSAGE, N_("Logical Effort:")},
  /*  4 */ {0, {8,128,24,192}, EDITTEXT, ""}
 };
-DIALOG le_logeffortdialog = {{75,75,149,281}, N_("Logical Effort"), 0, 4, le_logeffortdialogitems};
+static DIALOG le_logeffortdialog = {{75,75,149,281}, N_("Logical Effort"), 0, 4, le_logeffortdialogitems};
 
 /* special items for the "Logical Effort effort" dialog: */
 #define DLEE_EFFVALUE    4		/* Effort (edit text) */
@@ -400,7 +402,7 @@ void le_setlogicaleffort(void)
 	char line[50], *pt;
 	LENODE statle;
 
-	ni = (NODEINST *)askaid(us_aid, "get-node");
+	ni = (NODEINST *)asktool(us_tool, "get-node");
 	if (ni == NONODEINST)
 	{
 		ttyputerr(_("Select a node first"));
@@ -449,12 +451,12 @@ void le_setarccapacitance(ARCINST *ai, double c)
 		if (ai->end[0].ypos == ai->end[1].ypos)
 		{
 			/* horizontal arc: push text to top */
-			var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSUP;
+			TDSETPOS(var->textdescript, VTPOSUP);
 		}
 		if (ai->end[0].xpos == ai->end[1].xpos)
 		{
 			/* vertical arc: push text to right */
-			var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSRIGHT;
+			TDSETPOS(var->textdescript, VTPOSRIGHT);
 		}
 	}
 	endobjectchange((INTBIG)ai, VARCINST);
@@ -520,7 +522,7 @@ void le_analyzepath(void)
 	ttyputmsg(_("Minimum path delay is %g"), Dhat);
 
 	/* determine whether or not to set capacitance values */
-	var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	displaycapacitance = state & DISPLAYCAPACITANCE;
@@ -599,7 +601,7 @@ ttyputmsg("      Layer %s has %g x %g = %g", layername(ap->tech, ap->layer),
 		}
 
 		/* save the results */
-		nd = (NETDELAY *)emalloc(sizeof (NETDELAY), le_aid->cluster);
+		nd = (NETDELAY *)emalloc(sizeof (NETDELAY), le_tool->cluster);
 		if (nd == 0) break;
 		nd->pdenominator = (float)p_active->width / flambda;
 		nd->ndenominator = (float)n_active->width / flambda;
@@ -835,7 +837,7 @@ void le_gatherfacet(INTBIG show)
 		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
 			describenodeproto(np), (INTBIG)le->ni->geom);
 	}
-	(void)askaid(us_aid, "show-multiple", (INTBIG)returninfstr());
+	(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr());
 
 	/* display the connection sites */
 	arrowsize = lambdaoffacet(np) * 2;
@@ -847,9 +849,9 @@ void le_gatherfacet(INTBIG show)
 			if (ai->end[0].portarcinst == le->piin) which = 0; else which = 1;
 			x = ai->end[which].xpos;
 			y = ai->end[which].ypos;
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 		for(i=0; i<le->numoutputnodes; i++)
 		{
@@ -857,9 +859,9 @@ void le_gatherfacet(INTBIG show)
 			if (ai->end[0].portarcinst == le->outputports[i]) which = 0; else which = 1;
 			x = ai->end[which].xpos+arrowsize;
 			y = ai->end[which].ypos+arrowsize;
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 	}
 }
@@ -875,8 +877,8 @@ void le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inp
 	REGISTER INTBIG i;
 
 	/* add input node to list of outputs */
-	newoutputnodelist = (LENODE **)emalloc((out->numoutputnodes+1) * (sizeof (LENODE *)), le_aid->cluster);
-	newoutputportlist = (PORTARCINST **)emalloc((out->numoutputnodes+1) * (sizeof (PORTARCINST *)), le_aid->cluster);
+	newoutputnodelist = (LENODE **)emalloc((out->numoutputnodes+1) * (sizeof (LENODE *)), le_tool->cluster);
+	newoutputportlist = (PORTARCINST **)emalloc((out->numoutputnodes+1) * (sizeof (PORTARCINST *)), le_tool->cluster);
 	for(i=0; i<out->numoutputnodes; i++)
 	{
 		newoutputnodelist[i] = out->outputnodes[i];
@@ -894,8 +896,8 @@ void le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inp
 	out->numoutputnodes++;
 
 	/* add output node to list of inputs */
-	newinputnodelist = (LENODE **)emalloc((in->numinputnodes+1) * (sizeof (LENODE *)), le_aid->cluster);
-	newinputportlist = (PORTARCINST **)emalloc((in->numinputnodes+1) * (sizeof (PORTARCINST *)), le_aid->cluster);
+	newinputnodelist = (LENODE **)emalloc((in->numinputnodes+1) * (sizeof (LENODE *)), le_tool->cluster);
+	newinputportlist = (PORTARCINST **)emalloc((in->numinputnodes+1) * (sizeof (PORTARCINST *)), le_tool->cluster);
 	for(i=0; i<in->numinputnodes; i++)
 	{
 		newinputnodelist[i] = in->inputnodes[i];
@@ -923,7 +925,7 @@ void le_analyzefacet(void)
 	double h, needed, maxstageeffort;
 
 	/* determine maximum stage effort */
-	var = getvalkey((INTBIG)le_aid, VAID, VFLOAT, le_maximumstageeffort);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort);
 	if (var == NOVARIABLE) maxstageeffort = MAXSTAGEEFFORT; else
 		maxstageeffort = (double)castfloat(var->addr);
 
@@ -961,7 +963,7 @@ void le_analyzefacet(void)
 	}
 
 	/* determine whether or not to set capacitance values */
-	var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	displaycapacitance = state & DISPLAYCAPACITANCE;
@@ -1009,7 +1011,7 @@ void le_gatherpath(INTBIG show)
 	if (np == NONODEPROTO) return;
 
 	/* get all selected objects (must be 2 nodes) */
-	list = (GEOM **)askaid(us_aid, "get-all-objects");
+	list = (GEOM **)asktool(us_tool, "get-all-objects");
 	if (list[0] == NOGEOM || list[1] == NOGEOM || list[2] != NOGEOM)
 	{
 		ttyputerr(_("Select two objects at the ends of a path"));
@@ -1135,7 +1137,7 @@ void le_gatherpath(INTBIG show)
 	}
 
 	/* display the path between the nodes */
-	(void)askaid(us_aid, "clear");
+	(void)asktool(us_tool, "clear");
 	(void)initinfstr();
 	first = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1153,7 +1155,7 @@ void le_gatherpath(INTBIG show)
 		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
 			describenodeproto(np), (INTBIG)ai->geom);
 	}
-	(void)askaid(us_aid, "show-multiple", (INTBIG)returninfstr());
+	(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr());
 
 	arrowsize = lambdaoffacet(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
@@ -1164,9 +1166,9 @@ void le_gatherpath(INTBIG show)
 			if (ai->end[0].portarcinst == le->piin) which = 0; else which = 1;
 			x = ai->end[which].xpos;
 			y = ai->end[which].ypos;
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 		if (le->piout != NOPORTARCINST)
 		{
@@ -1174,9 +1176,9 @@ void le_gatherpath(INTBIG show)
 			if (ai->end[0].portarcinst == le->piout) which = 0; else which = 1;
 			x = ai->end[which].xpos+arrowsize;
 			y = ai->end[which].ypos+arrowsize;
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)askaid(us_aid, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 	}
 }
@@ -1240,7 +1242,7 @@ void le_unwind(NODEINST *start, NODEINST *prev)
 
 	/* add this node to the chain, if it can be analyzed */
 	le = NOLENODE;
-	func = nodefunction(start, 0);
+	func = nodefunction(start);
 	switch (func)
 	{
 		case NPPIN:
@@ -1377,7 +1379,7 @@ void le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
 	/* see if the other end of the arc is a terminal point */
 	if (ai->end[0].portarcinst == tpi) otherend = 1; else otherend = 0;
 	oni = ai->end[otherend].nodeinst;
-	func = nodefunction(oni, 0);
+	func = nodefunction(oni);
 	if (func != NPPIN && func != NPCONTACT && func != NPNODE && func != NPCONNECT)
 	{
 		/* end of this chain: add capacitance into one of the path accumulators */
@@ -1409,7 +1411,7 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 	/* determine the number of inputs to the gate */
 	*inputs = 0;
 	inputnegates = outputnegates = 0;
-	func = nodefunction(ni, 0);
+	func = nodefunction(ni);
 	inputport = "a";   outputport1 = outputport2 = "y";
 	if (func == NPTRANMOS || func == NPTRAPMOS)
 	{
@@ -1699,7 +1701,7 @@ LENODE *le_alloclenode(void)
 		le_lenodefree = le->nextlenode;
 	} else
 	{
-		le = (LENODE *)emalloc(sizeof (LENODE), le_aid->cluster);
+		le = (LENODE *)emalloc(sizeof (LENODE), le_tool->cluster);
 		if (le == 0) return(NOLENODE);
 	}
 	return(le);
@@ -1724,4 +1726,4 @@ void le_freelenode(LENODE *le)
 	le_lenodefree = le;
 }
 
-#endif  /* LOGEFFAID - at top */
+#endif  /* LOGEFFTOOL - at top */
