@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if PROJECTAID
+#if PROJECTTOOL
 
 #include "global.h"
 #include "projecttool.h"
@@ -93,7 +93,7 @@ typedef struct Ipuser
 	struct Ipuser *nextpuser;
 } PUSER;
 
-PUSER *proj_users = NOPUSER;
+static PUSER *proj_users = NOPUSER;
 
 /***** project file information *****/
 
@@ -111,76 +111,76 @@ typedef struct Iprojectfacet
 	struct Iprojectfacet *nextprojectfacet;
 } PROJECTFACET;
 
-PROJECTFACET *proj_firstprojectfacet = NOPROJECTFACET;
-PROJECTFACET *proj_projectfacetfree = NOPROJECTFACET;
+static PROJECTFACET *proj_firstprojectfacet = NOPROJECTFACET;
+static PROJECTFACET *proj_projectfacetfree = NOPROJECTFACET;
 
 /***** miscellaneous *****/
 
-AIDENTRY     *proj_aid;					/* this tool */
-char          proj_username[256];		/* current user's name */
-INTBIG        proj_lockedkey;			/* key for "PROJ_locked" */
-INTBIG        proj_pathkey;				/* key for "PROJ_path" */
-INTBIG        proj_userkey;				/* key for "PROJ_user" */
-INTSML        proj_active;				/* nonzero if the system is active */
-INTSML        proj_ignorechanges;		/* nonzero to ignore broadcast changes */
-AIDENTRY     *proj_source;				/* source of changes */
-INTBIG        proj_batchnumber;			/* ID number of this batch of changes */
-PUSER        *proj_userpos;				/* current user for dialog display */
-FILE         *proj_io;					/* channel to project file */
-INTBIG       *proj_saveaidstate = 0;	/* saved aid state information */
-INTBIG        proj_filetypeproj;		/* Project disk file descriptor */
-INTBIG        proj_filetypeprojusers;	/* Project users disk file descriptor */
+static TOOL         *proj_tool;					/* this tool */
+static char          proj_username[256];		/* current user's name */
+static INTBIG        proj_lockedkey;			/* key for "PROJ_locked" */
+static INTBIG        proj_pathkey;				/* key for "PROJ_path" */
+static INTBIG        proj_userkey;				/* key for "PROJ_user" */
+static INTSML        proj_active;				/* nonzero if the system is active */
+static INTSML        proj_ignorechanges;		/* nonzero to ignore broadcast changes */
+static TOOL         *proj_source;				/* source of changes */
+static INTBIG        proj_batchnumber;			/* ID number of this batch of changes */
+static PUSER        *proj_userpos;				/* current user for dialog display */
+static FILE         *proj_io;					/* channel to project file */
+static INTBIG       *proj_savetoolstate = 0;		/* saved tool state information */
+static INTBIG        proj_filetypeproj;			/* Project disk file descriptor */
+static INTBIG        proj_filetypeprojusers;	/* Project users disk file descriptor */
 
 /* prototypes for local routines */
-void          proj_addfacet(char *facetname);
-FCHECK       *proj_allocfcheck(void);
-PROJECTFACET *proj_allocprojectfacet(void);
-void          proj_buildproject(LIBRARY *lib);
-void          proj_checkin(char *facetname);
-void          proj_checkinmany(LIBRARY *lib);
-void          proj_checkout(char *facetname, INTSML showfacet);
-void          proj_deletefacet(char *facetname);
-void          proj_endwritingprojectfile(void);
-PROJECTFACET *proj_findfacet(NODEPROTO *np);
-void          proj_freefcheck(FCHECK *f);
-void          proj_freeprojectfacet(PROJECTFACET *pf);
-INTSML        proj_getcomments(PROJECTFACET *pf, char *direction);
-NODEPROTO    *proj_getfacet(PROJECTFACET *pf, LIBRARY *lib);
-void          proj_getoldversion(char *facetname);
-INTSML        proj_getprojinfo(LIBRARY *lib, char *path, char *projfile);
-INTSML        proj_getusername(INTSML newone, LIBRARY *lib);
-INTSML        proj_initusers(char **c);
-INTSML        proj_loadlist(LIBRARY *lib);
-INTSML        proj_lockprojfile(char *projectpath, char *projectfile);
-void          proj_marklocked(NODEPROTO *np, INTSML locked);
-char         *proj_nextuser(void);
-void          proj_queuecheck(NODEPROTO *facet);
-INTSML        proj_readprojectfile(char *pathname, char *filename);
-void          proj_restoretoolstate(void);
-void          proj_showlistdialog(LIBRARY *lib);
-INTSML        proj_startwritingprojectfile(char *pathname, char *filename);
-char         *proj_templibraryname(void);
-INTSML        proj_turnofftools(void);
-void          proj_unlockprojfile(char *projectpath, char *projectfile);
-void          proj_update(LIBRARY *lib);
-INTSML        proj_usenewestversion(NODEPROTO *oldnp, NODEPROTO *newnp);
-void          proj_validatelocks(LIBRARY *lib);
-char         *proj_wantpassword(INTSML mode, char *username);
-INTSML        proj_writefacet(NODEPROTO *np);
+static void          proj_addfacet(char *facetname);
+static FCHECK       *proj_allocfcheck(void);
+static PROJECTFACET *proj_allocprojectfacet(void);
+static void          proj_buildproject(LIBRARY *lib);
+static void          proj_checkin(char *facetname);
+static void          proj_checkinmany(LIBRARY *lib);
+static void          proj_checkout(char *facetname, INTSML showfacet);
+static void          proj_deletefacet(char *facetname);
+static void          proj_endwritingprojectfile(void);
+static PROJECTFACET *proj_findfacet(NODEPROTO *np);
+static void          proj_freefcheck(FCHECK *f);
+static void          proj_freeprojectfacet(PROJECTFACET *pf);
+static INTSML        proj_getcomments(PROJECTFACET *pf, char *direction);
+static NODEPROTO    *proj_getfacet(PROJECTFACET *pf, LIBRARY *lib);
+static void          proj_getoldversion(char *facetname);
+static INTSML        proj_getprojinfo(LIBRARY *lib, char *path, char *projfile);
+static INTSML        proj_getusername(INTSML newone, LIBRARY *lib);
+static INTSML        proj_initusers(char **c);
+static INTSML        proj_loadlist(LIBRARY *lib);
+static INTSML        proj_lockprojfile(char *projectpath, char *projectfile);
+static void          proj_marklocked(NODEPROTO *np, INTSML locked);
+static char         *proj_nextuser(void);
+static void          proj_queuecheck(NODEPROTO *facet);
+static INTSML        proj_readprojectfile(char *pathname, char *filename);
+static void          proj_restoretoolstate(void);
+static void          proj_showlistdialog(LIBRARY *lib);
+static INTSML        proj_startwritingprojectfile(char *pathname, char *filename);
+static char         *proj_templibraryname(void);
+static INTSML        proj_turnofftools(void);
+static void          proj_unlockprojfile(char *projectpath, char *projectfile);
+static void          proj_update(LIBRARY *lib);
+static INTSML        proj_usenewestversion(NODEPROTO *oldnp, NODEPROTO *newnp);
+static void          proj_validatelocks(LIBRARY *lib);
+static char         *proj_wantpassword(INTSML mode, char *username);
+static INTSML        proj_writefacet(NODEPROTO *np);
 
 /* prototypes for local routines that should be in the system */
-NODEPROTO    *copyrecursively(NODEPROTO *fromnp, LIBRARY *tolib);
-NODEPROTO    *copyskeleton(NODEPROTO *fromnp, LIBRARY *tolib);
+static NODEPROTO    *copyrecursively(NODEPROTO *fromnp, LIBRARY *tolib);
+static NODEPROTO    *copyskeleton(NODEPROTO *fromnp, LIBRARY *tolib);
 
 /************************ CONTROL ***********************/
 
-void proj_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void proj_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* ignore pass 3 initialization */
-	if (thisaid == 0) return;
+	if (thistool == 0) return;
 
 	/* miscellaneous initialization during pass 2 */
-	if (thisaid == NOAID)
+	if (thistool == NOTOOL)
 	{
 		proj_lockedkey = makekey("PROJ_locked");
 		proj_pathkey = makekey("PROJ_path");
@@ -193,12 +193,13 @@ void proj_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		return;
 	}
 
-	/* copy aid pointer during pass 1 */
-	proj_aid = thisaid;
+	/* copy tool pointer during pass 1 */
+	proj_tool = thistool;
 }
 
 void proj_done(void)
 {
+#ifdef DEBUGMEMORY
 	REGISTER FCHECK *f;
 
 	while (proj_firstfcheck != NOFCHECK)
@@ -213,15 +214,16 @@ void proj_done(void)
 		proj_fcheckfree = proj_fcheckfree->nextfcheck;
 		efree((char *)f);
 	}
-	if (proj_saveaidstate != 0)
-		efree((char *)proj_saveaidstate);
+	if (proj_savetoolstate != 0)
+		efree((char *)proj_savetoolstate);
+#endif
 }
 
 void proj_slice(void)
 {
 	REGISTER FCHECK *f, *nextf;
 	REGISTER NODEPROTO *np;
-	AIDENTRY *aid;
+	TOOL *tool;
 	REGISTER INTSML undoit;
 	REGISTER INTBIG lowbatch, highbatch, retval;
 
@@ -259,7 +261,7 @@ void proj_slice(void)
 			returninfstr());
 		for(;;)
 		{
-			retval = undoabatch(&aid);
+			retval = undoabatch(&tool);
 			if (retval == 0) break;
 			if (retval < 0) retval = -retval;
 			if (retval <= lowbatch) break;
@@ -395,9 +397,9 @@ INTSML proj_set(INTSML count, char *par[])
 	return(1);
 }
 
-void proj_startbatch(AIDENTRY *source, INTSML undoredo)
+void proj_startbatch(TOOL *source, INTSML undoredo)
 {
-	if (proj_ignorechanges != 0) proj_source = proj_aid; else
+	if (proj_ignorechanges != 0) proj_source = proj_tool; else
 		proj_source = source;
 	proj_batchnumber = getcurrentbatchnumber();
 }
@@ -405,26 +407,26 @@ void proj_startbatch(AIDENTRY *source, INTSML undoredo)
 void proj_modifynodeinst(NODEINST *ni, INTBIG olx, INTBIG oly, INTBIG ohx, INTBIG ohy,
 	INTSML orot, INTSML otran)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	proj_queuecheck(ni->parent);
 }
 
 void proj_modifyarcinst(ARCINST *ai, INTBIG oxA, INTBIG oyA, INTBIG oxB, INTBIG oyB,
 	INTBIG owid, INTBIG olen)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	proj_queuecheck(ai->parent);
 }
 
 void proj_modifyportproto(PORTPROTO *pp, NODEINST *oni, PORTPROTO *opp)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	proj_queuecheck(pp->parent);
 }
 
-void proj_modifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG old)
+void proj_modifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *old)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -435,7 +437,7 @@ void proj_modifydescript(INTBIG addr, INTBIG type, INTBIG key, INTBIG old)
 
 void proj_newobject(INTBIG addr, INTBIG type)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -446,7 +448,7 @@ void proj_newobject(INTBIG addr, INTBIG type)
 
 void proj_killobject(INTBIG addr, INTBIG type)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -457,7 +459,7 @@ void proj_killobject(INTBIG addr, INTBIG type)
 
 void proj_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -470,9 +472,9 @@ void proj_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
 }
 
 void proj_killvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG oldaddr, INTBIG oldtype,
-	INTBIG olddescript)
+	UINTBIG *olddescript)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -487,7 +489,7 @@ void proj_killvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG oldaddr, INT
 void proj_modifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype,
 	INTBIG aindex, INTBIG oldvalue)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -499,7 +501,7 @@ void proj_modifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype,
 
 void proj_insertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype, INTBIG index)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -512,7 +514,7 @@ void proj_insertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype, I
 void proj_deletevariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG vartype, INTBIG index,
 	INTBIG oldvalue)
 {
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	switch (type&VTYPE)
 	{
 		case VNODEINST:  proj_queuecheck(((NODEINST *)addr)->parent);   break;
@@ -527,7 +529,7 @@ void proj_readlibrary(LIBRARY *lib)
 	REGISTER NODEPROTO *np;
 
 	/* scan the library to see if any facets are locked */
-	if (proj_ignorechanges != 0 || proj_source == proj_aid) return;
+	if (proj_ignorechanges != 0 || proj_source == proj_tool) return;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (getvalkey((INTBIG)np, VNODEPROTO, VINTEGER, proj_lockedkey) != NOVARIABLE)
@@ -749,8 +751,8 @@ void proj_checkout(char *facetname, INTSML showfacet)
 										describenodeproto(oldvers)); else
 								{
 									/* update record for the facet */
-									(void)reallocstring(&pf->owner, proj_username, proj_aid->cluster);
-									(void)reallocstring(&pf->lastowner, "", proj_aid->cluster);
+									(void)reallocstring(&pf->owner, proj_username, proj_tool->cluster);
+									(void)reallocstring(&pf->lastowner, "", proj_tool->cluster);
 									proj_marklocked(newvers, 0);
 									worked = 1;
 								}
@@ -883,7 +885,7 @@ void proj_checkout(char *facetname, INTSML showfacet)
 }
 
 /* Project Old Version */
-DIALOGITEM proj_oldversdialogitems[] =
+static DIALOGITEM proj_oldversdialogitems[] =
 {
  /*  1 */ {0, {176,224,200,288}, BUTTON, N_("OK")},
  /*  2 */ {0, {176,16,200,80}, BUTTON, N_("Cancel")},
@@ -891,7 +893,7 @@ DIALOGITEM proj_oldversdialogitems[] =
  /*  4 */ {0, {28,12,166,312}, SCROLL, ""},
  /*  5 */ {0, {4,140,20,312}, MESSAGE, ""}
 };
-DIALOG proj_oldversdialog = {{108,75,318,396}, N_("Get Old Version of Facet"), 0, 5, proj_oldversdialogitems};
+static DIALOG proj_oldversdialog = {{108,75,318,396}, N_("Get Old Version of Facet"), 0, 5, proj_oldversdialogitems};
 
 /* special items for the "get old version" dialog: */
 #define DPRV_FACETLIST  4		/* Facet list (scroll) */
@@ -1264,13 +1266,13 @@ void proj_addfacet(char *facetname)
 					{
 						strcpy(libname, projectfile);
 						libname[strlen(libname)-5] = 0;
-						(void)allocstring(&pf->libname, libname, proj_aid->cluster);
-						(void)allocstring(&pf->cellname, np->cell->cellname, proj_aid->cluster);
+						(void)allocstring(&pf->libname, libname, proj_tool->cluster);
+						(void)allocstring(&pf->cellname, np->cell->cellname, proj_tool->cluster);
 						pf->cellview = np->cellview;
 						pf->cellversion = np->version;
-						(void)allocstring(&pf->owner, "", proj_aid->cluster);
-						(void)allocstring(&pf->lastowner, proj_username, proj_aid->cluster);
-						(void)allocstring(&pf->comment, _("Initial checkin"), proj_aid->cluster);
+						(void)allocstring(&pf->owner, "", proj_tool->cluster);
+						(void)allocstring(&pf->lastowner, proj_username, proj_tool->cluster);
+						(void)allocstring(&pf->comment, _("Initial checkin"), proj_tool->cluster);
 
 						/* link it in */
 						pf->nextprojectfacet = NOPROJECTFACET;
@@ -1422,7 +1424,7 @@ void proj_deletefacet(char *facetname)
 /************************ USER DATABASE ***********************/
 
 /* Project User */
-DIALOGITEM proj_usersdialogitems[] =
+static DIALOGITEM proj_usersdialogitems[] =
 {
  /*  1 */ {0, {28,184,52,312}, BUTTON, N_("Select User")},
  /*  2 */ {0, {188,212,212,276}, BUTTON, N_("Cancel")},
@@ -1432,7 +1434,7 @@ DIALOGITEM proj_usersdialogitems[] =
  /*  6 */ {0, {64,184,88,312}, BUTTON, N_("Change Password")},
  /*  7 */ {0, {100,184,124,312}, BUTTON, N_("New User")}
 };
-DIALOG proj_usersdialog = {{50,75,279,398}, N_("User Name"), 0, 7, proj_usersdialogitems};
+static DIALOG proj_usersdialog = {{50,75,279,398}, N_("User Name"), 0, 7, proj_usersdialogitems};
 
 /* special items for the "User selection" dialog: */
 #define DPRU_USERLIST  3		/* User list (scroll) */
@@ -1476,10 +1478,10 @@ INTSML proj_getusername(INTSML newone, LIBRARY *lib)
 				break;
 			}
 			*pt++ = 0;
-			pu = (PUSER *)emalloc(sizeof (PUSER), proj_aid->cluster);
+			pu = (PUSER *)emalloc(sizeof (PUSER), proj_tool->cluster);
 			if (pu == 0) break;
-			(void)allocstring(&pu->username, userline, proj_aid->cluster);
-			(void)allocstring(&pu->userpassword, pt, proj_aid->cluster);
+			(void)allocstring(&pu->username, userline, proj_tool->cluster);
+			(void)allocstring(&pu->userpassword, pt, proj_tool->cluster);
 			pu->nextpuser = NOPUSER;
 			if (proj_users == NOPUSER) proj_users = lastpu = pu; else
 				lastpu->nextpuser = pu;
@@ -1593,7 +1595,7 @@ INTSML proj_getusername(INTSML newone, LIBRARY *lib)
 				ttyputerr(_("Failed to type password the same way twice"));
 				continue;
 			}
-			reallocstring(&pu->userpassword, pwdline, proj_aid->cluster);
+			reallocstring(&pu->userpassword, pwdline, proj_tool->cluster);
 			writeback = 1;
 			continue;
 		}
@@ -1611,10 +1613,10 @@ INTSML proj_getusername(INTSML newone, LIBRARY *lib)
 				continue;
 			}
 
-			pu = (PUSER *)emalloc(sizeof (PUSER), proj_aid->cluster);
+			pu = (PUSER *)emalloc(sizeof (PUSER), proj_tool->cluster);
 			if (pu == 0) continue;
-			(void)allocstring(&pu->username, userline, proj_aid->cluster);
-			(void)allocstring(&pu->userpassword, pwdline, proj_aid->cluster);
+			(void)allocstring(&pu->username, userline, proj_tool->cluster);
+			(void)allocstring(&pu->userpassword, pwdline, proj_tool->cluster);
 			pu->nextpuser = proj_users;
 			proj_users = pu;
 			DiaLoadTextDialog(DPRU_USERLIST, proj_initusers, proj_nextuser,
@@ -1662,14 +1664,14 @@ INTSML proj_getusername(INTSML newone, LIBRARY *lib)
 }
 
 /* Project Password */
-DIALOGITEM proj_passworddialogitems[] =
+static DIALOGITEM proj_passworddialogitems[] =
 {
  /*  1 */ {0, {72,12,96,76}, BUTTON, N_("OK")},
  /*  2 */ {0, {72,132,96,196}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {12,8,28,205}, MESSAGE, N_("Password for")},
  /*  4 */ {0, {40,48,56,165}, EDITTEXT, ""}
 };
-DIALOG proj_passworddialog = {{298,75,404,292}, N_("User / Password"), 0, 4, proj_passworddialogitems};
+static DIALOG proj_passworddialog = {{298,75,404,292}, N_("User / Password"), 0, 4, proj_passworddialogitems};
 
 /* special items for the "Password prompt" dialog: */
 #define DPRP_USERNAME  3		/* User name (stat text) */
@@ -1795,8 +1797,8 @@ void proj_checkinmany(LIBRARY *lib)
 							if (proj_writefacet(np) != 0)
 								ttyputerr(_("Error writing facet %s"), describenodeproto(np)); else
 							{
-								(void)reallocstring(&pf->owner, "", proj_aid->cluster);
-								(void)reallocstring(&pf->lastowner, proj_username, proj_aid->cluster);
+								(void)reallocstring(&pf->owner, "", proj_tool->cluster);
+								(void)reallocstring(&pf->lastowner, proj_username, proj_tool->cluster);
 								pf->cellversion = np->version;
 								proj_marklocked(np, 1);
 								ttyputmsg(_("Facet %s checked in"), describenodeproto(np));
@@ -1860,7 +1862,7 @@ INTSML proj_getprojinfo(LIBRARY *lib, char *path, char *projfile)
 }
 
 /* Project List */
-DIALOGITEM proj_listdialogitems[] =
+static DIALOGITEM proj_listdialogitems[] =
 {
  /*  1 */ {0, {204,312,228,376}, BUTTON, N_("Done")},
  /*  2 */ {0, {4,4,196,376}, SCROLL, ""},
@@ -1871,7 +1873,7 @@ DIALOGITEM proj_listdialogitems[] =
  /*  7 */ {0, {204,8,228,108}, BUTTON, N_("Check It In")},
  /*  8 */ {0, {204,232,228,296}, BUTTON, N_("Update")}
 };
-DIALOG proj_listdialog = {{50,75,383,462}, N_("Project Management"), 0, 8, proj_listdialogitems};
+static DIALOG proj_listdialog = {{50,75,383,462}, N_("Project Management"), 0, 8, proj_listdialogitems};
 
 /* special items for the "Project list" dialog: */
 #define DPRL_PROJLIST  2		/* Project list (scroll) */
@@ -2038,10 +2040,10 @@ INTSML proj_loadlist(LIBRARY *lib)
 		/* describe this project facet */
 		if (pf->cellview == el_unknownview)
 		{
-			sprintf(line, "%s;%d", pf->cellname, pf->cellversion);
+			sprintf(line, "%s;%ld", pf->cellname, pf->cellversion);
 		} else
 		{
-			sprintf(line, "%s{%s};%d", pf->cellname, pf->cellview->sviewname,
+			sprintf(line, "%s{%s};%ld", pf->cellname, pf->cellview->sviewname,
 				pf->cellversion);
 		}
 		if (*pf->owner == 0)
@@ -2089,14 +2091,14 @@ INTSML proj_loadlist(LIBRARY *lib)
 }
 
 /* Project Comments */
-DIALOGITEM proj_commentsdialogitems[] =
+static DIALOGITEM proj_commentsdialogitems[] =
 {
  /*  1 */ {0, {104,244,128,308}, BUTTON, N_("OK")},
  /*  2 */ {0, {104,48,128,112}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {4,8,20,363}, MESSAGE, N_("Reason for checking out facet")},
  /*  4 */ {0, {28,12,92,358}, EDITTEXT, ""}
 };
-DIALOG proj_commentsdialog = {{108,75,248,447}, N_("Project Comments"), 0, 4, proj_commentsdialogitems};
+static DIALOG proj_commentsdialog = {{108,75,248,447}, N_("Project Comments"), 0, 4, proj_commentsdialogitems};
 
 /* special items for the "Project list" dialog: */
 #define DPRC_COMMENT_L  3		/* Comment label (stat text) */
@@ -2121,7 +2123,7 @@ INTSML proj_getcomments(PROJECTFACET *pf, char *direction)
 		if (itemHit == CANCEL || itemHit == OK) break;
 	}
 	if (itemHit == OK)
-		(void)reallocstring(&pf->comment, DiaGetText(DPRC_COMMENT), proj_aid->cluster);
+		(void)reallocstring(&pf->comment, DiaGetText(DPRC_COMMENT), proj_tool->cluster);
 	DiaDoneDialog();
 	if (itemHit == CANCEL) return(1);
 	return(0);
@@ -2184,7 +2186,7 @@ INTSML proj_readprojectfile(char *pathname, char *filename)
 			break;
 		}
 		*pt++ = 0;
-		(void)allocstring(&pf->libname, start, proj_aid->cluster);
+		(void)allocstring(&pf->libname, start, proj_tool->cluster);
 
 		/* get cell name */
 		for(start = pt; *pt != 0; pt++) if (*pt == ':') break;
@@ -2195,7 +2197,7 @@ INTSML proj_readprojectfile(char *pathname, char *filename)
 			break;
 		}
 		*pt++ = 0;
-		(void)allocstring(&pf->cellname, start, proj_aid->cluster);
+		(void)allocstring(&pf->cellname, start, proj_tool->cluster);
 
 		/* get version */
 		pf->cellversion = atoi(pt);
@@ -2230,7 +2232,7 @@ INTSML proj_readprojectfile(char *pathname, char *filename)
 			break;
 		}
 		*pt++ = 0;
-		(void)allocstring(&pf->owner, start, proj_aid->cluster);
+		(void)allocstring(&pf->owner, start, proj_tool->cluster);
 
 		/* get last owner */
 		for(start = pt; *pt != 0; pt++) if (*pt == ':') break;
@@ -2241,10 +2243,10 @@ INTSML proj_readprojectfile(char *pathname, char *filename)
 			break;
 		}
 		*pt++ = 0;
-		(void)allocstring(&pf->lastowner, start, proj_aid->cluster);
+		(void)allocstring(&pf->lastowner, start, proj_tool->cluster);
 
 		/* get comments */
-		(void)allocstring(&pf->comment, pt, proj_aid->cluster);
+		(void)allocstring(&pf->comment, pt, proj_tool->cluster);
 
 		/* check for duplication */
 		for(opf = proj_firstprojectfacet; opf != NOPROJECTFACET; opf = opf->nextprojectfacet)
@@ -2303,7 +2305,7 @@ PROJECTFACET *proj_allocprojectfacet(void)
 		proj_projectfacetfree = proj_projectfacetfree->nextprojectfacet;
 	} else
 	{
-		pf = (PROJECTFACET *)emalloc(sizeof (PROJECTFACET), proj_aid->cluster);
+		pf = (PROJECTFACET *)emalloc(sizeof (PROJECTFACET), proj_tool->cluster);
 		if (pf == 0) return(0);
 	}
 	return(pf);
@@ -2450,7 +2452,7 @@ FCHECK *proj_allocfcheck(void)
 
 	if (proj_fcheckfree == NOFCHECK)
 	{
-		f = (FCHECK *)emalloc((sizeof (FCHECK)), proj_aid->cluster);
+		f = (FCHECK *)emalloc((sizeof (FCHECK)), proj_tool->cluster);
 		if (f == 0) return(NOFCHECK);
 	} else
 	{
@@ -2487,7 +2489,7 @@ NODEPROTO *proj_getfacet(PROJECTFACET *pf, LIBRARY *lib)
 		ttyputerr(_("Cannot find project info on library %s"), lib->libname);
 		return(NONODEPROTO);
 	}
-	sprintf(facetlibname, "%d-%s.elib", pf->cellversion, pf->cellview->viewname);
+	sprintf(facetlibname, "%ld-%s.elib", pf->cellversion, pf->cellview->viewname);
 	facetprojfile[strlen(facetprojfile)-5] = 0;
 	strcat(facetlibpath, facetprojfile);
 	sep[0] = DIRSEP;   sep[1] = 0;
@@ -2507,9 +2509,9 @@ NODEPROTO *proj_getfacet(PROJECTFACET *pf, LIBRARY *lib)
 		proj_restoretoolstate();
 		return(NONODEPROTO);
 	}
-	oldverbose = askaid(io_aid, "verbose", 0);
-	ret = askaid(io_aid, "read", (INTBIG)flib, (INTBIG)"binary");
-	(void)askaid(io_aid, "verbose", oldverbose);
+	oldverbose = asktool(io_tool, "verbose", 0);
+	ret = asktool(io_tool, "read", (INTBIG)flib, (INTBIG)"binary");
+	(void)asktool(io_tool, "verbose", oldverbose);
 	if (ret != 0)
 	{
 		ttyputerr(_("Cannot read library %s"), facetlibpath);
@@ -2542,7 +2544,7 @@ NODEPROTO *proj_getfacet(PROJECTFACET *pf, LIBRARY *lib)
 	(*el_curconstraint->solve)(newnp);
 
 	/* must do this explicitly because the library kill flushes change batches */
-	/* (void)askaid(net_aid, "re-number", (INTBIG)newnp); */
+	/* (void)asktool(net_tool, "re-number", (INTBIG)newnp); */
 
 	/* kill the library */
 	killlibrary(flib);
@@ -2670,8 +2672,8 @@ INTSML proj_writefacet(NODEPROTO *np)
 	flib->curnodeproto = npcopy;
 	flib->userbits |= READFROMDISK;
 	makeoptionstemporary(flib);
-	retval = askaid(io_aid, "write", (INTBIG)flib, (INTBIG)"binary");
-	restoreoptionstate();
+	retval = asktool(io_tool, "write", (INTBIG)flib, (INTBIG)"binary");
+	restoreoptionstate(flib);
 	if (retval != 0)
 	{
 		ttyputerr(_("Could not save library with %s in it"), describenodeproto(np));
@@ -2709,20 +2711,20 @@ char *proj_templibraryname(void)
 INTSML proj_turnofftools(void)
 {
 	REGISTER INTSML i;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 
 	/* turn off all tools for this operation */
-	if (proj_saveaidstate == 0)
+	if (proj_savetoolstate == 0)
 	{
-		proj_saveaidstate = (INTBIG *)emalloc(el_maxaid * SIZEOFINTBIG, el_tempcluster);
-		if (proj_saveaidstate == 0) return(1);
+		proj_savetoolstate = (INTBIG *)emalloc(el_maxtools * SIZEOFINTBIG, el_tempcluster);
+		if (proj_savetoolstate == 0) return(1);
 	}
-	for(i=0; i<el_maxaid; i++)
+	for(i=0; i<el_maxtools; i++)
 	{
-		aid = &el_aids[i];
-		proj_saveaidstate[i] = aid->aidstate;
-		if (aid == us_aid || aid == proj_aid || aid == net_aid) continue;
-		aid->aidstate &= ~AIDON;
+		tool = &el_tools[i];
+		proj_savetoolstate[i] = tool->toolstate;
+		if (tool == us_tool || tool == proj_tool || tool == net_tool) continue;
+		tool->toolstate &= ~TOOLON;
 	}
 	proj_ignorechanges = 1;
 	return(0);
@@ -2735,9 +2737,9 @@ void proj_restoretoolstate(void)
 {
 	REGISTER INTSML i;
 
-	if (proj_saveaidstate == 0) return;
-	for(i=0; i<el_maxaid; i++)
-		el_aids[i].aidstate = proj_saveaidstate[i];
+	if (proj_savetoolstate == 0) return;
+	for(i=0; i<el_maxtools; i++)
+		el_tools[i].toolstate = proj_savetoolstate[i];
 	proj_ignorechanges = 0;
 }
 
@@ -2806,7 +2808,7 @@ NODEPROTO *copyskeleton(NODEPROTO *fromnp, LIBRARY *tolib)
 	INTBIG newx, newy;
 	XARRAY trans, localtrans, ntrans;
 	REGISTER NODEPROTO *np;
-	REGISTER PORTPROTO *pp, *rpp, *newpp;
+	REGISTER PORTPROTO *pp, *rpp;
 	REGISTER NODEINST *ni, *newni;
 
 	/* cannot skeletonize text-only views */
@@ -2858,7 +2860,7 @@ NODEPROTO *copyskeleton(NODEPROTO *fromnp, LIBRARY *tolib)
 		endobjectchange((INTBIG)newni, VNODEINST);
 
 		/* export the port from the node */
-		newpp = newportproto(np, newni, rpp, pp->protoname);
+		(void)newportproto(np, newni, rpp, pp->protoname);
 	}
 
 	/* make sure facet is the same size */
@@ -2882,4 +2884,4 @@ NODEPROTO *copyskeleton(NODEPROTO *fromnp, LIBRARY *tolib)
 	return(np);
 }
 
-#endif  /* PROJECTAID - at top */
+#endif  /* PROJECTTOOL - at top */
