@@ -30,13 +30,13 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "planmos.h"
 
-/* the PLA aid table */
+/* the PLA tool table */
 static KEYWORD planmosonoffopt[] =
 {
 	{"on",          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -96,16 +96,16 @@ static KEYWORD plaopt[] =
 COMCOMP pla_plap = {plaopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Select a PLA generator to use"), 0};
 
-AIDENTRY *pla_aid;				/* the PLA aid object */
+TOOL     *pla_tool;				/* the PLA tool object */
 INTBIG    pla_lam;				/* Feature size in internal units */
 INTBIG    pla_filetypeplatab;	/* PLA table disk file descriptor */
 
 /* PLA access routine called from electric user interface */
-void pla_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void pla_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* only initialize during pass 1 */
-	if (thisaid == NOAID || thisaid == 0) return;
-	pla_aid = thisaid;
+	if (thistool == NOTOOL || thistool == 0) return;
+	pla_tool = thistool;
 
 	/* initialize the nMOS PLA generator */
 	pla_fin = NULL;
@@ -187,12 +187,12 @@ INTSML pla_set(INTSML count, char *par[])
 			plac_p_generate();
 			return(0);
 		}
-		ttyputbadusage("tellaid pla cmos");
+		ttyputbadusage("telltool pla cmos");
 		return(1);
 	}
 
 	/* Invalid control to the PLA generator.  Print a small summary */
-	ttyputbadusage("tellaid pla");
+	ttyputbadusage("telltool pla");
 	return(1);
 }
 
@@ -202,15 +202,15 @@ void pla_slice(void)
 	{
 		ttyputerr(_("nMOS PLA '%s' is incompletely defined"), pla_name);
 		if (pla_fin != NULL) xclose(pla_fin);
-		aidturnoff(pla_aid, 0);
+		toolturnoff(pla_tool, 0);
 		setactivity(_("Incomplete nMOS PLA generated"));
 		return;
 	}
 	xclose(pla_fin);
-	aidturnoff(pla_aid, 0);
+	toolturnoff(pla_tool, 0);
 	setactivity(_("nMOS PLA generated"));
 }
 
 void pla_done(void) {}
 
-#endif  /* PLCAID - at stop */
+#endif  /* PLATOOL - at stop */
