@@ -29,17 +29,18 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "placmos.h"
 
-NODEINST *plac_decode_bufs(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, NODEPROTO*, INTBIG,
-	NODEINST**, INTBIG);
-void plac_dec_exp(NODEPROTO*, NODEINST*, NODEPROTO*);
-INTSML plac_decode_route(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*,
-	NODEINST*, INTBIG);
+/* prototypes for local routines */
+static NODEINST *plac_decode_bufs(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, NODEPROTO*, INTBIG,
+					NODEINST**, INTBIG);
+static void plac_dec_exp(NODEPROTO*, NODEINST*, NODEPROTO*);
+static INTSML plac_decode_route(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*,
+					NODEINST*, INTBIG);
 
 NODEPROTO *plac_decode_gen(LIBRARY *library, NODEPROTO *pmos_np, NODEPROTO *nmos_np,
 	char *facet_name, INTBIG INPUTS)
@@ -435,4 +436,4 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	return(0);
 }
 
-#endif  /* PLCAID - at top */
+#endif  /* PLATOOL - at top */
