@@ -29,19 +29,19 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "placmos.h"
 
 /* prototypes for local routines */
-INTSML plac_pmos_init_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
-INTSML plac_pmos_init_rows(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
-INTSML plac_pwr_strap(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-INTSML plac_pmos_make_one(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
-INTSML plac_pmos_complete_row(INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
-INTSML plac_pmos_finish_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
+static INTSML plac_pmos_init_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static INTSML plac_pmos_init_rows(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static INTSML plac_pwr_strap(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static INTSML plac_pmos_make_one(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
+static INTSML plac_pmos_complete_row(INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
+static INTSML plac_pmos_finish_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
 
 NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 {
@@ -418,4 +418,4 @@ INTSML plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offse
 	return(0);
 }
 
-#endif  /* PLAAID - at top */
+#endif  /* PLATOOL - at top */
