@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
@@ -342,4 +342,4 @@ NODEPROTO *plac_make_pla(LIBRARY *library, NODEPROTO *decode_np, NODEPROTO *or_p
 	return(pla_np);
 }
 
-#endif /* PLAAID - at top */
+#endif /* PLATOOL - at top */
