@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "placmos.h"
@@ -38,7 +38,7 @@
 #include "usr.h"
 
 /* prototypes for local routines */
-INTBIG plac_init_bits(void);
+static INTBIG plac_init_bits(void);
 
 NODEINST *plac_make_Pin(NODEPROTO *facet, INTBIG X, INTBIG Y, INTBIG size, char *pin_type)
 {
@@ -82,7 +82,7 @@ UCITEM *plac_newUCITEM(void)
 {
 	UCITEM *temp;
 
-	temp = (UCITEM *)emalloc(sizeof (UCITEM), pla_aid->cluster);
+	temp = (UCITEM *)emalloc(sizeof (UCITEM), pla_tool->cluster);
 	temp->nodeinst = NONODEINST;
 	temp->rightitem = NOUCITEM;
 	temp->bottomitem = NOUCITEM;
@@ -152,4 +152,4 @@ NODEINST *plac_make_instance(NODEPROTO *pla_facet, NODEPROTO *Inst_proto, INTBIG
 	return(node_inst);
 }
 
-#endif  /* PLAAID - at top */
+#endif  /* PLATOOL - at top */
