@@ -30,15 +30,15 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "planmos.h"
 
 /* prototypes for local routines */
-NODEPROTO *pla_nmos_InPullup(void);
-NODEPROTO *pla_nmos_OutPullup(void);
+static NODEPROTO *pla_nmos_InPullup(void);
+static NODEPROTO *pla_nmos_OutPullup(void);
 
 PORTPROTO *pla_FindPort(NODEINST *node, INTBIG x, INTBIG y)
 {
@@ -46,7 +46,7 @@ PORTPROTO *pla_FindPort(NODEINST *node, INTBIG x, INTBIG y)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, pla_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, pla_tool->cluster);
 	if (node != NONODEINST)
 	{
 		for(pp = node->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -897,4 +897,4 @@ NODEPROTO *pla_nmos_Pullup(void)
 	return(pu);
 }
 
-#endif /* PLAAID - at top */
+#endif /* PLATOOL - at top */
