@@ -35,22 +35,22 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "planmos.h"
 
 /* prototypes for local routines */
-PROGTRANS *pla_FindPColTrans(INTSML, PROGTRANS*);
-FACETIST *pla_PlaceInputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-FACETIST *pla_PlaceOutputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-FACETIST *pla_PlacePullupsonAND(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-FACETIST *pla_PlacePullupsonOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
-PROGTRANS *pla_Program(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-PROGTRANS *pla_ProgramAND(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-PROGTRANS *pla_ProgramOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML pla_ProgramPLA(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static PROGTRANS *pla_FindPColTrans(INTSML, PROGTRANS*);
+static FACETIST  *pla_PlaceInputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static FACETIST  *pla_PlaceOutputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static FACETIST  *pla_PlacePullupsonAND(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static FACETIST  *pla_PlacePullupsonOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static PROGTRANS *pla_Program(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static PROGTRANS *pla_ProgramAND(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static PROGTRANS *pla_ProgramOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static INTSML     pla_ProgramPLA(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 
 /*
  * Make the PLA.  First define all the primitives and then
@@ -71,7 +71,7 @@ INTSML pla_Make(void)
 	pla_fin = xopen(pla_infile, pla_filetypeplatab, "", &filename);
 	if (pla_fin == NULL)
 	{
-		ttyputerr(_("File '%s' not found, use 'tellaid pla nmos file FILE'"), pla_infile);
+		ttyputerr(_("File '%s' not found, use 'telltool pla nmos file FILE'"), pla_infile);
 		return(ERRORRET);
 	}
 	if (pla_verbose == ON)
@@ -179,9 +179,9 @@ INTSML pla_Make(void)
 	/* Create the pla prototype with these dimensions.
 	 * First find a name for the PLA.
 	 */
-	while(1)
+	for(;;)
 	{
-		if (pla_ProcessFlags() == ERRORRET) return(OK);
+		if (pla_ProcessFlags() == ERRORRET) break;
 
 		pla_facet = NONODEPROTO;
 		pla_alv = pla_atg = pla_arg = pla_otv = NOVDDGND;
@@ -189,17 +189,17 @@ INTSML pla_Make(void)
 
 		if (pla_inputs == 0)
 		{
-			ttyputerr(_("Use 'tellaid pla nmos inputs VALUE' to set inputs"));
+			ttyputerr(_("Use 'telltool pla nmos inputs VALUE' to set inputs"));
 			return(ERRORRET);
 		}
 		if (pla_outputs == 0)
 		{
-			ttyputerr(_("Use 'tellaid pla nmos outputs VALUE' to set outputs"));
+			ttyputerr(_("Use 'telltool pla nmos outputs VALUE' to set outputs"));
 			return(ERRORRET);
 		}
 		if (pla_pterms == 0)
 		{
-			ttyputerr(_("Use 'tellaid pla nmos pterms VALUE' to set prod. terms"));
+			ttyputerr(_("Use 'telltool pla nmos pterms VALUE' to set prod. terms"));
 			return(ERRORRET);
 		}
 		if (namesame(pla_name, DEFNAME) == 0)
@@ -222,6 +222,7 @@ INTSML pla_Make(void)
 		while((pos = pla_GetKeyWord(keyword)) != ERRORRET)
 			if (pos == END) break;
 	}
+	return(OK);
 }
 
 /*
@@ -281,7 +282,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 	for(i = 1; i <= pla_inputs; i++)
 	{
 		if (pla_verbose == ON) ttyputmsg(M_("Placing input facet %d"), i);
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
+		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
 		if (ptr == NOFACETIST)
 		{
 			ttyputerr(_("PlaceInputs: ran out of storage space. i=%d"), i);
@@ -358,7 +359,7 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 	{
 		if (pla_verbose == ON) ttyputmsg(M_("Placing output facet %d"), o);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
+		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
 		if (ptr == NOFACETIST)
 		{
 			ttyputerr(_("PlaceOutputs: ran out of storage space. o=%d"), o);
@@ -442,7 +443,7 @@ FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *p
 		if (pla_verbose == ON)
 			ttyputmsg(M_("Placing pullup facet %d in AND-plane"), p);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
+		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
 		if (ptr == NOFACETIST)
 		{
 			ttyputerr(_("PlacePullupsonAND: ran out of storage space, p=%d"), p);
@@ -510,7 +511,7 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 		if (pla_verbose == ON)
 			ttyputmsg(M_("Placing pullup facet %d in OR-plane"), i);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
+		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
 		if (ptr == NOFACETIST)
 		{
 			ttyputerr(_("PlacePullupsonOR: ran out of storage space, i=%d"), i);
@@ -582,7 +583,7 @@ PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *
 	 * Now instance the pla_prog_proto at the coordinates computed above
 	 * in the calculated orientation
 	 */
-	trans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_aid->cluster);
+	trans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_tool->cluster);
 	if (trans == NOPROGTRANS)
 	{
 		ttyputerr(_("Program: ran out of storage for PROGTRANS"));
@@ -873,7 +874,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 		 * Instance a progtrans structure and place the connect facet in it
 		 * so that the connections can be made more uniformly
 		 */
-		CurTrans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_aid->cluster);
+		CurTrans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_tool->cluster);
 		if (CurTrans == NOPROGTRANS)
 		{
 			ttyputnomemory();
@@ -1014,4 +1015,4 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 	return(OK);
 }
 
-#endif  /* PLAAID - at top */
+#endif  /* PLATOOL - at top */
