@@ -35,28 +35,28 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
 #include "planmos.h"
 
 /* prototypes for local routines */
-void pla_CHfromPuAND(INTBIG, FACETIST*, NODEPROTO*);
-void pla_CVfromInput(INTBIG, INTBIG, FACETIST*, NODEPROTO*);
-void pla_CVfromOutput(FACETIST*, FACETIST*, NODEPROTO*);
-INTSML pla_ConnectFirstFacet(INTBIG, FACETIST*, NODEPROTO*);
-void pla_ConnectOnMetal(INTBIG, VDDGND*, char*, NODEPROTO*);
-void pla_ConnectThruFacets(INTBIG, VDDGND*, char*, NODEPROTO*);
-void pla_DrawArcs(INTBIG, PROGTRANS*, FACETIST*, INTBIG, NODEPROTO*);
-void pla_InstTurnPin(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, VDDGND*, VDDGND*, char*, NODEPROTO*);
+static void   pla_CHfromPuAND(INTBIG, FACETIST*, NODEPROTO*);
+static void   pla_CVfromInput(INTBIG, INTBIG, FACETIST*, NODEPROTO*);
+static void   pla_CVfromOutput(FACETIST*, FACETIST*, NODEPROTO*);
+static INTSML pla_ConnectFirstFacet(INTBIG, FACETIST*, NODEPROTO*);
+static void   pla_ConnectOnMetal(INTBIG, VDDGND*, char*, NODEPROTO*);
+static void   pla_ConnectThruFacets(INTBIG, VDDGND*, char*, NODEPROTO*);
+static void   pla_DrawArcs(INTBIG, PROGTRANS*, FACETIST*, INTBIG, NODEPROTO*);
+static void   pla_InstTurnPin(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, VDDGND*, VDDGND*, char*, NODEPROTO*);
 
 /* pla_AssignPort:  Find the proper port and note down its coordinates. */
 PORT *pla_AssignPort(NODEINST *inst, INTBIG x, INTBIG y)
 {
 	PORT *prt;
 
-	prt = (PORT *)emalloc(sizeof(PORT), pla_aid->cluster);
+	prt = (PORT *)emalloc(sizeof(PORT), pla_tool->cluster);
 	if (prt == NOPORT)
 	{
 		ttyputnomemory();
@@ -577,7 +577,7 @@ VDDGND *pla_MkVddGnd(INTBIG which, VDDGND **prevptr)
 {
 	VDDGND *ptr;
 
-	ptr = (VDDGND *)emalloc(sizeof(VDDGND), pla_aid->cluster);
+	ptr = (VDDGND *)emalloc(sizeof(VDDGND), pla_tool->cluster);
 	if (ptr == NOVDDGND) ttyputnomemory(); else
 		if (ptr == NOVDDGND) return(ptr);
 
@@ -800,4 +800,4 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 		ttyputerr(_("RunVddGnd: cannot export GND point"));
 }
 
-#endif  /* PLAAID - at top */
+#endif  /* PLATOOL - at top */
