@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: rout.c
- * Routines for the wire routing aid
+ * Routines for the wire routing tool
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if ROUTAID
+#if ROUTTOOL
 
 #include "global.h"
 #include "rout.h"
@@ -37,11 +37,12 @@
 #include "tecschem.h"
 #include "tecgen.h"
 #include "edialogs.h"
+#include "efunction.h"
 
-/* the ROUTER aid table */
+/* the ROUTER tool table */
 static COMCOMP routerfacetp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
 	NOBACKUP, INPUTOPT, " \t", M_("Facet to stitch"), 0};
-COMCOMP routerarcp = {NOKEYWORD, topofarcs, nextarcs, NOPARAMS,
+static COMCOMP routerarcp = {NOKEYWORD, topofarcs, nextarcs, NOPARAMS,
 	NOBACKUP, INPUTOPT, " \t", M_("Arc prototype to use in stitching (* to reset)"), 0};
 static KEYWORD routerautoopt[] =
 {
@@ -98,7 +99,7 @@ static KEYWORD routermazeopt[] =
 	{"route",   1, {&routermazeroutep,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
-COMCOMP routermazep = {routermazeopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
+static COMCOMP routermazep = {routermazeopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Maze routing operation"), 0 };
 static KEYWORD routernopt[] =
 {
@@ -107,7 +108,7 @@ static KEYWORD routernopt[] =
 };
 static COMCOMP routernp = {routernopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 	NOBACKUP, INPUTOPT, " \t", M_("Negating action"), 0};
-#if ROUTAIDSUN
+#if ROUTTOOLSUN
 static KEYWORD routerparopt[] =
 {
 	{"go",               0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -122,32 +123,35 @@ static KEYWORD routeropt[] =
 	{"mimic-stitch",   1,{&routermimicp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"river-route",    1,{&routerriverp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"maze-route",     1,{&routermazep,NOKEY,NOKEY,NOKEY,NOKEY}},
-#if ROUTAIDSUN
+#if ROUTTOOLSUN
 	{"par-route",      1,{&routerparp,NOKEY,NOKEY,NOKEY,NOKEY}},
 #endif
 	{"use-arc",        1,{&routerarcp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"select",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"no-stitch",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"unroute",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{"copy-topology",  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{"paste-topology", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"not",            1,{&routernp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP ro_routerp = {routeropt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Routing action"), 0};
 
-RCHECK *ro_firstrcheck;
-RCHECK *ro_rcheckfree;
+       RCHECK *ro_firstrcheck;
+static RCHECK *ro_rcheckfree;
 
-AIDENTRY  *ro_source;			/* source of batch of changes */
-INTBIG     ro_statekey;			/* cached key for "ROUT_state" */
-INTBIG     ro_state;			/* cached value for "ROUT_state" */
-INTBIG     ro_optionskey;		/* cached key for "ROUT_options" */
-INTBIG     ro_preferedkey;		/* cached key for "ROUT_prefered_arc" */
-ARCINST   *ro_createdarc;		/* last created arc for mimicing */
-NODEINST  *ro_deletednodes[2];	/* nodes at end of last deleted arc */
-PORTPROTO *ro_deletedports[2];	/* ports on nodes at end of last deleted arc */
-ARCPROTO  *ro_deletedarc;		/* type of last deleted arc */
-AIDENTRY  *ro_aid;				/* the Router aid object */
+static TOOL      *ro_source;			/* source of batch of changes */
+       INTBIG     ro_statekey;			/* cached key for "ROUT_state" */
+       INTBIG     ro_state;				/* cached value for "ROUT_state" */
+static INTBIG     ro_optionskey;		/* cached key for "ROUT_options" */
+       INTBIG     ro_preferedkey;		/* cached key for "ROUT_prefered_arc" */
+       ARCINST   *ro_createdarc;		/* last created arc for mimicing */
+       NODEINST  *ro_deletednodes[2];	/* nodes at end of last deleted arc */
+       PORTPROTO *ro_deletedports[2];	/* ports on nodes at end of last deleted arc */
+       ARCPROTO  *ro_deletedarc;		/* type of last deleted arc */
+	   NODEPROTO *ro_copiedtopofacet;	/* facet whose topology is being copied */
+       TOOL      *ro_tool;				/* the Router tool object */
 
 /* working memory for "ro_findnetends()" */
 static INTBIG      ro_findnetlisttotal = 0;
@@ -157,12 +161,14 @@ static INTBIG     *ro_findnetlistx;
 static INTBIG     *ro_findnetlisty;
 
 /* prototypes for local routines */
-RCHECK *ro_allocrcheck(void);
-void ro_freercheck(RCHECK*);
-void ro_queuercheck(NODEINST*);
-void ro_unroutecurrent(void);
-INTSML ro_unroutenet(NETWORK *net);
-void ro_optionsdlog(void);
+static RCHECK *ro_allocrcheck(void);
+static void    ro_queuercheck(NODEINST*);
+static void    ro_unroutecurrent(void);
+static INTSML  ro_unroutenet(NETWORK *net);
+static void    ro_optionsdlog(void);
+static void    ro_pastetopology(NODEPROTO *np);
+static int     ro_sortinstspatially(const void *e1, const void *e2);
+static INTSML  ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp);
 
 /*
  * routine to allocate a new check module from the pool (if any) or memory
@@ -173,7 +179,7 @@ RCHECK *ro_allocrcheck(void)
 
 	if (ro_rcheckfree == NORCHECK)
 	{
-		r = (RCHECK *)emalloc(sizeof (RCHECK), ro_aid->cluster);
+		r = (RCHECK *)emalloc(sizeof (RCHECK), ro_tool->cluster);
 		if (r == 0) return(NORCHECK);
 	} else
 	{
@@ -211,18 +217,20 @@ void ro_queuercheck(NODEINST *ni)
 	ro_firstrcheck = r;
 }
 
-void ro_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void ro_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
-	if (thisaid == 0)
+	if (thistool == 0)
 	{
 		/* pass 3: nothing to do */
-	} else if (thisaid == NOAID)
+		/* EMPTY */ 
+	} else if (thistool == NOTOOL)
 	{
 		/* pass 2: nothing to do */
+		/* EMPTY */ 
 	} else
 	{
 		/* pass 1: initialize */
-		ro_aid = thisaid;
+		ro_tool = thistool;
 
 		/* set default mode for router: facet stitching */
 		ro_statekey = makekey("ROUT_state");
@@ -230,7 +238,7 @@ void ro_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		ro_preferedkey = makekey("ROUT_prefered_arc");
 		nextchangequiet();
 		ro_state = NOSTITCH;
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey, ro_state, VINTEGER|VDONTSAVE);
+		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey, ro_state, VINTEGER|VDONTSAVE);
 
 		/* initialize the free lists */
 		ro_rcheckfree = NORCHECK;
@@ -240,6 +248,9 @@ void ro_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		ro_createdarc = NOARCINST;
 		ro_deletedarc = NOARCPROTO;
 
+		/* no facet topology was copied */
+		ro_copiedtopofacet = NONODEPROTO;
+
 		/* delcare dialogs */
 		DiaDeclareHook("routeopt", &routerarcp, ro_optionsdlog);
 	}
@@ -247,6 +258,7 @@ void ro_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 
 void ro_done(void)
 {
+#ifdef DEBUGMEMORY
 	RCHECK *r;
 
 	/* free all check modules */
@@ -274,6 +286,7 @@ void ro_done(void)
 	ro_freemimicmemory();
 	ro_freerivermemory();
 	ro_freemazememory();
+#endif
 }
 
 INTSML ro_set(INTSML count, char *par[])
@@ -297,7 +310,7 @@ INTSML ro_set(INTSML count, char *par[])
 			case MIMICSTITCH:
 				ttyputmsg(M_("Default is mimic-stitch routing"));  break;
 		}
-		var = getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey);
+		var = getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey);
 		if (var != NOVARIABLE)
 			ttyputmsg(M_("Default arc for river routing is %s"),
 				describearcproto(((ARCPROTO *)var->addr)));
@@ -308,7 +321,7 @@ INTSML ro_set(INTSML count, char *par[])
 
 	if (namesamen(pp, "no-stitch", l) == 0)
 	{
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			(ro_state & ~STITCHMODE) | NOSTITCH, VINTEGER|VDONTSAVE);
 		return(0);
 	}
@@ -319,7 +332,7 @@ INTSML ro_set(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "enable", l) == 0)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | AUTOSTITCH, VINTEGER|VDONTSAVE);
 			return(0);
 		}
@@ -354,7 +367,11 @@ INTSML ro_set(INTSML count, char *par[])
 			}
 
 			for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			{
+				/* ignore recursive references (showing icon in contents) */
+				if (ni->proto->cell == np->cell) continue;
 				ro_queuercheck(ni);
+			}
 
 			/* fake enabling of auto-stitching */
 			savestate = ro_state;
@@ -370,7 +387,7 @@ INTSML ro_set(INTSML count, char *par[])
 		}
 		if (namesamen(pp, "highlighted-stitch-now", l) == 0)
 		{
-			list = (GEOM **)askaid(us_aid, "get-all-nodes");
+			list = (GEOM **)asktool(us_tool, "get-all-nodes");
 			if (list[0] == NOGEOM)
 			{
 				ttyputerr(_("Select an area to be stitched"));
@@ -391,7 +408,7 @@ INTSML ro_set(INTSML count, char *par[])
 			ttyputverbose(M_("Stitching complete"));
 			return(0);
 		}
-		ttyputbadusage("tellaid routing auto-stitch");
+		ttyputbadusage("telltool routing auto-stitch");
 		return(1);
 	}
 
@@ -399,7 +416,7 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid routing mimic-stitch OPTION");
+			ttyputusage("telltool routing mimic-stitch OPTION");
 			return(1);
 		}
 		l = strlen(pp = par[1]);
@@ -410,39 +427,39 @@ INTSML ro_set(INTSML count, char *par[])
 		}
 		if (namesamen(pp, "enable", l) == 0)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | MIMICSTITCH, VINTEGER|VDONTSAVE);
 			return(0);
 		}
 		if (namesamen(pp, "stitch-and-unstitch", l) == 0 && l >= 8)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route and unroute"));
 			return(0);
 		}
 		if (namesamen(pp, "stitch-only", l) == 0 && l >= 8)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will only route, not unroute"));
 			return(0);
 		}
 		if (namesamen(pp, "port-general", l) == 0 && l >= 8)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route to any port"));
 			return(0);
 		}
 		if (namesamen(pp, "port-specific", l) == 0 && l >= 8)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will rout only to similar ports"));
 			return(0);
 		}
-		ttyputbadusage("tellaid routing mimic-stitching");
+		ttyputbadusage("telltool routing mimic-stitching");
 		return(1);
 	}
 
@@ -493,7 +510,7 @@ INTSML ro_set(INTSML count, char *par[])
 				ro_mazerouteselected();
 				return(0);
 			}
-			ttyputbadusage("tellaid routing maze-route");
+			ttyputbadusage("telltool routing maze-route");
 			return(1);
 		}
 		if (namesamen(pp, "set", l) == 0)
@@ -528,30 +545,53 @@ INTSML ro_set(INTSML count, char *par[])
 				return 0;
 			}
 
-			ttyputbadusage("tellaid routing maze-route set");
+			ttyputbadusage("telltool routing maze-route set");
 			return(1);
 		}
 	}
 
-#if ROUTAIDSUN
-	if (namesamen(pp, "par-route", l) == 0)
+#if ROUTTOOLSUN
+	if (namesamen(pp, "par-route", l) == 0 && l >= 3)
 	{
 		ro_par();
 		return(0);
 	}
 #endif
 
+	if (namesamen(pp, "copy-topology", l) == 0)
+	{
+		np = getcurfacet();
+		if (np == NONODEPROTO)
+		{
+			ttyputerr(_("No current facet"));
+			return(1);
+		}
+		ro_copiedtopofacet = np;
+		return(0);
+	}
+	if (namesamen(pp, "paste-topology", l) == 0 && l >= 3)
+	{
+		np = getcurfacet();
+		if (np == NONODEPROTO)
+		{
+			ttyputerr(_("No current facet"));
+			return(1);
+		}
+		ro_pastetopology(np);
+		return(0);
+	}
+
 	if (namesamen(pp, "use-arc", l) == 0)
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid routing use-arc ARCPROTO");
+			ttyputusage("telltool routing use-arc ARCPROTO");
 			return(1);
 		}
 		if (strcmp(par[1], "*") == 0)
 		{
-			if (getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey) != NOVARIABLE)
-				(void)delvalkey((INTBIG)ro_aid, VAID, ro_preferedkey);
+			if (getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey) != NOVARIABLE)
+				(void)delvalkey((INTBIG)ro_tool, VTOOL, ro_preferedkey);
 			ttyputverbose(M_("No arc will be presumed for stitching"));
 			return(0);
 		}
@@ -562,7 +602,7 @@ INTSML ro_set(INTSML count, char *par[])
 			return(1);
 		}
 		ttyputverbose(M_("Default stitching arc will be %s"), describearcproto(ap));
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_preferedkey, (INTBIG)ap, VARCPROTO);
+		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_preferedkey, (INTBIG)ap, VARCPROTO);
 		return(0);
 	}
 
@@ -576,30 +616,30 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputusage("tellaid routing not OPTION");
+			ttyputusage("telltool routing not OPTION");
 			return(1);
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "select", l) == 0)
 		{
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				ro_state & ~SELECT, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Wire placement not subject to approval"));
 			return(0);
 		}
-		ttyputbadusage("tellaid routing not");
+		ttyputbadusage("telltool routing not");
 		return(1);
 	}
 
 	if (namesamen(pp, "select", l) == 0)
 	{
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			ro_state | SELECT, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Wire placement subject to approval"));
 		return(0);
 	}
 
-	ttyputbadusage("tellaid routing");
+	ttyputbadusage("telltool routing");
 	return(1);
 }
 
@@ -608,7 +648,7 @@ void ro_slice(void)
 	if ((ro_state&(SELSKIP|SELDONE)) != 0)
 	{
 		ro_state &= ~(SELSKIP|SELDONE);
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey, ro_state, VINTEGER|VDONTSAVE);
+		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey, ro_state, VINTEGER|VDONTSAVE);
 	}
 
 	switch (ro_state&STITCHMODE)
@@ -626,7 +666,7 @@ void ro_slice(void)
 
 /******************** DATABASE CHANGES ********************/
 
-void ro_startbatch(AIDENTRY *source, INTSML undoredo)
+void ro_startbatch(TOOL *source, INTSML undoredo)
 {
 	ro_source = source;
 }
@@ -636,7 +676,7 @@ void ro_modifynodeinst(NODEINST *ni, INTBIG oldlx, INTBIG oldly, INTBIG oldhx,
 {
 	if ((ro_state&STITCHMODE) == AUTOSTITCH)
 	{
-		if (ro_source != ro_aid) ro_queuercheck(ni);
+		if (ro_source != ro_tool) ro_queuercheck(ni);
 	}
 	ro_createdarc = NOARCINST;
 	ro_deletedarc = NOARCPROTO;
@@ -660,7 +700,7 @@ void ro_newobject(INTBIG addr, INTBIG type)
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 
-	if (ro_source == ro_aid) return;
+	if (ro_source == ro_tool) return;
 	if ((type&VTYPE) == VNODEINST)
 	{
 		if ((ro_state&STITCHMODE) == AUTOSTITCH)
@@ -686,7 +726,7 @@ void ro_killobject(INTBIG addr, INTBIG type)
 {
 	REGISTER ARCINST *ai;
 
-	if (ro_source == ro_aid) return;
+	if (ro_source == ro_tool) return;
 	if ((type&VTYPE) == VARCINST)
 	{
 		ai = (ARCINST *)addr;
@@ -833,6 +873,8 @@ INTSML ro_unroutenet(NETWORK *net)
 					if (covered[i] + covered[j] != 1) continue;
 				}
 				dist = computedistance(xlist[i], ylist[i], xlist[j], ylist[j]);
+
+				/* LINTED "bestdist" used in proper order */
 				if (found == 0 && dist >= bestdist) continue;
 				found = 0;
 				bestdist = dist;
@@ -852,7 +894,7 @@ INTSML ro_unroutenet(NETWORK *net)
 			return(1);
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
-		(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
+		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 	}
 	return(0);
 }
@@ -914,13 +956,13 @@ INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 					newtotal = listcount * 2;
 					if (newtotal == 0) newtotal = 10;
 					newlistni = (NODEINST **)emalloc(newtotal * (sizeof (NODEINST *)),
-						ro_aid->cluster);
+						ro_tool->cluster);
 					newlistpp = (PORTPROTO **)emalloc(newtotal * (sizeof (PORTPROTO *)),
-						ro_aid->cluster);
+						ro_tool->cluster);
 					newlistx = (INTBIG *)emalloc(newtotal * SIZEOFINTBIG,
-						ro_aid->cluster);
+						ro_tool->cluster);
 					newlisty = (INTBIG *)emalloc(newtotal * SIZEOFINTBIG,
-						ro_aid->cluster);
+						ro_tool->cluster);
 					for(j=0; j<listcount; j++)
 					{
 						newlistni[j] = ro_findnetlistni[j];
@@ -964,15 +1006,342 @@ INTBIG ro_getoptions(void)
 {
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)ro_aid, VAID, VINTEGER, ro_optionskey);
+	var = getvalkey((INTBIG)ro_tool, VTOOL, VINTEGER, ro_optionskey);
 	if (var != NOVARIABLE) return(var->addr);
 	return(0);
 }
 
+/****************************** TOPOLOGY COPYING ******************************/
+
+/*
+ * Routine to copy the topology of facet "ro_copiedtopofacet" to facet "tonp".
+ */
+void ro_pastetopology(NODEPROTO *tonp)
+{
+	REGISTER LIBRARY *lib;
+	REGISTER NODEPROTO *np;
+	REGISTER NODEINST *ni, *oni, *tni, *otni, *fni, *ofni, **fromlist, **tolist;
+	REGISTER ARCINST *ai, *oai;
+	REGISTER PORTPROTO *tpp, *otpp, *fpp;
+	REGISTER PORTARCINST *fpi, *ofpi;
+	REGISTER NETWORK *net;
+	REGISTER INTBIG fromcount, tocount, i, j, fun, ofun;
+	REGISTER char *matchname;
+	REGISTER VARIABLE *var, *ovar;
+
+	if (ro_copiedtopofacet == NONODEPROTO)
+	{
+		ttyputerr(_("Must copy topology before pasting it"));
+		return;
+	}
+
+	/* first validate the source facet */
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+	{
+		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			if (np == ro_copiedtopofacet) break;
+		if (np != NONODEPROTO) break;
+	}
+	if (lib == NOLIBRARY)
+	{
+		ttyputerr(_("Copied facet is no longer valid"));
+		return;
+	}
+
+	/* make sure copy goes to a different facet */
+	if (ro_copiedtopofacet == tonp)
+	{
+		ttyputerr(_("Topology must be copied to a different facet"));
+		return;
+	}
+
+	/* reset association pointers in the destination facet */
+	for(ni = tonp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		ni->temp1 = 0;
+
+	/* look for associations */
+	for(ni = tonp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	{
+		if (ni->temp1 != 0) continue;
+
+		/* ignore connecting nodes */
+		if (ni->proto->primindex != 0)
+		{
+			fun = nodefunction(ni);
+			if (fun == NPUNKNOWN || fun == NPPIN || fun == NPCONTACT ||
+				fun == NPNODE) continue;
+		}
+
+		/* count the number of this type of node in the two facets */
+		fromcount = 0;
+		for(oni = ro_copiedtopofacet->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		{
+			if (ni->proto->primindex == 0)
+			{
+				if (oni->proto->cell == ni->proto->cell) fromcount++;
+			} else
+			{
+				ofun = nodefunction(oni);
+				if (ofun == fun) fromcount++;
+			}
+		}
+		tocount = 0;
+		for(oni = tonp->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		{
+			if (ni->proto->primindex == 0)
+			{
+				if (oni->proto == ni->proto) tocount++;
+			} else
+			{
+				ofun = nodefunction(oni);
+				if (ofun == fun) tocount++;
+			}
+		}
+
+		/* problem if the numbers don't match */
+		if (tocount != fromcount)
+		{
+			if (fromcount == 0) continue;
+			ttyputerr(_("Warning: %s has %ld of %s but facet %s has %d"),
+				describenodeproto(ro_copiedtopofacet), fromcount, describenodeproto(ni->proto),
+				describenodeproto(tonp), tocount);
+			return;
+		}
+
+		/* gather all of the instances */
+		fromlist = (NODEINST **)emalloc(fromcount * (sizeof (NODEINST *)), ro_tool->cluster);
+		if (fromlist == 0) return;
+		fromcount = 0;
+		for(oni = ro_copiedtopofacet->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		{
+			if (ni->proto->primindex == 0)
+			{
+				if (oni->proto->cell == ni->proto->cell) fromlist[fromcount++] = oni;
+			} else
+			{
+				ofun = nodefunction(oni);
+				if (ofun == fun) fromlist[fromcount++] = oni;
+			}
+		}
+		tolist = (NODEINST **)emalloc(tocount * (sizeof (NODEINST *)), ro_tool->cluster);
+		if (tolist == 0) return;
+		tocount = 0;
+		for(oni = tonp->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		{
+			if (ni->proto->primindex == 0)
+			{
+				if (oni->proto == ni->proto) tolist[tocount++] = oni;
+			} else
+			{
+				ofun = nodefunction(oni);
+				if (ofun == fun) tolist[tocount++] = oni;
+			}
+		}
+
+		/* look for name matches */
+		for(i=0; i<fromcount; i++)
+		{
+			var = getvalkey((INTBIG)fromlist[i], VNODEINST, VSTRING, el_node_name);
+			if (var == NOVARIABLE) continue;
+			for(j=0; j<tocount; j++)
+			{
+				if (tolist[j] == NONODEINST) continue;
+				ovar = getvalkey((INTBIG)tolist[j], VNODEINST, VSTRING, el_node_name);
+				if (ovar == NOVARIABLE) continue;
+				if (namesame((char *)var->addr, (char *)ovar->addr) == 0) break;
+			}
+			if (j < tocount)
+			{
+				/* name match found: set the association */
+				tolist[j]->temp1 = (INTBIG)fromlist[i];
+				fromlist[i] = NONODEINST;
+			}
+		}
+
+		/* remove the matched instances */
+		j = 0;
+		for(i=0; i<fromcount; i++)
+			if (fromlist[i] != NONODEINST) fromlist[j++] = fromlist[i];
+		fromcount = j;
+		j = 0;
+		for(i=0; i<tocount; i++)
+			if (tolist[i]->temp1 == 0) tolist[j++] = tolist[i];
+		tocount = j;
+		if (fromcount != tocount)
+		{
+			ttyputerr(_("Error: after name match, there are %ld instances of %s in source and %ld in destination"),
+				fromcount, describenodeproto(ni->proto), tocount);
+			return;
+		}
+
+		/* sort the rest by position and force matches based on that */
+		if (fromcount == 0) continue;
+		esort(fromlist, fromcount, sizeof (NODEINST *), ro_sortinstspatially);
+		esort(tolist, tocount, sizeof (NODEINST *), ro_sortinstspatially);
+		for(i=0; i<tocount; i++)
+			tolist[i]->temp1 = (INTBIG)fromlist[i];
+
+		/* free the arrays */
+		efree((char *)fromlist);
+		efree((char *)tolist);
+	}
+
+	/* association made, now copy the topology */
+	for(tni = tonp->firstnodeinst; tni != NONODEINST; tni = tni->nextnodeinst)
+	{
+		if (tni->temp1 == 0) continue;
+		fni = (NODEINST *)tni->temp1;
+
+		/* look for another node that may match */
+		for(otni = tonp->firstnodeinst; otni != NONODEINST; otni = otni->nextnodeinst)
+		{
+			if (tni == otni) continue;
+			if (otni->temp1 == 0) continue;
+			ofni = (NODEINST *)otni->temp1;
+
+			/* see if they share a connection in the original */
+			for(fpi = fni->firstportarcinst; fpi != NOPORTARCINST; fpi = fpi->nextportarcinst)
+			{
+				ai = fpi->conarcinst;
+				for(ofpi = ofni->firstportarcinst; ofpi != NOPORTARCINST; ofpi = ofpi->nextportarcinst)
+				{
+					oai = ofpi->conarcinst;
+					if (oai->network == ai->network) break;
+				}
+				if (ofpi != NOPORTARCINST) break;
+			}
+			if (fpi == NOPORTARCINST) continue;
+
+			/* this connection should be repeated in the other facet */
+			for(tpp = tni->proto->firstportproto; tpp != NOPORTPROTO; tpp = tpp->nextportproto)
+				if (namesame(tpp->protoname, fpi->proto->protoname) == 0) break;
+			if (tpp == NOPORTPROTO) continue;
+			for(otpp = tni->proto->firstportproto; otpp != NOPORTPROTO; otpp = otpp->nextportproto)
+				if (namesame(otpp->protoname, ofpi->proto->protoname) == 0) break;
+			if (otpp == NOPORTPROTO) continue;
+
+			/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
+			if (ro_makeunroutedconnection(tni, tpp, otni, otpp) != 0) return;
+		}
+	}
+
+	/* add in any exported but unconnected pins */
+	for(tni = tonp->firstnodeinst; tni != NONODEINST; tni = tni->nextnodeinst)
+	{
+		if (tni->temp1 != 0) continue;
+		if (tni->proto->primindex == 0) continue;
+		if (tni->firstportexpinst == NOPORTEXPINST) continue;
+		fun = nodefunction(tni);
+		if (fun != NPPIN && fun != NPCONTACT) continue;
+
+		/* find that export in the source facet */
+		tpp = tni->proto->firstportproto;
+		matchname = tni->firstportexpinst->exportproto->protoname;
+		for(fpp = ro_copiedtopofacet->firstportproto; fpp != NOPORTPROTO; fpp = fpp->nextportproto)
+		{
+			net = fpp->network;
+			if (fpp->network->signals > 1)
+			{
+				for(i=0; i<fpp->network->signals; i++)
+				{
+					net = fpp->network->networklist[i];
+					if (net->namecount <= 0) continue;
+					if (namesame(net->netname, matchname) == 0) break;
+				}
+				if (i < fpp->network->signals) break;
+			} else
+			{
+				if (namesame(fpp->protoname, matchname) == 0) break;
+			}
+		}
+		if (fpp == NOPORTPROTO) continue;
+
+		/* check to see if this is connected elsewhere in the "to" facet */
+		for(otni = tonp->firstnodeinst; otni != NONODEINST; otni = otni->nextnodeinst)
+		{
+			if (otni->temp1 == 0) continue;
+			ofni = (NODEINST *)otni->temp1;
+
+			/* see if they share a connection in the original */
+			for(ofpi = ofni->firstportarcinst; ofpi != NOPORTARCINST; ofpi = ofpi->nextportarcinst)
+			{
+				ai = ofpi->conarcinst;
+				if (ai->network == net) break;
+			}
+			if (ofpi != NOPORTARCINST) break;
+		}
+		if (otni != NONODEINST)
+		{
+			/* find the proper port in this facet */
+			for(otpp = otni->proto->firstportproto; otpp != NOPORTPROTO; otpp = otpp->nextportproto)
+				if (namesame(otpp->protoname, ofpi->proto->protoname) == 0) break;
+			if (otpp == NOPORTPROTO) continue;
+
+			/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
+			if (ro_makeunroutedconnection(tni, tpp, otni, otpp) != 0) return;
+		}
+	}
+}
+
+/*
+ * Helper routine to run an unrouted wire between node "fni", port "fpp" and node "tni", port
+ * "tpp".  If the connection is already there, the routine doesn't make another.
+ * Returns nonzero on error.
+ */
+INTSML ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp)
+{
+	REGISTER PORTARCINST *fpi, *tpi;
+	REGISTER ARCINST *fai, *tai, *ai;
+	INTBIG fx, fy, tx, ty;
+	REGISTER INTBIG wid, bits;
+	REGISTER NODEPROTO *np;
+
+	/* see if they are already connected */
+	for(fpi = fni->firstportarcinst; fpi != NOPORTARCINST; fpi = fpi->nextportarcinst)
+		if (fpi->proto == fpp) break;
+	for(tpi = tni->firstportarcinst; tpi != NOPORTARCINST; tpi = tpi->nextportarcinst)
+		if (tpi->proto == tpp) break;
+	if (fpi != NOPORTARCINST && tpi != NOPORTARCINST)
+	{
+		fai = fpi->conarcinst;
+		tai = tpi->conarcinst;
+		if (fai->network == tai->network) return(0);
+	}
+
+	/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
+	portposition(fni, fpp, &fx, &fy);
+	portposition(tni, tpp, &tx, &ty);
+	bits = us_makearcuserbits(gen_unroutedarc);
+	wid = defaultarcwidth(gen_unroutedarc);
+	np = fni->parent;
+	ai = newarcinst(gen_unroutedarc, wid, bits, fni, fpp, fx, fy, tni, tpp, tx, ty, np);
+	if (ai == NOARCINST) return(1);
+	endobjectchange((INTBIG)ai, VARCINST);
+	return(0);
+}
+
+/*
+ * Helper routine for sorting instances spatially
+ */
+int ro_sortinstspatially(const void *e1, const void *e2)
+{
+	REGISTER NODEINST *n1, *n2;
+	REGISTER INTBIG x1, y1, x2, y2;
+
+	n1 = *((NODEINST **)e1);
+	n2 = *((NODEINST **)e2);
+	x1 = (n1->lowx + n1->highx) / 2;
+	y1 = (n1->lowy + n1->highy) / 2;
+	x2 = (n2->lowx + n2->highx) / 2;
+	y2 = (n2->lowy + n2->highy) / 2;
+	if (y1 == y2) return(x1 - x2);
+	return(y1 - y2);
+}
+
 /****************************** ROUTING OPTIONS DIALOG ******************************/
 
 /* Routing Options */
-DIALOGITEM ro_optionsdialogitems[] =
+static DIALOGITEM ro_optionsdialogitems[] =
 {
  /*  1 */ {0, {216,208,240,272}, BUTTON, N_("OK")},
  /*  2 */ {0, {216,12,240,76}, BUTTON, N_("Cancel")},
@@ -986,7 +1355,7 @@ DIALOGITEM ro_optionsdialogitems[] =
  /* 10 */ {0, {164,24,180,268}, CHECK, N_("Node types must match")},
  /* 11 */ {0, {140,24,156,268}, CHECK, N_("Nodes sizes must match")}
 };
-DIALOG ro_optionsdialog = {{50,75,299,356}, N_("Routing Options"), 0, 11, ro_optionsdialogitems};
+static DIALOG ro_optionsdialog = {{50,75,299,356}, N_("Routing Options"), 0, 11, ro_optionsdialogitems};
 
 /* special items for the "Routing Options" dialog: */
 #define DROO_ARCLIST         3		/* Arc list (popup) */
@@ -1004,7 +1373,7 @@ void ro_optionsdlog(void)
 	char **arcnames, *paramstart[3];
 
 	/* gather list of arcs */
-	var = getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey);
+	var = getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey);
 	if (var == NOVARIABLE) oldap = NOARCPROTO; else
 		oldap = (ARCPROTO *)var->addr;
 	numarcnames = 0;
@@ -1071,17 +1440,17 @@ void ro_optionsdlog(void)
 		if (DiaGetControl(DROO_MINTERACTIVE) != 0) options |= MIMICINTERACTIVE; else
 			options &= ~MIMICINTERACTIVE;
 		if (options != oldoptions)
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey, options, VINTEGER);
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey, options, VINTEGER);
 		paramstart[0] = "use-arc";
 		if (ap != oldap)
 		{
 			if (ap == NOARCPROTO) paramstart[1] = "*"; else
 				paramstart[1] = ap->protoname;
-			(void)tellaid(ro_aid, 2, paramstart);
+			(void)telltool(ro_tool, 2, paramstart);
 		}
 	}
 	DiaDoneDialog();
 	efree((char *)arcs);
 }
 
-#endif  /* ROUTAID - at top */
+#endif  /* ROUTTOOL - at top */
