@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if ROUTAID
+#if ROUTTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -37,16 +37,16 @@
 #include "usr.h"
 #include <math.h>
 
-ARCPROTO *ro_preferedarc;	/* the prefered arc */
+static ARCPROTO *ro_preferedarc;	/* the prefered arc */
 
-INTBIG ro_checkstitching(NODEINST*);
-INTBIG ro_testpoly(NODEINST*, PORTPROTO*, ARCPROTO*, POLYGON*, NODEINST*);
-INTBIG ro_comparepoly(NODEINST*, PORTPROTO*, POLYGON*, NODEINST*, PORTPROTO*, POLYGON*, ARCPROTO*);
-ARCPROTO *ro_getarcproto(PORTPROTO*, PORTPROTO*, TECHNOLOGY*);
-INTSML ro_canconnect(ARCPROTO*, PORTPROTO*);
-void ro_findsmallestlayer(ARCPROTO*);
-void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly);
-void ro_freercheck(RCHECK*);
+/* prototypes for local routines */
+static INTBIG ro_checkstitching(NODEINST*);
+static INTBIG ro_testpoly(NODEINST*, PORTPROTO*, ARCPROTO*, POLYGON*, NODEINST*);
+static INTBIG ro_comparepoly(NODEINST*, PORTPROTO*, POLYGON*, NODEINST*, PORTPROTO*, POLYGON*, ARCPROTO*);
+static INTSML ro_canconnect(ARCPROTO*, PORTPROTO*);
+static void ro_findsmallestlayer(ARCPROTO*);
+static void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly);
+static INTBIG ro_didaccept(ARCINST*, ARCINST*, ARCINST*);
 
 void ro_autostitch(void)
 {
@@ -64,10 +64,10 @@ void ro_autostitch(void)
 	REGISTER VARIABLE *var;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		return;
 	}
 
@@ -132,7 +132,7 @@ void ro_autostitch(void)
 
 	/* find out the prefered routing arc */
 	ro_preferedarc = NOARCPROTO;
-	var = getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey);
+	var = getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey);
 	if (var != NOVARIABLE) ro_preferedarc = (ARCPROTO *)var->addr; else
 	{
 		/* see if there is a default user arc */
@@ -170,7 +170,7 @@ void ro_autostitch(void)
 
 	/* if selection was done, restore the highlighting */
 	if ((ro_state&SELDONE) != 0)
-		(void)askaid(us_aid, "up-stack");
+		(void)asktool(us_tool, "up-stack");
 
 	/* report results */
 	if (count != 0)
@@ -195,7 +195,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* look for any other nodes that touch or overlap this one */
 	lx = ni->geom->lowx;   hx = ni->geom->highx;
@@ -437,7 +437,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	REGISTER INTBIG dist, ox, oy, bestdist, lx, hx, ly, hy;
 
 	/* get polygon */
-	if (opoly == NOPOLYGON) opoly = allocstaticpolygon(4, ro_aid->cluster);
+	if (opoly == NOPOLYGON) opoly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* get network associated with the node/port */
 	net = getnetonport(ni, pp);
@@ -621,13 +621,13 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
 		/* save highlighting on the first selection */
 		if ((ro_state&SELDONE) == 0)
 		{
-			(void)askaid(us_aid, "down-stack");
-			(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey, ro_state | SELDONE,
+			(void)asktool(us_tool, "down-stack");
+			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey, ro_state | SELDONE,
 				VINTEGER|VDONTSAVE);
 		}
 
 		/* erase all highlighting */
-		(void)askaid(us_aid, "clear");
+		(void)asktool(us_tool, "clear");
 
 		/* force the stitch to be drawn */
 		endobjectchange((INTBIG)ai, VARCINST);
@@ -635,21 +635,21 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
 		if (alt2 != NOARCINST) endobjectchange((INTBIG)alt2, VARCINST);
 
 		/* highlight the stitch */
-		(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
-		if (alt1 != NOARCINST) (void)askaid(us_aid, "show-object", (INTBIG)alt1->geom);
-		if (alt2 != NOARCINST) (void)askaid(us_aid, "show-object", (INTBIG)alt2->geom);
+		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
+		if (alt1 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt1->geom);
+		if (alt2 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt2->geom);
 
 		/* loop on user response */
 		for(;;)
 		{
 			ttyputmsg(_("Ok? "));
 			ch = (char)ttygetchar();
-			(void)askaid(us_aid, "clear");
+			(void)asktool(us_tool, "clear");
 			if (ch == 's')
 			{
-				var = getvalkey((INTBIG)ro_aid, VAID, VINTEGER, ro_statekey);
+				var = getvalkey((INTBIG)ro_tool, VTOOL, VINTEGER, ro_statekey);
 				if (var != NOVARIABLE)
-					(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
+					(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 						var->addr & ~SELSKIP, VINTEGER|VDONTSAVE);
 				break;
 			}
@@ -709,7 +709,7 @@ void ro_findsmallestlayer(ARCPROTO *ap)
 	if (ap->temp1 >= 0) return;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* get a dummy arc to analyze */
 	ai = dummyarc();
@@ -726,6 +726,8 @@ void ro_findsmallestlayer(ARCPROTO *ap)
 	{
 		shapearcpoly(ai, i, poly);
 		area = (float)fabs(areapoly(poly));
+
+		/* LINTED "bestarea" used in proper order */
 		if (bestfound != 0 && area >= bestarea) continue;
 		bestarea = area;
 		bestfound++;
@@ -753,7 +755,7 @@ void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly)
 	if (nfun == NPPIN)
 	{
 		/* get polygon */
-		if (apoly == NOPOLYGON) apoly = allocstaticpolygon(4, ro_aid->cluster);
+		if (apoly == NOPOLYGON) apoly = allocstaticpolygon(4, ro_tool->cluster);
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			ai = pi->conarcinst;
@@ -791,4 +793,4 @@ void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly)
 	}
 }
 
-#endif  /* ROUTAID - at top */
+#endif  /* ROUTTOOL - at top */
