@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if ROUTAID
+#if ROUTTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -211,67 +211,65 @@ typedef enum {SR_MOR, SR_MAND, SR_MSET} SRMODE;
 		ro_mazeset_line(region,region->layers[SCH_VERTLAYER],SR_GSET,Mlx,Mly,Mhx,Mhy,SR_MSET);	\
 }
 
-INTSML     ro_mazedebug = 0;
-ARCPROTO  *ro_mazevertwire, *ro_mazehoriwire;
-NODEPROTO *ro_mazesteiner;
-INTBIG     ro_mazegridx, ro_mazegridy;
-INTBIG     ro_mazeoffsetx, ro_mazeoffsety;
-INTBIG     ro_mazeboundary;
-FILE      *ro_mazedebuggingout;
-SRREGION  *ro_theregion = NOSRREGION;
+static INTSML     ro_mazedebug = 0;
+static ARCPROTO  *ro_mazevertwire, *ro_mazehoriwire;
+static NODEPROTO *ro_mazesteiner;
+static FILE      *ro_mazedebuggingout;
+static SRREGION  *ro_theregion = NOSRREGION;
+       INTBIG     ro_mazegridx, ro_mazegridy;
+       INTBIG     ro_mazeoffsetx, ro_mazeoffsety;
+       INTBIG     ro_mazeboundary;
 
 /* database access functions */
-SRNET     *ro_mazenet_free_list = NOSRNET;
-SRPORT    *ro_mazeport_free_list = NOSRPORT;
-SRPATH    *ro_mazepath_free_list = NOSRPATH;
-SRWAVEPT  *ro_mazewavept_free_list = NOSRWAVEPT;
+static SRNET     *ro_mazenet_free_list = NOSRNET;
+static SRPORT    *ro_mazeport_free_list = NOSRPORT;
+static SRPATH    *ro_mazepath_free_list = NOSRPATH;
+static SRWAVEPT  *ro_mazewavept_free_list = NOSRWAVEPT;
 
 /* prototypes for local routines */
-INTBIG      ro_anglediff(INTBIG ang1, INTBIG ang2);
-TECHNOLOGY *ro_findtech(NODEINST *ni, PORTPROTO *pp);
-SRLAYER    *ro_mazeadd_layer(SRREGION *region, INTSML index,  SRDIRECTION direction, INTBIG gridx, INTBIG gridy, INTBIG alignx, INTBIG aligny);
-SRNET      *ro_mazeadd_net(SRREGION *region);
-SRPATH     *ro_mazeadd_path(SRPORT *port, SRLAYER *layer, SREND e1, SREND e2, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
-SRPORT     *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, NODEINST *ni, PORTPROTO *pp);
-INTSML      ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
-void        ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTSML end, INTBIG dx, INTBIG dy);
-SRLAYER    *ro_mazealloc_layer(void);
-SRNET      *ro_mazealloc_net(void);
-SRPATH     *ro_mazealloc_path(void);
-SRPORT     *ro_mazealloc_port(void);
-SRWAVEPT   *ro_mazealloc_wavept(void);
-void        ro_mazeclear_maze(SRNET *net);
-INTSML      ro_mazecreate_wavefront(SRPORT *port);
-SRREGION   *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy);
-void        ro_mazedelete_net(SRNET *net);
-void        ro_mazedelete_port(SRPORT *port);
-void        ro_mazecleanout_region(SRREGION *region);
-UINTBIG     ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy);
-void        ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *region);
-void        ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
-void        ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
-void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer);
-void        ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers);
-INTSML      ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
-INTSML      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
-INTSML      ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
-INTSML      ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path);
-INTBIG      ro_mazefindport(NODEPROTO*, INTBIG, INTBIG, ARCPROTO*, NODEINST *nis[], PORTPROTO *pps[], INTSML);
-INTBIG      ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, INTSML forcefind);
-void        ro_mazefree_net(SRNET *net);
-void        ro_mazefree_path(SRPATH *path);
-void        ro_mazefree_port(SRPORT *port);
-void        ro_mazefree_wavept(SRWAVEPT *wavept);
-SRPATH     *ro_mazeget_path(SRPORT *port, SRLAYER *layer, SREND e1, SREND e2, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
-SRREGION   *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why, INTBIG gridx, INTBIG gridy, INTBIG offsetx, INTBIG offsety);
-INTSML      ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code);
-INTSML      ro_mazeroute_net(SRNET *net);
-INTSML      ro_mazeroutenet(NETWORK *net);
-SRWAVEPT   *ro_mazesearch_wavefront(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y);
-void        ro_mazeset_box(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
-void        ro_mazeset_line(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
-void        ro_mazeset_point(SRLAYER *layer, SRGPT type, INTBIG x, INTBIG y, SRMODE mode);
-INTSML      ro_mazetest_pt(SRGPT pt, INTBIG code);
+static INTBIG      ro_anglediff(INTBIG ang1, INTBIG ang2);
+static TECHNOLOGY *ro_findtech(NODEINST *ni, PORTPROTO *pp);
+static SRLAYER    *ro_mazeadd_layer(SRREGION *region, INTSML index,  SRDIRECTION direction, INTBIG gridx, INTBIG gridy, INTBIG alignx, INTBIG aligny);
+static SRNET      *ro_mazeadd_net(SRREGION *region);
+static SRPORT     *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, NODEINST *ni, PORTPROTO *pp);
+static INTSML      ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
+static void        ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTSML end, INTBIG dx, INTBIG dy);
+static SRNET      *ro_mazealloc_net(void);
+static SRPATH     *ro_mazealloc_path(void);
+static SRPORT     *ro_mazealloc_port(void);
+static SRWAVEPT   *ro_mazealloc_wavept(void);
+static void        ro_mazeclear_maze(SRNET *net);
+static INTSML      ro_mazecreate_wavefront(SRPORT *port);
+static SRREGION   *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy);
+static void        ro_mazedelete_net(SRNET *net);
+static void        ro_mazedelete_port(SRPORT *port);
+static void        ro_mazecleanout_region(SRREGION *region);
+static UINTBIG     ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy);
+static void        ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *region);
+static void        ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
+static void        ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
+static void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer);
+static void        ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers);
+static INTSML      ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
+static INTSML      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
+static INTSML      ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
+static INTSML      ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path);
+static INTBIG      ro_mazefindport(NODEPROTO*, INTBIG, INTBIG, ARCPROTO*, NODEINST *nis[], PORTPROTO *pps[], INTSML);
+static INTBIG      ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, INTSML forcefind);
+static void        ro_mazefree_net(SRNET *net);
+static void        ro_mazefree_path(SRPATH *path);
+static void        ro_mazefree_port(SRPORT *port);
+static void        ro_mazefree_wavept(SRWAVEPT *wavept);
+static SRPATH     *ro_mazeget_path(SRPORT *port, SRLAYER *layer, SREND e1, SREND e2, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
+static SRREGION   *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why, INTBIG gridx, INTBIG gridy, INTBIG offsetx, INTBIG offsety);
+static INTSML      ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code);
+static INTSML      ro_mazeroute_net(SRNET *net);
+static INTSML      ro_mazeroutenet(NETWORK *net);
+static SRWAVEPT   *ro_mazesearch_wavefront(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y);
+static void        ro_mazeset_box(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
+static void        ro_mazeset_line(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
+static void        ro_mazeset_point(SRLAYER *layer, SRGPT type, INTBIG x, INTBIG y, SRMODE mode);
+static INTSML      ro_mazetest_pt(SRGPT pt, INTBIG code);
 
 /*
  * Routine to free all memory associated with this module.
@@ -428,7 +426,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* get extent of net and mark nodes and arcs on it */
 	count = ro_findnetends(net, &nilist, &pplist, &xplist, &yplist);
@@ -681,7 +679,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 	INTBIG fcnt, tcnt, fx, fy, tx, ty, ofx, ofy, bits, xs, ys, xc, yc;
 	static POLYGON *poly = NOPOLYGON;
 
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* adjust paths to account for precise port location */
 	for (path = net->paths; path != NOSRPATH; path = path->next)
@@ -919,7 +917,7 @@ void ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *regi
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* if selected net or group route and temp1 is set */
 	if (net != NONETWORK && ai->network == net) return;
@@ -965,7 +963,7 @@ void ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION
 	ARCINST *iar;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	/* don't draw invisible pins */
 	np = ni->proto;
@@ -1062,7 +1060,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 	REGISTER PORTPROTO *pp, *closestpp;
 	REGISTER NODEINST *ni, *closestni;
 
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 
 	cnt = 0;
 	closestni = NONODEINST;
@@ -1099,6 +1097,8 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 					} else
 					{
 						dist = polydistance(poly, x, y);
+
+						/* LINTED "bestdist" used in proper order */
 						if (closestni == NONODEINST || dist < bestdist)
 						{
 							bestdist = dist;
@@ -1219,7 +1219,7 @@ SRNET *ro_mazealloc_net(void)
 		ro_mazenet_free_list = net->next;
 	} else
 	{
-		net = (SRNET *)emalloc(sizeof (SRNET), ro_aid->cluster);
+		net = (SRNET *)emalloc(sizeof (SRNET), ro_tool->cluster);
 		if (net == 0) return(NOSRNET);
 	}
 	return net;
@@ -1261,7 +1261,7 @@ SRPATH *ro_mazealloc_path(void)
 		ro_mazepath_free_list = path->next;
 	} else
 	{
-		path = (SRPATH *)emalloc(sizeof (SRPATH), ro_aid->cluster);
+		path = (SRPATH *)emalloc(sizeof (SRPATH), ro_tool->cluster);
 		if (path == 0) return(NOSRPATH);
 	}
 	return path;
@@ -1283,7 +1283,7 @@ SRPORT *ro_mazealloc_port(void)
 		ro_mazeport_free_list = port->next;
 	} else
 	{
-		port = (SRPORT *)emalloc(sizeof (SRPORT), ro_aid->cluster);
+		port = (SRPORT *)emalloc(sizeof (SRPORT), ro_tool->cluster);
 		if (port == 0) return(NOSRPORT);
 	}
 	return port;
@@ -1326,7 +1326,7 @@ SRWAVEPT *ro_mazealloc_wavept(void)
 		ro_mazewavept_free_list = wavept->next;
 	} else
 	{
-		wavept = (SRWAVEPT *)emalloc(sizeof (SRWAVEPT), ro_aid->cluster);
+		wavept = (SRWAVEPT *)emalloc(sizeof (SRWAVEPT), ro_tool->cluster);
 		if (wavept == 0) return(NOSRWAVEPT);
 	}
 	return wavept;
@@ -1349,7 +1349,7 @@ SRREGION *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why,
 
 	if (ro_theregion == NOSRREGION)
 	{
-		ro_theregion = (SRREGION *)emalloc(sizeof (SRREGION), ro_aid->cluster);
+		ro_theregion = (SRREGION *)emalloc(sizeof (SRREGION), ro_tool->cluster);
 		if (ro_theregion == NOSRREGION) return NOSRREGION;
 		for (index = 0; index < SRMAXLAYERS; index++)
 			ro_theregion->layers[index] = NOSRLAYER;
@@ -1407,7 +1407,7 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
 	if (region->layers[index] == NOSRLAYER)
 	{
 		/* allocate and initialize the layer */
-		layer = (SRLAYER *)emalloc(sizeof (SRLAYER), ro_aid->cluster);
+		layer = (SRLAYER *)emalloc(sizeof (SRLAYER), ro_tool->cluster);
 		if (layer == NOSRLAYER) return NOSRLAYER;
 		region->layers[index] = layer;
 		layer->grids = 0;
@@ -1462,14 +1462,14 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
 			efree((char *)layer->grids);
 			layer->grids = 0;
 		}
-		layer->grids = (SRGPT **)emalloc(sizeof (SRGPT *) * layer->wid, ro_aid->cluster);
+		layer->grids = (SRGPT **)emalloc(sizeof (SRGPT *) * layer->wid, ro_tool->cluster);
 		if (layer->grids == NULL) return NOSRLAYER;
 		if (layer->vused != 0)
 		{
 			efree((char *)layer->vused);
 			layer->vused = 0;
 		}
-		layer->vused = (char *)emalloc(sizeof (char) * layer->wid, ro_aid->cluster);
+		layer->vused = (char *)emalloc(sizeof (char) * layer->wid, ro_tool->cluster);
 		if (layer->vused == NULL) return NOSRLAYER;
 		layer->allocwid = layer->wid;
 	}
@@ -1480,7 +1480,7 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
 			efree((char *)layer->hused);
 			layer->hused = 0;
 		}
-		layer->hused = (char *)emalloc(sizeof (char) * layer->hei, ro_aid->cluster);
+		layer->hused = (char *)emalloc(sizeof (char) * layer->hei, ro_tool->cluster);
 		if (layer->hused == NULL) return NOSRLAYER;
 		layer->allochei = layer->hei;
 	}
@@ -1491,7 +1491,7 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
 			efree((char *)layer->array);
 			layer->array = 0;
 		}
-		layer->array = (SRGPT *)emalloc(sizeof (SRGPT *) * layer->wid * layer->hei, ro_aid->cluster);
+		layer->array = (SRGPT *)emalloc(sizeof (SRGPT *) * layer->wid * layer->hei, ro_tool->cluster);
 		if (layer->array == NULL) return NOSRLAYER;
 		layer->allocarray = layer->wid * layer->hei;
 	}
@@ -1713,18 +1713,6 @@ SRPATH *ro_mazeget_path(SRPORT *port, SRLAYER *layer,
 	return path;
 }
 
-SRPATH *ro_mazeadd_path(SRPORT *port, SRLAYER *layer, SREND e1, SREND e2,
-	INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
-{
-	SRPATH *path;
-
-	path = ro_mazeget_path(port, layer, e1, e2, x1, y1, x2, y2);
-	if (path == NOSRPATH) return NOSRPATH;
-
-	path->type = SRPFIXED;
-	return path;
-}
-
 SRPORT *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2,
 	NODEINST *ni, PORTPROTO *pp)
 {
@@ -2011,12 +1999,12 @@ INTSML ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 	code = layer->grids[sx][sy] & SR_GMASK;
 	if (code == SR_GSTART) code = SR_GMAX;
 		else code--;
-	do
+	for(;;)
 	{
 		dx = dy = 0;
 
 		/* scan around the point */
-		do
+		for(;;)
 		{
 			if (pstart == 1)
 			{
@@ -2233,13 +2221,13 @@ INTSML ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 
 			/* could not start route, just return */
 			return SRERROR;
-		} while (1);
+		}
 
 		/* set path started */
 		pstart = 1;
 
 		/* now continue scan until the end of the path */
-		while (1)
+		for(;;)
 		{
 			if (code == SR_GSTART) code = SR_GMAX;
 				else code--;
@@ -2370,7 +2358,7 @@ INTSML ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 			sy = ey;
 			break;
 		}
-	} while (1);
+	}
 }
 
 INTSML ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code)
@@ -2489,8 +2477,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 				status = ro_mazeexamine_pt(port, layer, x, wavept->y, code);
 				if (status == SRROUTED)
 				{
-					if (!found ||
-						(layer->hused[bwavept.y] & SR_GSET)  ||
+					/* LINTED "bwavept" used in proper order */
+					if (!found || (layer->hused[bwavept.y] & SR_GSET)  ||
 						(!(layer->hused[wavept->y] & SR_GSET) &&
 						layer->hused[wavept->y] < layer->hused[bwavept.y]))
 					{
@@ -2917,7 +2905,7 @@ void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
 				{
 					if (layer->grids[x][y] & SR_GWAVE) gpt = 'W'; else
 						if (layer->grids[x][y] != 0)
-							gpt =  'A' + (layer->grids[x][y] & SR_GMASK) - SR_GSTART;
+							gpt = 'A' + (layer->grids[x][y] & SR_GMASK) - SR_GSTART;
 				}
 			}
 			xprintf(ro_mazedebuggingout, "%c", gpt);
@@ -2927,4 +2915,4 @@ void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
 	xprintf(ro_mazedebuggingout, "\n");
 }
 
-#endif  /* ROUTAID - at top */
+#endif  /* ROUTTOOL - at top */
