@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: routmimic.c
- * Arc mimic code for the wire routing aid
+ * Arc mimic code for the wire routing tool
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if ROUTAID
+#if ROUTTOOL
 
 #include "global.h"
 #include "rout.h"
@@ -50,15 +50,16 @@ typedef struct Ipossiblearc
 	struct Ipossiblearc *nextpossiblearc;
 } POSSIBLEARC;
 
-POSSIBLEARC *ro_mimicpossiblearcfree = NOPOSSIBLEARC;
+static POSSIBLEARC *ro_mimicpossiblearcfree = NOPOSSIBLEARC;
 
-INTBIG ro_totalmimicports = 0;
-POLYGON **ro_mimicportpolys;
+static INTBIG       ro_totalmimicports = 0;
+static POLYGON    **ro_mimicportpolys;
 
-void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports);
-INTBIG ro_mimiccreate(ARCINST *arc);
-POSSIBLEARC *ro_allocpossiblearc(void);
-void ro_freepossiblearc(POSSIBLEARC *pa);
+/* prototypes for local routines */
+static void         ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports);
+static INTBIG       ro_mimiccreate(ARCINST *arc);
+static POSSIBLEARC *ro_allocpossiblearc(void);
+static void         ro_freepossiblearc(POSSIBLEARC *pa);
 
 /*
  * Routine to free all memory associated with this module.
@@ -215,7 +216,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 	ttyputmsg(_("Mimicing last arc..."));
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, ro_tool->cluster);
 
 	facet = ai->parent;
 	options = ro_getoptions();
@@ -240,11 +241,11 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 	if (total == 0) return(count);
 	if (total > ro_totalmimicports)
 	{
-		newportpolys = (POLYGON **)emalloc(total * (sizeof (POLYGON *)), ro_aid->cluster);
+		newportpolys = (POLYGON **)emalloc(total * (sizeof (POLYGON *)), ro_tool->cluster);
 		for(i=0; i<ro_totalmimicports; i++)
 			newportpolys[i] = ro_mimicportpolys[i];
 		for(i=ro_totalmimicports; i<total; i++)
-			newportpolys[i] = allocpolygon(4, ro_aid->cluster);
+			newportpolys[i] = allocpolygon(4, ro_tool->cluster);
 		if (ro_totalmimicports > 0) efree((char *)ro_mimicportpolys);
 		ro_mimicportpolys = newportpolys;
 		ro_totalmimicports = total;
@@ -465,8 +466,8 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 		} else
 		{
 			/* show the wires to be created */
-			(void)askaid(us_aid, "down-stack");
-			(void)askaid(us_aid, "clear");
+			(void)asktool(us_tool, "down-stack");
+			(void)asktool(us_tool, "clear");
 			total = 0;
 			for(pa = firstpossiblearc; pa != NOPOSSIBLEARC; pa = pa->nextpossiblearc)
 			{
@@ -474,17 +475,17 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				if (pa->x1 == pa->x2 && pa->y1 == pa->y2)
 				{
 					dist = el_curlib->lambda[el_curtech->techindex];
-					(void)askaid(us_aid, "show-area", pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
+					(void)asktool(us_tool, "show-area", pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
 						(INTBIG)facet);
 				} else
 				{
-					(void)askaid(us_aid, "show-line", pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
+					(void)asktool(us_tool, "show-line", pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
 				}
 				total++;
 			}
 			sprintf(question, _("Create %ld %s shown here?"), total, makeplural(_("wire"), total));
 			total = ttygetparam(question, &us_yesnop, 5, pars);
-			(void)askaid(us_aid, "up-stack");
+			(void)asktool(us_tool, "up-stack");
 			if (total > 0 && namesamen(pars[0], "no", strlen(pars[0])) == 0) continue;
 		}
 
@@ -507,7 +508,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 			endobjectchange((INTBIG)newai, VARCINST);
 			count++;
 		}
-		(void)askaid(us_aid, "flush-changes");
+		(void)asktool(us_tool, "flush-changes");
 	}
 
 	/* free memory for mimicing */
@@ -528,7 +529,7 @@ POSSIBLEARC *ro_allocpossiblearc(void)
 
 	if (ro_mimicpossiblearcfree == NOPOSSIBLEARC)
 	{
-		pa = (POSSIBLEARC *)emalloc(sizeof (POSSIBLEARC), ro_aid->cluster);
+		pa = (POSSIBLEARC *)emalloc(sizeof (POSSIBLEARC), ro_tool->cluster);
 		if (pa == 0) return(NOPOSSIBLEARC);
 	} else
 	{
@@ -544,4 +545,4 @@ void ro_freepossiblearc(POSSIBLEARC *pa)
 	ro_mimicpossiblearcfree = pa;
 }
 
-#endif  /* ROUTAID - at top */
+#endif  /* ROUTTOOL - at top */
