@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: routriver.c
- * Routines for the river-routing option of the routing aid
+ * Routines for the river-routing option of the routing tool
  * Written by: Telle Whitney, Schlumberger Palo Alto Research
  *
  * Copyright (c) 2000 Static Free Software.
@@ -68,7 +68,7 @@
  */
 
 #include "config.h"
-#if ROUTAID
+#if ROUTTOOL
 
 #include "global.h"
 #include "rout.h"
@@ -222,72 +222,71 @@ static COMCOMP ro_riverp = {ro_riveropt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 
 /******** prototypes for local routines ********/
 
-RPATH *ro_newrpath(INTBIG, ARCPROTO*, INTSML);
-void ro_freerpath(RPATH*);
-RPOINT *ro_newrivpoint(RPATH*, INTBIG, INTBIG, RPOINT*);
-RPOINT *ro_newrvpoint(INTBIG, INTBIG, INTSML);
-void ro_freerivpoint(RPOINT*);
-RCOORD *ro_newcoord(INTBIG);
-RDESC *ro_newroutedesc(INTBIG, INTBIG, INTSML, INTBIG, INTBIG, INTSML, ARCINST*, INTBIG, ARCINST*, INTBIG, RDESC*);
-void ro_freeroutedesc(RDESC*);
-RDESC **ro_newrdarray(INTSML);
-void ro_freerdarray(RDESC**);
-void ro_initialize(void);
-void ro_clipwire(RPOINT*, INTBIG, INTBIG);
-INTSML ro_check_points(RDESC*, INTBIG, INTBIG);
-RDESC *ro_addright(RDESC*, RDESC*);
-RDESC *ro_addleft(RDESC*, RDESC*);
-void ro_structure_points(RDESC*);
-INTSML ro_check_structured_points(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG);
-RDESC *ro_reverse(RDESC*);
-void ro_cleanup(void);
-INTSML ro_routepathtype(RPOINT*, RPOINT*);
-RPATH *ro_makeorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
-RPATH *ro_addpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
-RPATH *ro_makesideorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
-RPATH *ro_sideaddpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
-INTSML ro_process_right(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
-INTSML ro_process_left(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
-void ro_remap_points(RPOINT*, TRANSFORM*);
-INTBIG ro_remap_second(INTBIG, TRANSFORM*);
-INTBIG ro_height_coordinate(INTBIG);
-INTSML ro_calculate_height_and_process(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG*);
-void ro_calculate_bb(INTBIG*, INTBIG*, INTBIG*, INTBIG*, RDESC*, RDESC*);
-INTSML ro_sorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void ro_swap(INTBIG, INTBIG, RDESC**);
-void ro_sortquick(INTBIG, INTBIG, INTBIG, RDESC**);
-RDESC *ro_quicksort(RDESC*);
-INTSML ro_unsorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void ro_checkthefacet(NODEINST*);
-void ro_pseudomake(RDESC*, NODEPROTO*);
-void ro_makepseudogeometry(NODEPROTO*);
-NODEINST *ro_thenode(RDESC*, NODEPROTO*, RPOINT*, NODEPROTO*);
-PORTPROTO *ro_theport(PORTPROTO*, RDESC*, RPOINT*);
-void ro_makegeometry(RDESC*, NODEPROTO*);
-void ro_clear_flags(NODEPROTO*);
-INTSML ro_isunroutedpin(NODEINST*);
-INTSML ro_is_interesting_arc(ARCINST*);
-void ro_set_flags(ARCINST*);
-void ro_mark_tobedeleted(ARCINST*);
-INTSML ro_delnodeinst(NODEINST*);
-void ro_kill_wires(NODEPROTO*);
-void ro_makethegeometry(NODEPROTO*);
-RCOORD *ro_tallyvote(RCOORD*, INTBIG);
-void ro_vote(INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML ro_simplefigxx(RCOORD*, RCOORD*, RCOORD*, RCOORD*, INTSML, RCOORD**, RCOORD**);
-RCOORD *ro_largest(RCOORD*);
-RCOORD *ro_next_largest(RCOORD*, RCOORD*);
-void ro_figureoutrails(INTSML);
-INTBIG ro_point_val(RPOINT*, INTSML);
-void ro_swap_points(RDESC*);
-void ro_set_wires_to_rails(RDESC*);
-RDESC *ro_addwire(RDESC*, ARCINST*, INTSML*);
-RDESC *ro_findhighlightedwires(NODEPROTO*, INTSML*);
-RDESC *ro_findnormalwires(NODEPROTO*, INTSML*);
-INTSML ro_findwires(NODEPROTO*);
-INTSML ro_move_instance(void);
-INTSML ro_query_user(void);
-void ro_sumup(PORTARCINST*);
+static RPATH *ro_newrpath(INTBIG, ARCPROTO*, INTSML);
+static void ro_freerpath(RPATH*);
+static RPOINT *ro_newrivpoint(RPATH*, INTBIG, INTBIG, RPOINT*);
+static RPOINT *ro_newrvpoint(INTBIG, INTBIG, INTSML);
+static void ro_freerivpoint(RPOINT*);
+static RCOORD *ro_newcoord(INTBIG);
+static RDESC *ro_newroutedesc(INTBIG, INTBIG, INTSML, INTBIG, INTBIG, INTSML, ARCINST*, INTBIG, ARCINST*, INTBIG, RDESC*);
+static void ro_freeroutedesc(RDESC*);
+static RDESC **ro_newrdarray(INTSML);
+static void ro_freerdarray(RDESC**);
+static void ro_initialize(void);
+static void ro_clipwire(RPOINT*, INTBIG, INTBIG);
+static INTSML ro_check_points(RDESC*, INTBIG, INTBIG);
+static RDESC *ro_addright(RDESC*, RDESC*);
+static RDESC *ro_addleft(RDESC*, RDESC*);
+static void ro_structure_points(RDESC*);
+static INTSML ro_check_structured_points(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG);
+static RDESC *ro_reverse(RDESC*);
+static void ro_cleanup(void);
+static INTSML ro_routepathtype(RPOINT*, RPOINT*);
+static RPATH *ro_makeorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
+static RPATH *ro_addpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
+static RPATH *ro_makesideorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
+static RPATH *ro_sideaddpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
+static INTSML ro_process_right(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
+static INTSML ro_process_left(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
+static void ro_remap_points(RPOINT*, TRANSFORM*);
+static INTBIG ro_remap_second(INTBIG, TRANSFORM*);
+static INTBIG ro_height_coordinate(INTBIG);
+static INTSML ro_calculate_height_and_process(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG*);
+static void ro_calculate_bb(INTBIG*, INTBIG*, INTBIG*, INTBIG*, RDESC*, RDESC*);
+static INTSML ro_sorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static RDESC *ro_quicksort(RDESC*);
+static INTSML ro_unsorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void ro_checkthefacet(NODEINST*);
+static void ro_pseudomake(RDESC*, NODEPROTO*);
+static void ro_makepseudogeometry(NODEPROTO*);
+static NODEINST *ro_thenode(RDESC*, NODEPROTO*, RPOINT*, NODEPROTO*);
+static PORTPROTO *ro_theport(PORTPROTO*, RDESC*, RPOINT*);
+static void ro_makegeometry(RDESC*, NODEPROTO*);
+static void ro_clear_flags(NODEPROTO*);
+static INTSML ro_isunroutedpin(NODEINST*);
+static INTSML ro_is_interesting_arc(ARCINST*);
+static void ro_set_flags(ARCINST*);
+static void ro_mark_tobedeleted(ARCINST*);
+static INTSML ro_delnodeinst(NODEINST*);
+static void ro_kill_wires(NODEPROTO*);
+static void ro_makethegeometry(NODEPROTO*);
+static RCOORD *ro_tallyvote(RCOORD*, INTBIG);
+static void ro_vote(INTBIG, INTBIG, INTBIG, INTBIG);
+static INTSML ro_simplefigxx(RCOORD*, RCOORD*, RCOORD*, RCOORD*, INTSML, RCOORD**, RCOORD**);
+static RCOORD *ro_largest(RCOORD*);
+static RCOORD *ro_next_largest(RCOORD*, RCOORD*);
+static void ro_figureoutrails(INTSML);
+static INTBIG ro_point_val(RPOINT*, INTSML);
+static void ro_swap_points(RDESC*);
+static void ro_set_wires_to_rails(RDESC*);
+static RDESC *ro_addwire(RDESC*, ARCINST*, INTSML*);
+static RDESC *ro_findhighlightedwires(NODEPROTO*, INTSML*);
+static RDESC *ro_findnormalwires(NODEPROTO*, INTSML*);
+static INTSML ro_findwires(NODEPROTO*);
+static INTSML ro_move_instance(void);
+static INTSML ro_query_user(void);
+static void ro_sumup(PORTARCINST*);
+static int ro_rivpointascending(const void*, const void*);
 
 /******************** MEMORY MANAGEMENT ROUTINES ****************************/
 
@@ -295,7 +294,7 @@ RPATH *ro_newrpath(INTBIG width, ARCPROTO *ptype, INTSML routetype)
 {
 	RPATH *rp;
 
-	rp = (RPATH *)emalloc(sizeof(RPATH), ro_aid->cluster);
+	rp = (RPATH *)emalloc(sizeof(RPATH), ro_tool->cluster);
 	if (rp == 0) return(0);
 	rp->width = width;   rp->pathtype = ptype;   rp->routetype = routetype;
 	rp->pathdesc = NULLRPOINT;   rp->lastp = NULLRPOINT;
@@ -317,7 +316,7 @@ RPOINT *ro_newrivpoint(RPATH *rp, INTBIG first, INTBIG sec, RPOINT *next)
 {
 	RPOINT *rvp;
 
-	rvp = (RPOINT *)emalloc(sizeof(RPOINT), ro_aid->cluster);
+	rvp = (RPOINT *)emalloc(sizeof(RPOINT), ro_tool->cluster);
 	if (rvp == 0) return(0);
 	rvp->first = first;   rvp->second = sec;   rvp->x = 0;   rvp->y = 0;
 	rvp->side = NOSIDE;
@@ -332,7 +331,7 @@ RPOINT *ro_newrvpoint(INTBIG x, INTBIG y, INTSML side)
 {
 	RPOINT *rvp;
 
-	rvp = (RPOINT *)emalloc(sizeof(RPOINT), ro_aid->cluster);
+	rvp = (RPOINT *)emalloc(sizeof(RPOINT), ro_tool->cluster);
 	if (rvp == 0) return(0);
 	rvp->x = x;   rvp->y = y;   rvp->first = 0;   rvp->second = 0;
 	rvp->side = side;
@@ -349,7 +348,7 @@ RCOORD *ro_newcoord(INTBIG c)
 {
 	RCOORD *cc;
 
-	cc = (RCOORD *)emalloc(sizeof(RCOORD), ro_aid->cluster);
+	cc = (RCOORD *)emalloc(sizeof(RCOORD), ro_tool->cluster);
 	if (cc == 0) return(0);
 	cc->val = c;   cc->total = 0;
 	cc->next = NULLCOORD;
@@ -361,7 +360,7 @@ RDESC *ro_newroutedesc(INTBIG fx, INTBIG fy, INTSML fside, INTBIG sx, INTBIG sy,
 {
 	RDESC *rd;
 
-	rd = (RDESC *)emalloc(sizeof(RDESC), ro_aid->cluster);
+	rd = (RDESC *)emalloc(sizeof(RDESC), ro_tool->cluster);
 	if (rd == 0) return(0);
 	rd->from = ro_newrvpoint(fx, fy, fside);
 	if (rd->from == 0) return(0);
@@ -386,7 +385,7 @@ RDESC **ro_newrdarray(INTSML size)
 	RDESC **r;
 	INTSML i;
 
-	r = (RDESC **)emalloc(((size+1)*sizeof(RDESC *)), ro_aid->cluster);
+	r = (RDESC **)emalloc(((size+1)*sizeof(RDESC *)), ro_tool->cluster);
 	if (r == 0) return(0);
 	for(i=0; i<=size; i++) r[i] = NULLRDESC;
 	return(r);
@@ -1100,57 +1099,17 @@ INTSML ro_sorted_rivrot(ARCPROTO *layerdesc, RDESC *listr, INTBIG width,
 	return(YES);
 }
 
-/* sort the points before doing the river route */
-void ro_swap(INTBIG first, INTBIG second, RDESC **thelist)
+/*
+ * Helper routine for "esort" that makes river points go in ascending order.
+ * Used from "ro_quicksort()".
+ */
+int ro_rivpointascending(const void *e1, const void *e2)
 {
-	RDESC *temp;
+	REGISTER RDESC *c1, *c2;
 
-	temp = thelist[first];
-	thelist[first] = thelist[second];
-	thelist[second] = temp;
-}
-
-void ro_sortquick(INTBIG start, INTBIG endv, INTBIG len, RDESC **thelist)
-{
-	INTBIG mright, mleft, endv1;
-	INTBIG valcr;
-	INTBIG i, swp;
-
-	if (endv-start > 9)
-	{
-		/* do a quicksort */
-		mright = endv+1;
-		mleft = start;
-		valcr = thelist[start]->sortval;
-		while (mleft < mright)
-		{
-			mleft = mleft+1;
-			while (thelist[mleft]->sortval < valcr && mleft != len) mleft++;
-			mright--;
-			while (thelist[mright]->sortval > valcr) mright--;
-			if (mleft < mright) ro_swap(mright, mleft, thelist);
-		}
-		ro_swap(start, mright, thelist);
-		ro_sortquick(start, mright-1, len, thelist);
-		ro_sortquick(mleft, endv, len, thelist);
-	} else
-	{
-		/* do a bubble sort */
-		swp = YES;
-		while (swp)
-		{
-			swp = NO;
-			endv1 = endv-1;
-			for(i = start; i <= endv1; i++)
-			{
-				if (thelist[i]->sortval > thelist[i+1]->sortval)
-				{
-					ro_swap(i, i+1, thelist);
-					swp = YES;
-				}
-			}
-		}
-	}
+	c1 = *((RDESC **)e1);
+	c2 = *((RDESC **)e2);
+	return(c1->sortval - c2->sortval);
 }
 
 /* Quicksorts the rivpoints */
@@ -1172,7 +1131,8 @@ RDESC *ro_quicksort(RDESC *rd)
 		rd->sortval = (xdir ? rd->from->x : rd->from->y);
 	}
 
-	ro_sortquick(0, len-1, len-1, thearray);
+	/* instead of "ro_sortquick(0, len-1, len-1, thearray)"... */
+	esort(thearray, len, sizeof (RDESC *), ro_rivpointascending);
 	for(i=0; i<len; i++) thearray[i]->next = thearray[i+1];
 	r = *thearray;   ro_freerdarray(thearray);
 	return(r);
@@ -1219,7 +1179,7 @@ void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
 			if (prev->x == rp->x && rp->x == rp->next->x) continue;
 			if (prev->y == rp->y && rp->y == rp->next->y) continue;
 		}
-		(void)askaid(us_aid, "show-line", prev->x, prev->y, rp->x, rp->y, facet);
+		(void)asktool(us_tool, "show-line", prev->x, prev->y, rp->x, rp->y, facet);
 		prev = rp;
 	}
 	ro_checkthefacet(rd->unroutedwire2->end[rd->unroutedend2].nodeinst);
@@ -1237,7 +1197,7 @@ void ro_makepseudogeometry(NODEPROTO *facet)
 		latoa(ro_rrinfo.urx), latoa(ro_rrinfo.lly), latoa(ro_rrinfo.ury));
 
 	/* remove highlighting */
-	(void)askaid(us_aid, "clear");
+	(void)asktool(us_tool, "clear");
 
 	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
 	for(q = ro_rrinfo.leftp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
@@ -1443,7 +1403,7 @@ void ro_makethegeometry(NODEPROTO *np)
 {
 	RDESC *q;
 
-	(void)askaid(us_aid, "clear");
+	(void)asktool(us_tool, "clear");
 	ro_clear_flags(np);
 	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next)
 	{
@@ -1698,7 +1658,7 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTSML *tot)
 	INTSML i, total, wireadded;
 
 	/* get list of all highlighted arcs */
-	list = (GEOM **)askaid(us_aid, "get-all-arcs");
+	list = (GEOM **)asktool(us_tool, "get-all-arcs");
 	if (list[0] == NOGEOM)
 	{
 		total = 0;   tot = &total;
@@ -1706,7 +1666,7 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTSML *tot)
 	}
 
 	/* get boundary of highlight */
-	(void)askaid(us_aid, "get-highlighted-area", (INTBIG)&ro_rrinfo.llx,
+	(void)asktool(us_tool, "get-highlighted-area", (INTBIG)&ro_rrinfo.llx,
 		(INTBIG)&ro_rrinfo.urx, (INTBIG)&ro_rrinfo.lly, (INTBIG)&ro_rrinfo.ury);
 
 	/* reset flags on all arcs in this facet */
@@ -1767,6 +1727,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER ARCINST *ai;
 	INTSML total;
+	INTBIG edge;
 	RDESC *thelist;
 	REGISTER VARIABLE *var;
 
@@ -1792,7 +1753,7 @@ INTSML ro_findwires(NODEPROTO *np)
 
 	/* first look for the current arcproto */
 	wantap = NOARCPROTO;
-	var = getval((INTBIG)us_aid, VAID, VARCPROTO, "USER_current_arc");
+	var = getval((INTBIG)us_tool, VTOOL, VARCPROTO, "USER_current_arc");
 	if (var != NOVARIABLE)
 	{
 		ap = (ARCPROTO *)var->addr;
@@ -1833,7 +1794,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	ro_figureoutrails(total);   ro_set_wires_to_rails(thelist);
 
 	/* figure out the worst design rule spacing for this type of arc */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, ro_tool->cluster);
 	ai = dummyarc();
 	ai->proto = wantap;
 	ai->width = defaultarcwidth(wantap);
@@ -1841,7 +1802,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	(void)arcpolys(ai, NOWINDOWPART);
 	shapearcpoly(ai, 0, poly);
 	amt = drcmindistance(ai->proto->tech, np->cell->lib, poly->layer, ai->width,
-		poly->layer, ai->width, 0, 0, 0);
+		poly->layer, ai->width, 0, 0, &edge, 0);
 	if (amt < 0) amt = lambdaofarc(ai);
 	return(ro_unsorted_rivrot(wantap, thelist, ai->width, amt, amt, amt, 0));
 }
@@ -1941,4 +1902,4 @@ void ro_sumup(PORTARCINST *pi)
 		pi->proto->connects[i]->temp1++;
 }
 
-#endif  /* ROUTAID - at top */
+#endif  /* ROUTTOOL - at top */
