@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SCAID
+#if SCTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -41,7 +41,7 @@
 ------------------------------------------------------------------------
 */
 
-AIDENTRY         *sc_aid;			/* the Silicon Compiler aid object */
+TOOL             *sc_tool;			/* the Silicon Compiler tool object */
 INTBIG            sc_filetypescsim;	/* Silicon compiler simulation file descriptor */
 INTBIG            sc_filetypesctab;	/* Silicon compiler table file descriptor */
 static INTBIG     sc_simkey;		/* key for the ALS info */
@@ -62,33 +62,33 @@ extern int        sc_sim_format;
 extern COMCOMP    sc_makep;
 
 /* prototypes for local routines */
-void Sc_set_leaf_port_type(PORTPROTO*, int);
-void Sc_create_connection(NODEINST **ni, PORTPROTO **pp, INTBIG x, INTBIG y,
-	ARCPROTO *arc);
-void sc_optionsdlog(void);
+static void Sc_set_leaf_port_type(PORTPROTO*, int);
+static void Sc_create_connection(NODEINST **ni, PORTPROTO **pp, INTBIG x, INTBIG y,
+			ARCPROTO *arc);
+static void sc_optionsdlog(void);
 
 /***********************************************************************
 Module:  sc_init
 ------------------------------------------------------------------------
 Description:
-	Initialize routine for the Silicon Compiler aid.
+	Initialize routine for the Silicon Compiler tool.
 ------------------------------------------------------------------------
 */
 
-void sc_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void sc_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* only initialize during pass 1 */
-	if (thisaid == NOAID || thisaid == 0) return;
-	sc_aid = thisaid;
+	if (thistool == NOTOOL || thistool == 0) return;
+	sc_tool = thistool;
 	Sc_initialize();
 	if ((sc_simkey = makekey("SC_sim")) == -1)
-		ttyputmsg("ERROR making SIM key in SC Aid");
+		ttyputmsg("ERROR making SIM key in SC Tool");
 	if ((sc_bitskey = makekey("SC_bits")) == -1)
-		ttyputmsg("ERROR making BITS key in SC Aid");
+		ttyputmsg("ERROR making BITS key in SC Tool");
 	if ((sc_numskey = makekey("SC_nums")) == -1)
-		ttyputmsg("ERROR making NUMS key in SC Aid");
+		ttyputmsg("ERROR making NUMS key in SC Tool");
 	if ((sc_silkey = makekey("SC_silos")) == -1)
-		ttyputmsg("ERROR making SILOS key in SC Aid.");
+		ttyputmsg("ERROR making SILOS key in SC Tool.");
 	DiaDeclareHook("silcomp", &sc_makep, sc_optionsdlog);
 	sc_filetypescsim = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "scsim", _("QUISC simulation"));
 	sc_filetypesctab = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "sctab", _("QUISC table"));
@@ -98,7 +98,7 @@ void sc_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 Module:  sc_slice
 ------------------------------------------------------------------------
 Description:
-	Main module of the Silicon Compiler aid.  Invoked by the onaid
+	Main module of the Silicon Compiler tool.  Invoked by the ontool
 	command.
 ------------------------------------------------------------------------
 */
@@ -107,14 +107,14 @@ void sc_slice(void)
 {
 	el_pleasestop = 0;
 	Sc_main();
-	aidturnoff(sc_aid, 0);
+	toolturnoff(sc_tool, 0);
 }
 
 /***********************************************************************
 Module:  sc_set
 ------------------------------------------------------------------------
 Description:
-	Module invoked by the tellaid command.
+	Module invoked by the telltool command.
 ------------------------------------------------------------------------
 */
 
@@ -128,7 +128,7 @@ INTSML sc_set(INTSML count, char *pars[])
 Module:  sc_request
 ------------------------------------------------------------------------
 Description:
-	Module invoked by the askaid command.
+	Module invoked by the asktool command.
 ------------------------------------------------------------------------
 */
 
@@ -140,7 +140,7 @@ INTBIG sc_request(char *command, va_list ap)
 }
 
 /***********************************************************************
-Default Silicon Compiler aid routines.
+Default Silicon Compiler tool routines.
 ------------------------------------------------------------------------
 */
 
@@ -175,71 +175,71 @@ INTBIG ScGetParameter(INTBIG paramnum)
 	switch (paramnum)
 	{
 		case SC_PARAM_MAKE_HORIZ_ARC:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_horiz_arc");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_horiz_arc");
 			if (var == NOVARIABLE) return((INTBIG)DEFAULT_ARC_HORIZONTAL);
 			break;
 		case SC_PARAM_MAKE_VERT_ARC:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_vert_arc");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_vert_arc");
 			if (var == NOVARIABLE) return((INTBIG)DEFAULT_ARC_VERTICAL);
 			break;
 		case SC_PARAM_MAKE_L1_WIDTH:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_l1_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_l1_width");
 			if (var == NOVARIABLE) return(DEFAULT_L1_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_L2_WIDTH:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_l2_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_l2_width");
 			if (var == NOVARIABLE) return(DEFAULT_L2_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_PWR_WIDTH:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_pwr_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwr_width");
 			if (var == NOVARIABLE) return(DEFAULT_POWER_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_WIDTH:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_main_pwr_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_main_pwr_width");
 			if (var == NOVARIABLE) return(DEFAULT_MAIN_POWER_WIDTH);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_RAIL:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_main_pwr_rail");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_main_pwr_rail");
 			if (var == NOVARIABLE) return(DEFAULT_MAIN_POWER_RAIL);
 			break;
 		case SC_PARAM_MAKE_PWELL_SIZE:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_pwell_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwell_size");
 			if (var == NOVARIABLE) return(DEFAULT_PWELL_SIZE);
 			break;
 		case SC_PARAM_MAKE_PWELL_OFFSET:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_pwell_offset");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwell_offset");
 			if (var == NOVARIABLE) return(DEFAULT_PWELL_OFFSET);
 			break;
 		case SC_PARAM_MAKE_NWELL_SIZE:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_nwell_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_nwell_size");
 			if (var == NOVARIABLE) return(DEFAULT_NWELL_SIZE);
 			break;
 		case SC_PARAM_MAKE_NWELL_OFFSET:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_nwell_offset");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_nwell_offset");
 			if (var == NOVARIABLE) return(DEFAULT_NWELL_OFFSET);
 			break;
 		case SC_PARAM_MAKE_VIA_SIZE:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_via_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_via_size");
 			if (var == NOVARIABLE) return(DEFAULT_VIA_SIZE);
 			break;
 		case SC_PARAM_MAKE_MIN_SPACING:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_min_spacing");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_min_spacing");
 			if (var == NOVARIABLE) return(DEFAULT_MIN_SPACING);
 			break;
 		case SC_PARAM_ROUTE_FEEDTHRU_SIZE:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_feedthru_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_feedthru_size");
 			if (var == NOVARIABLE) return(DEFAULT_FEED_THROUGH_SIZE);
 			break;
 		case SC_PARAM_ROUTE_PORT_X_MIN_DIST:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_port_x_min_dist");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_port_x_min_dist");
 			if (var == NOVARIABLE) return(DEFAULT_PORT_X_MIN_DISTANCE);
 			break;
 		case SC_PARAM_ROUTE_ACTIVE_DIST:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_active_dist");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_active_dist");
 			if (var == NOVARIABLE) return(DEFAULT_ACTIVE_DISTANCE);
 			break;
 		case SC_PARAM_PLACE_NUM_ROWS:
-			var = getval((INTBIG)sc_aid, VAID, -1, "SC_num_rows");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_num_rows");
 			if (var == NOVARIABLE) return(DEFAULT_NUM_OF_ROWS);
 			break;
 	}
@@ -251,55 +251,55 @@ void ScSetParameter(INTBIG paramnum, INTBIG addr)
 	switch (paramnum)
 	{
 		case SC_PARAM_MAKE_HORIZ_ARC:
-			setval((INTBIG)sc_aid, VAID, "SC_horiz_arc", addr, VARCPROTO);
+			setval((INTBIG)sc_tool, VTOOL, "SC_horiz_arc", addr, VARCPROTO);
 			break;
 		case SC_PARAM_MAKE_VERT_ARC:
-			setval((INTBIG)sc_aid, VAID, "SC_vert_arc", addr, VARCPROTO);
+			setval((INTBIG)sc_tool, VTOOL, "SC_vert_arc", addr, VARCPROTO);
 			break;
 		case SC_PARAM_MAKE_L1_WIDTH:
-			setval((INTBIG)sc_aid, VAID, "SC_l1_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_l1_width", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_L2_WIDTH:
-			setval((INTBIG)sc_aid, VAID, "SC_l2_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_l2_width", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWR_WIDTH:
-			setval((INTBIG)sc_aid, VAID, "SC_pwr_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_pwr_width", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_WIDTH:
-			setval((INTBIG)sc_aid, VAID, "SC_main_pwr_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_main_pwr_width", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_RAIL:
-			setval((INTBIG)sc_aid, VAID, "SC_main_pwr_rail", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_main_pwr_rail", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWELL_SIZE:
-			setval((INTBIG)sc_aid, VAID, "SC_pwell_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_pwell_size", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWELL_OFFSET:
-			setval((INTBIG)sc_aid, VAID, "SC_pwell_offset", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_pwell_offset", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_NWELL_SIZE:
-			setval((INTBIG)sc_aid, VAID, "SC_nwell_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_nwell_size", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_NWELL_OFFSET:
-			setval((INTBIG)sc_aid, VAID, "SC_nwell_offset", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_nwell_offset", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_VIA_SIZE:
-			setval((INTBIG)sc_aid, VAID, "SC_via_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_via_size", addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MIN_SPACING:
-			setval((INTBIG)sc_aid, VAID, "SC_min_spacing", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_min_spacing", addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_FEEDTHRU_SIZE:
-			setval((INTBIG)sc_aid, VAID, "SC_feedthru_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_feedthru_size", addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_PORT_X_MIN_DIST:
-			setval((INTBIG)sc_aid, VAID, "SC_port_x_min_dist", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_port_x_min_dist", addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_ACTIVE_DIST:
-			setval((INTBIG)sc_aid, VAID, "SC_active_dist", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_active_dist", addr, VINTEGER);
 			break;
 		case SC_PARAM_PLACE_NUM_ROWS:
-			setval((INTBIG)sc_aid, VAID, "SC_num_rows", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, "SC_num_rows", addr, VINTEGER);
 			break;
 	}
 }
@@ -568,7 +568,7 @@ char  **Sc_leaf_facet_sim_info(char *leaffacet)
 	for (i = 0; simlist2[i] != NOSTRING; i++) numsim++;
 
 	/* create array of pointers */
-	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_aid->cluster))
+	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_tool->cluster))
 		== 0) return((char **)NULL);
 	for (i = 0; i < numsim; i++) simlist[i] = simlist2[i];
 	simlist[numsim] = NULL;
@@ -606,7 +606,7 @@ int Sc_leaf_facet_set_sim(SCSIM *simline, char *leaffacet)
 	for (nextsim = simline; nextsim; nextsim = nextsim->next) numsim++;
 
 	/* create array of pointers */
-	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_aid->cluster)) == 0)
+	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_tool->cluster)) == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	for (i = 0; i < numsim; i++)
 	{
@@ -685,7 +685,7 @@ int Sc_leaf_facet_set_nums(char *leaffacet, SCCELLNUMS *nums)
 	var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER|VISARRAY, sc_numskey);
 	if (var == NOVARIABLE)
 	{
-		if ((jarray = emalloc((i + 1) * sizeof(INTBIG), sc_aid->cluster)) == 0)
+		if ((jarray = emalloc((i + 1) * sizeof(INTBIG), sc_tool->cluster)) == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		iarray = (int *)nums;
 		for (j = 0; j < i; j++) jarray[j] = iarray[j];
@@ -1116,7 +1116,7 @@ int Sc_library_read(char *libname)
 		if (reallocstring(&lib->libfile, libname, lib->cluster))
 			return(Sc_seterrmsg(SC_NOMEMORY));
 	}
-	if (askaid(io_aid, "read", (INTBIG)lib, "binary") != 0)
+	if (asktool(io_tool, "read", (INTBIG)lib, "binary") != 0)
 	{
 		eraselibrary(lib);
 		return(Sc_seterrmsg(SC_LIBNOREAD, libname));
@@ -1174,10 +1174,11 @@ int Sc_setup_for_maker(ARCPROTO *layer1, ARCPROTO *layer2)
 {
 	REGISTER ARCPROTO *ap, *alternatearc, **arclist;
 	REGISTER int fun, i;
+	REGISTER TECHNOLOGY *tech;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* make sure there is a polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sc_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sc_tool->cluster);
 
 	/* find the horizontal (layer 1) and vertical (layer 2) arcs */
 	sc_layer1arc = sc_layer2arc = alternatearc = NOARCPROTO;
@@ -1205,8 +1206,11 @@ int Sc_setup_for_maker(ARCPROTO *layer1, ARCPROTO *layer2)
 	if (sc_layer1arc == NOARCPROTO) return(Sc_seterrmsg(SC_NO_LAYER1_ARC));
 	if (sc_layer2arc == NOARCPROTO) return(Sc_seterrmsg(SC_NO_LAYER2_ARC));
 
+	/* use technology of the first arc */
+	tech = sc_layer1arc->tech;
+
 	/* find the contact between the two layers */
-	for(sc_viaproto = el_curtech->firstnodeproto; sc_viaproto != NONODEPROTO;
+	for(sc_viaproto = tech->firstnodeproto; sc_viaproto != NONODEPROTO;
 		sc_viaproto = sc_viaproto->nextnodeproto)
 	{
 		fun = (sc_viaproto->userbits&NFUNCTION) >> NFUNCTIONSH;
@@ -1234,12 +1238,12 @@ int Sc_setup_for_maker(ARCPROTO *layer1, ARCPROTO *layer2)
 	 */
 	if (ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE) == 0) sc_pwellproto = NONODEPROTO; else
 	{
-		sc_pwellproto = getpurelayernode(el_curtech, -1, LFWELL|LFPTYPE);
+		sc_pwellproto = getpurelayernode(tech, -1, LFWELL|LFPTYPE);
 		if (sc_pwellproto == NONODEPROTO) return(Sc_seterrmsg(SC_NO_LAYER_PWELL));
 	}
 	if (ScGetParameter(SC_PARAM_MAKE_NWELL_SIZE) == 0) sc_nwellproto = NONODEPROTO; else
 	{
-		sc_nwellproto = getpurelayernode(el_curtech, -1, LFWELL|LFNTYPE);
+		sc_nwellproto = getpurelayernode(tech, -1, LFWELL|LFNTYPE);
 		if (sc_nwellproto == NONODEPROTO) return(Sc_seterrmsg(SC_NO_LAYER_PWELL));
 	}
 
@@ -1325,8 +1329,7 @@ char  *Sc_create_leaf_instance(char *name, char *type, int minx, int maxx, int m
 		ttyputmsg(_("ERROR creating name of instance '%s'."), name);
 	} else
 	{
-		var->textdescript = (var->textdescript & ~VTSIZE) |
-			(defaulttextsize(3) << VTSIZESH);
+		defaulttextsize(3, var->textdescript);
 	}
 	return((char *)binst);
 }
@@ -1734,7 +1737,7 @@ void Sc_schematic(void)
 /****************************** DIALOG ******************************/
 
 /* Silicon Compiler Options */
-DIALOGITEM sc_optionsdialogitems[] =
+static DIALOGITEM sc_optionsdialogitems[] =
 {
  /*  1 */ {0, {500,268,524,326}, BUTTON, N_("OK")},
  /*  2 */ {0, {500,36,524,94}, BUTTON, N_("Cancel")},
@@ -1773,7 +1776,7 @@ DIALOGITEM sc_optionsdialogitems[] =
  /* 35 */ {0, {280,8,296,199}, MESSAGE, N_("N-Well offset from top:")},
  /* 36 */ {0, {280,204,296,278}, EDITTEXT, "2.5"}
 };
-DIALOG sc_optionsdialog = {{50,75,583,472}, N_("Silicon Compiler Options"), 0, 36, sc_optionsdialogitems};
+static DIALOG sc_optionsdialog = {{50,75,583,472}, N_("Silicon Compiler Options"), 0, 36, sc_optionsdialogitems};
 
 /* special items for the "Silicon Compiler Options" dialog: */
 #define DSCO_VERTARCS      3		/* Vertical arc list (popup) */
@@ -1800,7 +1803,6 @@ void sc_optionsdlog(void)
 		pwrwidth, mainpwrwidth, pwellsize, pwelloffset, nwellsize, nwelloffset,
 		viasize, minspacing, feedthrusize, portxmindist, activedist, numrows,
 		mainpwrrail;
-	extern AIDENTRY *ro_aid;
 	REGISTER ARCPROTO *ap, *aphoriz, *apvert;
 	char **arcnames, numstring[20], *transnames[2];
 	static char *powerarcnames[2] = {N_("Horizontal Arc"), N_("Vertical Arc")};
@@ -1920,4 +1922,4 @@ void sc_optionsdlog(void)
 	DiaDoneDialog();
 }
 
-#endif  /* SCAID - at top */
+#endif  /* SCTOOL - at top */
