@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SCAID
+#if SCTOOL
 
 #include "global.h"
 #include "sc1.h"
@@ -39,8 +39,8 @@ extern SCCELL	*sc_curcell;
 extern SCCELL	*sc_cells;
 
 /* prototypes for local routines */
-int Sc_verify_cell(SCCELL*);
-int Sc_verify_ext_node(SCEXTNODE*, char*);
+static int Sc_verify_cell(SCCELL*);
+static int Sc_verify_ext_node(SCEXTNODE*, char*);
 
 /***********************************************************************
 Module:  Sc_export
@@ -108,7 +108,7 @@ int Sc_export(int count, char *pars[])
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	newnptr->number = sc_curcell->max_node_num++;
 	*searchnptr = newnptr;
-	niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_aid->cluster);
+	niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_tool->cluster);
 	if (niport == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	niport->port = (char *)NULL;
@@ -117,11 +117,11 @@ int Sc_export(int count, char *pars[])
 	newnptr->ports = niport;
 
 	/* add to export port list */
-	newport = (SCPORT *)emalloc(sizeof(SCPORT), sc_aid->cluster);
+	newport = (SCPORT *)emalloc(sizeof(SCPORT), sc_tool->cluster);
 	if (newport == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	niport->port = (char *)newport;
-	if (allocstring(&newport->name, pars[2], sc_aid->cluster))
+	if (allocstring(&newport->name, pars[2], sc_tool->cluster))
 	{
 		efree((char *)newport);
 		return(Sc_seterrmsg(SC_NOMEMORY));
@@ -477,4 +477,4 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 	return(SC_NOERROR);
 }
 
-#endif  /* SCAID - at top */
+#endif  /* SCTOOL - at top */
