@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -38,24 +38,44 @@
 
 /********************************* GLOBALS *********************************/
 
-MODPTR      simals_modroot = 0, simals_modptr2, simals_primroot = 0;
-ROWPTR      simals_rowptr2;
-IOPTR       simals_ioptr2;
-CONPTR      simals_conptr2, simals_levelptr = 0, simals_cellroot = 0;
-EXPTR       simals_exptr2;
-NODEPTR     simals_noderoot = 0, simals_drive_node;
-LINKPTR     simals_linkfront = 0, simals_linkback = 0, simals_setroot = 0;
-TRAKPTR     simals_trakroot = 0;
-LOADPTR     simals_chekroot;
-char      **simals_rowptr1, **simals_ioptr1, *simals_instbuf = 0;
-INTBIG      simals_loop_count, simals_pseq, simals_nseq, *simals_instptr = 0,
-			simals_ibufsize, simals_iptrsize, simals_trakfull, simals_trakptr;
-INTBIG      simals_no_update;		/* cached key for "SIM_als_no_update" */
-INTSML      simals_seed_flag = 1, simals_trace_all_nodes = 0;
-float       simals_time_abs, simals_delta_def, simals_linear_def,
-			simals_exp_def, simals_random_def, simals_abs_def;
-NODEPROTO  *simals_mainproto = NONODEPROTO;
-INTBIG      simals_trace_size = 0;
+       MODPTR      simals_modroot = 0;
+static MODPTR      simals_modptr2;
+       MODPTR      simals_primroot = 0;
+       ROWPTR      simals_rowptr2;
+       IOPTR       simals_ioptr2;
+static CONPTR      simals_conptr2;
+       CONPTR      simals_levelptr = 0;
+       CONPTR      simals_cellroot = 0;
+       EXPTR       simals_exptr2;
+       NODEPTR     simals_noderoot = 0;
+       NODEPTR     simals_drive_node;
+       LINKPTR     simals_linkfront = 0;
+       LINKPTR     simals_linkback = 0;
+       LINKPTR     simals_setroot = 0;
+       TRAKPTR     simals_trakroot = 0;
+       LOADPTR     simals_chekroot;
+       char      **simals_rowptr1;
+       char      **simals_ioptr1;
+       char       *simals_instbuf = 0;
+static INTBIG      simals_loop_count;
+       INTBIG      simals_pseq;
+       INTBIG      simals_nseq;
+       INTBIG     *simals_instptr = 0;
+static INTBIG      simals_ibufsize;
+static INTBIG      simals_iptrsize;
+       INTBIG      simals_trakfull;
+       INTBIG      simals_trakptr;
+       INTBIG      simals_no_update;		/* cached key for "SIM_als_no_update" */
+       INTSML      simals_seed_flag = 1;
+       INTSML      simals_trace_all_nodes = 0;
+       float       simals_time_abs;
+static float       simals_delta_def;
+static float       simals_linear_def;
+static float       simals_exp_def;
+static float       simals_random_def;
+static float       simals_abs_def;
+       NODEPROTO  *simals_mainproto = NONODEPROTO;
+       INTBIG      simals_trace_size = 0;
 
 /********************************* LOCALS *********************************/
 
@@ -63,23 +83,24 @@ static INTBIG     i_ptr;
 static char       delay[16];
 
 /* prototypes for local routines */
-INTSML simals_alloc_char_buffer(char**, INTBIG*, INTBIG);
-INTSML simals_get_string(char*);
-INTSML simals_get_int(INTBIG*);
-INTSML simals_get_float(float*);
-INTSML simals_get_name(char*);
-INTSML simals_fragment_line(char*);
-INTSML simals_parse_struct_header(char);
-INTSML simals_parse_gate(void);
-INTSML simals_parse_node(void);
-INTSML simals_parse_timing(void);
-INTSML simals_parse_fanout(void);
-INTSML simals_parse_load(void);
-INTSML simals_parse_model(void);
-INTSML simals_parse_function(void);
-INTSML simals_parse_func_input(EXPORT**);
-INTSML simals_parse_func_output(void);
-INTSML simals_parse_delay(void);
+static INTSML simals_alloc_char_buffer(char**, INTBIG*, INTBIG);
+static INTSML simals_get_string(char*);
+static INTSML simals_get_int(INTBIG*);
+static INTSML simals_get_float(float*);
+static INTSML simals_get_name(char*);
+static INTSML simals_fragment_line(char*);
+static INTSML simals_parse_struct_header(char);
+static INTSML simals_parse_gate(void);
+static INTSML simals_parse_node(void);
+static INTSML simals_parse_timing(void);
+static INTSML simals_parse_fanout(void);
+static INTSML simals_parse_load(void);
+static INTSML simals_parse_model(void);
+static INTSML simals_parse_function(void);
+static INTSML simals_parse_func_input(EXPORT**);
+static INTSML simals_parse_func_output(void);
+static INTSML simals_parse_delay(void);
+static INTSML simals_alloc_ptr_buffer(INTBIG**, INTBIG*, INTBIG);
 
 /******************************************************************************/
 
@@ -98,7 +119,7 @@ void simals_init(void)
 	}
 	if (simals_trace_size == 0)
 	{
-		var = getval((INTBIG)sim_aid, VAID, VINTEGER, "SIM_als_num_events");
+		var = getval((INTBIG)sim_tool, VTOOL, VINTEGER, "SIM_als_num_events");
 		if (var == NOVARIABLE) simals_trace_size = DEFAULT_TRACE_SIZE; else
 			simals_trace_size = var->addr;
 	}
@@ -225,7 +246,7 @@ void simals_com_comp(INTSML count, char *par[10])
 		simals_order_command((INTSML)(count-1), &par[1]);
 		return;
 	}
-	ttyputbadusage("tellaid simulation als");
+	ttyputbadusage("telltool simulation als");
 }
 
 /*
@@ -251,9 +272,9 @@ char *simals_alloc_mem(INTBIG size)
 	INTBIG   i;
 
 #ifdef DEBUGMEMORY
-	ptr = (char *)_emalloc(size, sim_aid->cluster, filename, lineno);
+	ptr = (char *)_emalloc(size, sim_tool->cluster, filename, lineno);
 #else
-	ptr = (char *)emalloc(size, sim_aid->cluster);
+	ptr = (char *)emalloc(size, sim_tool->cluster);
 #endif
 	if (ptr == 0)
 	{
@@ -343,7 +364,7 @@ INTSML simals_get_string(char *sp)
 {
 	INTBIG   i;
 	char  line[260];
-	extern AIDENTRY *vhdl_aid;
+	extern TOOL *vhdl_tool;
 
 	if (((simals_instptr[i_ptr] < 0) || (simals_instbuf[simals_instptr[i_ptr]] == '#')) && simals_loop_count)
 	{
@@ -353,7 +374,7 @@ INTSML simals_get_string(char *sp)
 
 	while ((simals_instptr[i_ptr] < 0) || (simals_instbuf[simals_instptr[i_ptr]] == '#'))
 	{
-		i = askaid(vhdl_aid, "get-line", (INTBIG)line);
+		i = asktool(vhdl_tool, "get-line", (INTBIG)line);
 
 		if (i == 0)
 		{
@@ -428,7 +449,7 @@ INTBIG simals_atoi(char *s1)
 			switch (s1[1])
 			{
 				case 'B':
-					for (i = 2; 1; ++i)
+					for (i = 2; ; ++i)
 					{
 						if ((s1[i] >= '0') && (s1[i] <= '1'))
 						{
@@ -439,7 +460,7 @@ INTBIG simals_atoi(char *s1)
 					}
 					break;
 				case 'X':
-					for (i = 2; 1; ++i)
+					for (i = 2; ; ++i)
 					{
 						if ((s1[i] >= '0') && (s1[i] <= '9'))
 						{
@@ -455,7 +476,7 @@ INTBIG simals_atoi(char *s1)
 					}
 					break;
 				default:
-					for (i = 1; 1; ++i)
+					for (i = 1; ; ++i)
 					{
 						if ((s1[i] >= '0') && (s1[i] <= '7'))
 						{
@@ -569,7 +590,7 @@ INTSML simals_get_name(char *sp)
 	}
 
 	(void)strcat(s1, s2);
-	while (1)
+	for(;;)
 	{
 		i = simals_get_string(s2);
 		if (i) return(1);
@@ -599,7 +620,7 @@ INTSML simals_fragment_line(char *line)
 	j = count = simals_instptr[0] = 0;
 	k = 1;
 
-	for (i = 0; 1; ++i)
+	for (i = 0; ; ++i)
 	{
 		if (j > (simals_ibufsize - 3))
 		{
@@ -703,10 +724,10 @@ INTSML simals_read_net_desc(NODEPROTO *np)
 {
 	char    s1[256], *intended;
 	INTSML    i;
-	extern AIDENTRY *vhdl_aid;
+	extern TOOL *vhdl_tool;
 
 	simals_mainproto = np;
-	if (askaid(vhdl_aid, "begin-netlist-input", (INTBIG)np, sim_filetypeals, (INTBIG)&intended) != 0)
+	if (asktool(vhdl_tool, "begin-netlist-input", (INTBIG)np, sim_filetypeals, (INTBIG)&intended) != 0)
 	{
 		ttyputerr(_("Cannot read %s"), intended);
 		return(1);
@@ -717,7 +738,7 @@ INTSML simals_read_net_desc(NODEPROTO *np)
 	i_ptr = 0;
 	simals_loop_count = 0;
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_string(s1);
 		if (i) break;
@@ -726,17 +747,17 @@ INTSML simals_read_net_desc(NODEPROTO *np)
 		{
 			if (simals_parse_struct_header(s1[0]) != 0)
 			{
-				(void)askaid(vhdl_aid, "end-input");
+				(void)asktool(vhdl_tool, "end-input");
 				return(1);
 			}
 			continue;
 		}
 
 		ttyputerr(_("ERROR: String '%s' invalid (expecting gate, function, or model)"), s1);
-		(void)askaid(vhdl_aid, "end-input");
+		(void)asktool(vhdl_tool, "end-input");
 		return(1);
 	}
-	(void)askaid(vhdl_aid, "end-input");
+	(void)asktool(vhdl_tool, "end-input");
 	return(0);
 }
 
@@ -767,7 +788,7 @@ INTSML simals_parse_struct_header(char flag)
 	}
 
 	modptr1 = &simals_modroot;
-	while (1)
+	for(;;)
 	{
 		if (*modptr1 == 0)
 		{
@@ -808,7 +829,7 @@ INTSML simals_parse_struct_header(char flag)
 		return(1);
 	}
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i)
@@ -819,7 +840,7 @@ INTSML simals_parse_struct_header(char flag)
 		if (s1[0] == ')') break;
 
 		exptr1 = &simals_modptr2->exptr;
-		while (1)
+		for(;;)
 		{
 			if (*exptr1 == 0)
 			{
@@ -878,7 +899,7 @@ INTSML simals_parse_gate(void)
 
 	simals_delta_def = simals_linear_def = simals_exp_def = simals_random_def = simals_abs_def = 0;
 	simals_rowptr1 = &(simals_modptr2->ptr);
-	while (1)
+	for(;;)
 	{
 		i = simals_get_string(s1);
 		if (i || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
@@ -898,7 +919,7 @@ INTSML simals_parse_gate(void)
 			simals_rowptr2->exp = simals_exp_def;
 			simals_rowptr2->random = simals_random_def;
 			simals_rowptr2->abs = simals_abs_def;
-			(void)allocstring(&(simals_rowptr2->delay), delay, sim_aid->cluster);
+			(void)allocstring(&(simals_rowptr2->delay), delay, sim_tool->cluster);
 			(void)sprintf(delay, "XX");  /* reset name */
 			simals_rowptr2->next = 0;
 			*simals_rowptr1 = (char*) simals_rowptr2;
@@ -981,7 +1002,7 @@ INTSML simals_parse_node(void)
 	INTBIG   i, j;
 	char  s1[256];
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
@@ -1119,7 +1140,7 @@ INTSML simals_parse_timing(void)
 
 	simals_delta_def = simals_linear_def = simals_exp_def = simals_random_def = simals_abs_def = 0;
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_string(s1);
 		if (i)
@@ -1278,7 +1299,7 @@ INTSML simals_parse_load(void)
 	for (loadptr2 = simals_modptr2->loadptr; loadptr2 != 0; loadptr2 = loadptr2->next)
 		loadptr1 = &loadptr2->next;
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
@@ -1337,7 +1358,7 @@ INTSML simals_parse_model(void)
 	EXPORT **exptr1;
 	CONNECT **conptr1;
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
@@ -1361,7 +1382,7 @@ INTSML simals_parse_model(void)
 		}
 
 		conptr1 = (CONNECT **)&simals_modptr2->ptr;
-		while (1)
+		for(;;)
 		{
 			if (*conptr1 == 0)
 			{
@@ -1410,7 +1431,7 @@ INTSML simals_parse_model(void)
 		}
 
 		exptr1 = &simals_conptr2->exptr;
-		while (1)
+		for(;;)
 		{
 			i = simals_get_name(s1);
 			if (i)
@@ -1464,7 +1485,7 @@ INTSML simals_parse_function(void)
 	funchead->userint = 0;
 	funchead->userfloat = 0.0;
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_string(s1);
 		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
@@ -1550,7 +1571,7 @@ INTSML simals_parse_func_input(EXPORT **exptr1)
 	INTSML   i;
 	char    s1[256];
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
@@ -1586,7 +1607,7 @@ INTSML simals_parse_func_output(void)
 	INTSML   i;
 	char    s1[256];
 
-	while (1)
+	for(;;)
 	{
 		i = simals_get_name(s1);
 		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
@@ -1598,7 +1619,7 @@ INTSML simals_parse_func_output(void)
 			break;
 		}
 
-		for (simals_exptr2 = simals_modptr2->exptr; 1; simals_exptr2 = simals_exptr2->next)
+		for (simals_exptr2 = simals_modptr2->exptr; ; simals_exptr2 = simals_exptr2->next)
 		{
 			if (!simals_exptr2)
 			{
@@ -1633,7 +1654,7 @@ INTSML simals_fragment_command(char *line)
 	j = count = simals_instptr[0] = simals_instbuf[0] = 0;
 	k = 1;
 
-	for (i = 0; 1; ++i)
+	for (i = 0; ; ++i)
 	{
 		if (j > (simals_ibufsize - 3))
 		{
@@ -1703,7 +1724,7 @@ void simals_compute_node_name(NODEPTR nodehead, char *sp)
 	cellhead = nodehead->cellptr;
 	strcpy(sp, simals_compute_path_name(cellhead));
 
-	for (exhead = cellhead->exptr; 1; exhead = exhead->next)
+	for (exhead = cellhead->exptr; ; exhead = exhead->next)
 	{
 		if (nodehead == exhead->nodeptr)
 		{
@@ -1837,11 +1858,11 @@ CONPTR simals_find_level(char *sp)
 		i = 0;
 	}
 
-	for (j = 0; 1; ++i)
+	for(j = 0; ; ++i)
 	{
 		if ((sp[i] == '.') || ! (sp[i]))
 		{
-			for (s1[j] = 0; 1; cellptr = cellptr->next)
+			for(s1[j] = 0; ; cellptr = cellptr->next)
 			{
 				if (! cellptr) return(0);
 				if (! strcmp(s1, cellptr->inst_name))
@@ -1888,4 +1909,4 @@ void simals_trans_number_to_state(INTBIG state_num, char *s1)
 	}
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
