@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -38,27 +38,27 @@
 #include "usrdiacom.h"
 
 /* prototypes for local routines */
-void simals_erase_submod(CONPTR);
-void simals_print_in_entry(ROWPTR);
-void simals_print_out_entry(ROWPTR);
-void simals_print_xref_entry(CONPTR, INTBIG);
-char *simals_strengthstring(INTSML);
-void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib);
-INTSML simals_fgets(char *line, INTSML limit, FILE *file);
-void simals_sdfannotate(CONPTR cellhead);
-NODEINST *simals_getcellinstance(char *celltype, char *instance);
-void simals_sdfportdelay(CONPTR cellhead, NODEINST *ni, char *path);
-INTBIG simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES delaytype);
-INTBIG simals_getdval(char *tstring, DELAY_TYPES delaytype);
-void simals_order_save(void);
-void simals_order_restore(char *list);
-void simals_update_netlist(void);
-char *simals_parent_level(char *child);
-INTSML simals_get_tdindex(char *name);
+static void     simals_erase_submod(CONPTR);
+static void     simals_print_in_entry(ROWPTR);
+static void      simals_print_out_entry(ROWPTR);
+static void      simals_print_xref_entry(CONPTR, INTBIG);
+static char     *simals_strengthstring(INTSML);
+static void      simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib);
+static INTSML    simals_fgets(char *line, INTSML limit, FILE *file);
+static void      simals_sdfannotate(CONPTR cellhead);
+static NODEINST *simals_getcellinstance(char *celltype, char *instance);
+static void      simals_sdfportdelay(CONPTR cellhead, NODEINST *ni, char *path);
+static INTBIG    simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES delaytype);
+static INTBIG    simals_getdval(char *tstring, DELAY_TYPES delaytype);
+static void      simals_order_save(void);
+static void      simals_order_restore(char *list);
+static void      simals_update_netlist(void);
+static char     *simals_parent_level(char *child);
+static INTSML    simals_get_tdindex(char *name);
 
 /* local variables */
-DELAY_TYPES simals_sdfdelaytype;
-char *tnames[] = {"01", "10", "0Z", "Z1", "1Z", "Z0", "0X", "X1", "1X", "X0", "XZ", "ZX"};
+static DELAY_TYPES simals_sdfdelaytype;
+static char *simals_tnames[] = {"01", "10", "0Z", "Z1", "1Z", "Z0", "0X", "X1", "1X", "X0", "XZ", "ZX"};
 
 /****************************** ACTEL MODELS ******************************/
 
@@ -92,7 +92,7 @@ void simals_build_actel_command(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputusage("tellaid simulation als build-actel-model TABLEFILE");
+		ttyputusage("telltool simulation als build-actel-model TABLEFILE");
 		return;
 	}
 	len = strlen(par[0]);
@@ -147,7 +147,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 	ACTELPARAM *ap, *lastap, *inputlist, *outputlist, *paramlist, *paramtail, *nextap, *newap;
 	void *sa;
 
-	sa = newstringarray(sim_aid->cluster);
+	sa = newstringarray(sim_tool->cluster);
 	if (sa == 0) return;
 
 	/* dump header information for the model */
@@ -207,9 +207,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 									name, start);
 								return;
 							}
-							newap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_aid->cluster);
+							newap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 							if (newap == 0) return;
-							(void)allocstring(&newap->paramname, ap->paramname, sim_aid->cluster);
+							(void)allocstring(&newap->paramname, ap->paramname, sim_tool->cluster);
 							newap->paramtype = ap->paramtype;
 							newap->duplicate = 1;
 							ap = newap;
@@ -238,9 +238,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 									name, start);
 								return;
 							}
-							newap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_aid->cluster);
+							newap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 							if (newap == 0) return;
-							(void)allocstring(&newap->paramname, ap->paramname, sim_aid->cluster);
+							(void)allocstring(&newap->paramname, ap->paramname, sim_tool->cluster);
 							newap->paramtype = ap->paramtype;
 							newap->duplicate = 1;
 							ap = newap;
@@ -343,9 +343,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				start = pt;
 				while (*pt != 0 && *pt != ' ' && *pt != '\t' && *pt != ',' && *pt != ';') pt++;
 				save = *pt;   *pt = 0;
-				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_aid->cluster);
+				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 				if (ap == 0) break;
-				(void)allocstring(&ap->paramname, start, sim_aid->cluster);
+				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
 				if (edgesense != 0) ap->paramtype = edgesenseinputparam; else
 					ap->paramtype = inputparam;
 				ap->duplicate = 0;
@@ -371,9 +371,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				start = pt;
 				while (*pt != 0 && *pt != ' ' && *pt != '\t' && *pt != ',' && *pt != ';') pt++;
 				save = *pt;   *pt = 0;
-				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_aid->cluster);
+				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 				if (ap == 0) break;
-				(void)allocstring(&ap->paramname, start, sim_aid->cluster);
+				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
 				ap->paramtype = outputparam;
 				ap->duplicate = 0;
 				ap->next = outputlist;
@@ -398,9 +398,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				start = pt;
 				while (*pt != 0 && *pt != ' ' && *pt != '\t' && *pt != ',' && *pt != ';') pt++;
 				save = *pt;   *pt = 0;
-				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_aid->cluster);
+				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 				if (ap == 0) break;
-				(void)allocstring(&ap->paramname, start, sim_aid->cluster);
+				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
 				if (fourstate != 0) ap->paramtype = fourstatebiputparam; else
 					ap->paramtype = bidirparam;
 				ap->duplicate = 0;
@@ -507,7 +507,7 @@ void simals_clock_command(INTSML count, char *par[])
 	}
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als clock NODENAME (freq | period | custom)");
+		ttyputusage("telltool simulation als clock NODENAME (freq | period | custom)");
 		return;
 	}
 
@@ -531,7 +531,7 @@ void simals_clock_command(INTSML count, char *par[])
 	{
 		if (count < 3)
 		{
-			ttyputusage("tellaid simulation als clock NODENAME frequency/period PERIOD");
+			ttyputusage("telltool simulation als clock NODENAME frequency/period PERIOD");
 			return;
 		}
 		time = (float)atof(par[2]);
@@ -591,14 +591,14 @@ void simals_clock_command(INTSML count, char *par[])
 
 	if (namesamen(par[1], "custom", l) != 0)
 	{
-		ttyputbadusage("tellaid simulation als clock");
+		ttyputbadusage("telltool simulation als clock");
 		return;
 	}
 
 	/* handle custom clock specification */
 	if (count < 7)
 	{
-		ttyputusage("tellaid simulation als clock custom RAN STR CY (L D) *");
+		ttyputusage("telltool simulation als clock custom RAN STR CY (L D) *");
 		return;
 	}
 
@@ -999,7 +999,7 @@ void simals_level_command(INTSML count, char *par[])
 	}
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als level OPTION");
+		ttyputusage("telltool simulation als level OPTION");
 		return;
 	}
 
@@ -1035,7 +1035,7 @@ void simals_level_command(INTSML count, char *par[])
 		}
 	} else
 	{
-		ttyputbadusage("tellaid simulation als level");
+		ttyputbadusage("telltool simulation als level");
 		return;
 	}
 
@@ -1076,7 +1076,7 @@ void simals_print_command(INTSML count, char *par[])
 
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als print OPTION");
+		ttyputusage("telltool simulation als print OPTION");
 		return;
 	}
 	l = strlen(pt = par[0]);
@@ -1193,7 +1193,7 @@ void simals_print_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid simulation als print state NODENAME");
+			ttyputusage("telltool simulation als print state NODENAME");
 			return;
 		}
 		simals_convert_to_upper(par[1]);
@@ -1228,7 +1228,7 @@ void simals_print_command(INTSML count, char *par[])
 		}
 		return;
 	}
-	ttyputbadusage("tellaid simulation als print");
+	ttyputbadusage("telltool simulation als print");
 }
 
 char *simals_strengthstring(INTSML strength)
@@ -1380,7 +1380,7 @@ void simals_print_xref_entry(CONPTR cellhead, INTBIG tab)
 			if (delay != 0)
 			{
 				if (k == 0) (void)initinfstr();
-				(void)sprintf(ts, "%s=%ld ", tnames[i], delay);
+				(void)sprintf(ts, "%s=%ld ", simals_tnames[i], delay);
 				(void)addstringtoinfstr(ts);
 				k++;
 			}
@@ -1408,7 +1408,7 @@ void simals_seed_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als seed (reset | no-reset)");
+		ttyputusage("telltool simulation als seed (reset | no-reset)");
 		return;
 	}
 	if (namesamen(par[0], "reset", strlen(par[0])) == 0)
@@ -1440,7 +1440,7 @@ void simals_set_command(INTSML count, char *par[])
 	}
 	if (count < 4)
 	{
-		ttyputusage("tellaid simulation als set NODE LEVEL STRENGTH TIME");
+		ttyputusage("telltool simulation als set NODE LEVEL STRENGTH TIME");
 		return;
 	}
 	simals_convert_to_upper(par[0]);
@@ -1487,21 +1487,21 @@ void simals_trace_command(INTSML count, char *par[])
 
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als trace OPTION");
+		ttyputusage("telltool simulation als trace OPTION");
 		return;
 	}
 	l = strlen(pt = par[0]);
 	if (namesamen(pt, "on", l) == 0 && l >= 2)
 	{
-		(void)setvalkey((INTBIG)sim_aid, VAID, simals_no_update, 0, VINTEGER);
+		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update, 0, VINTEGER);
 		return;
 	}
 	if (namesamen(pt, "off", l) == 0 && l >= 2)
 	{
-		(void)setvalkey((INTBIG)sim_aid, VAID, simals_no_update, 1, VINTEGER);
+		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update, 1, VINTEGER);
 		return;
 	}
-	ttyputbadusage("tellaid simulation als trace");
+	ttyputbadusage("telltool simulation als trace");
 }
 
 /****************************** VECTOR ******************************/
@@ -1526,7 +1526,7 @@ void simals_vector_command(INTSML count, char *par[])
 	}
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als vector OPTION");
+		ttyputusage("telltool simulation als vector OPTION");
 		return;
 	}
 	l = strlen(pt = par[0]);
@@ -1535,7 +1535,7 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid simulation als vector load FILENAME");
+			ttyputusage("telltool simulation als vector load FILENAME");
 			return;
 		}
 		vin = xopen(par[1], sim_filetypealsvec, "", &filename);
@@ -1564,7 +1564,7 @@ void simals_vector_command(INTSML count, char *par[])
 		}
 
 		flag = 1;
-		while (1)
+		for(;;)
 		{
 			if (flag)
 			{
@@ -1612,7 +1612,7 @@ void simals_vector_command(INTSML count, char *par[])
 				clokhead->delay = 0;
 
 				vectptr1 = (char**) &(clokhead->inptr);
-				while (1)
+				for(;;)
 				{
 					i = xfgets(s1, 255, vin);
 					if (i != 0)
@@ -1682,7 +1682,7 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("tellaid simulation als vector save FILENAME");
+			ttyputusage("telltool simulation als vector save FILENAME");
 			return;
 		}
 		vout = xcreate(par[1], sim_filetypealsvec, 0, &truename);
@@ -1725,7 +1725,7 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 3)
 		{
-			ttyputusage("tellaid simulation als vector delete NODE OPTIONS");
+			ttyputusage("telltool simulation als vector delete NODE OPTIONS");
 			return;
 		}
 		simals_convert_to_upper(par[1]);
@@ -1780,7 +1780,7 @@ void simals_vector_command(INTSML count, char *par[])
 
 		if (count < 4)
 		{
-			ttyputusage("tellaid simulation als vector delete time TIME");
+			ttyputusage("telltool simulation als vector delete time TIME");
 			return;
 		}
 		time = (float)atof(par[2]);
@@ -1825,7 +1825,7 @@ void simals_vector_command(INTSML count, char *par[])
 		return;
 	}
 
-	ttyputbadusage("tellaid simulation als vector");
+	ttyputbadusage("telltool simulation als vector");
 }
 
 /****************************** ANNOTATE ******************************/
@@ -1840,7 +1840,7 @@ void simals_annotate_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als annotate [minimum | typical | maximum]");
+		ttyputusage("telltool simulation als annotate [minimum | typical | maximum]");
 		return;
 	}
 
@@ -1855,7 +1855,7 @@ void simals_annotate_command(INTSML count, char *par[])
 			else if (namesamen(par[0], "max", 3) == 0) simals_sdfdelaytype = DELAY_MAX;
 				else
 	{
-		ttyputbadusage("tellaid simulation als annotate");
+		ttyputbadusage("telltool simulation als annotate");
 		return;
 	}
 
@@ -1965,7 +1965,7 @@ void simals_sdfportdelay(CONPTR cellhead, NODEINST *ni, char *path)
 							for (j=0; j<12; j++)
 							{
 								delay = simals_getportdelayvalue(((char **)var->addr)[i],
-									tnames[j], simals_sdfdelaytype);
+									simals_tnames[j], simals_sdfdelaytype);
 								if (delay != -1) exhead->td[j] = delay; else
 									exhead->td[j] = 0;
 							}
@@ -2073,7 +2073,7 @@ void simals_order_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputusage("tellaid simulation als order [save | restore]");
+		ttyputusage("telltool simulation als order [save | restore]");
 		return;
 	}
 
@@ -2082,13 +2082,13 @@ void simals_order_command(INTSML count, char *par[])
 	{
 		if (count != 2)
 		{
-			ttyputusage("tellaid simulation als order restore OPTION");
+			ttyputusage("telltool simulation als order restore OPTION");
 			return;
 		}
 		simals_order_restore(par[1]);
 	} else
 	{
-		ttyputbadusage("tellaid simulation als order");
+		ttyputbadusage("telltool simulation als order");
 		return;
 	}
 }
@@ -2278,7 +2278,7 @@ INTSML simals_get_tdindex(char *name)
 
 	for (i=0; i<12; i++)
 	{
-		if (!strcmp(tnames[i], name)) return(i);
+		if (!strcmp(simals_tnames[i], name)) return(i);
 	}
 	return(0);  /* return '01' index */
 }
@@ -2316,4 +2316,4 @@ char *simals_parent_level(char *child)
 	return(returninfstr());
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
