@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -41,17 +41,17 @@ static MODEL **simals_primptr1;
 static char *simals_mainname = 0;
 
 /* prototypes for local routines */
-INTSML simals_flatten_model(CONPTR);
-INTSML simals_process_connect_list(CONPTR, CONPTR);
-MODPTR simals_find_model(char*);
-EXPTR simals_find_xref_entry(CONPTR, char*);
-INTSML simals_process_gate(CONPTR, MODPTR);
-INTSML simals_process_io_entry(MODPTR, CONPTR, IOPTR, char);
-INTSML simals_create_pin_entry(MODPTR, char*, NODEPTR);
-STATPTR simals_create_stat_entry(MODPTR, char*, NODEPTR);
-float simals_find_load_value(MODPTR, char*);
-INTSML simals_process_set_entry(CONPTR, IOPTR);
-INTSML simals_process_function(CONPTR, MODPTR);
+static INTSML  simals_flatten_model(CONPTR);
+static INTSML  simals_process_connect_list(CONPTR, CONPTR);
+static MODPTR  simals_find_model(char*);
+static EXPTR   simals_find_xref_entry(CONPTR, char*);
+static INTSML  simals_process_gate(CONPTR, MODPTR);
+static INTSML  simals_process_io_entry(MODPTR, CONPTR, IOPTR, char);
+static INTSML  simals_create_pin_entry(MODPTR, char*, NODEPTR);
+static STATPTR simals_create_stat_entry(MODPTR, char*, NODEPTR);
+static float   simals_find_load_value(MODPTR, char*);
+static INTSML  simals_process_set_entry(CONPTR, IOPTR);
+static INTSML  simals_process_function(CONPTR, MODPTR);
 
 /*
  * Routine to free all memory associated with this module.
@@ -102,7 +102,7 @@ INTSML simals_flatten_network(void)
 
 	/* get upper-case version of main proto */
 	if (simals_mainname != 0) efree(simals_mainname);
-	(void)allocstring(&simals_mainname, simals_mainproto->cell->cellname, sim_aid->cluster);
+	(void)allocstring(&simals_mainname, simals_mainproto->cell->cellname, sim_tool->cluster);
 	simals_convert_to_upper(simals_mainname);
 
 	simals_cellroot = (CONPTR) simals_alloc_mem((INTBIG)sizeof(CONNECT));
@@ -240,7 +240,7 @@ INTSML simals_process_connect_list(CONPTR cellhead, CONPTR conhead)
 			}
 
 			xrefptr1 = &cellptr2->exptr;
-			while (1)
+			for(;;)
 			{
 				if (*xrefptr1 == 0)
 				{
@@ -292,16 +292,17 @@ MODPTR  simals_find_model(char *model_name)
 		if (!isalnum(*pt)) *pt = '_';
 
 	modhead = simals_modroot;
-	while (1)
+	for(;;)
 	{
 		if (modhead == 0)
 		{
 			ttyputerr(_("ERROR: Model '%s' not found, simulation aborted"), propername);
-			return(0);
+			break;
 		}
 		if (! strcmp(modhead->name, propername)) return(modhead);
 		modhead = modhead->next;
 	}
+	return(0);
 }
 
 /*
@@ -322,7 +323,7 @@ EXPTR simals_find_xref_entry(CONPTR cellhead, char *name)
 	NODEPTR  nodeptr2;
 
 	xrefptr1 = &cellhead->exptr;
-	while (1)
+	for(;;)
 	{
 		if (*xrefptr1 == 0)
 		{
@@ -386,7 +387,7 @@ INTSML simals_process_gate(CONPTR cellhead, MODPTR modhead)
 	simals_primptr2->fanout = modhead->fanout;
 	simals_primptr2->priority = modhead->priority;
 	simals_primptr2->next = 0;
-	(void)allocstring(&(simals_primptr2->level), simals_compute_path_name(cellhead), sim_aid->cluster);
+	(void)allocstring(&(simals_primptr2->level), simals_compute_path_name(cellhead), sim_tool->cluster);
 	*simals_primptr1 = simals_primptr2;
 	simals_primptr1 = &simals_primptr2->next;
 
@@ -405,7 +406,7 @@ INTSML simals_process_gate(CONPTR cellhead, MODPTR modhead)
 		simals_rowptr2->random = rowhead->random;
 		simals_rowptr2->delay = rowhead->delay;
 		if (rowhead->delay == 0) simals_rowptr2->delay = 0; else
-			(void)allocstring(&(simals_rowptr2->delay), rowhead->delay, sim_aid->cluster);
+			(void)allocstring(&(simals_rowptr2->delay), rowhead->delay, sim_tool->cluster);
 		simals_rowptr2->next = 0;
 		*simals_rowptr1 = (char*) simals_rowptr2;
 		simals_rowptr1 = (char**) &(simals_rowptr2->next);
@@ -510,7 +511,7 @@ INTSML simals_create_pin_entry(MODPTR modhead, char *node_name, NODEPTR nodehead
 	LOADPTR  pinptr2;
 
 	pinptr1 = &nodehead->pinptr;
-	while (1)
+	for(;;)
 	{
 		if (*pinptr1 == 0)
 		{
@@ -550,12 +551,12 @@ STATPTR  simals_create_stat_entry(MODPTR modhead, char *node_name, NODEPTR nodeh
 	STATPTR  statptr2;
 
 	statptr1 = &nodehead->statptr;
-	while (1)
+	for(;;)
 	{
 		if (*statptr1 == 0)
 		{
 			statptr2 = (STATPTR)simals_alloc_mem((INTBIG)sizeof(STAT));
-			if (statptr2 == 0) return(0);
+			if (statptr2 == 0) break;
 			statptr2->primptr = simals_primptr2;
 			statptr2->nodeptr = nodehead;
 			statptr2->next = 0;
@@ -567,6 +568,7 @@ STATPTR  simals_create_stat_entry(MODPTR modhead, char *node_name, NODEPTR nodeh
 		if (statptr2->primptr == simals_primptr2) return(statptr2);
 		statptr1 = &statptr2->next;
 	}
+	return(0);
 }
 
 /*
@@ -669,7 +671,7 @@ INTSML simals_process_function(CONPTR cellhead, MODPTR modhead)
 	simals_primptr2->priority = modhead->priority;
 	simals_primptr2->next = 0;
 	(void)allocstring(&(simals_primptr2->level), simals_compute_path_name(cellhead),
-		sim_aid->cluster);
+		sim_tool->cluster);
 	*simals_primptr1 = simals_primptr2;
 	simals_primptr1 = &simals_primptr2->next;
 
@@ -726,4 +728,4 @@ INTSML simals_process_function(CONPTR cellhead, MODPTR modhead)
 	return(0);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
