@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -43,11 +43,11 @@ static INTSML sim_window_iter;
 static INTSML sim_als_wantweak = 0, sim_als_wantstrong = 0, sim_als_wantfull = 0;
 
 /* prototypes for local routines */
-INTSML sim_window_topofdsignals(char**);
-char *sim_window_nextdsignals(void);
-INTBIG simals_count_channels(CONPTR);
-void simals_helpwindow(INTSML waveform);
-INTSML simals_getwidevalue(INTBIG *value);
+static INTSML  sim_window_topofdsignals(char**);
+static char   *sim_window_nextdsignals(void);
+static INTBIG  simals_count_channels(CONPTR);
+static void    simals_helpwindow(INTSML waveform);
+static INTSML  simals_getwidevalue(INTBIG *value);
 
 INTSML sim_window_topofdsignals(char **c)
 {
@@ -73,13 +73,36 @@ char *sim_window_nextdsignals(void)
 static COMCOMP sim_window_pickdtrace = {NOKEYWORD, sim_window_topofdsignals,
 	sim_window_nextdsignals, NOPARAMS, NOBACKUP, 0, " \t", N_("pick a signal to display"), ""};
 
+/*
+ * Routine to start ALS simulation of facet "np".
+ */
+INTSML simals_startsimulation(NODEPROTO *np)
+{
+	extern TOOL *vhdl_tool;
+
+	/* initialize memory */
+	simals_init();
+
+	/* demand an ALS netlist */
+	(void)asktool(vhdl_tool, "want-netlist-input", (INTBIG)np, sim_filetypeals);
+
+	/* read netlist */
+	simals_erase_model();
+	if (simals_read_net_desc(np) != 0) return(1);
+	if (simals_flatten_network() != 0) return(1);
+
+	/* initialize display */
+	simals_init_display();
+	return(0);
+}
+
 /*
  * The character handler for the waveform window of ALS simulation
  */
 INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 {
 	REGISTER INTBIG i, j, traces, pos, thispos, lines, strength, *tracelist,
-		tr, trl, nexttr, prevtr, highsig, *highsigs, windowstate, bit, fulltrace;
+		tr, trl, nexttr, prevtr, highsig, *highsigs, windowstate, bit;
 	INTBIG state;
 	REGISTER VARIABLE *var;
 	char *par[30], *name;
@@ -110,13 +133,12 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 	if (sim_window_isactive(&np) == 0)
 		return(us_charhandler(w, chr));
 
-	fulltrace = 0;
 	switch (chr)
 	{
 		/* update display */
 		case 'u':
 			endtime = simals_initialize_simulator(1);
-			var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_window_state);
+			var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
 			if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
 			if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
 			return(0);
@@ -390,7 +412,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 	}
 
 	endtime = simals_initialize_simulator(0);
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_window_state);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
 	if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
 	if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
 	return(0);
@@ -419,7 +441,7 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 			return(0);
 		case 'u':
 			endtime = simals_initialize_simulator(1);
-			var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_window_state);
+			var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
 			if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
 			if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
 			return(0);
@@ -520,21 +542,21 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 	simals_insert_set_list(sethead);
 	endtime = simals_initialize_simulator(0);
 
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_window_state);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
 	if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
 	if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
 	return(0);
 }
 
 /* Simulation: Wide Value */
-DIALOGITEM sim_widedialogitems[] =
+static DIALOGITEM sim_widedialogitems[] =
 {
  /*  1 */ {0, {36,148,60,228}, BUTTON, N_("OK")},
- /*  2 */ {0, {4,4,20,148}, MESSAGE, N_("Value to set on bus:")},
- /*  3 */ {0, {36,16,60,96}, BUTTON, N_("Cancel")},
+ /*  2 */ {0, {36,16,60,96}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {4,4,20,148}, MESSAGE, N_("Value to set on bus:")},
  /*  4 */ {0, {4,152,20,240}, EDITTEXT, ""}
 };
-DIALOG sim_widedialog = {{75,75,144,324}, N_("Set Wide Value"), 0, 4, sim_widedialogitems};
+static DIALOG sim_widedialog = {{75,75,144,324}, N_("Set Wide Value"), 0, 4, sim_widedialogitems};
 
 /* special items for the "wide value" dialog: */
 #define DSWV_VALUE     4		/* Width (edit text) */
@@ -678,7 +700,7 @@ INTSML simals_set_current_level(void)
 				name = "";
 				simals_levelptr->display_page[i].nodeptr = 0;
 			}
-			(void)allocstring(&simals_levelptr->display_page[i].name, name, sim_aid->cluster);
+			(void)allocstring(&simals_levelptr->display_page[i].name, name, sim_tool->cluster);
 		}
 	}
 
@@ -689,7 +711,7 @@ INTSML simals_set_current_level(void)
 		/* no simulation running: start it up */
 		if (simals_levelptr->num_chn <= 0) return(1);
 
-		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_window_state);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
 		if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
 		var = getvalkey((INTBIG)simals_mainproto, VNODEPROTO, VSTRING|VISARRAY, sim_window_signal_order);
 		if (var != NOVARIABLE)
@@ -697,7 +719,7 @@ INTSML simals_set_current_level(void)
 			oldsigcount = getlength(var);
 			if (oldsigcount > 0)
 			{
-				sa = newstringarray(sim_aid->cluster);
+				sa = newstringarray(sim_tool->cluster);
 				for(i=0; i<oldsigcount; i++)
 					addtostringarray(sa, ((char **)var->addr)[i]);
 				oldsignames = getstringarray(sa, &oldsigcount);
@@ -822,8 +844,8 @@ void simals_fill_display_arrays(void)
 	for (j=0; j<num_chan; j++)
 	{
 		if (nodelist[j] == 0) continue;
-		timearrays[j] = (float *)emalloc(numsteps[j] * (sizeof (float)), sim_aid->cluster);
-		statearrays[j] = (INTSML *)emalloc(numsteps[j] * SIZEOFINTSML, sim_aid->cluster);
+		timearrays[j] = (float *)emalloc(numsteps[j] * (sizeof (float)), sim_tool->cluster);
+		statearrays[j] = (INTSML *)emalloc(numsteps[j] * SIZEOFINTSML, sim_tool->cluster);
 		if (timearrays[j] == 0 || statearrays[j] == 0) return;
 	}
 
@@ -865,4 +887,4 @@ void simals_fill_display_arrays(void)
 	efree((char *)statearrays);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
