@@ -30,24 +30,24 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
 #include "simals.h"
 
-LINKPTR simals_freelink = 0;
+static LINKPTR simals_freelink = 0;
 INTSML  simals_tracing = 0;
-char *simals_statedesc[] = {N_("High"), N_("Undefined"), N_("Low")};
-char *simals_strengthdesc[] = {N_("Off-"), N_("Weak-"), N_("Weak-"), "", "",
+static char *simals_statedesc[] = {N_("High"), N_("Undefined"), N_("Low")};
+static char *simals_strengthdesc[] = {N_("Off-"), N_("Weak-"), N_("Weak-"), "", "",
 	N_("Strong-"), N_("Strong-")};
 
 /* prototypes for local routines */
-INTSML simals_fire_event(void);
-void simals_create_check_list(NODEPTR, LINKPTR);
-INTSML simals_schedule_new_events(void);
-void simals_calculate_clock_time(LINKPTR, ROWPTR);
-INTSML simals_calculate_event_time(MODPTR, ROWPTR);
+static INTSML simals_fire_event(void);
+static void   simals_create_check_list(NODEPTR, LINKPTR);
+static INTSML simals_schedule_new_events(void);
+static void   simals_calculate_clock_time(LINKPTR, ROWPTR);
+static INTSML simals_calculate_event_time(MODPTR, ROWPTR);
 
 /*
  * Routine to free all memory associated with this module.
@@ -138,7 +138,7 @@ float simals_initialize_simulator(INTSML force)
 
 	/* now run the simulation */
 	if (force != 0) var = NOVARIABLE; else
-		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, simals_no_update);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, simals_no_update);
 	if (var == NOVARIABLE || var->addr == 0)
 	{
 		/* fire events until end of time or quiesced */
@@ -686,12 +686,12 @@ char **simals_insert_set_list(LINKPTR linkhead)
 	LINKPTR linkptr2;
 
 	linkptr1 = (char **)&simals_setroot;
-	while (1)
+	for(;;)
 	{
 		if ((*linkptr1) == 0)
 		{
 			*linkptr1 = (char *)linkhead;
-			return(linkptr1);
+			break;
 		}
 		linkptr2 = (LINKPTR)*linkptr1;
 		if (linkptr2->time > linkhead->time || (linkptr2->time == linkhead->time &&
@@ -699,10 +699,11 @@ char **simals_insert_set_list(LINKPTR linkhead)
 		{
 			linkhead->right = linkptr2;
 			*linkptr1 = (char *)linkhead;
-			return(linkptr1);
+			break;
 		}
 		linkptr1 = (char **)&(linkptr2->right);
 	}
+	return(linkptr1);
 }
 
 /*
@@ -724,7 +725,7 @@ void simals_insert_link_list(LINKPTR linkhead)
 	linkptr1 = (char **)&simals_linkback;
 	linkptr2 = simals_linkback;
 	linkptr3 = 0;
-	while (1)
+	for(;;)
 	{
 		if (! linkptr2)
 		{
@@ -768,7 +769,7 @@ void simals_insert_link_list(LINKPTR linkhead)
 			linkptr1 = (char **)&(linkptr2->up);
 			linkptr2 = linkptr2->up;
 			linkptr3 = 0;
-			while (1)
+			for(;;)
 			{
 				if (linkptr2->priority <= linkhead->priority)
 				{
@@ -790,4 +791,4 @@ void simals_insert_link_list(LINKPTR linkhead)
 	}
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
