@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -40,30 +40,30 @@ extern INTSML simals_tracing;
 extern char *simals_statedesc[], *simals_strengthdesc[];
 
 /* prototypes for local routines */
-INTSML simals_schedule_node_update(MODPTR, EXPTR, unsigned char, INTBIG, INTSML, float);
-void simals_calculate_bidir_outputs(MODPTR, EXPTR*, INTSML);
-INTSML simals_bidir_path_search(MODPTR);
-void simals_PMOSTRAN(MODPTR);
-void simals_NMOSTRAN(MODPTR);
-void simals_PMOSTRANWeak(MODPTR);
-void simals_NMOSTRANWeak(MODPTR);
-void simals_JK_FF(MODPTR);
-void simals_DFFLOP(MODPTR);
-void simals_BUS_TO_STATE(MODPTR);
-void simals_STATE_TO_BUS(MODPTR);
+static INTSML simals_schedule_node_update(MODPTR, EXPTR, unsigned char, INTBIG, INTSML, float);
+static void   simals_calculate_bidir_outputs(MODPTR, EXPTR*, INTSML);
+static INTSML simals_bidir_path_search(MODPTR);
+static void   simals_PMOSTRAN(MODPTR);
+static void   simals_NMOSTRAN(MODPTR);
+static void   simals_PMOSTRANWeak(MODPTR);
+static void   simals_NMOSTRANWeak(MODPTR);
+static void   simals_JK_FF(MODPTR);
+static void   simals_DFFLOP(MODPTR);
+static void   simals_BUS_TO_STATE(MODPTR);
+static void   simals_STATE_TO_BUS(MODPTR);
 #if 0			/* unused user functions */
-void simals_Q_CALC(MODPTR);
-void simals_STATS(MODPTR);
-void simals_COUNTER(MODPTR);
-void simals_DELAY_CALC(MODPTR);
-void simals_FIFO(MODPTR);
-void simals_RX_DATA(MODPTR);
-void simals_A_F_REGISTERS(MODPTR);
-void simals_CONTROL_LOGIC(MODPTR);
-void simals_MOD2_ADDER(MODPTR);
-void simals_ABOVE_ADDER(MODPTR);
-void simals_WRITE_OUT(MODPTR);
-void simals_BUS12_TO_STATE(MODPTR);
+static void   simals_Q_CALC(MODPTR);
+static void   simals_STATS(MODPTR);
+static void   simals_COUNTER(MODPTR);
+static void   simals_DELAY_CALC(MODPTR);
+static void   simals_FIFO(MODPTR);
+static void   simals_RX_DATA(MODPTR);
+static void   simals_A_F_REGISTERS(MODPTR);
+static void   simals_CONTROL_LOGIC(MODPTR);
+static void   simals_MOD2_ADDER(MODPTR);
+static void   simals_ABOVE_ADDER(MODPTR);
+static void   simals_WRITE_OUT(MODPTR);
+static void   simals_BUS12_TO_STATE(MODPTR);
 #endif
 
 /*
@@ -198,8 +198,8 @@ INTSML simals_schedule_node_update(MODPTR primhead, EXPTR exhead, unsigned char
  *	side[]      = pointers to nodes on each side of the bidir element
  *  outstrength = output strength
  */
-NODEPTR  simals_target_node;
-INTBIG   simals_bidirclock = 0;
+static NODEPTR  simals_target_node;
+static INTBIG   simals_bidirclock = 0;
 
 #define FASTERSIM 1			/* new method prevents excessive graph searching */
 
@@ -1227,4 +1227,4 @@ void simals_BUS12_TO_STATE(MODPTR primhead)
 }
 #endif
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
