@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -53,16 +53,16 @@ INTBIG sim_fasthenryztailkey = 0;			/* cached key for "SIM_fasthenry_z_tail" */
 INTBIG sim_fasthenrygroupnamekey = 0;		/* cached key for "SIM_fasthenry_group_name" */
 
 /* prototypes for local routines */
-INTSML sim_writefhfacet(NODEPROTO *np, FILE *io);
-void   sim_fasthenryarcdlog(void);
-void   sim_fasthenrydlog(void);
-void   sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
-		INTBIG *runsperdecade, INTBIG *numpoles, INTBIG *seglenlimit, INTBIG *thickness,
-		INTBIG *widsubdiv, INTBIG *heisubdiv);
-char  *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubdiv,
-		INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, INTSML *zhover, INTSML *ztover,
-		INTBIG *defz);
-PORTPROTO *sim_fasthenryfindotherport(ARCINST *ai, INTBIG end);
+static INTSML sim_writefhfacet(NODEPROTO *np, FILE *io);
+static void   sim_fasthenryarcdlog(void);
+static void   sim_fasthenrydlog(void);
+static void   sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
+				INTBIG *runsperdecade, INTBIG *numpoles, INTBIG *seglenlimit, INTBIG *thickness,
+				INTBIG *widsubdiv, INTBIG *heisubdiv);
+static char  *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubdiv,
+				INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, INTSML *zhover, INTSML *ztover,
+				INTBIG *defz);
+static PORTPROTO *sim_fasthenryfindotherport(ARCINST *ai, INTBIG end);
 
 /*
  * Routine called once to initialize this module
@@ -88,10 +88,10 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	REGISTER INTBIG argc, i;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -199,7 +199,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp, *opp;
-	REGISTER INTBIG nodezval, zval, x1, y1, z1, x2, y2, z2, wid, thatend;
+	REGISTER INTBIG nodezval, zval, wid, thatend;
 	float xf, yf, zf, wf, hf;
 	char *nname, *n1name, *n2name, *groupname;
 	static POLYGON *poly = NOPOLYGON;
@@ -210,7 +210,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	INTSML zhover, ztover;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_tool->cluster);
 
 	/* stop if requested */
 	if (el_pleasestop != 0)
@@ -225,7 +225,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 
 	/* make sure that all nodes have names on them */
 	backannotate = 0;
-	if (askaid(net_aid, "name-all-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-all-nodes", (INTBIG)np) != 0) backannotate++;
 
 	/* look at every node in the facet */
 	xprintf(io, "\n* Traces\n");
@@ -244,6 +244,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			if (ai->end[1].portarcinst == pi && ztover != 0) zval = z_tail;
 			if (found != 0)
 			{
+				/* LINTED "nodezval" used in proper order */
 				if (zval != nodezval)
 					ttyputerr(_("Warning: inconsistent z value at node %s"),
 						describenodeinst(ni));
@@ -278,11 +279,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			&z_head, &z_tail, &zhover, &ztover, &defz);
 		if (groupname == 0) continue;
 
-		/* get coordinates and size */
-		x1 = ai->end[0].xpos;   y1 = ai->end[0].ypos;
-		z1 = defz;   if (zhover != 0) z1 = z_head;
-		x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
-		z2 = defz;   if (ztover != 0) z2 = z_tail;
+		/* get size */
 		wid = ai->width;
 
 		/* get the name of the nodes on each end */
@@ -357,7 +354,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	{
 		if (ai->temp1 != 0) continue;
 		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, sim_fasthenrygroupnamekey);
-		if (var = NOVARIABLE) continue;
+		if (var == NOVARIABLE) continue;
 		ttyputerr(_("Warning: arc %s is not on a measured trace"), describearcinst(ai));
 	}
 	return(backannotate);
@@ -394,23 +391,23 @@ void sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
 {
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrystatekey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenrystatekey);
 	if (var != NOVARIABLE) *options = var->addr; else *options = 0;
-	var = getvalkey((INTBIG)sim_aid, VAID, VFLOAT, sim_fasthenryfreqstartkey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VFLOAT, sim_fasthenryfreqstartkey);
 	if (var != NOVARIABLE) *startfreq = castfloat(var->addr); else *startfreq = 0.0;
-	var = getvalkey((INTBIG)sim_aid, VAID, VFLOAT, sim_fasthenryfreqendkey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VFLOAT, sim_fasthenryfreqendkey);
 	if (var != NOVARIABLE) *endfreq = castfloat(var->addr); else *endfreq = 0.0;
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenryrunsperdecadekey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenryrunsperdecadekey);
 	if (var != NOVARIABLE) *runsperdecade = var->addr; else *runsperdecade = 1;
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrynumpoleskey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenrynumpoleskey);
 	if (var != NOVARIABLE) *numpoles = var->addr; else *numpoles = 20;
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenryseglimitkey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenryseglimitkey);
 	if (var != NOVARIABLE) *seglenlimit = var->addr; else *seglenlimit = 0;
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrythicknesskey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenrythicknesskey);
 	if (var != NOVARIABLE) *thickness = var->addr; else *thickness = 2*el_curlib->lambda[el_curtech->techindex];
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrywidthsubdivkey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenrywidthsubdivkey);
 	if (var != NOVARIABLE) *widsubdiv = var->addr; else *widsubdiv = 1;
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenryheightsubdivkey);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_fasthenryheightsubdivkey);
 	if (var != NOVARIABLE) *heisubdiv = var->addr; else *heisubdiv = 1;
 }
 
@@ -424,7 +421,7 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_tool->cluster);
 
 	/* get miscellaneous parameters */
 	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenrythicknesskey);
@@ -466,7 +463,7 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 /***************************************** DIALOGS *****************************************/
 
 /* Simulation: FastHenry Options */
-DIALOGITEM sim_fasthenrydialogitems[] =
+static DIALOGITEM sim_fasthenrydialogitems[] =
 {
  /*  1 */ {0, {164,392,188,472}, BUTTON, N_("OK")},
  /*  2 */ {0, {164,12,188,92}, BUTTON, N_("Cancel")},
@@ -493,7 +490,7 @@ DIALOGITEM sim_fasthenrydialogitems[] =
  /* 23 */ {0, {176,140,192,344}, POPUP, ""},
  /* 24 */ {0, {156,176,172,320}, MESSAGE, N_("After writing deck:")}
 };
-DIALOG sim_fasthenrydialog = {{75,75,276,564}, N_("FastHenry Options"), 0, 24, sim_fasthenrydialogitems};
+static DIALOG sim_fasthenrydialog = {{75,75,276,564}, N_("FastHenry Options"), 0, 24, sim_fasthenrydialogitems};
 
 /* special items for the "FastHenry options" dialog: */
 #define DFHO_FREQSTART      4		/* frequency start (edit text) */
@@ -648,39 +645,39 @@ void sim_fasthenrydlog(void)
 		if (i == 1) value |= FHEXECUTERUNFH; else
 			if (i == 2) value |= FHEXECUTERUNFHMUL;
 		if (value != options)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrystatekey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenrystatekey, value, VINTEGER);
 
 		/* save other limits */
 		fvalue = (float)atof(DiaGetText(DFHO_FREQSTART));
 		if (fvalue != startfreq)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqstartkey, castint(fvalue), VFLOAT);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenryfreqstartkey, castint(fvalue), VFLOAT);
 		fvalue = (float)atof(DiaGetText(DFHO_FREQEND));
 		if (fvalue != endfreq)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqendkey, castint(fvalue), VFLOAT);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenryfreqendkey, castint(fvalue), VFLOAT);
 		value = atoi(DiaGetText(DFHO_RUNSPERDEC));
 		if (value != runsperdecade)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryrunsperdecadekey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenryrunsperdecadekey, value, VINTEGER);
 		value = atola(DiaGetText(DFHO_MAXSEGLEN));
 		if (value != seglenlimit)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryseglimitkey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenryseglimitkey, value, VINTEGER);
 		value = atola(DiaGetText(DFHO_DEFTHICK));
 		if (value != thickness)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrythicknesskey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenrythicknesskey, value, VINTEGER);
 		value = atoi(DiaGetText(DFHO_DEFWIDSUB));
 		if (value != widsubdiv)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrywidthsubdivkey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenrywidthsubdivkey, value, VINTEGER);
 		value = atoi(DiaGetText(DFHO_DEFHEISUB));
 		if (value != heisubdiv)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryheightsubdivkey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenryheightsubdivkey, value, VINTEGER);
 		value = atoi(DiaGetText(DFHO_NUMPOLES));
 		if (value != numpoles)
-			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrynumpoleskey, value, VINTEGER);
+			(void)setvalkey((INTBIG)sim_tool, VTOOL, sim_fasthenrynumpoleskey, value, VINTEGER);
 	}
 	DiaDoneDialog();
 }
 
 /* Simulation: FastHenry Arc */
-DIALOGITEM sim_fasthenryarcdialogitems[] =
+static DIALOGITEM sim_fasthenryarcdialogitems[] =
 {
  /*  1 */ {0, {88,236,112,316}, BUTTON, N_("OK")},
  /*  2 */ {0, {40,236,64,316}, BUTTON, N_("Cancel")},
@@ -715,7 +712,7 @@ DIALOGITEM sim_fasthenryarcdialogitems[] =
  /* 31 */ {0, {304,88,320,168}, MESSAGE, N_("Default Z:")},
  /* 32 */ {0, {304,172,320,268}, MESSAGE, ""}
 };
-DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, N_("FastHenry Arc Properties"), 0, 32, sim_fasthenryarcdialogitems};
+static DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, N_("FastHenry Arc Properties"), 0, 32, sim_fasthenryarcdialogitems};
 
 /* special items for the "FastHenry arc" dialog: */
 #define DFHA_ARCTHICK_L      3		/* arc thickness label (stat text) */
@@ -741,7 +738,7 @@ DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, N_("FastHenry Arc Properties")
 
 void sim_fasthenryarcdlog(void)
 {
-	REGISTER INTBIG itemHit, value, groupnamesize, i, which, val;
+	REGISTER INTBIG itemHit, value, groupnamesize, i, val;
 	REGISTER ARCINST *ai, *oai;
 	REGISTER VARIABLE *var;
 	char line[60], *groupname, *pt, **groupnames, **newgroupnames, *newname;
@@ -751,7 +748,7 @@ void sim_fasthenryarcdlog(void)
 	INTSML zhover, ztover;
 
 	/* get currently selected arc */
-	ai = (ARCINST *)askaid(us_aid, "get-arc");
+	ai = (ARCINST *)asktool(us_tool, "get-arc");
 	if (ai == NOARCINST)
 	{
 		ttyputerr(_("Select an arc first"));
@@ -775,16 +772,19 @@ void sim_fasthenryarcdlog(void)
 		if (var != NOVARIABLE)
 		{
 			for(i=0; i<groupnamesize; i++)
+			{
+				/* LINTED "groupnames" used in proper order */
 				if (namesame(groupnames[i], (char *)var->addr) == 0) break;
+			}
 			if (i < groupnamesize) continue;
 
 			/* add to the list */
 			newgroupnames = (char **)emalloc((groupnamesize+1) * (sizeof (char *)),
-				sim_aid->cluster);
+				sim_tool->cluster);
 			for(i=0; i<groupnamesize; i++)
 				newgroupnames[i] = groupnames[i];
 			(void)allocstring(&newgroupnames[groupnamesize], (char *)var->addr,
-				sim_aid->cluster);
+				sim_tool->cluster);
 			if (groupnamesize > 0) efree((char *)groupnames);
 			groupnames = newgroupnames;
 			groupnamesize++;
@@ -792,8 +792,8 @@ void sim_fasthenryarcdlog(void)
 	}
 	if (groupnamesize == 0)
 	{
-		groupnames = (char **)emalloc((sizeof (char *)), sim_aid->cluster);
-		(void)allocstring(&groupnames[0], _("Group 1"), sim_aid->cluster);
+		groupnames = (char **)emalloc((sizeof (char *)), sim_tool->cluster);
+		(void)allocstring(&groupnames[0], _("Group 1"), sim_tool->cluster);
 		groupnamesize++;
 	}
 	DiaSetPopup(DFHA_GROUPNAME, groupnamesize, groupnames);
@@ -922,14 +922,13 @@ void sim_fasthenryarcdlog(void)
 			if (i < groupnamesize) continue;
 
 			/* add to the list */
-			newgroupnames = (char **)emalloc((groupnamesize+1) * (sizeof (char *)), sim_aid->cluster);
+			newgroupnames = (char **)emalloc((groupnamesize+1) * (sizeof (char *)), sim_tool->cluster);
 			for(i=0; i<groupnamesize; i++)
 				newgroupnames[i] = groupnames[i];
-			(void)allocstring(&newgroupnames[groupnamesize], newname, sim_aid->cluster);
+			(void)allocstring(&newgroupnames[groupnamesize], newname, sim_tool->cluster);
 			if (groupnamesize > 0) efree((char *)groupnames);
 			groupnames = newgroupnames;
 			groupnamesize++;
-			which = DiaGetPopupEntry(DFHA_GROUPNAME);
 			DiaSetPopup(DFHA_GROUPNAME, groupnamesize, groupnames);
 			DiaSetPopupEntry(DFHA_GROUPNAME, groupnamesize-1);
 			continue;
@@ -1029,4 +1028,4 @@ void sim_fasthenryarcdlog(void)
 	efree((char *)groupnames);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
