@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: simirsim.c
- * Simulation aid: IRSIM deck generator
+ * Simulation tool: IRSIM deck generator
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2001 Static Free Software.
@@ -29,55 +29,40 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
+#include "simirsim.h"
 #include "efunction.h"
 #include "egraphics.h"
 #include "network.h"
 #include "tecschem.h"
 #include <math.h>
 
-#define NOIRSIMTRANSISTOR ((IRSIMTRANSISTOR *)-1)
+       IRSIMTRANSISTOR *sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
+static IRSIMTRANSISTOR *sim_irsimtransistorfree = NOIRSIMTRANSISTOR;
 
-typedef struct Iirsimtransistor
-{
-	INTBIG transistortype;
-	INTSML sourcefound, drainfound;
-	INTBIG xpos, ypos;
-	INTBIG length, width;
-	INTBIG source, gate, drain;
-	INTBIG sourcex, sourcey;
-	INTBIG drainx, drainy;
-	float sarea, darea;
-	INTBIG sperimeter, dperimeter;
-	struct Iirsimtransistor *nextirsimtransistor;
-} IRSIMTRANSISTOR;
-
-IRSIMTRANSISTOR *sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
-IRSIMTRANSISTOR *sim_irsimtransistorfree = NOIRSIMTRANSISTOR;
-
-INTBIG   sim_irsimlambda;
-INTBIG   sim_irsimnetnumber;
-char   **sim_irsimnetnames;
-INTBIG   sim_irsimnettotal = 0;
-FILE    *sim_irsimio;
+       INTBIG   sim_irsimnetnumber = 0;
+       char   **sim_irsimnetnames;
+       INTBIG  *sim_irsimnetsignals;
+static INTBIG   sim_irsimnettotal = 0;
+static INTBIG   sim_irsimlambda;
 
 /* prototypes for local routines */
-INTBIG           sim_irsimprint(NODEPROTO *facet, FILE *f);
-IRSIMTRANSISTOR *sim_allocirsimtransistor(void);
-void             sim_freeirsimtransistor(IRSIMTRANSISTOR *it);
-INTBIG           sim_irsimrecurse(NODEPROTO *facet, XARRAY trans);
-void             sim_irsimgetallgeometry(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y,
-					INTSML count);
-void             sim_irsimgetareaperimeter(INTBIG *x, INTBIG *y, INTSML count,
-					float *a, INTBIG *p);
-INTBIG           sim_irsimnewnetnumber(char *name);
-char            *sim_irsimbuildnetname(char *name);
-INTSML           sim_cropbox(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, INTBIG bx,
-					INTBIG ux, INTBIG by, INTBIG uy);
-INTSML           sim_clipagainstgates(POLYGON *poly, ARCINST *ai, XARRAY trans);
+static IRSIMTRANSISTOR *sim_allocirsimtransistor(void);
+static void             sim_freeirsimtransistor(IRSIMTRANSISTOR *it);
+static INTBIG           sim_irsimrecurse(NODEPROTO *facet, XARRAY trans);
+static void             sim_irsimgetallgeometry(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y,
+							INTSML count);
+static void             sim_irsimgetareaperimeter(INTBIG *x, INTBIG *y, INTSML count,
+							float *a, INTBIG *p);
+static INTBIG           sim_irsimnewnetnumber(char *name);
+static char            *sim_irsimbuildnetname(char *name);
+static INTSML           sim_cropbox(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, INTBIG bx,
+							INTBIG ux, INTBIG by, INTBIG uy);
+static INTSML           sim_clipagainstgates(POLYGON *poly, ARCINST *ai, XARRAY trans);
+static void             sim_irsimfreenetworkinfo(void);
 
 /*
  * Routine to free all memory associated with this module.
@@ -86,32 +71,35 @@ void sim_freeirsimmemory(void)
 {
 	REGISTER IRSIMTRANSISTOR *it;
 
+	sim_irsimfreenetworkinfo();
 	while (sim_irsimtransistorfree != NOIRSIMTRANSISTOR)
 	{
 		it = sim_irsimtransistorfree;
 		sim_irsimtransistorfree = it->nextirsimtransistor;
 		efree((char *)it);
 	}
-	if (sim_irsimnettotal > 0) efree((char *)sim_irsimnetnames);
+	if (sim_irsimnettotal > 0)
+	{
+		efree((char *)sim_irsimnetnames);
+		efree((char *)sim_irsimnetsignals);
+	}
 }
 
+/*
+ * Routine to write a simulation deck for facet "facet".  This is called when the user
+ * just requests a deck, so the file is not temporary.
+ */
 void sim_writeirsim(NODEPROTO *facet)
 {
-	REGISTER INTBIG backannotate;
 	REGISTER FILE *f;
-	REGISTER TECHNOLOGY *tech;
-	char *truename, creationdate[80], revisiondate[80];
+	char *truename;
 	REGISTER char *netfile;
-	REGISTER IRSIMTRANSISTOR *it, *nextit;
-	REGISTER PORTPROTO *pp;
-	REGISTER char *name;
-	REGISTER INTBIG sa, sp, da, dp, i;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -129,9 +117,85 @@ void sim_writeirsim(NODEPROTO *facet)
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
-	sim_irsimio = f;
+
+	sim_irsimgeneratedeck(facet, f);
+
+	xclose(f);
+	ttyputmsg(_("%s written"), truename);
+}
+
+/*
+ * Routine to clear out the IRSIM network in memory (from the last facet that was
+ * simulated).
+ */
+void sim_irsimfreenetworkinfo(void)
+{
+	REGISTER IRSIMTRANSISTOR *it, *nextit;
+	REGISTER INTBIG i;
+
+	for(it = sim_firstirsimtransistor; it != NOIRSIMTRANSISTOR; it = nextit)
+	{
+		nextit = it->nextirsimtransistor;
+		sim_freeirsimtransistor(it);
+	}
+	for(i=0; i<sim_irsimnetnumber; i++) efree(sim_irsimnetnames[i]);
+}
+
+/*
+ * Routine to generate an IRSIM deck for facet "facet" and write it to stream "f".
+ */
+void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
+{
+	REGISTER INTBIG backannotate;
+	REGISTER TECHNOLOGY *tech;
+	char creationdate[80], revisiondate[80];
+	REGISTER IRSIMTRANSISTOR *it;
+	REGISTER PORTPROTO *pp;
+	REGISTER NETWORK *net;
+	REGISTER char *name;
+	REGISTER INTBIG sa, sp, da, dp, i;
+
+	/* get value of lambda */
 	tech = facet->tech;
 	sim_irsimlambda = facet->cell->lib->lambda[tech->techindex];
+
+	/*
+	 * extract the IRSIM information from facet "facet".  Creates a linked
+	 * list of transistors in "sim_firstirsimtransistor" and creates
+	 * "sim_irsimnetnumber" networks in "sim_irsimnetnames".
+	 */
+	sim_irsimfreenetworkinfo();
+	sim_irsimnetnumber = 0;
+	begintraversehierarchy();
+	sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
+	backannotate = 0;
+	if (asktool(net_tool, "name-nets", (INTBIG)facet) != 0) backannotate++;
+	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+		net->temp1 = -1;
+	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	{
+		if (pp->network->temp1 != -1) continue;
+		if (pp->network->signals > 1)
+		{
+			for(i=0; i<pp->network->signals; i++)
+			{
+				net = pp->network->networklist[i];
+				if (net->namecount <= 0) continue;
+				net->temp1 = sim_irsimnewnetnumber(net->netname);
+			}
+		} else
+		{
+			name = pp->protoname;
+			if (portispower(pp) != 0) name = "vdd"; else
+				if (portisground(pp) != 0) name = "gnd";
+			pp->network->temp1 = sim_irsimnewnetnumber(name);
+		}
+	}
+	mergeinit();
+	if (sim_irsimrecurse(facet, el_matid) != 0) backannotate++;
+	mergedone(sim_irsimgetallgeometry);
+
+	/* write deck to "f" */	
 	xprintf(f,"| units: %g tech: %s format: SU\n",
 		scaletodispunit(sim_irsimlambda, DISPUNITCMIC), tech->techname);
 	if (facet->creationdate == 0) creationdate[0] = 0; else
@@ -140,23 +204,8 @@ void sim_writeirsim(NODEPROTO *facet)
 		sprintf(revisiondate, _(", modified %s"), timetostring(facet->revisiondate));
 	xprintf(f, "| Facet %s%s%s\n", describenodeproto(facet), creationdate, revisiondate);
 
-	/* set unique network numbers on the exports */
-	sim_irsimnetnumber = 0;
-	begintraversehierarchy();
-	sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(it = sim_firstirsimtransistor; it != NOIRSIMTRANSISTOR; it = it->nextirsimtransistor)
 	{
-		name = pp->protoname;
-		if (portispower(pp) != 0) name = "vdd"; else
-			if (portisground(pp) != 0) name = "gnd";
-		pp->temp1 = sim_irsimnewnetnumber(name);
-	}
-	mergeinit();
-	backannotate = sim_irsimrecurse(facet, el_matid);
-	mergedone(sim_irsimgetallgeometry);
-	for(it = sim_firstirsimtransistor; it != NOIRSIMTRANSISTOR; it = nextit)
-	{
-		nextit = it->nextirsimtransistor;
 		if (it->transistortype == NPTRANMOS) xprintf(f, "n"); else
 			xprintf(f, "p");
 		xprintf(f, " %s", sim_irsimnetnames[it->gate]);
@@ -178,12 +227,8 @@ void sim_writeirsim(NODEPROTO *facet)
 		if (dp == 0) dp = it->width + 12*sim_irsimlambda;
 		xprintf(f, " s=A_%s,P_%s", latoa(sa), latoa(sp));
 		xprintf(f, " d=A_%s,P_%s\n", latoa(da), latoa(dp));
-		sim_freeirsimtransistor(it);
 	}
-	for(i=0; i<sim_irsimnetnumber; i++) efree(sim_irsimnetnames[i]);
 
-	xclose(f);
-	ttyputmsg(_("%s written"), truename);
 	if (backannotate != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 }
@@ -197,6 +242,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai;
+	REGISTER VARIABLE *var;
 	REGISTER INTBIG netnumber, i, tot, fun, backannotate, type, realtype;
 	INTBIG x, y;
 	REGISTER IRSIMTRANSISTOR *it;
@@ -204,23 +250,23 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_tool->cluster);
 
 	backannotate = 0;
-	if (askaid(net_aid, "name-nodes", (INTBIG)facet) != 0) backannotate++;
-	if (askaid(net_aid, "name-nets", (INTBIG)facet) != 0) backannotate++;
-
-	/* pickup net numbers from exports */
-	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
-		net->temp1 = -1;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-		pp->network->temp1 = pp->temp1;
+	if (asktool(net_tool, "name-nodes", (INTBIG)facet) != 0) backannotate++;
 
 	/* create unique numbers for internal nets */
 	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
-		if (net->temp1 >= 0) continue;
-		net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(net->netname));
+		if (net->temp1 != -1) continue;
+		if (net->signals > 1) continue;
+		if (net->namecount > 0)
+		{
+			net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(net->netname));
+		} else
+		{
+			net->temp1 = sim_irsimnewnetnumber("INTERNAL");
+		}
 	}
 
 	/* now examine all geometry in the facet */
@@ -232,14 +278,17 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 			if (ni->firstportarcinst != NOPORTARCINST)
 			{
 				i = ni->firstportarcinst->conarcinst->network->temp1;
-				if (np == sch_pwrprim)
+				if (i != -1)
 				{
-					if (namesame(sim_irsimnetnames[i], "vdd") != 0)
-						(void)reallocstring(&sim_irsimnetnames[i], "vdd", sim_aid->cluster);
-				} else
-				{
-					if (namesame(sim_irsimnetnames[i], "gnd") != 0)
-						(void)reallocstring(&sim_irsimnetnames[i], "gnd", sim_aid->cluster);
+					if (np == sch_pwrprim)
+					{
+						if (namesame(sim_irsimnetnames[i], "vdd") != 0)
+							(void)reallocstring(&sim_irsimnetnames[i], "vdd", sim_tool->cluster);
+					} else
+					{
+						if (namesame(sim_irsimnetnames[i], "gnd") != 0)
+							(void)reallocstring(&sim_irsimnetnames[i], "gnd", sim_tool->cluster);
+					}
 				}
 			}
 		}
@@ -247,25 +296,84 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 		transmult(singletrans, trans, localtrans);
 		if (np->primindex == 0)
 		{
+			/* ignore recursive references (showing icon in contents) */
+			if (np->cell == facet->cell) continue;
+
 			/* facet instance: recurse */
 			cnp = contentsview(np);
 			if (cnp == NONODEPROTO) cnp = np;
-			for(pp = cnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-				pp->temp1 = -1;
+
+			if (asktool(net_tool, "name-nets", (INTBIG)cnp) != 0) backannotate++;
+			for(net = cnp->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+				net->temp1 = -1;
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 			{
 				pp = equivalentport(np, pi->proto, cnp);
-				pp->temp1 = pi->conarcinst->network->temp1;
+				if (pp == NOPORTPROTO)
+				{
+					ttyputmsg("Cannot find icon export '%s' in facet %s",
+						pi->proto->protoname, describenodeproto(cnp));
+				} else
+				{
+					pp->network->temp1 = pi->conarcinst->network->temp1;
+					if (pp->network->signals > 1 &&
+						pp->network->signals == pi->conarcinst->network->signals)
+					{
+						for(i=0; i<pp->network->signals; i++)
+						{
+							net = pp->network->networklist[i];
+							net->temp1 = pi->conarcinst->network->networklist[i]->temp1;
+						}
+					}
+				}
 			}
+
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 			{
 				pp = equivalentport(np, pe->proto, cnp);
-				pp->temp1 = pe->exportproto->network->temp1;
+				if (pp == NOPORTPROTO)
+				{
+					ttyputmsg("Cannot find icon export '%s' in facet %s",
+						pe->proto->protoname, describenodeproto(cnp));
+				} else
+				{
+					pp->network->temp1 = pe->exportproto->network->temp1;
+					if (pp->network->signals > 1 &&
+						pp->network->signals == pe->exportproto->network->signals)
+					{
+						for(i=0; i<pp->network->signals; i++)
+						{
+							net = pp->network->networklist[i];
+							net->temp1 = pe->exportproto->network->networklist[i]->temp1;
+						}
+					}
+				}
 			}
 			for(pp = cnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			{
-				if (pp->temp1 >= 0) continue;
-				pp->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(pp->protoname));
+				if (pp->network->temp1 != -1) continue;
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				if (pp->network->signals > 1)
+				{
+					for(i=0; i<pp->network->signals; i++)
+					{
+						net = pp->network->networklist[i];
+						if (net->temp1 != -1) continue;
+						if (net->namecount <= 0) continue;
+						(void)initinfstr();
+						if (var != NOVARIABLE)
+							(void)formatinfstr("%s/", (char *)var->addr);
+						(void)addstringtoinfstr(net->netname);
+						net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(returninfstr()));
+					}
+				} else
+				{
+					(void)initinfstr();
+					if (var != NOVARIABLE)
+						(void)formatinfstr("%s/", (char *)var->addr);
+					(void)addstringtoinfstr(pp->protoname);
+					pp->network->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(returninfstr()));
+				}
 			}
 			maketrans(ni, singletrans);
 			transmult(singletrans, localtrans, subrot);
@@ -277,7 +385,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 			/* primitive: see if it is a transistor */
 			it = NOIRSIMTRANSISTOR;
 			type = (np->userbits&NFUNCTION) >> NFUNCTIONSH;
-			realtype = nodefunction(ni, 0);
+			realtype = nodefunction(ni);
 			if (realtype == NPTRANMOS || realtype == NPTRA4NMOS ||
 				realtype == NPTRAPMOS || realtype == NPTRA4PMOS)
 			{
@@ -399,7 +507,7 @@ INTSML sim_clipagainstgates(POLYGON *poly, ARCINST *ai, XARRAY trans)
 	static POLYGON *gatepoly = NOPOLYGON;
 
 	/* get polygon */
-	if (gatepoly == NOPOLYGON) gatepoly = allocstaticpolygon(4, sim_aid->cluster);
+	if (gatepoly == NOPOLYGON) gatepoly = allocstaticpolygon(4, sim_tool->cluster);
 
 	if (isbox(poly, &plx, &phx, &ply, &phy) == 0) return(0);
 
@@ -465,10 +573,21 @@ void sim_irsimgetallgeometry(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *
 {
 	REGISTER IRSIMTRANSISTOR *it;
 	POLYGON fakepoly;
-	REGISTER INTBIG found;
+	REGISTER INTBIG found, lx, hx, ly, hy, i;
 	INTBIG perimeter, a, p;
+	REGISTER char *name;
 	float area;
 
+	/* get bounds of this geometry */
+	lx = hx = x[0];
+	ly = hy = y[0];
+	for(i=1; i<count; i++)
+	{
+		if (x[i] < lx) lx = x[i];
+		if (x[i] > hx) hx = x[i];
+		if (y[i] < ly) ly = y[i];
+		if (y[i] > hy) hy = y[i];
+	}
 	found = 0;
 	for(it = sim_firstirsimtransistor; it != NOIRSIMTRANSISTOR; it = it->nextirsimtransistor)
 		it->sourcefound = it->drainfound = 0;
@@ -477,26 +596,34 @@ void sim_irsimgetallgeometry(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *
 		/* see if the source or drain of this transistor is in the polygon */
 		if (it->sarea == 0.0)
 		{
-			fakepoly.count = count;
-			fakepoly.xv = x;
-			fakepoly.yv = y;
-			fakepoly.style = FILLED;
-			if (isinside(it->sourcex, it->sourcey, &fakepoly) != 0)
+			if (it->sourcex >= lx && it->sourcex <= hx &&
+				it->sourcey >= ly && it->sourcey <= hy)
 			{
-				it->sourcefound = 1;
-				found++;
+				fakepoly.count = count;
+				fakepoly.xv = x;
+				fakepoly.yv = y;
+				fakepoly.style = FILLED;
+				if (isinside(it->sourcex, it->sourcey, &fakepoly) != 0)
+				{
+					it->sourcefound = 1;
+					found++;
+				}
 			}
 		}
 		if (it->darea == 0.0)
 		{
-			fakepoly.count = count;
-			fakepoly.xv = x;
-			fakepoly.yv = y;
-			fakepoly.style = FILLED;
-			if (isinside(it->drainx, it->drainy, &fakepoly) != 0)
+			if (it->drainx >= lx && it->drainx <= hx &&
+				it->drainy >= ly && it->drainy <= hy)
 			{
-				it->drainfound = 1;
-				found++;
+				fakepoly.count = count;
+				fakepoly.xv = x;
+				fakepoly.yv = y;
+				fakepoly.style = FILLED;
+				if (isinside(it->drainx, it->drainy, &fakepoly) != 0)
+				{
+					it->drainfound = 1;
+					found++;
+				}
 			}
 		}
 	}
@@ -519,11 +646,15 @@ void sim_irsimgetallgeometry(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *
 		}
 	} else
 	{
-		a = (INTBIG)(area / sim_irsimlambda);
-		a = (a + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
-		p = (perimeter + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
-		xprintf(sim_irsimio, "| Unattached diffusion on node %s has A=%s P=%s\n",
-			sim_irsimnetnames[layer], latoa(a), latoa(p));
+		name = sim_irsimnetnames[layer];
+		if (namesame(name, "vdd") != 0 && namesame(name, "gnd") != 0)
+		{
+			a = (INTBIG)(area / sim_irsimlambda);
+			a = (a + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
+			p = (perimeter + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
+			ttyputerr("Warning: unattached diffusion on node %s has Area %s, Perimeter %s",
+				name, latoa(a), latoa(p));
+		}
 	}
 }
 
@@ -606,7 +737,7 @@ IRSIMTRANSISTOR *sim_allocirsimtransistor(void)
 		sim_irsimtransistorfree = it->nextirsimtransistor;
 	} else
 	{
-		it = (IRSIMTRANSISTOR *)emalloc(sizeof (IRSIMTRANSISTOR), sim_aid->cluster);
+		it = (IRSIMTRANSISTOR *)emalloc(sizeof (IRSIMTRANSISTOR), sim_tool->cluster);
 		if (it == 0) return(NOIRSIMTRANSISTOR);
 	}
 	return(it);
@@ -620,24 +751,34 @@ void sim_freeirsimtransistor(IRSIMTRANSISTOR *it)
 
 INTBIG sim_irsimnewnetnumber(char *name)
 {
-	REGISTER INTBIG newtotal, i;
+	REGISTER INTBIG newtotal, i, *newsignals;
 	REGISTER char **newnames;
 
 	if (sim_irsimnetnumber >= sim_irsimnettotal)
 	{
 		newtotal = sim_irsimnetnumber * 2;
 		if (newtotal <= 0) newtotal = 10;
-		newnames = (char **)emalloc(newtotal * (sizeof (char *)), sim_aid->cluster);
+		newnames = (char **)emalloc(newtotal * (sizeof (char *)), sim_tool->cluster);
 		if (newnames == 0) return(-1);
+		newsignals = (INTBIG *)emalloc(newtotal * SIZEOFINTBIG, sim_tool->cluster);
+		if (newsignals == 0) return(-1);
 		for(i=0; i<sim_irsimnetnumber; i++)
+		{
 			newnames[i] = sim_irsimnetnames[i];
-		if (sim_irsimnettotal > 0) efree((char *)sim_irsimnetnames);
+			newsignals[i] = sim_irsimnetsignals[i];
+		}
+		if (sim_irsimnettotal > 0)
+		{
+			efree((char *)sim_irsimnetnames);
+			efree((char *)sim_irsimnetsignals);
+		}
 		sim_irsimnetnames = newnames;
+		sim_irsimnetsignals = newsignals;
 		sim_irsimnettotal = newtotal;
 	}
 	i = sim_irsimnetnumber++;
-	(void)allocstring(&sim_irsimnetnames[i], name, sim_aid->cluster);
+	(void)allocstring(&sim_irsimnetnames[i], name, sim_tool->cluster);
 	return(i);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
