@@ -40,7 +40,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -52,9 +52,9 @@ static INTBIG sim_mossiminternal;
 static INTBIG sim_mossim_strength = 0;
 
 /* prototypes for local routines */
-INTSML sim_writemossimfacet(NODEPROTO*, INTSML);
-void sim_addmossimnode(NODEINST*, PORTPROTO*);
-char *sim_mossim_netname(ARCINST*);
+static INTSML sim_writemossimfacet(NODEPROTO*, INTSML);
+static void   sim_addmossimnode(NODEINST*, PORTPROTO*);
+static char  *sim_mossim_netname(ARCINST*);
 
 /*
  * routine to write a ".ntk" file from the facet "np"
@@ -66,10 +66,10 @@ void sim_writemossim(NODEPROTO *np)
 	REGISTER LIBRARY *lib;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -107,7 +107,7 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 	REGISTER INTBIG type, inst, i, strength;
 	REGISTER INTSML backannotate;
 	REGISTER VARIABLE *var;
-	REGISTER NODEPROTO *snp;
+	REGISTER NODEPROTO *snp, *subnp;
 	char temp[20], *str;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai, *nai;
@@ -123,15 +123,19 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 	backannotate = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		if (ni->proto->primindex != 0) continue;
-		snp = contentsview(ni->proto);
-		if (snp == NONODEPROTO) snp = ni->proto;
+		subnp = ni->proto;
+		if (subnp->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (subnp->cell == np->cell) continue;
+		snp = contentsview(subnp);
+		if (snp == NONODEPROTO) snp = subnp;
 		if (snp->temp1 != 0) continue;
 		if (sim_writemossimfacet(snp, 0) != 0) backannotate = 1;
 	}
 
 	/* make sure that all nodes have names on them */
-	if (askaid(net_aid, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
 
 	/* initialize instance counter */
 	inst = 1;
@@ -269,10 +273,11 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 	/* now write the transistors */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		if (ni->proto->primindex != 0)
+		subnp = ni->proto;
+		if (subnp->primindex != 0)
 		{
 			/* handle primitives */
-			type = (INTSML)((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
+			type = (INTSML)((subnp->userbits&NFUNCTION) >> NFUNCTIONSH);
 
 			/* if it is a transistor, write the information */
 			if (type != NPTRANMOS && type != NPTRADMOS && type != NPTRAPMOS && type != NPTRANS)
@@ -282,16 +287,16 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 			if (type == NPTRANS)
 			{
 				/* undefined transistor: look at its transistor type */
-				type = nodefunction(ni, 0);
+				type = nodefunction(ni);
 
 				/* gate is port 0, source is port 1, drain is port 2 */
-				gate = ni->proto->firstportproto;
+				gate = subnp->firstportproto;
 				source = gate->nextportproto;
 				drain = source->nextportproto;
 			} else
 			{
 				/* gate is port 0 or 2, source is port 1, drain is port 3 */
-				gate = ni->proto->firstportproto;
+				gate = subnp->firstportproto;
 				source = gate->nextportproto;
 				drain = source->nextportproto->nextportproto;
 			}
@@ -324,15 +329,18 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 			xprintf(sim_mossimfile, "%s", returninfstr());
 		} else
 		{
+			/* ignore recursive references (showing icon in contents) */
+			if (subnp->cell == np->cell) continue;
+
 			/* complex node: make instance call */
 			(void)initinfstr();
 			(void)addstringtoinfstr("h ");
 
 			/* see if this facet is an icon for the real thing */
-			snp = contentsview(ni->proto);
+			snp = contentsview(subnp);
 			if (snp != NONODEPROTO)
 				(void)addstringtoinfstr(snp->cell->cellname); else
-					(void)addstringtoinfstr(ni->proto->cell->cellname);
+					(void)addstringtoinfstr(subnp->cell->cellname);
 			(void)addtoinfstr(' ');
 
 			/* get appropriate name of node */
@@ -342,7 +350,7 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 				ttyputerr(_("MOSSIM generation warning: no name on node %s"),
 					describenodeinst(ni));
 				(void)addstringtoinfstr("INST");
-				(void)sprintf(temp, "%d", inst++);
+				(void)sprintf(temp, "%ld", inst++);
 				(void)addstringtoinfstr(temp);
 			} else (void)addstringtoinfstr((char *)var->addr);
 
@@ -351,14 +359,14 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 				/* icon facet: report ports according to order on contents */
 				for(pp = snp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				{
-					spp = equivalentport(snp, pp, ni->proto);
+					spp = equivalentport(snp, pp, subnp);
 					if (spp == NOPORTPROTO) continue;
 					sim_addmossimnode(ni, spp);
 				}
 			} else
 			{
 				/* normal facet: simply report ports in order */
-				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					sim_addmossimnode(ni, pp);
 			}
 			(void)addstringtoinfstr(" ;\n");
@@ -464,4 +472,4 @@ char *sim_mossim_netname(ARCINST *ai)
 	return((char *)ai->temp2);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
