@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -64,31 +64,31 @@
 
 /********************** global variables *********************/
 
-FILE *sim_silfile;
+static FILE  *sim_silfile;
 extern INTBIG sim_pseudonet;		/* for internal networks */
-INTBIG sim_silos_global_name = 0;
-INTBIG sim_silos_model_key = 0;		/* for model on cell */
+static INTBIG sim_silos_global_name = 0;
+static INTBIG sim_silos_model_key = 0;		/* for model on cell */
 
 /* ************************************************************* */
 
 /* prototypes for local routines */
-INTBIG sim_writesilfacet(NODEPROTO*, INTSML);
-void sim_writesilinstances(NODEPROTO*, INTSML);
-char *sim_silportname(INTSML, NODEINST*, PORTPROTO*, NODEPROTO*);
-char *sim_silname(NODEINST*);
-char *sim_silproto(NODEINST*, INTSML);
-char *sim_siltext(char*);
-void sim_sendtosil(char*);
-char *sim_silarcname(ARCINST*);
-INTSML sim_silnegated(PORTARCINST*);
-char *sim_silspecials(char*);
-INTSML sim_silostype(NODEINST*, char**);
-char *sim_silrisetime(NODEINST*);
-char *sim_silfalltime(NODEINST*);
-INTBIG sim_silgetcapacitance(NODEINST*);
-void sim_silwriteflipflop(INTSML, NODEINST*, NODEPROTO*, INTSML);
-char *sim_sil_isaport(NODEPROTO*, char*);
-static char *sim_convertsub(char*);
+static INTBIG  sim_writesilfacet(NODEPROTO*, INTSML);
+static void    sim_writesilinstances(NODEPROTO*, INTSML);
+static char   *sim_silportname(INTSML, NODEINST*, PORTPROTO*, NODEPROTO*);
+static char   *sim_silname(NODEINST*);
+static char   *sim_silproto(NODEINST*, INTSML);
+static char   *sim_siltext(char*);
+static void    sim_sendtosil(char*);
+static char   *sim_silarcname(ARCINST*);
+static INTSML  sim_silnegated(PORTARCINST*);
+static char   *sim_silspecials(char*);
+static INTSML  sim_silostype(NODEINST*);
+static char   *sim_silrisetime(NODEINST*);
+static char   *sim_silfalltime(NODEINST*);
+static INTBIG  sim_silgetcapacitance(NODEINST*);
+static void    sim_silwriteflipflop(INTSML, NODEINST*, NODEPROTO*, INTSML);
+static char   *sim_sil_isaport(NODEPROTO*, char*);
+static char   *sim_convertsub(char*);
 
 /*
  * routine to write a ".sil" file from the facet "np"
@@ -102,10 +102,10 @@ void sim_writesilnetlist(NODEPROTO *np)
 	INTBIG rnum;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -207,7 +207,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 		{
 			if (ni->proto->primindex == 0) continue;	/* only real sources */
 
-			nodetype = nodefunction(ni, &extra);
+			nodetype = nodefunction(ni);
 			if (nodetype != NPSOURCE) continue;
 
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name);
@@ -220,7 +220,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 			}
 
 			/* Get the source type */
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sch_sourcekey);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sch_spicemodelkey);
 			if (var == NOVARIABLE)
 			{
 				ttyputerr(_("Unspecified source:"));
@@ -311,6 +311,9 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 	{
 		if (ni->proto->primindex != 0) continue;
 
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
+
 		/* get actual subfacet (including contents/body distinction) */
 		/* NOTE: this gets the schematic before the layout */
 		onp = contentsview(ni->proto);
@@ -324,7 +327,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 	}
 
 	/* make sure that all nodes have names on them */
-	if (askaid(net_aid, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
 
 	/* mark this facet as written */
 	np->temp1++;
@@ -386,13 +389,11 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 	REGISTER PORTPROTO *pp, *lastpp, *outpp;
 	REGISTER PORTARCINST *pi;
 	char line[100];
-	char *extra;
 
 	sim_pseudonet = 1;
 	schem_ref = 1;
 
-	/* Look at every node in this facet */
-
+	/* look at every node in this facet */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		ni->temp1 = 0;
@@ -408,10 +409,10 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 		/* all remaining nodes have at least two distinct ports */
 		ni->temp1 = schem_ref++;
 
-		/* Reset flag for output port */
+		/* reset flag for output port */
 		outpp = NOPORTPROTO;
 
-		nodetype = sim_silostype(ni, &extra);
+		nodetype = sim_silostype(ni);
 		switch (nodetype)
 		{
 			case SILOSFACET:		/* Complex cell uses instance name */
@@ -529,7 +530,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 					j = sim_silgetcapacitance(ni);
 					if (j >= 0)
 					{
-						(void)sprintf(line, " %d", j);
+						(void)sprintf(line, " %ld", j);
 						sim_sendtosil(line);
 					} else
 						ttyputerr(_("Warning: capacitor with no value"));
@@ -670,7 +671,6 @@ char *sim_silname(NODEINST *ni)
  */
 char *sim_silproto(NODEINST *ni,INTSML neg)
 {
-	char *extra;
 	REGISTER INTSML f;
 	static char name[100];
 
@@ -682,7 +682,7 @@ char *sim_silproto(NODEINST *ni,INTSML neg)
 		return(name);
 	}
 
-	f = sim_silostype(ni, &extra);
+	f = sim_silostype(ni);
 	switch (f)
 	{
 		case SILOSNMOS:
@@ -821,16 +821,13 @@ char *sim_silspecials(char *str)
  * Read the contents of the added string, make it available to
  * the caller
  */
-INTSML sim_silostype(NODEINST *ni, char **info)
+INTSML sim_silostype(NODEINST *ni)
 {
 	INTBIG func;
-	REGISTER VARIABLE *var;
-	char *string;
 
 	if (ni->proto->primindex == 0) return(SILOSFACET);
 
-	func = nodefunction(ni, &string);
-	*info = string;
+	func = nodefunction(ni);
 	switch(func)
 	{
 		case NPTRAPMOS:
@@ -861,12 +858,6 @@ INTSML sim_silostype(NODEINST *ni, char **info)
 			}
 			return(SILOSDFF);
 		case NPSOURCE:
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name);
-			if (var != NOVARIABLE)
-			{
-				string = (char *)var->addr;
-				*info = string;
-			}
 			return(SILOSCLOCK);
 		case NPMETER:
 			return(SILOSOUT);
@@ -1031,4 +1022,4 @@ static char *sim_convertsub(char *string)
 	return(newname);
 }
 
-#endif	/* SIMAID - at top */
+#endif	/* SIMTOOL - at top */
