@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: simsim.c
- * Simulation aid: ESIM, RSIM, RNL, and COSMOS controller
+ * Simulation tool: ESIM, RSIM, RNL, and COSMOS controller
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -39,18 +39,18 @@
 #include <setjmp.h>
 
 static INTBIG sim_cosmos_attribute = 0;
-jmp_buf sim_userdone;		/* for when simulator command is done */
-INTBIG sim_index, sim_vdd, sim_gnd, sim_namethresh,
-	  sim_phi1h, sim_phi1l, sim_phi2h, sim_phi2l, count_unconn;
-char *sim_name, *sim_prompt, *sim_inputfile = 0;
+static jmp_buf sim_userdone;		/* for when simulator command is done */
+static INTBIG sim_index, sim_vdd, sim_gnd, sim_namethresh,
+		 sim_phi1h, sim_phi1l, sim_phi2h, sim_phi2l, count_unconn;
+static char *sim_name, *sim_prompt, *sim_inputfile = 0;
 
 /* prototypes for local routines */
-INTSML sim_simsearch(INTSML, NODEPROTO*, INTSML);
-void sim_simtell(void);
-void sim_simprint(NODEPROTO*, FILE*, INTSML);
-void sim_simprintcosmos(NODEPROTO*, FILE*, INTSML);
-char *sim_makenodename(INTBIG, INTSML);
-void sim_prop(ARCINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
+static INTSML  sim_simsearch(INTSML, NODEPROTO*, INTSML);
+static void    sim_simtell(void);
+static void    sim_simprint(NODEPROTO*, FILE*, INTSML);
+static void    sim_simprintcosmos(NODEPROTO*, FILE*, INTSML);
+static char   *sim_makenodename(INTBIG, INTSML);
+static void    sim_prop(ARCINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 
 void sim_writesim(NODEPROTO *simnt, INTSML format)
 {
@@ -63,10 +63,10 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	REGISTER char *simprog, *presimtmp, *presimprog, *netfile;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -81,19 +81,19 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	sim_simnt = simnt;
 
 	/* initialize for the particular simulator */
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_format);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
 	if (var == NOVARIABLE) format = -1; else format = (INTSML)var->addr;
 
 	/* construct the simulation description file name from the facet */
 	(void)initinfstr();
 	(void)addstringtoinfstr(simnt->cell->cellname);
 	(void)addstringtoinfstr(".sim");
-	var = setvalkey((INTBIG)sim_aid, VAID, sim_netfile, (INTBIG)returninfstr(), VSTRING|VDONTSAVE);
+	var = setvalkey((INTBIG)sim_tool, VTOOL, sim_netfile, (INTBIG)returninfstr(), VSTRING|VDONTSAVE);
 	if (var != NOVARIABLE) netfile = (char *)var->addr; else netfile = "";
 
 	/* also record the actual input file to the simulator */
 	if (sim_inputfile != 0) efree(sim_inputfile);
-	(void)allocstring(&sim_inputfile, netfile, sim_aid->cluster);
+	(void)allocstring(&sim_inputfile, netfile, sim_tool->cluster);
 
 	/* create the simulation file */
 	if (format == RSIM) filetype = sim_filetypersim; else
@@ -239,7 +239,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	xclose(f);
 
 	/* if execution is not desired, quit now */
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_dontrun);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_dontrun);
 	if (format == COSMOS || (var != NOVARIABLE && var->addr == SIMRUNNO))
 	{
 		if (count_unconn != 0)
@@ -293,7 +293,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 		}
 		ewait(sim_process);
 		ttyputmsg(_("Pre-simulator finished"));
-		(void)reallocstring(&sim_inputfile, presimtmp, sim_aid->cluster);
+		(void)reallocstring(&sim_inputfile, presimtmp, sim_tool->cluster);
 	}
 
 	/* for communication with simulator, read fromsim[0], write tosim[1] */
@@ -493,10 +493,10 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 			if (pp->network != ai->network) continue;
 			if (pp->temp1 == want)
 			{
-				(void)askaid(us_aid, "clear");
-				(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
+				(void)asktool(us_tool, "clear");
+				(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 				newpar[0] = "highlight";
-				(void)tellaid(net_aid, 1, newpar);
+				(void)telltool(net_tool, 1, newpar);
 				return(0);
 			}
 			darea = dperim = parea = pperim = marea = mperim = 0;
@@ -509,10 +509,10 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 		{
 			if (sim_index == want)
 			{
-				(void)askaid(us_aid, "clear");
-				(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
+				(void)asktool(us_tool, "clear");
+				(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 				newpar[0] = "highlight";
-				(void)tellaid(net_aid, 1, newpar);
+				(void)telltool(net_tool, 1, newpar);
 				return(0);
 			}
 			darea = dperim = parea = pperim = marea = mperim = 0;
@@ -525,8 +525,8 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (pp->temp1 == want)
 	{
-		(void)askaid(us_aid, "clear");
-		(void)askaid(us_aid, "show-port", (INTBIG)pp->subnodeinst->geom, (INTBIG)pp->subportproto);
+		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, "show-port", (INTBIG)pp->subnodeinst->geom, (INTBIG)pp->subportproto);
 		return(0);
 	}
 
@@ -541,6 +541,9 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 			if (np->primindex == 0)
 			{
 				type = NPUNKNOWN;
+
+				/* ignore recursive references (showing icon in contents) */
+				if (np->cell == facet->cell) continue;
 				np = contentsview(snp);
 				if (np == NONODEPROTO) np = snp;
 			}
@@ -621,7 +624,7 @@ void sim_resumesim(INTSML firsttime)
 	if (firsttime)
 	{
 		ttyputmsg(_("Type 'help' if you need it"));
-		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_format);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
 		if (var == NOVARIABLE) format = -1; else format = var->addr;
 		if (format == RNL)
 		{
@@ -647,13 +650,13 @@ void sim_resumesim(INTSML firsttime)
 				ekill(sim_process);
 				ewait(sim_process);
 				sim_process = -1;
-				var = getvalkey((INTBIG)sim_aid, VAID, VSTRING, sim_netfile);
+				var = getvalkey((INTBIG)sim_tool, VTOOL, VSTRING, sim_netfile);
 				if (var != NOVARIABLE)
 					ttyputmsg(_("Net list saved in '%s'"), (char *)var->addr);
 				return;
 			case 3:			/* pause the simulation */
 				if (firsttime)
-					ttyputmsg(_("Type '-tellaid simulation resume' to return"));
+					ttyputmsg(_("Type '-telltool simulation resume' to return"));
 				return;
 		}
 
@@ -706,14 +709,14 @@ void sim_simtell(void)
 		if (len > 1 && namesamen(pp, "help", len) == 0)
 		{
 			newpar[0] = "help";   newpar[1] = sim_name;
-			(void)tellaid(us_aid, 2, newpar);
+			(void)telltool(us_tool, 2, newpar);
 		} else break;
 	}
 
 	/* send user command to simulator */
 	if (*pp == 'q')
 	{
-		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_format);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
 		if (var != NOVARIABLE && var->addr == RNL) *pp = CTRLDKEY;
 	}
 	len = strlen(pp);
@@ -783,6 +786,9 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 		if (np->primindex == 0)
 		{
 			type = NPUNKNOWN;
+
+			/* ignore recursive references (showing icon in contents) */
+			if (np->cell == facet->cell) continue;
 			np = contentsview(snp);
 			if (np == NONODEPROTO) np = snp;
 		}
@@ -858,7 +864,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 			if (type == NPTRANS)
 			{
 				/* undefined transistor: look at its transistor type */
-				type = nodefunction(ni, 0);
+				type = nodefunction(ni);
 
 				/* gate is port 0, source is port 1, drain is port 2 */
 				p = np->firstportproto;    gate = p->temp1;
@@ -995,6 +1001,9 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 		if (np->primindex == 0)
 		{
 			type = NPUNKNOWN;
+
+			/* ignore recursive references (showing icon in contents) */
+			if (np->cell == facet->cell) continue;
 			np = contentsview(snp);
 			if (np == NONODEPROTO) np = snp;
 		}
@@ -1071,7 +1080,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 			if (type == NPTRANS)
 			{
 				/* undefined transistor: look at its transistor type */
-				type = nodefunction(ni, 0);
+				type = nodefunction(ni);
 
 				/* gate is port 0, source is port 1, drain is port 2 */
 				gate = np->firstportproto;
@@ -1250,4 +1259,4 @@ void sim_prop(ARCINST *ai, INTBIG indx, INTBIG *darea, INTBIG *dperim, INTBIG *p
 	}
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
