@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "sim.h"
@@ -52,7 +52,7 @@ typedef struct Inumbers
 	struct Inumbers *nextnumbers;
 } NUMBERS;
 
-NUMBERS *sim_numbersfree = NONUMBERS;
+static NUMBERS *sim_numbersfree = NONUMBERS;
 
 extern INTSML   spice_state;			/* value of "SIM_spice_state" */
 extern char     sim_deck_facetname[];	/* name extracted from .SPO/TR0 file */
@@ -71,18 +71,19 @@ static INTBIG   sim_window_filepos;
 static INTBIG   sim_window_filelen;
 
 /* prototypes for local routines */
-NUMBERS *sim_allocnumbers(INTSML);
-void sim_freenumbers(NUMBERS*);
-void sim_spice_terminate(FILE*, char*, char*);
-INTSML sim_getfromsimulator(void);
-INTSML sim_window_topofsignals(char**);
-char *sim_window_nextsignals(void);
-INTSML sim_spice_plotvalues(INTSML);
-INTSML sim_window_ensurespace(INTSML);
-INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode);
-INTBIG sim_window_findsignalname(char *name);
-INTSML sim_spice_charhandlerschem(WINDOWPART *w, INTSML chr);
-INTSML sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr);
+static NUMBERS *sim_allocnumbers(INTSML);
+static void     sim_freenumbers(NUMBERS*);
+static void     sim_spice_terminate(FILE*, char*, char*);
+static INTSML   sim_getfromsimulator(void);
+static INTSML   sim_window_topofsignals(char**);
+static char    *sim_window_nextsignals(void);
+static INTSML   sim_spice_plotvalues(INTSML);
+static INTSML   sim_window_ensurespace(INTSML);
+static INTBIG   sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode);
+static INTBIG   sim_window_findsignalname(char *name);
+static INTSML   sim_spice_charhandlerschem(WINDOWPART *w, INTSML chr);
+static INTSML   sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr);
+static void     sim_window_addhighlightednet(INTSML);
 
 /*
  * routine to allocate a new numbers module from the pool (if any) or memory
@@ -93,7 +94,7 @@ NUMBERS *sim_allocnumbers(INTSML total)
 
 	if (sim_numbersfree == NONUMBERS)
 	{
-		d = (NUMBERS *)emalloc(sizeof (NUMBERS), sim_aid->cluster);
+		d = (NUMBERS *)emalloc(sizeof (NUMBERS), sim_tool->cluster);
 		if (d == 0) return(NONUMBERS);
 	} else
 	{
@@ -101,7 +102,7 @@ NUMBERS *sim_allocnumbers(INTSML total)
 		sim_numbersfree = (NUMBERS *)d->nextnumbers;
 	}
 
-	d->list = (float *)emalloc(((sizeof (float)) * total), sim_aid->cluster);
+	d->list = (float *)emalloc(((sizeof (float)) * total), sim_tool->cluster);
 	if (d->list == 0) return(NONUMBERS);
 	d->count = total;
 	return(d);
@@ -140,7 +141,7 @@ void sim_spice_execute(char *infile, char *outfile)
 	char *host, *path, *name, *execpars[8], *truename;
 
 	/* determine execution/parsing mode */
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_dontrun);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_dontrun);
 	if (var == NOVARIABLE) parsemode = SIMRUNNO; else
 		parsemode = var->addr;
 
@@ -249,7 +250,7 @@ void sim_spice_execute(char *infile, char *outfile)
 	 * Determine the "spice_state".  If we're doing a write-execute-parse,
 	 * then we've already done this.  If we're just doing a parse, we have not.
 	 */
-	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_spice_state);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_spice_state);
 	if (var != NOVARIABLE) spice_state = (INTSML)var->addr; else spice_state = 0;
 
 	/* free any former data */
@@ -417,8 +418,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 
 		/* generate dummy names */
 		important = sim_window_signals;
-		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_aid->cluster);
-		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_aid->cluster);
+		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_tool->cluster);
+		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_tool->cluster);
 		if (sim_window_signames == 0 || sim_window_sigtypes == 0)
 		{
 			/* terminate execution so we can restart simulator */
@@ -427,7 +428,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		for(i=0; i<sim_window_signals; i++)
 		{
 			(void)sprintf(line, "Signal %ld", i+1);
-			(void)allocstring(&sim_window_signames[i], line, sim_aid->cluster);
+			(void)allocstring(&sim_window_signames[i], line, sim_tool->cluster);
 		}
 	} else if ((spice_state & SPICETYPE) == SPICE3)
 	{
@@ -526,8 +527,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 
 		/* generate dummy names */
 		important = sim_window_signals;
-		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_aid->cluster);
-		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_aid->cluster);
+		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_tool->cluster);
+		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_tool->cluster);
 		if (sim_window_signames == 0 || sim_window_sigtypes == 0)
 		{
 			/* terminate execution so we can restart simulator */
@@ -536,7 +537,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		for(i=0; i<sim_window_signals; i++)
 		{
 			(void)sprintf(line, "Signal %ld", i+1);
-			(void)allocstring(&sim_window_signames[i], line, sim_aid->cluster);
+			(void)allocstring(&sim_window_signames[i], line, sim_tool->cluster);
 		}
 	} else if ((spice_state & SPICETYPE) == SPICEHSPICE)
 	{
@@ -588,8 +589,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 
 		/* get the type of each signal */
 		important = numnoi;
-		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_aid->cluster);
-		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_aid->cluster);
+		sim_window_signames = (char **)emalloc(sim_window_signals * (sizeof (char *)), sim_tool->cluster);
+		sim_window_sigtypes = (INTSML *)emalloc(sim_window_signals * SIZEOFINTSML, sim_tool->cluster);
 		if (sim_window_signames == 0 || sim_window_sigtypes == 0)
 		{
 			/* terminate execution so we can restart simulator */
@@ -628,7 +629,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 			}
 			if (k == 0) continue;
 			if (k < nodcnt) l = k + numnoi - 1; else l = k - nodcnt;
-			(void)allocstring(&sim_window_signames[l], line, sim_aid->cluster);
+			(void)allocstring(&sim_window_signames[l], line, sim_tool->cluster);
 		}
 
 		/* finish line, ensure the end-of-header */
@@ -869,7 +870,7 @@ INTSML sim_spice_plotvalues(INTSML important)
 		oldsigcount = getlength(var);
 		if (oldsigcount > 0)
 		{
-			sa = newstringarray(sim_aid->cluster);
+			sa = newstringarray(sim_tool->cluster);
 			for(i=0; i<oldsigcount; i++)
 				addtostringarray(sa, ((char **)var->addr)[i]);
 			oldsignames = getstringarray(sa, &oldsigcount);
@@ -919,9 +920,9 @@ INTSML sim_window_ensurespace(INTSML count)
 		sim_window_limit = 0;
 	}
 	take = count + 10;
-	sim_window_time = (float *)emalloc(take * (sizeof (float)), sim_aid->cluster);
+	sim_window_time = (float *)emalloc(take * (sizeof (float)), sim_tool->cluster);
 	if (sim_window_time == 0) return(1);
-	sim_window_val = (float *)emalloc(take * (sizeof (float)), sim_aid->cluster);
+	sim_window_val = (float *)emalloc(take * (sizeof (float)), sim_tool->cluster);
 	if (sim_window_val == 0) return(1);
 	sim_window_limit = take;
 	return(0);
@@ -1130,7 +1131,7 @@ void sim_window_addhighlightednet(INTSML overlay)
 		return;
 	}
 
-	ai = (ARCINST *)askaid(us_aid, "get-arc");
+	ai = (ARCINST *)asktool(us_tool, "get-arc");
 	if (ai == NOARCINST)
 	{
 		ttyputerr(_("Select an arc first"));
@@ -1353,4 +1354,4 @@ INTBIG sim_window_findsignalname(char *name)
 	return(-1);
 }
 
-#endif  /* SIMAID - at top */
+#endif  /* SIMTOOL - at top */
