@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: simtexsim.c
- * Simulation aid: TEXSIM output generator
+ * Simulation tool: TEXSIM output generator
  * Written by: T.J.Goodman, University of Canterbury, N.Z.
  *
  * Copyright (c) 2000 Static Free Software.
@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SIMAID
+#if SIMTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -47,32 +47,30 @@
 
 #define RESFILE "reservedwords.dat"			/* optional used to check for reserved words */
 
-FILE *sim_texfile, *reservefile;
+static FILE *sim_texfile, *reservefile;
 
 /* prototypes for local routines */
-void sim_writetexcell(NODEPROTO*, INTBIG);
-char *sim_textdlpower(NODEINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
-INTSML sim_texcountwires(NODEINST*);
-char *sim_texsrcname(NODEINST*, PORTARCINST*);
-char *sim_texwritesignals(NODEINST*, INTBIG, INTBIG*);
-char *sim_texwriteffsignals(NODEINST*, INTBIG*);
-char *sim_textracesignal(PORTARCINST*, NODEINST*);
-void sim_texwriteinv(PORTARCINST*, char*, char*);
-char *sim_textdlinst(NODEINST*, INTBIG);
-void sim_texerror(INTBIG, INTBIG*, char*);
-void sim_texstrprint(char*);
-char *sim_texname(char*);
-char *sim_texproto(NODEINST*, INTBIG, INTBIG*);
-char *sim_texffname(NODEINST*, INTBIG*);
-char *sim_texgetdelay(NODEINST*, INTBIG);
-INTSML sim_texnegatedoutput(NODEINST*);
-char *sim_texlibname(NODEPROTO*);
-PORTARCINST *sim_oppendpai(PORTARCINST*);
-NODEINST *sim_oppendni(PORTARCINST*);
-INTSML sim_texcheckname(char*);
-void sim_texcompile(NODEPROTO*, INTBIG*);
-void sim_texfindmodule(char*, char*, INTBIG*);
-INTBIG sim_strcspn(char *str, char *set);
+static void         sim_writetexcell(NODEPROTO*, INTBIG);
+static char        *sim_textdlpower(NODEINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
+static INTSML       sim_texcountwires(NODEINST*);
+static char        *sim_texsrcname(NODEINST*, PORTARCINST*);
+static char        *sim_texwritesignals(NODEINST*, INTBIG, INTBIG*);
+static char        *sim_texwriteffsignals(NODEINST*, INTBIG*);
+static char        *sim_textracesignal(PORTARCINST*, NODEINST*);
+static void         sim_texwriteinv(PORTARCINST*, char*, char*);
+static char        *sim_textdlinst(NODEINST*, INTBIG);
+static void         sim_texerror(INTBIG, INTBIG*, char*);
+static void         sim_texstrprint(char*);
+static char        *sim_texname(char*);
+static char        *sim_texproto(NODEINST*, INTBIG, INTBIG*);
+static char        *sim_texffname(NODEINST*, INTBIG*);
+static char        *sim_texgetdelay(NODEINST*, INTBIG);
+static INTSML       sim_texnegatedoutput(NODEINST*);
+static char        *sim_texlibname(NODEPROTO*);
+static PORTARCINST *sim_oppendpai(PORTARCINST*);
+static NODEINST    *sim_oppendni(PORTARCINST*);
+static INTSML       sim_texcheckname(char*);
+static INTBIG       sim_strcspn(char *str, char *set);
 
 void sim_writetexnetlist(NODEPROTO *np)
 {
@@ -155,18 +153,21 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 		if (ni->proto->primindex != 0) continue;
 		if (ni->proto->temp1 != 0) continue;
 
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
+
 		sim_writetexcell(ni->proto, 0);
 	}
 
 	/* mark this node written */
 	np->temp1++;
 
-	/********************* MODULE ***************************************/
+	/* MODULE */
 	sim_texstrprint("MODULE:  ");
 	sim_texstrprint(sim_texname(describenodeproto(np)));
 	sim_texstrprint(";\n\n");
 
-	/**************************** INPUTS ***********************************/
+	/* INPUTS */
 	if (np->firstportproto != NOPORTPROTO)
 	{
 		(void)initinfstr();
@@ -189,7 +190,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 		addstringtoinfstr(";\n\n");
 		sim_texstrprint(returninfstr());
 
-		/*********************** OUTPUTS ****************************************/
+		/* OUTPUTS */
 		(void)initinfstr();
 		addstringtoinfstr("OUTPUTS:\n");
 
@@ -208,7 +209,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 		sim_texstrprint(returninfstr());
 	}
 
-	/******************* USE ******************************************/
+	/* USE */
 	(void)initinfstr();
 	(void)addstringtoinfstr("USE:\n\n");  /* write USE: */
 
@@ -216,7 +217,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	{
 		if (ni->temp1 != 0) continue;
 		ni->temp1++;	     /* mark node seen */
-		f = nodefunction(ni, 0);
+		f = nodefunction(ni);
 
 		switch(f)
 		{
@@ -303,6 +304,8 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			/*  This case can either be for an existing  user defined module in this */
 			/*  directory or for a module from the MASTER directory */
 			case NPUNKNOWN:
+				/* ignore recursive references (showing icon in contents) */
+				if (ni->proto->cell == np->cell) continue;
 				(void)addstringtoinfstr("  ");
 				(void)addstringtoinfstr(sim_texproto(ni, f, &module_err));
 				(void)addstringtoinfstr(" = ");
@@ -335,7 +338,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	sim_texstrprint(ptr);
 	sim_texstrprint("\n");
 
-	/*************************  DEFINE  ***********************************/
+	/* DEFINE */
 	sim_texstrprint("DEFINE:\n");
 
 	/* count no. of inverters (negated arcs not attached to logic primitives */
@@ -345,12 +348,12 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 		if ((ai->userbits&ISNEGATED) == 0) continue;
 		if ((ai->end[0].portarcinst->proto->userbits&STATEBITS) == OUTPORT)
 		{
-			f = nodefunction(ai->end[0].nodeinst, 0);
+			f = nodefunction(ai->end[0].nodeinst);
 			if (f == NPGATEAND || f == NPGATEOR || f == NPGATEXOR || f == NPBUFFER)
 				ai->temp1 = -1; else ai->temp1 = count++;
 		} else if ((ai->end[1].portarcinst->proto->userbits&STATEBITS) == OUTPORT)
 		{
-			f = nodefunction(ai->end[1].nodeinst, 0);
+			f = nodefunction(ai->end[1].nodeinst);
 			if (f == NPGATEAND || f == NPGATEOR || f == NPGATEXOR || f == NPBUFFER)
 				ai->temp1 = -1; else ai->temp1 = count++;
 		} else ai->temp1 = count++;
@@ -367,7 +370,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	for (ni = np->firstnodeinst, count=1; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		ni->temp1 = 0;
-		f = nodefunction(ni, 0);
+		f = nodefunction(ni);
 
 		/* handle nodeinst descriptions */
 		switch(f)
@@ -381,13 +384,16 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 				sim_texstrprint(sim_textdlpower(ni, f, &pwr, &gnd, &module_err));
 				break;
 
+			case NPUNKNOWN:
+				/* ignore recursive references (showing icon in contents) */
+				if (ni->proto->cell == np->cell) continue;
+				/* FALLTHROUGH */ 
 			case NPTRANS:
 			case NPGATEXOR:
 			case NPGATEAND:
 			case NPGATEOR:
 			case NPBUFFER:
 			case NPFLIPFLOP:
-			case NPUNKNOWN:
 				ni->temp2 = count++;
 				strcpy(str1, sim_textdlinst(ni, f));
 				strcat(str1, " = ");
@@ -1091,4 +1097,4 @@ INTBIG sim_strcspn(char *str, char *set)
 	return(pos);
 }
 
-#endif /* SIMAID - at top */
+#endif /* SIMTOOL - at top */
