@@ -49,23 +49,38 @@ COMCOMP art_parse = {artopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 
 
 TECHNOLOGY *art_tech;
-INTBIG      art_state;			/* state bits */
+static INTBIG      art_state;			/* state bits */
 INTBIG      art_messagekey;		/* key for "ART_message" */
 INTBIG      art_colorkey;		/* key for "ART_color" */
 INTBIG      art_degreeskey;		/* key for "ART_degrees" */
 INTBIG      art_patternkey;		/* key for "ART_pattern" */
-NODEPROTO  *art_pinprim, *art_openedpolygonprim, *art_boxprim, *art_crossedboxprim;
-NODEPROTO  *art_filledboxprim, *art_circleprim, *art_filledcircleprim, *art_splineprim;
-NODEPROTO  *art_triangleprim, *art_filledtriangleprim, *art_arrowprim;
-NODEPROTO  *art_openeddottedpolygonprim, *art_openeddashedpolygonprim;
-NODEPROTO  *art_openedthickerpolygonprim, *art_closedpolygonprim, *art_filledpolygonprim;
-ARCPROTO   *art_solidarc, *art_dash1arc, *art_dash2arc, *art_dash3arc;
+NODEPROTO  *art_pinprim;
+NODEPROTO  *art_openedpolygonprim;
+NODEPROTO  *art_boxprim;
+NODEPROTO  *art_crossedboxprim;
+NODEPROTO  *art_filledboxprim;
+NODEPROTO  *art_circleprim;
+NODEPROTO  *art_filledcircleprim;
+NODEPROTO  *art_splineprim;
+NODEPROTO  *art_triangleprim;
+NODEPROTO  *art_filledtriangleprim;
+NODEPROTO  *art_arrowprim;
+NODEPROTO  *art_openeddottedpolygonprim;
+NODEPROTO  *art_openeddashedpolygonprim;
+NODEPROTO  *art_openedthickerpolygonprim;
+NODEPROTO  *art_closedpolygonprim;
+NODEPROTO  *art_filledpolygonprim;
+ARCPROTO   *art_solidarc;
+ARCPROTO   *art_dottedarc;
+ARCPROTO   *art_dashedarc;
+ARCPROTO   *art_thickerarc;
 
 /* prototypes for local routines */
-void art_getgraphics(INTBIG, INTBIG);
-void art_fillellipse(INTBIG, INTBIG, INTBIG, INTBIG, double, double, POLYGON*);
-void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTSML steps);
-void art_setstate(INTBIG newstate);
+static void art_getgraphics(INTBIG, INTBIG);
+static void art_fillellipse(INTBIG, INTBIG, INTBIG, INTBIG, double, double, POLYGON*);
+static void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTSML steps);
+static void art_setstate(INTBIG newstate);
+static void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly);
 
 /******************** LAYERS ********************/
 
@@ -91,9 +106,9 @@ static INTBIG art_gds_layers[MAXLAYERS] = {1};
 
 #define ARCPROTOCOUNT  4
 #define ASOLID         0
-#define ADASH1         1
-#define ADASH2         2
-#define ADASH3         3
+#define ADOTTED        1
+#define ADASHED        2
+#define ATHICKER       3
 
 /* solid arc */
 static TECH_ARCLAY art_al_s[] = {{LOPAQUE, 0, FILLED}};
@@ -105,21 +120,21 @@ static TECH_ARCS art_a_s = {
 /* dotted arc */
 static TECH_ARCLAY art_al_d1[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d1 = {
-	"Dash-1",0,ADASH1,												/* name */
+	"Dotted",0,ADOTTED,												/* name */
 	1,art_al_d1,													/* layers */
 	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* dashed arc */
 static TECH_ARCLAY art_al_d2[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d2 = {
-	"Dash-2",0,ADASH2,												/* name */
+	"Dashed",0,ADASHED,												/* name */
 	1,art_al_d2,													/* layers */
 	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* thicker arc */
 static TECH_ARCLAY art_al_d3[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d3 = {
-	"Dash-3",0,ADASH3,												/* name */
+	"Thicker",0,ATHICKER,											/* name */
 	1,art_al_d3,													/* layers */
 	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
@@ -129,7 +144,7 @@ TECH_ARCS *art_arcprotos[ARCPROTOCOUNT+1] = {&art_a_s, &art_a_d1,
 /******************** PORTINST CONNECTIONS ********************/
 
 /* these values are replaced with actual arcproto addresses */
-static INTBIG art_pc_d[] = {-1, ASOLID, ADASH1, ADASH2, ADASH3, ALLGEN, -1};
+static INTBIG art_pc_d[] = {-1, ASOLID, ADOTTED, ADASHED, ATHICKER, ALLGEN, -1};
 
 /******************** NODES ********************/
 
@@ -408,11 +423,11 @@ TECH_VARIABLES art_variables[] =
 	{"TECH_layer_function", (char *)art_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_layer_letters", (char *)art_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the IO aid */
+	/* set information for the IO tool */
 	{"IO_dxf_layer_names", (char *)art_dxf_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{"IO_gds_layer_numbers", (char *)art_gds_layers, 0.0,
@@ -451,9 +466,9 @@ INTSML art_initprocess(TECHNOLOGY *tech, INTSML pass)
 		art_filledpolygonprim = getnodeproto("artwork:Filled-Polygon");
 
 		art_solidarc = getarcproto("Artwork:Solid");
-		art_dash1arc = getarcproto("Artwork:Dash-1");
-		art_dash2arc = getarcproto("Artwork:Dash-2");
-		art_dash3arc = getarcproto("Artwork:Dash-3");
+		art_dottedarc = getarcproto("Artwork:Dotted");
+		art_dashedarc = getarcproto("Artwork:Dashed");
+		art_thickerarc = getarcproto("Artwork:Thicker");
 
 		art_messagekey = makekey("ART_message");
 		art_colorkey = makekey("ART_color");
@@ -558,79 +573,13 @@ INTBIG art_nodeEpolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 
 void art_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML sty;
-	REGISTER INTBIG pindex, dist, cx, cy, sx, sy, count;
-	REGISTER VARIABLE *var;
-	double startoffset, endangle;
-	INTBIG dummypoints[8];
-
 	/* handle displayable variables */
 	if (box >= tech_realpolys)
 	{
 		(void)tech_filldisplayablenvar(ni, poly, tech_curwindowpart, 0);
 	} else
 	{
-		pindex = ni->proto->primindex;
-		if (pindex == NCIRCLE)
-		{
-			/* handle ellipses */
-			getarcdegrees(ni, &startoffset, &endangle);
-			if (ni->highx - ni->lowx != ni->highy - ni->lowy)
-			{
-				art_fillellipse(ni->lowx, ni->lowy, ni->highx, ni->highy, startoffset, endangle, poly);
-				poly->layer = art_nodeprotos[pindex-1]->layerlist[box].layernum;
-			} else
-			{
-				tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
-					lambdaofnode(ni), FILLED);
-
-				/* if there is arc information here, make it an arc of a circle */
-				if (startoffset != 0.0 || endangle != 0.0)
-				{
-					/* fill an arc of a circle here */
-					if (poly->limit < 3) (void)extendpolygon(poly, 3);
-					dist = poly->xv[1] - poly->xv[0];
-					poly->xv[2] = poly->xv[0] + rounddouble(cos(startoffset) * (double)dist);
-					poly->yv[2] = poly->yv[0] + rounddouble(sin(startoffset) * (double)dist);
-					poly->xv[1] = poly->xv[0] + rounddouble(cos(startoffset+endangle) * (double)dist);
-					poly->yv[1] = poly->yv[0] + rounddouble(sin(startoffset+endangle) * (double)dist);
-					poly->count = 3;
-					poly->style = CIRCLEARC;
-				}
-			}
-		} else if (pindex == NSPLINE)
-		{
-			poly->layer = art_nodeprotos[pindex-1]->layerlist[box].layernum;
-			cx = (ni->highx + ni->lowx) / 2;   cy = (ni->highy + ni->lowy) / 2;
-			var = gettrace(ni);
-			if (var != NOVARIABLE)
-			{
-				count = getlength(var) / 2;
-				art_fillspline((INTBIG *)var->addr, count, cx, cy, poly, SPLINEGRAIN);
-			} else
-			{
-				sx = ni->highx - ni->lowx;   sy = ni->highy - ni->lowy;
-				dummypoints[0] = -sx / 2;   dummypoints[1] =  sy / 2;
-				dummypoints[2] = -sx / 6;   dummypoints[3] = -sy / 2;
-				dummypoints[4] =  sx / 6;   dummypoints[5] =  sy / 2;
-				dummypoints[6] =  sx / 2;   dummypoints[7] = -sy / 2;
-				art_fillspline(dummypoints, 4, cx, cy, poly, SPLINEGRAIN);
-			}
-		} else
-		{
-			switch (pindex)
-			{
-				case NOPENED:   sty = OPENED;    break;
-				case NOPENEDT1: sty = OPENEDT1;  break;
-				case NOPENEDT2: sty = OPENEDT2;  break;
-				case NOPENEDT3: sty = OPENEDT3;  break;
-				case NCLOSED:   sty = CLOSED;    break;
-				default:        sty = FILLED;    break;
-			}
-
-			tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
-				lambdaofnode(ni), sty);
-		}
+		art_fillnodebox(ni, box, poly);
 	}
 
 	/* use stipple pattern if specified */
@@ -656,8 +605,7 @@ void art_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	}
 
 	/* just use first graphic polygon as the port */
-	(void)art_nodepolys(ni, 0, NOWINDOWPART);
-	art_shapenodepoly(ni, 0, poly);
+	art_fillnodebox(ni, 0, poly);
 	xformpoly(poly, trans);
 }
 
@@ -705,9 +653,9 @@ void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 		poly->desc = &art_o_lay;
 		if (realwid == 0 && poly->style != CIRCLEARC) switch (ai->proto->arcindex)
 		{
-			case ADASH1: poly->style = OPENEDT1;   break;
-			case ADASH2: poly->style = OPENEDT2;   break;
-			case ADASH3: poly->style = OPENEDT3;   break;
+			case ADOTTED:  poly->style = OPENEDT1;   break;
+			case ADASHED:  poly->style = OPENEDT2;   break;
+			case ATHICKER: poly->style = OPENEDT3;   break;
 		}
 	} else poly->desc = &art_st_lay;
 
@@ -715,6 +663,80 @@ void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 	poly->desc->bits = (INTSML)art_bits;
 }
 
+/*
+ * Helper routine to fill in polygon "box" of node "ni" into polygon "poly".
+ */
+void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
+{
+	REGISTER INTSML sty;
+	REGISTER INTBIG pindex, dist, cx, cy, sx, sy, count;
+	REGISTER VARIABLE *var;
+	double startoffset, endangle;
+	INTBIG dummypoints[8];
+
+	pindex = ni->proto->primindex;
+	if (pindex == NCIRCLE)
+	{
+		/* handle ellipses */
+		getarcdegrees(ni, &startoffset, &endangle);
+		if (ni->highx - ni->lowx != ni->highy - ni->lowy)
+		{
+			art_fillellipse(ni->lowx, ni->lowy, ni->highx, ni->highy, startoffset, endangle, poly);
+			poly->layer = art_nodeprotos[pindex-1]->layerlist[box].layernum;
+		} else
+		{
+			tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
+				lambdaofnode(ni), FILLED);
+
+			/* if there is arc information here, make it an arc of a circle */
+			if (startoffset != 0.0 || endangle != 0.0)
+			{
+				/* fill an arc of a circle here */
+				if (poly->limit < 3) (void)extendpolygon(poly, 3);
+				dist = poly->xv[1] - poly->xv[0];
+				poly->xv[2] = poly->xv[0] + rounddouble(cos(startoffset) * (double)dist);
+				poly->yv[2] = poly->yv[0] + rounddouble(sin(startoffset) * (double)dist);
+				poly->xv[1] = poly->xv[0] + rounddouble(cos(startoffset+endangle) * (double)dist);
+				poly->yv[1] = poly->yv[0] + rounddouble(sin(startoffset+endangle) * (double)dist);
+				poly->count = 3;
+				poly->style = CIRCLEARC;
+			}
+		}
+	} else if (pindex == NSPLINE)
+	{
+		poly->layer = art_nodeprotos[pindex-1]->layerlist[box].layernum;
+		cx = (ni->highx + ni->lowx) / 2;   cy = (ni->highy + ni->lowy) / 2;
+		var = gettrace(ni);
+		if (var != NOVARIABLE)
+		{
+			count = getlength(var) / 2;
+			art_fillspline((INTBIG *)var->addr, count, cx, cy, poly, SPLINEGRAIN);
+		} else
+		{
+			sx = ni->highx - ni->lowx;   sy = ni->highy - ni->lowy;
+			dummypoints[0] = -sx / 2;   dummypoints[1] =  sy / 2;
+			dummypoints[2] = -sx / 6;   dummypoints[3] = -sy / 2;
+			dummypoints[4] =  sx / 6;   dummypoints[5] =  sy / 2;
+			dummypoints[6] =  sx / 2;   dummypoints[7] = -sy / 2;
+			art_fillspline(dummypoints, 4, cx, cy, poly, SPLINEGRAIN);
+		}
+	} else
+	{
+		switch (pindex)
+		{
+			case NOPENED:   sty = OPENED;    break;
+			case NOPENEDT1: sty = OPENEDT1;  break;
+			case NOPENEDT2: sty = OPENEDT2;  break;
+			case NOPENEDT3: sty = OPENEDT3;  break;
+			case NCLOSED:   sty = CLOSED;    break;
+			default:        sty = FILLED;    break;
+		}
+
+		tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
+			lambdaofnode(ni), sty);
+	}
+}
+
 void art_getgraphics(INTBIG addr, INTBIG type)
 {
 	REGISTER INTSML i, sty;
