@@ -58,10 +58,10 @@ typedef struct
 	void  **paramvalue;
 } LISPTREE;
 
-LISPTREE *fpga_treestack[MAXDEPTH];
-INTSML    fpga_treedepth;
-LISPTREE *fpga_treepos;
-LISPTREE *fpga_freelisptree = 0;
+static LISPTREE *fpga_treestack[MAXDEPTH];
+static INTSML    fpga_treedepth;
+static LISPTREE *fpga_treepos;
+static LISPTREE *fpga_freelisptree = 0;
 
 /******************** ADDITIONAL INFORMATION ABOUT PRIMITIVES ********************/
 
@@ -102,8 +102,8 @@ typedef struct
 	FPGAPIP    **piplist;
 } FPGANODE;
 
-INTSML     fpga_nodecount;
-FPGANODE **fpga_nodes;
+static INTSML     fpga_nodecount;
+static FPGANODE **fpga_nodes;
 
 /******************** STANDARD TECHNOLOGY STRUCTURES ********************/
 
@@ -116,7 +116,7 @@ static KEYWORD fpgadltopt[] =
 	{"off",           0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
-COMCOMP fpgatdispp = {fpgadltopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
+static COMCOMP fpgatdispp = {fpgadltopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("FPGA text display option"), ""};
 static KEYWORD fpgadlopt[] =
 {
@@ -126,7 +126,7 @@ static KEYWORD fpgadlopt[] =
 	{"empty",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
-COMCOMP fpgadispp = {fpgadlopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
+static COMCOMP fpgadispp = {fpgadlopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("FPGA display level"), ""};
 static KEYWORD fpgaopt[] =
 {
@@ -147,22 +147,22 @@ COMCOMP fpga_parse = {fpgaopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 #define ACTIVEPRIMDISPLAY  02		/*   display only active internals */
 #define TEXTDISPLAY       010		/* set to display text */
 
-TECHNOLOGY    *fpga_tech;
-INTSML         fpga_internaldisplay;
-INTSML         fpga_curpip;
-INTSML         fpga_curnet, fpga_cursegment;
-INTBIG         fpga_lineno;
-INTBIG         fpga_filesize;
-INTBIG         fpga_activepipskey;		/* cached key for "FPGA_activepips" */
-INTBIG         fpga_activerepeaterskey;	/* cached key for "FPGA_activerepeaters" */
-INTBIG         fpga_nodepipcachekey;	/* cached key for "FPGA_nodepipcache" */
-INTBIG         fpga_arcactivecachekey;	/* cached key for "FPGA_arcactivecache" */
-FPGANODE      *fpga_fn;					/* current pointer for pip examining */
-char          *fpga_repeatername;		/* name of current repeater for activity examining */
-INTSML         fpga_repeaterisactive;	/* nonzero if current repeater is found to be active */
-NODEPROTO     *fpga_wirepinprim;		/* wire pin */
-NODEPROTO     *fpga_pipprim;			/* pip */
-NODEPROTO     *fpga_repeaterprim;		/* repeater */
+static TECHNOLOGY    *fpga_tech;
+static INTSML         fpga_internaldisplay;
+static INTSML         fpga_curpip;
+static INTSML         fpga_curnet, fpga_cursegment;
+static INTBIG         fpga_lineno;
+static INTBIG         fpga_filesize;
+static INTBIG         fpga_activepipskey;		/* cached key for "FPGA_activepips" */
+static INTBIG         fpga_activerepeaterskey;	/* cached key for "FPGA_activerepeaters" */
+static INTBIG         fpga_nodepipcachekey;		/* cached key for "FPGA_nodepipcache" */
+static INTBIG         fpga_arcactivecachekey;	/* cached key for "FPGA_arcactivecache" */
+static FPGANODE      *fpga_fn;					/* current pointer for pip examining */
+static char          *fpga_repeatername;		/* name of current repeater for activity examining */
+static INTSML         fpga_repeaterisactive;	/* nonzero if current repeater is found to be active */
+static NODEPROTO     *fpga_wirepinprim;			/* wire pin */
+static NODEPROTO     *fpga_pipprim;				/* pip */
+static NODEPROTO     *fpga_repeaterprim;		/* repeater */
 
 /* working memory for "fpga_arcactive()" */
 static INTSML fpga_arcbufsize = 0;
@@ -172,32 +172,33 @@ static unsigned char *fpga_arcbuf;
 static INTSML fpga_pipbufsize = 0;
 static unsigned char *fpga_pipbuf;
 
-INTSML     fpga_addparameter(LISPTREE *tree, INTSML type, void *value);
-LISPTREE  *fpga_alloclisptree(void);
-INTSML     fpga_arcactive(ARCINST *ai);
-INTSML     fpga_arcendactive(ARCINST *ai, INTSML j);
-void       fpga_clearcache(NODEINST *ni);
-void       fpga_describenetseg(NODEINST *ni, FPGANET *fnet, INTSML whichseg, POLYGON *poly);
-void       fpga_describepip(NODEINST *ni, FPGANODE *fn, INTSML pipindex, POLYGON *poly);
-void       fpga_findvariableobjects(NODEINST *ni, INTBIG varkey, void (*setit)(char*));
-void       fpga_killptree(LISPTREE *lt);
-INTSML     fpga_makeblockinstance(NODEPROTO *np, LISPTREE *lt);
-INTSML     fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt);
-INTSML     fpga_makeblockport(NODEPROTO *np, LISPTREE *lt);
-INTSML     fpga_makeblockrepeater(NODEPROTO *np, LISPTREE *lt);
-NODEPROTO *fpga_makefacet(LISPTREE *lt);
-INTSML     fpga_makeprimitive(LISPTREE *lt);
-INTSML     fpga_makeprimitives(LISPTREE *lt);
-INTSML     fpga_makeprimnet(NODEPROTO *np, LISPTREE *lt, FPGANODE *fn, FPGANET *fnet);
-INTSML     fpga_makeprimpip(NODEPROTO *np, LISPTREE *lt, FPGANODE *fn, FPGAPIP *fpip);
-INTSML     fpga_makeprimport(NODEPROTO *np, LISPTREE *lt, FPGAPORT *fp);
-NODEPROTO *fpga_placeprimitives(LISPTREE *lt);
-INTSML     fpga_pushkeyword(char *pt);
-LISPTREE  *fpga_readfile(FILE *f);
-void       fpga_reevaluatepips(NODEINST *ni, FPGANODE *fn);
-INTSML     fpga_repeateractive(NODEINST *ni);
-void       fpga_setpips(char *name);
-void       fpga_setrepeater(char *name);
+/* prototypes for local routines */
+static INTSML     fpga_addparameter(LISPTREE *tree, INTSML type, void *value);
+static LISPTREE  *fpga_alloclisptree(void);
+static INTSML     fpga_arcactive(ARCINST *ai);
+static INTSML     fpga_arcendactive(ARCINST *ai, INTSML j);
+static void       fpga_clearcache(NODEINST *ni);
+static void       fpga_describenetseg(NODEINST *ni, FPGANET *fnet, INTSML whichseg, POLYGON *poly);
+static void       fpga_describepip(NODEINST *ni, FPGANODE *fn, INTSML pipindex, POLYGON *poly);
+static void       fpga_findvariableobjects(NODEINST *ni, INTBIG varkey, void (*setit)(char*));
+static void       fpga_killptree(LISPTREE *lt);
+static INTSML     fpga_makeblockinstance(NODEPROTO *np, LISPTREE *lt);
+static INTSML     fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt);
+static INTSML     fpga_makeblockport(NODEPROTO *np, LISPTREE *lt);
+static INTSML     fpga_makeblockrepeater(NODEPROTO *np, LISPTREE *lt);
+static NODEPROTO *fpga_makefacet(LISPTREE *lt);
+static INTSML     fpga_makeprimitive(LISPTREE *lt);
+static INTSML     fpga_makeprimitives(LISPTREE *lt);
+static INTSML     fpga_makeprimnet(NODEPROTO *np, LISPTREE *lt, FPGANODE *fn, FPGANET *fnet);
+static INTSML     fpga_makeprimpip(NODEPROTO *np, LISPTREE *lt, FPGANODE *fn, FPGAPIP *fpip);
+static INTSML     fpga_makeprimport(NODEPROTO *np, LISPTREE *lt, FPGAPORT *fp);
+static NODEPROTO *fpga_placeprimitives(LISPTREE *lt);
+static INTSML     fpga_pushkeyword(char *pt);
+static LISPTREE  *fpga_readfile(FILE *f);
+static void       fpga_reevaluatepips(NODEINST *ni, FPGANODE *fn);
+static INTSML     fpga_repeateractive(NODEINST *ni);
+static void       fpga_setpips(char *name);
+static void       fpga_setrepeater(char *name);
 
 /******************** LAYERS ********************/
 
@@ -241,7 +242,7 @@ TECH_ARCS *fpga_arcprotos[ARCPROTOCOUNT+1] = {&fpga_a_w, ((TECH_ARCS *)-1)};
 /******************** PORTINST CONNECTIONS ********************/
 
 /* these values are replaced with actual arcproto addresses */
-INTBIG fpga_pc_wire[]	= {-1, AWIRE, ALLGEN, -1};
+static INTBIG fpga_pc_wire[]	= {-1, AWIRE, ALLGEN, -1};
 
 /******************** NODES ********************/
 
@@ -264,7 +265,7 @@ static TECH_PORTS fpga_wirepin_p[] = {				/* ports */
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON fpga_wirepin_l[] = {			/* layers */
 	{LWIRE, 0, 2, DISC, POINTS, fpga_g_pindisc}};
-TECH_NODES fpga_wirepin = {
+static TECH_NODES fpga_wirepin = {
 	"Wire_Pin",NWIREPIN,NONODEPROTO,				/* name */
 	K1,K1,											/* size */
 	1,fpga_wirepin_p,								/* ports */
@@ -278,7 +279,7 @@ static TECH_PORTS fpga_pip_p[] = {					/* ports */
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON fpga_pip_l[] = {				/* layers */
 	{LPIP, 0, 4, FILLEDRECT, BOX, fpga_g_fullbox}};
-TECH_NODES fpga_pip = {
+static TECH_NODES fpga_pip = {
 	"Pip",NPIP,NONODEPROTO,							/* name */
 	K2,K2,											/* size */
 	1,fpga_pip_p,									/* ports */
@@ -294,7 +295,7 @@ static TECH_PORTS fpga_repeater_p[] = {				/* ports */
 		RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON fpga_repeater_l[] = {			/* layers */
 	{LREPEATER, 0, 4, FILLEDRECT, BOX, fpga_g_fullbox}};
-TECH_NODES fpga_repeater = {
+static TECH_NODES fpga_repeater = {
 	"Repeater",NREPEATER,NONODEPROTO,				/* name */
 	K10,K3,											/* size */
 	2,fpga_repeater_p,								/* ports */
@@ -323,7 +324,7 @@ TECH_VARIABLES fpga_variables[] =
 	{"TECH_node_width_offset", (char *)fpga_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
-	/* set information for the USER analysis aid */
+	/* set information for the USER analysis tool */
 	{"USER_layer_letters", (char *)fpga_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
@@ -351,6 +352,7 @@ INTSML fpga_initprocess(TECHNOLOGY *tech, INTSML pass)
 
 void fpga_termprocess(void)
 {
+#ifdef DEBUGMEMORY
 	LISPTREE *lt;
 	REGISTER INTBIG i, j, k;
 	REGISTER FPGANET *fnet;
@@ -420,6 +422,7 @@ void fpga_termprocess(void)
 		efree((char *)fn);
 	}
 	if (fpga_nodecount > 0) efree((char *)fpga_nodes);
+#endif
 }
 
 void fpga_setmode(INTSML count, char *par[])
@@ -432,7 +435,6 @@ void fpga_setmode(INTSML count, char *par[])
 	REGISTER INTSML l, total;
 	REGISTER LISPTREE *lt;
 	extern DIALOG us_progressdialog;
-	extern AIDENTRY *dr_aid;
 	static INTBIG filetypefpga = -1;
 
 	if (count == 0)
@@ -580,7 +582,7 @@ void fpga_setmode(INTSML count, char *par[])
 				(*el_curconstraint->solve)(NONODEPROTO);
 
 				/* recompute networks */
-				(void)askaid(net_aid, "total-re-number", (INTBIG)el_curlib);
+				(void)asktool(net_tool, "total-re-number");
 
 				/* display top facet */
 				subpar[0] = describenodeproto(topfacet);
@@ -736,6 +738,7 @@ void fpga_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 		/* first box is always the outline */
 		if (poly->limit < 2) (void)extendpolygon(poly, 2);
 		subrange(ni->lowx, ni->highx, -H0, 0, H0, 0, &poly->xv[0], &poly->xv[1], lambda);
+		subrange(ni->lowy, ni->highy, -H0, 0, H0, 0, &poly->yv[0], &poly->yv[1], lambda);
 		poly->count = 2;
 		poly->style = CLOSEDRECT;
 		poly->layer = LCOMP;
@@ -754,7 +757,8 @@ void fpga_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 				poly->count = 4;
 				poly->style = TEXTBOX;
 				poly->string = ni->proto->primname;
-				poly->font = TXT4L;
+				TDCLEAR(poly->textdescript);
+				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 				poly->tech = fpga_tech;
 				poly->layer = LCOMP;
 				break;
@@ -2018,7 +2022,7 @@ INTSML fpga_makeprimport(NODEPROTO *np, LISPTREE *lt, FPGAPORT *fp)
 	if (newpp == NOPORTPROTO) return(1);
 	newpp->parent = np;
 	if (allocstring(&newpp->protoname, (char *)ltname->paramvalue[0], fpga_tech->cluster) != 0) return(1);
-	newpp->textdescript = 0;
+	TDCLEAR(newpp->textdescript);
 	newpp->userbits = (180 << PORTARANGESH);
 	newpp->connects = fpga_wirepinprim->firstportproto->connects;
 
@@ -2624,8 +2628,9 @@ INTSML fpga_makeblockinstance(NODEPROTO *facet, LISPTREE *lt)
 		if (var != NOVARIABLE)
 		{
 			yoff = (ni->highy-ni->lowy) / lambda;
-			var->textdescript = (var->textdescript & ~(VTYOFF|VTSIZE|VTPOSITION)) |
-				(yoff << VTYOFFSH) | (defaulttextsize(3) << VTSIZESH) | VTPOSBOXED;
+			defaulttextsize(3, var->textdescript);
+			TDSETPOS(var->textdescript, VTPOSBOXED);
+			TDSETOFF(var->textdescript, TDGETXOFF(var->textdescript), yoff);
 		}
 	}
 	return(0);
@@ -2797,8 +2802,7 @@ INTSML fpga_makeblockrepeater(NODEPROTO *facet, LISPTREE *lt)
 		}
 		var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)ltname->paramvalue[0], VSTRING);
 		if (var != NOVARIABLE)
-			var->textdescript = (var->textdescript & ~VTSIZE) |
-				(defaulttextsize(3) << VTSIZESH);
+			defaulttextsize(3, var->textdescript);
 	}
 	return(0);
 }
