@@ -38,10 +38,10 @@
 #include "efunction.h"
 
 /* prototypes for local routines */
-void gem_addtailplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
-void gem_addheadplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
-void gem_add1linebody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
-void gem_addzigzagbody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void gem_addtailplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
+static void gem_addheadplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
+static void gem_add1linebody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
+static void gem_addzigzagbody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
 static TECHNOLOGY *gem_tech;
 
@@ -313,7 +313,7 @@ TECH_VARIABLES gem_variables[] =
 	{"TECH_layer_function", (char *)gem_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_layer_letters", (char *)gem_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
@@ -350,14 +350,16 @@ void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 	if (box == 0) return;
 
 	/* get element message */
-	poly->font = TXT1L;
+	TDCLEAR(poly->textdescript);
+	TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(4));
 	poly->tech = gem_tech;
 	switch (box)
 	{
 		case 1:
 			if (element == 0) element = makekey("GEM_element");
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, element);
-			poly->font = TXT4L;
+			TDCLEAR(poly->textdescript);
+			TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 			break;
 		case 2:
 			if (event1 == 0) event1 = makekey("GEM_event1");
