@@ -42,7 +42,7 @@ ARCPROTO   *gen_universalarc, *gen_invisiblearc, *gen_unroutedarc;
 ARCPROTO  **gen_upconn = 0;
 
 /* prototypes for local routines */
-void gen_makeunivlist(void);
+static void gen_makeunivlist(void);
 
 /******************** LAYERS ********************/
 
@@ -234,11 +234,11 @@ TECH_VARIABLES gen_variables[] =
 	{"TECH_node_width_offset", (char *)gen_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
-	/* set information for the I/O aid */
+	/* set information for the I/O tool */
 	{"IO_cif_layer_names", (char *)gen_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_layer_letters", (char *)gen_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
