@@ -39,7 +39,7 @@
 #include "efunction.h"
 
 /* prototypes for local routines */
-void mocmosold_setpseudo(void);
+static void mocmosold_setpseudo(void);
 
 /*
  * this technology has six important layers to draw:
@@ -568,11 +568,12 @@ static INTBIG mocmosold_arc_widoff[ARCPROTOCOUNT] = {0,0,0,K8,K8,0};
 /*
  * tables for converting between stipples and outlines
  */
-struct
+typedef struct
 {
 	TECH_ARCLAY *str;
 	INTSML        layer;
-} mocmosold_arcstipple[] =
+} STIPARC;
+static STIPARC mocmosold_arcstipple[] =
 {
 	{mocmosold_al_pa, 2},		/* select-p */
 	{mocmosold_al_na, 2},		/* select-n */
@@ -1138,11 +1139,13 @@ static INTBIG mocmosold_node_widoff[NODEPROTOCOUNT*4] = {
 /*
  * tables for converting between stipples and outlines
  */
-struct
+typedef struct
 {
 	TECH_POLYGON *str;
 	INTSML         layer;
-} mocmosold_nodepstipple[] =
+} STIPPCONV;
+
+static STIPPCONV mocmosold_nodepstipple[] =
 {
 	{mocmosold_mpa_l, 3},	/* select-p */
 	{mocmosold_mna_l, 3},	/* select-n */
@@ -1161,11 +1164,14 @@ struct
 	{mocmosold_m2_l, 0}		/* metal-2 */
 };
 static INTSML mocmosold_nodepstipplesize = 7;
-struct
+
+typedef struct
 {
 	TECH_SERPENT *str;
 	INTSML         layer;
-} mocmosold_nodesstipple[] =
+} STIPSCONV;
+
+static STIPSCONV mocmosold_nodesstipple[] =
 {
 	{mocmosold_tpa_l, 3},	/* select-p */
 	{mocmosold_tna_l, 3},	/* select-n */
@@ -1179,17 +1185,17 @@ static INTSML mocmosold_nodesstipplesize = 2;
 /* for SPICE simulation */
 #define mocmosold_MIN_RESIST	50.0f	/* minimum resistance consider */
 #define mocmosold_MIN_CAPAC	0.04f	/* minimum capacitance consider */
-float mocmosold_sim_spice_resistance[MAXLAYERS] = {  /* per square micron */
+static float mocmosold_sim_spice_resistance[MAXLAYERS] = {  /* per square micron */
 	0.03f /* METAL1 */,    0.03f /* METAL2 */,    50.0f /* POLY */,
 	10.0f /* SACT */,      10.0f /* DACT */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
 	0.0, 0.0, 0.0, 0.0};
-float mocmosold_sim_spice_capacitance[MAXLAYERS] = { /* per square micron */
+static float mocmosold_sim_spice_capacitance[MAXLAYERS] = { /* per square micron */
 	0.03f /* METAL1 */,    0.03f /* METAL2 */,    0.04f /* POLY */,
 	0.1f /* SACT */,       0.1f /* DACT */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
 	0.0, 0.0, 0.0, 0.0};
-char *mocmosold_sim_spice_header_level1[] = {
+static char *mocmosold_sim_spice_header_level1[] = {
 	"*CMOS/BULK-NWELL (PRELIMINARY PARAMETERS)",
 	".OPTIONS NOMOD DEFL=3UM DEFW=3UM DEFAD=70P DEFAS=70P LIMPTS=1000",
 	"+ITL4=1000 ITL5=0 RELTOL=0.01 ABSTOL=500PA VNTOL=500UV LVLTIM=2",
@@ -1202,7 +1208,7 @@ char *mocmosold_sim_spice_header_level1[] = {
 	"+LD=0.6E-6 TOX=40E-9 CGSO=3.0E-10 CGDO=3.0E-10 CJ=.2MF/M^2",
 	".MODEL DIFFCAP D CJO=.2MF/M^2",
 	NOSTRING};
-char *mocmosold_sim_spice_header_level2[] = {
+static char *mocmosold_sim_spice_header_level2[] = {
 	"* MOSIS 3u CMOS PARAMS",
 	".OPTIONS NOMOD DEFL=2UM DEFW=6UM DEFAD=100P DEFAS=100P",
 	"+LIMPTS=1000 ITL4=1000 ITL5=0 ABSTOL=500PA VNTOL=500UV",
@@ -1237,7 +1243,7 @@ char *mocmosold_sim_spice_header_level2[] = {
  * single line:
  *     .CIF 20 CX
  */
-char *mocmosold_drc_ecad_deck[] = {
+static char *mocmosold_drc_ecad_deck[] = {
 	"; MOSIS REV 6 'EITHER' CMOS DESIGN RULE FILE",
 	"; THIS COMMAND FILE CONSISTS OF COMMANDS FOR BOTH PWELL PROCESS AND NWELL PROCESS.",
 	"; Last modified:  7-Jul-90  KSS",
@@ -1444,19 +1450,19 @@ TECH_VARIABLES mocmosold_variables[] =
 	{"TECH_node_width_offset", (char *)mocmosold_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_color_map", (char *)mocmosold_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof mocmosold_colmap)<<VLENGTHSH)},
 	{"USER_layer_letters", (char *)mocmosold_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the I/O aid */
+	/* set information for the I/O tool */
 	{"IO_cif_layer_names", (char *)mocmosold_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{"IO_gds_layer_numbers", (char *)mocmosold_gds_layers, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the DRC aid */
+	/* set information for the DRC tool */
 	{"DRC_min_unconnected_distances", (char *)mocmosold_unconnectedtable, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|
 			(((sizeof mocmosold_unconnectedtable)/SIZEOFINTBIG)<<VLENGTHSH)},
@@ -1466,7 +1472,7 @@ TECH_VARIABLES mocmosold_variables[] =
 	{"DRC_ecad_deck", (char *)mocmosold_drc_ecad_deck, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY},
 
-	/* set information for the SIM aid (SPICE) */
+	/* set information for the SIM tool (SPICE) */
 	{"SIM_spice_min_resistance", 0, mocmosold_MIN_RESIST, VFLOAT|VDONTSAVE},
 	{"SIM_spice_min_capacitance", 0, mocmosold_MIN_CAPAC, VFLOAT|VDONTSAVE},
 	{"SIM_spice_resistance", (char *)mocmosold_sim_spice_resistance, 0.0,
