@@ -990,13 +990,13 @@ static INTBIG nmos_node_widoff[NODEPROTOCOUNT*4] = {0,0,0,0, 0,0,0,0, 0,0,0,0,
 /* for SPICE simulation */
 #define NMOS_MIN_RESIST	50.0f		/* minimum resistance consider */
 #define NMOS_MIN_CAPAC	0.04f		/* minimum capacitance consider */
-float nmos_sim_spice_resistance[MAXLAYERS] = {   /* per square micron */
+static float nmos_sim_spice_resistance[MAXLAYERS] = {   /* per square micron */
 	0.03f /* metal */,    50.0f /* poly */,   10.0f /* diff */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
-float nmos_sim_spice_capacitance[MAXLAYERS] = {  /* per square micron */
+static float nmos_sim_spice_capacitance[MAXLAYERS] = {  /* per square micron */
 	0.03f /* metal */,    0.04f /* poly */,   0.1f /* diff */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
-char *nmos_sim_spice_header_level1[] = {
+static char *nmos_sim_spice_header_level1[] = {
 	"*NMOS 4UM PROCESS",
 	".OPTIONS DEFL=4UM DEFW=4UM DEFAS=80PM^2 DEFAD=80PM^2",
 	".MODEL N NMOS LEVEL=1 VTO=1.1 KP=33UA/V^2 TOX=68NM GAMMA=.41",
@@ -1007,7 +1007,7 @@ char *nmos_sim_spice_header_level1[] = {
 	"+             JS=.2A/M^2 CJ=.11MF/M^2",
 	".MODEL DIFFCAP D CJO=.11MF/M^2",
 	NOSTRING};
-char *nmos_sim_spice_header_level3[] = {
+static char *nmos_sim_spice_header_level3[] = {
 	"*NMOS 4UM PROCESS",
 	".OPTIONS DEFL=4UM DEFW=4UM DEFAS=80PM^2 DEFAD=80PM^2",
 	"* RSH SET TO ZERO (MOSIS: RSH = 12)",
@@ -1037,17 +1037,17 @@ TECH_VARIABLES nmos_variables[] =
 	{"TECH_node_width_offset", (char *)nmos_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_layer_letters", (char *)nmos_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{"USER_color_map", (char *)nmos_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof nmos_colmap)<<VLENGTHSH)},
 
-	/* set information for the I/O aid */
+	/* set information for the I/O tool */
 	{"IO_cif_layer_names", (char *)nmos_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the DRC aid */
+	/* set information for the DRC tool */
 	{"DRC_min_unconnected_distances", (char *)nmos_unconnectedtable, 0.0,
 		 VFRACT|VDONTSAVE|VISARRAY|
 			(((sizeof nmos_unconnectedtable)/SIZEOFINTBIG)<<VLENGTHSH)},
@@ -1055,7 +1055,7 @@ TECH_VARIABLES nmos_variables[] =
 		VFRACT|VDONTSAVE|VISARRAY|
 			(((sizeof nmos_connectedtable) / SIZEOFINTBIG)<<VLENGTHSH)},
 
-	/* set information for the SIM aid (SPICE) */
+	/* set information for the SIM tool (SPICE) */
 	{"SIM_spice_min_resistance", 0, NMOS_MIN_RESIST, VFLOAT|VDONTSAVE},
 	{"SIM_spice_min_capacitance", 0, NMOS_MIN_CAPAC, VFLOAT|VDONTSAVE},
 	{"SIM_spice_resistance", (char *)nmos_sim_spice_resistance, 0.0,
