@@ -849,15 +849,15 @@ static INTBIG rcmos_node_widoff[NODEPROTOCOUNT*4] = {
 /* for SPICE simulation */
 #define RCMOS_MIN_RESIST	50.0f	/* minimum resistance consider */
 #define RCMOS_MIN_CAPAC	     0.04f	/* minimum capacitance consider */
-float rcmos_sim_spice_resistance[MAXLAYERS] = {  /* per square micron */
+static float rcmos_sim_spice_resistance[MAXLAYERS] = {  /* per square micron */
 	0.03f /* METAL1 */,    0.03f /* METAL2 */,    50.0f /* POLY */,
 	10.0f /* SACT */,      10.0f /* DACT */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
-float rcmos_sim_spice_capacitance[MAXLAYERS] = { /* per square micron */
+static float rcmos_sim_spice_capacitance[MAXLAYERS] = { /* per square micron */
 	0.03f /* METAL1 */,    0.03f /* METAL2 */,    0.04f /* POLY */,
 	0.1f /* SACT */,       0.1f /* DACT */,
 	0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
-char *rcmos_sim_spice_header_level1[] = {
+static char *rcmos_sim_spice_header_level1[] = {
 	"*CMOS/BULK-NWELL (PRELIMINARY PARAMETERS)",
 	".OPTIONS NOMOD DEFL=3UM DEFW=3UM DEFAD=70P DEFAS=70P LIMPTS=1000",
 	"+ITL4=1000 ITL5=0 RELTOL=0.01 ABSTOL=500PA VNTOL=500UV LVLTIM=2",
@@ -870,7 +870,7 @@ char *rcmos_sim_spice_header_level1[] = {
 	"+LD=0.6E-6 TOX=40E-9 CGSO=3.0E-10 CGDO=3.0E-10 CJ=.2MF/M^2",
 	".MODEL DIFFCAP D CJO=.2MF/M^2",
 	NOSTRING};
-char *rcmos_sim_spice_header_level2[] = {
+static char *rcmos_sim_spice_header_level2[] = {
 	"* CMOS 3um process parameters from MOSIS run M46M",
 	"* CBPEM2 Telmos/Sierracin",
 	".OPTIONS NOMOD DEFL=3UM DEFW=3UM DEFAD=70P DEFAS=70P LIMPTS=1000",
@@ -905,17 +905,17 @@ TECH_VARIABLES rcmos_variables[] =
 	{"TECH_node_width_offset", (char *)rcmos_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
-	/* set information for the USER aid */
+	/* set information for the USER tool */
 	{"USER_color_map", (char *)rcmos_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof rcmos_colmap)<<VLENGTHSH)},
 	{"USER_layer_letters", (char *)rcmos_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-			/* set information for the I/O aid */
+			/* set information for the I/O tool */
 	{"IO_cif_layer_names", (char *)rcmos_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
-	/* set information for the SIM aid (SPICE) */
+	/* set information for the SIM tool (SPICE) */
 	{"SIM_spice_min_resistance", 0, RCMOS_MIN_RESIST, VFLOAT|VDONTSAVE},
 	{"SIM_spice_min_capacitance", 0, RCMOS_MIN_CAPAC, VFLOAT|VDONTSAVE},
 	{"SIM_spice_resistance", (char *)rcmos_sim_spice_resistance, 0.0,
