@@ -32,14 +32,13 @@
 /*
  * The primitives of this technology can be parameterized as follows:
  *
- * "TRANSISTOR" uses "SCHEM_transistor_type" for size
+ * "TRANSISTOR" uses "ATTR_width", "ATTR_length", and "ATTR_area" for size
  * "RESISTOR"   uses "SCHEM_resistance"      for ohms
  * "CAPACITOR"  uses "SCHEM_capacitance"     for capacitance
  * "DIODE"      uses "SCHEM_diode"           for area
  * "INDUCTOR"   uses "SCHEM_inductance"      for Henrys
  * "BBOX"       uses "SCHEM_function"        for function
- * "POWER"      uses "SCHEM_source"          for characteristics
- * "SOURCE"     uses "SCHEM_source"          for the SPICE card
+ * "SOURCE"     uses "SIM_spice_model"       for the SPICE card
  * "METER"      uses "SCHEM_meter_type"      for SPICE range
  * "TWOPORT"    uses "SCHEM_twoport_type"    which is:
  *    siemens for transconductance (VCCS)
@@ -221,8 +220,6 @@ COMCOMP sch_parse = {schopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Schematic option"), M_("show current options")};
 
 TECHNOLOGY    *sch_tech;
-INTBIG         sch_transistortypekey;	/* key for "SCHEM_transistor_type" */
-INTBIG         sch_sourcekey;			/* key for "SCHEM_source" */
 INTBIG         sch_meterkey;			/* key for "SCHEM_meter_type" */
 INTBIG         sch_diodekey;			/* key for "SCHEM_diode" */
 INTBIG         sch_capacitancekey;		/* key for "SCHEM_capacitance" */
@@ -230,6 +227,7 @@ INTBIG         sch_resistancekey;		/* key for "SCHEM_resistance" */
 INTBIG         sch_inductancekey;		/* key for "SCHEM_inductance" */
 INTBIG         sch_twoportkey;			/* key for "SCHEM_twoport_type" */
 INTBIG         sch_functionkey;			/* key for "SCHEM_function" */
+INTBIG         sch_spicemodelkey;		/* key for "SIM_spice_model" */
 NODEPROTO     *sch_wirepinprim, *sch_buspinprim, *sch_wireconprim, *sch_bufprim,
               *sch_andprim, *sch_orprim, *sch_xorprim, *sch_ffprim, *sch_muxprim,
               *sch_bboxprim, *sch_switchprim, *sch_offpageprim, *sch_pwrprim,
@@ -239,7 +237,7 @@ NODEPROTO     *sch_wirepinprim, *sch_buspinprim, *sch_wireconprim, *sch_bufprim,
 ARCPROTO      *sch_wirearc, *sch_busarc;
 static INTBIG  sch_bubblediameter = K1+D4;
 static INTBIG  sch_bubblebox, sch_arrowbox;
-PORTPROTO     *sch_anddiffports, *sch_ordiffports, *sch_xordiffports;
+static PORTPROTO     *sch_anddiffports, *sch_ordiffports, *sch_xordiffports;
 INTBIG         sch_wirepinsizex;		/* X size if wire-pin primitives */
 INTBIG         sch_wirepinsizey;		/* Y size if wire-pin primitives */
 
@@ -308,9 +306,9 @@ TECH_ARCS *sch_arcprotos[ARCPROTOCOUNT+1] = {&sch_a_w, &sch_a_b, ((TECH_ARCS *)-
 /******************** PORTINST CONNECTIONS ********************/
 
 /* these values are replaced with actual arcproto addresses */
-INTBIG sch_pc_wire[]   = {-1, AWIRE, ALLGEN, -1};
-INTBIG sch_pc_bus[]    = {-1, ABUS, ALLGEN, -1};
-INTBIG sch_pc_either[] = {-1, AWIRE, ABUS, ALLGEN, -1};
+static INTBIG sch_pc_wire[]   = {-1, AWIRE, ALLGEN, -1};
+static INTBIG sch_pc_bus[]    = {-1, ABUS, ALLGEN, -1};
+static INTBIG sch_pc_either[] = {-1, AWIRE, ABUS, ALLGEN, -1};
 
 /******************** NODES ********************/
 
@@ -357,7 +355,6 @@ static char sch_V[] = "V";
 static char sch_PR[] = "PR";
 static char sch_QB[] = "QB";
 
-static INTBIG sch_g_nullpin[]    = {CENTER,    CENTER,    CENTER,    CENTER};
 static INTBIG sch_g_pindisc[]    = {CENTER,    CENTER,    RIGHTEDGE, CENTER};
 static INTBIG sch_g_buspindisc[] = {CENTER,    CENTER,    RIGHTBYP5, CENTER};
 static INTBIG sch_g_bustapdisc[] = {CENTER,    CENTER,    RIGHTBYP25,CENTER};
@@ -572,9 +569,7 @@ static TECH_PORTS sch_wirepin_p[] = {				/* ports */
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON sch_wirepin_l[] = {				/* layers */
 	{LARC, 0, 2, DISC, POINTS, sch_g_pindisc}};
-static TECH_POLYGON sch_wirepinn_l[] = {			/* layers */
-	{LARC, 0, 4, FILLEDRECT, BOX, sch_g_nullpin}};
-TECH_NODES sch_wirepin = {
+static TECH_NODES sch_wirepin = {
 	"Wire_Pin",NWIREPIN,NONODEPROTO,				/* name */
 	K1,K1,											/* size */
 	1,sch_wirepin_p,								/* ports */
@@ -589,7 +584,7 @@ static TECH_PORTS sch_buspin_p[] = {				/* ports */
 static TECH_POLYGON sch_buspin_l[] = {				/* layers */
 	{LBUS, 0, 2, DISC, POINTS, sch_g_buspindisc},
 	{LARC, 0, 2, DISC, POINTS, sch_g_bustapdisc}};
-TECH_NODES sch_buspin = {
+static TECH_NODES sch_buspin = {
 	"Bus_Pin",NBUSPIN,NONODEPROTO,					/* name */
 	K2,K2,											/* size */
 	1,sch_buspin_p,									/* ports */
@@ -602,9 +597,9 @@ static TECH_PORTS sch_wirecon_p[] = {				/* ports */
 	{sch_pc_either, "wire", NOPORTPROTO, (180<<PORTARANGESH)|PORTISOLATED,
 		LEFTIN0H, TOPIN0H, RIGHTIN0H, BOTIN0H}};
 static TECH_POLYGON sch_wirecon_l[] = {				/* layers */
-	{LNODE, 0,     4, CLOSEDRECT, BOX, sch_g_bbox},
-	{LTEXT, TXT2L, 1, TEXTCENT, POINTS, (INTBIG *)sch_g_wireconj}};
-TECH_NODES sch_wirecon = {
+	{LNODE, 0,                4, CLOSEDRECT, BOX, sch_g_bbox},
+	{LTEXT, TXTSETQLAMBDA(8), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_wireconj}};
+static TECH_NODES sch_wirecon = {
 	"Wire_Con",NWIRECON,NONODEPROTO,				/* name */
 	K2,K2,											/* size */
 	1,sch_wirecon_p,								/* ports */
@@ -622,7 +617,7 @@ static TECH_PORTS sch_buf_p[] = {					/* ports */
 		(2<<PORTNETSH)|OUTPORT, RIGHTBYP66, CENTER, RIGHTBYP66, CENTER}};
 static TECH_POLYGON sch_buf_l[] = {					/* layers */
 	{LNODE, 0, 3, CLOSED, POINTS, sch_g_inv}};
-TECH_NODES sch_buf = {
+static TECH_NODES sch_buf = {
 	"Buffer", NBUF, NONODEPROTO,					/* name */
 	K6,K6,											/* size */
 	3,sch_buf_p,									/* ports */
@@ -643,7 +638,7 @@ static TECH_PORTS sch_and_p[] = {					/* ports */
 static TECH_POLYGON sch_and_l[] = {					/* layers */
 	{LNODE, 0, 3, CIRCLEARC,  POINTS, sch_g_and},
 	{LNODE, 0, 6, OPENED,     POINTS, sch_g_andbox}};
-TECH_NODES sch_and = {
+static TECH_NODES sch_and = {
 	"And", NAND, NONODEPROTO,						/* name */
 	K8,K6,											/* size */
 	4,sch_and_p,									/* ports */
@@ -666,7 +661,7 @@ static TECH_POLYGON sch_or_l[] = {					/* layers */
 	{LNODE, 0, 3, CIRCLEARC, POINTS, sch_g_ort},
 	{LNODE, 0, 3, CIRCLEARC, POINTS, sch_g_orb},
 	{LNODE, 0, 8, VECTORS,   POINTS, sch_g_or}};
-TECH_NODES sch_or = {
+static TECH_NODES sch_or = {
 	"Or", NOR, NONODEPROTO,							/* name */
 	K10,K6,											/* size */
 	4,sch_or_p,										/* ports */
@@ -690,7 +685,7 @@ static TECH_POLYGON sch_xor_l[] = {					/* layers */
 	{LNODE, 0, 3, CIRCLEARC, POINTS, sch_g_orb},
 	{LNODE, 0, 3, CIRCLEARC, POINTS, sch_g_xor},
 	{LNODE, 0, 8, VECTORS,   POINTS, sch_g_or}};
-TECH_NODES sch_xor = {
+static TECH_NODES sch_xor = {
 	"Xor", NXOR, NONODEPROTO,						/* name */
 	K10,K6,											/* size */
 	4,sch_xor_p,									/* ports */
@@ -715,36 +710,36 @@ static TECH_PORTS sch_ff_p[] = {					/* ports */
 	{sch_pc_wire, "clear", NOPORTPROTO,(270<<PORTANGLESH)|(45<<PORTARANGESH)|
 		(6<<PORTNETSH)|INPORT,  CENTER, BOTEDGE, CENTER, BOTEDGE}};
 static TECH_POLYGON sch_ffp_l[] = {					/* layers */
-	{LNODE, 0,        4, CLOSEDRECT, BOX,    sch_g_ffbox},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
-	{LNODE, 0,        3, OPENED,     POINTS, sch_g_ffarrow},
-	{LNODE, 0,        4, OPENED,     POINTS, sch_g_ffp}};
+	{LNODE, 0,                4, CLOSEDRECT, BOX,    sch_g_ffbox},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
+	{LNODE, 0,                3, OPENED,     POINTS, sch_g_ffarrow},
+	{LNODE, 0,                4, OPENED,     POINTS, sch_g_ffp}};
 static TECH_POLYGON sch_ffn_l[] = {					/* layers */
-	{LNODE, 0,        4, CLOSEDRECT, BOX,    sch_g_ffbox},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
-	{LNODE, 0,        3, OPENED,     POINTS, sch_g_ffarrow},
-	{LNODE, 0,        4, OPENED,     POINTS, sch_g_ffn}};
+	{LNODE, 0,                4, CLOSEDRECT, BOX,    sch_g_ffbox},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
+	{LNODE, 0,                3, OPENED,     POINTS, sch_g_ffarrow},
+	{LNODE, 0,                4, OPENED,     POINTS, sch_g_ffn}};
 static TECH_POLYGON sch_ffms_l[] = {				/* layers */
-	{LNODE, 0,        4, CLOSEDRECT, BOX,    sch_g_ffbox},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
-	{LTEXT, TXT1L,    4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
-	{LNODE, 0,        3, OPENED,     POINTS, sch_g_ffarrow},
-	{LNODE, 0,        6, OPENED,     POINTS, sch_g_ffms}};
-TECH_NODES sch_ff = {
+	{LNODE, 0,                4, CLOSEDRECT, BOX,    sch_g_ffbox},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextd},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftexte},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextq},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextqb},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextpr},
+	{LTEXT, TXTSETQLAMBDA(4), 4, TEXTBOX,    POINTS, (INTBIG *)sch_g_fftextclr},
+	{LNODE, 0,                3, OPENED,     POINTS, sch_g_ffarrow},
+	{LNODE, 0,                6, OPENED,     POINTS, sch_g_ffms}};
+static TECH_NODES sch_ff = {
 	"Flip-Flop", NFF, NONODEPROTO,					/* name */
 	K6,K10,											/* size */
 	7,sch_ff_p,										/* ports */
@@ -762,7 +757,7 @@ static TECH_PORTS sch_mux_p[] = {					/* ports */
 		(1<<PORTNETSH)|OUTPORT, RIGHTBYP8, CENTER, RIGHTBYP8, CENTER}};
 	static TECH_POLYGON sch_mux_l[] = {					/* layers */
 	{LNODE, 0, 4, CLOSED,     POINTS, sch_g_mux}};
-TECH_NODES sch_mux = {
+static TECH_NODES sch_mux = {
 	"Mux", NMUX, NONODEPROTO,						/* name */
 	K8,K10,											/* size */
 	3,sch_mux_p,									/* ports */
@@ -782,7 +777,7 @@ static TECH_PORTS sch_bbox_p[] = {					/* ports */
 		(3<<PORTNETSH)|PORTISOLATED, LEFTEDGE,  BOTEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON sch_bbox_l[] = {				/* layers */
 	{LNODE, 0,         4, CLOSEDRECT, BOX,    sch_g_bbox}};
-TECH_NODES sch_bbox = {
+static TECH_NODES sch_bbox = {
 	"Bbox", NBBOX, NONODEPROTO,						/* name */
 	K10,K10,										/* size */
 	4,sch_bbox_p,									/* ports */
@@ -800,7 +795,7 @@ static TECH_POLYGON sch_switch_l[] = {				/* layers */
 	{LNODE, 0, 2, DISC,       POINTS, sch_g_switchin},
 	{LNODE, 0, 2, OPENED,     POINTS, sch_g_switchbar},
 	{LNODE, 0, 2, DISC,       POINTS, sch_g_switchout}};
-TECH_NODES sch_switch = {
+static TECH_NODES sch_switch = {
 	"Switch",NSWITCH,NONODEPROTO,					/* name */
 	K6,K2,											/* size */
 	2,sch_switch_p,									/* ports */
@@ -816,7 +811,7 @@ static TECH_PORTS sch_offpage_p[] = {				/* ports */
 		RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON sch_offpage_l[] = {				/* layers */
 	{LNODE, 0,         5, CLOSED,   POINTS, sch_g_offpage}};
-TECH_NODES sch_offpage = {
+static TECH_NODES sch_offpage = {
 	"Off-Page", NOFFPAGE, NONODEPROTO,				/* name */
 	K4,K2,											/* size */
 	2,sch_offpage_p,								/* ports */
@@ -831,7 +826,7 @@ static TECH_PORTS sch_pwr_p[] = {					/* ports */
 static TECH_POLYGON sch_pwr_l[] = {					/* layers */
 	{LNODE, 0,        2, CIRCLE,   POINTS, sch_g_pwr1},
 	{LNODE, 0,        2, CIRCLE,   POINTS, sch_g_pwr2}};
-TECH_NODES sch_pwr = {
+static TECH_NODES sch_pwr = {
 	"Power", NPWR, NONODEPROTO,						/* name */
 	K3,K3,											/* size */
 	1,sch_pwr_p,									/* ports */
@@ -845,7 +840,7 @@ static TECH_PORTS sch_gnd_p[] = {					/* ports */
 		GNDPORT, CENTER, TOPEDGE, CENTER, TOPEDGE}};
 static TECH_POLYGON sch_gnd_l[] = {					/* layers */
 	{LNODE, 0, 12, VECTORS, POINTS, sch_g_gnd}};
-TECH_NODES sch_gnd = {
+static TECH_NODES sch_gnd = {
 	"Ground", NGND, NONODEPROTO,					/* name */
 	K3,K4,											/* size */
 	1,sch_gnd_p,									/* ports */
@@ -860,30 +855,30 @@ static TECH_PORTS sch_source_p[] = {				/* ports */
 	{sch_pc_wire, "minus",  NOPORTPROTO, (270<<PORTANGLESH)|(0<<PORTARANGESH)|
 		(1<<PORTNETSH), CENTER, BOTEDGE, CENTER, BOTEDGE}};
 static TECH_POLYGON sch_sourcev_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LNODE, 0,         2, VECTORS,  POINTS, sch_g_sourcemi},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
+	{LNODE, 0,                2, VECTORS,  POINTS, sch_g_sourcemi},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
 static TECH_POLYGON sch_sourcec_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,         6, VECTORS,  POINTS, sch_g_sourcec},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LNODE, 0,                6, VECTORS,  POINTS, sch_g_sourcec},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
 static TECH_POLYGON sch_sourcet_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcet}};
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcet}};
 static TECH_POLYGON sch_sourcen_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcen}};
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcen}};
 static TECH_POLYGON sch_sourcex_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcex}};
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcex}};
 static TECH_POLYGON sch_sources_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXT1L,     1, TEXTCENT, POINTS, (INTBIG *)sch_g_sources}};
-TECH_NODES sch_source = {
+	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
+	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
+	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sources}};
+static TECH_NODES sch_source = {
 	"Source", NSOURCE, NONODEPROTO,					/* name */
 	K6,K6,											/* size */
 	2,sch_source_p,									/* ports */
@@ -940,7 +935,7 @@ static TECH_POLYGON sch_dmes_l[] = {				/* layers */
 static TECH_POLYGON sch_emes_l[] = {				/* layers */
 	{LNODE, 0,        14, VECTORS,    POINTS, sch_g_btran7},
 	{LNODE, 0,         2, OPENED,     POINTS, sch_g_nmos}};
-TECH_NODES sch_trans = {
+static TECH_NODES sch_trans = {
 	"Transistor", NTRANSISTOR, NONODEPROTO,			/* name */
 	K4,K4,											/* size */
 	3,sch_trans_p,									/* ports */
@@ -956,7 +951,7 @@ static TECH_PORTS sch_resist_p[] = {				/* ports */
 		(1<<PORTNETSH), RIGHTBYP66, CENTER, RIGHTBYP66, CENTER}};
 	static TECH_POLYGON sch_resist_l[] = {				/* layers */
 	{LNODE, 0,        10, OPENED,   POINTS, sch_g_resist}};
-TECH_NODES sch_resist = {
+static TECH_NODES sch_resist = {
 	"Resistor", NRESISTOR, NONODEPROTO,				/* name */
 	K6,K1,											/* size */
 	2,sch_resist_p,									/* ports */
@@ -973,7 +968,7 @@ static TECH_PORTS sch_capac_p[] = {					/* ports */
 static TECH_POLYGON sch_capac_l[] = {				/* layers */
 	{LNODE, 0,         8, VECTORS,  POINTS, sch_g_capac},
 	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_capace}};
-TECH_NODES sch_capac = {
+static TECH_NODES sch_capac = {
 	"Capacitor", NCAPACITOR, NONODEPROTO,			/* name */
 	K3,K4,											/* size */
 	2,sch_capac_p,									/* ports */
@@ -990,7 +985,7 @@ static TECH_PORTS sch_diode_p[] = {					/* ports */
 static TECH_POLYGON sch_diode_l[] = {				/* layers */
 	{LNODE, 0,         6, VECTORS,  POINTS, sch_g_diode1},
 	{LNODE, 0,         3, FILLED,   POINTS, sch_g_diode2}};
-TECH_NODES sch_diode = {
+static TECH_NODES sch_diode = {
 	"Diode", NDIODE, NONODEPROTO,					/* name */
 	K2,K4,											/* size */
 	2,sch_diode_p,									/* ports */
@@ -1009,7 +1004,7 @@ static TECH_POLYGON sch_induct_l[] = {				/* layers */
 	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_induct2},
 	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_induct3},
 	{LNODE, 0,         2, CIRCLE,   POINTS, sch_g_induct4}};
-TECH_NODES sch_induct = {
+static TECH_NODES sch_induct = {
 	"Inductor", NINDUCTOR, NONODEPROTO,				/* name */
 	K2,K4,											/* size */
 	2,sch_induct_p,									/* ports */
@@ -1024,9 +1019,9 @@ static TECH_PORTS sch_meter_p[] = {					/* ports */
 	{sch_pc_wire, "b",  NOPORTPROTO, (270<<PORTANGLESH)|(0<<PORTARANGESH)|
 		(1<<PORTNETSH), CENTER, BOTEDGE, CENTER, BOTEDGE}};
 static TECH_POLYGON sch_meterv_l[] = {				/* layers */
-	{LNODE, 0,         2, CIRCLE,  POINTS, sch_g_meter},
-	{LTEXT, TXT2L,     4, TEXTBOX, BOX,    (INTBIG *)sch_g_meterv}};
-TECH_NODES sch_meter = {
+	{LNODE, 0,                2, CIRCLE,  POINTS, sch_g_meter},
+	{LTEXT, TXTSETQLAMBDA(8), 4, TEXTBOX, BOX,    (INTBIG *)sch_g_meterv}};
+static TECH_NODES sch_meter = {
 	"Meter", NMETER, NONODEPROTO,					/* name */
 	K6,K6,											/* size */
 	2,sch_meter_p,									/* ports */
@@ -1040,7 +1035,7 @@ static TECH_PORTS sch_well_p[] = {				/* ports */
 		CENTER, TOPEDGE, CENTER, TOPEDGE}};
 static TECH_POLYGON sch_well_l[] = {				/* layers */
 	{LNODE, 0, 4, VECTORS, POINTS, sch_g_well}};
-TECH_NODES sch_well = {
+static TECH_NODES sch_well = {
 	"Well", NWELL, NONODEPROTO,						/* name */
 	K4,K2,											/* size */
 	1,sch_well_p,									/* ports */
@@ -1054,7 +1049,7 @@ static TECH_PORTS sch_substrate_p[] = {				/* ports */
 		CENTER, TOPEDGE, CENTER, TOPEDGE}};
 static TECH_POLYGON sch_substrate_l[] = {			/* layers */
 	{LNODE, 0, 8, VECTORS, POINTS, sch_g_substrate}};
-TECH_NODES sch_substrate = {
+static TECH_NODES sch_substrate = {
 	"Substrate", NSUBSTRATE, NONODEPROTO,			/* name */
 	K3,K3,											/* size */
 	1,sch_substrate_p,								/* ports */
@@ -1111,7 +1106,7 @@ static TECH_POLYGON sch_twoporttran_l[] = {			/* layers */
 	{LNODE, 0,         8, VECTORS,  POINTS, sch_g_twotrwire},
 	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_twoulpl},
 	{LNODE, 0,         4, VECTORS,  POINTS, sch_g_twourrpl}};
-TECH_NODES sch_twoport = {
+static TECH_NODES sch_twoport = {
 	"Two-Port", NTWOPORT, NONODEPROTO,				/* name */
 	K10,K6,											/* size */
 	4,sch_twoport_p,								/* ports */
@@ -1179,7 +1174,7 @@ static TECH_POLYGON sch_emes4_l[] = {				/* layers */
 	{LNODE, 0,        14, VECTORS,    POINTS, sch_g_btran7},
 	{LNODE, 0,         2, OPENED,     POINTS, sch_g_nmos},
 	{LNODE, 0,         6, VECTORS,    POINTS, sch_g_nmes4}};
-TECH_NODES sch_trans4 = {
+static TECH_NODES sch_trans4 = {
 	"4-Port-Transistor", NTRANSISTOR4, NONODEPROTO,	/* name */
 	K4,K4,											/* size */
 	4,sch_trans4_p,									/* ports */
@@ -1244,7 +1239,7 @@ TECH_VARIABLES sch_variables[] =
 	{"TECH_vhdl_names", (char *)sch_node_vhdlstring, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(NODEPROTOCOUNT<<VLENGTHSH)},
 
-	/* set information for the USER analysis aid */
+	/* set information for the USER analysis tool */
 	{"USER_layer_letters", (char *)sch_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
@@ -1287,8 +1282,6 @@ INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
 		sch_wirearc = getarcproto("schematic:wire");
 		sch_busarc = getarcproto("schematic:bus");
 
-		sch_transistortypekey = makekey("SCHEM_transistor_type");
-		sch_sourcekey = makekey("SCHEM_source");
 		sch_meterkey = makekey("SCHEM_meter_type");
 		sch_diodekey = makekey("SCHEM_diode");
 		sch_capacitancekey = makekey("SCHEM_capacitance");
@@ -1296,6 +1289,7 @@ INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
 		sch_inductancekey = makekey("SCHEM_inductance");
 		sch_twoportkey = makekey("SCHEM_twoport_type");
 		sch_functionkey = makekey("SCHEM_function");
+		sch_spicemodelkey = makekey("SIM_spice_model");
 
 		/* differential ports are enabled */
 		sch_anddiffports = sch_ordiffports = sch_xordiffports = NOPORTPROTO;
@@ -1714,7 +1708,6 @@ void sch_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	REGISTER INTBIG lambda;
 	REGISTER TECH_PORTS *tp;
-	static char shortenedstring[14];
 
 	/* handle displayable variables */
 	if (box >= tech_realpolys)
@@ -1763,7 +1756,8 @@ void sch_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 		tech_fillpoly(poly, &sch_layerlist[box], ni, lambda, FILLED);
 	}
 
-	poly->font = sch_layerlist[box].portnum;
+	TDCLEAR(poly->textdescript);
+	TDSETSIZE(poly->textdescript, sch_layerlist[box].portnum);
 	if (ni->parent == NONODEPROTO) poly->tech = sch_tech; else
 		poly->tech = ni->parent->tech;
 	poly->desc = sch_layers[poly->layer];
@@ -1957,7 +1951,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 				/* make this gate change visible if it is in a window */
 				for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 					if (w->curnodeproto == ni->parent) break;
-				if (w != NOWINDOWPART) (void)askaid(us_aid, "flush-changes");
+				if (w != NOWINDOWPART) (void)asktool(us_tool, "flush-changes");
 			}
 			return;
 		}
