@@ -118,6 +118,14 @@ extern TECH_VARIABLES gen_variables[];
   extern TECH_VARIABLES mocmossub_variables[];
 #endif
 
+#if TECMOCMOS2
+  extern GRAPHICS *mocmos2_layers[];
+  extern TECH_ARCS *mocmos2_arcprotos[];
+  extern TECH_NODES *mocmos2_nodeprotos[];
+  extern TECH_VARIABLES mocmos2_variables[];
+  INTSML mocmos2_initprocess(TECHNOLOGY*, INTSML);
+#endif
+
 #if TECNMOS
   extern GRAPHICS *nmos_layers[];
   extern TECH_ARCS *nmos_arcprotos[];
@@ -233,6 +241,18 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 #endif
 
+#if TECMOCMOS2
+	/* MOSIS CMOS, 2 micron (obsolete) */
+	{"mocmos2", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	N_("Complementary MOS (MOSIS, Orbit, P-Well, double metal, double poly)"),		/* description */
+	0, mocmos2_layers, 0, mocmos2_arcprotos, 0, mocmos2_nodeprotos, mocmos2_variables,	/* tables */
+	mocmos2_initprocess, 0, 0, 0,													/* control routines */
+	0, 0, 0, 0, 0,																	/* node routines */
+	0,																				/* port routine */
+	0, 0, 0,																		/* arc routines */
+	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
+#endif
+
 #if TECBICMOS
 	/* MOSIS BiCMOS */
 	{"bicmos", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
@@ -300,7 +320,7 @@ TECHNOLOGY el_technologylist[] =
 	fpga_nodepolys, fpga_nodeEpolys, fpga_shapenodepoly, fpga_shapeEnodepoly, 0,	/* node routines */
 	fpga_shapeportpoly,																/* port routine */
 	fpga_arcpolys, fpga_shapearcpoly, 0,											/* arc routines */
-	NOTECHNOLOGY, NONSTANDARD|STATICTECHNOLOGY, 0, 0},								/* miscellaneous */
+	NOTECHNOLOGY, NONSTANDARD|STATICTECHNOLOGY|NOPRIMTECHNOLOGY, 0, 0},				/* miscellaneous */
 #endif
 
 #if TECPCB
