@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcheck.c
- * User interface aid: database consistency check
+ * User interface tool: database consistency check
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -32,14 +32,16 @@
 #include "database.h"
 #include "efunction.h"
 #include "tecgen.h"
+#include "tecschem.h"
 #include "usr.h"
 
 extern ARCPROTO **gen_upconn;
 
 /* prototypes for local routines */
-void us_checklibrary(LIBRARY*, INTSML, INTBIG*, INTBIG*);
-INTSML us_checkvariables(INTSML*, VARIABLE*, LIBRARY*);
-INTBIG us_checkrtree(RTNODE*, RTNODE*, NODEPROTO*, INTBIG*, INTBIG*);
+static void us_checklibrary(LIBRARY*, INTSML, INTBIG*, INTBIG*);
+static INTSML us_checkvariables(INTSML*, VARIABLE*, LIBRARY*);
+static INTBIG us_checkrtree(RTNODE*, RTNODE*, NODEPROTO*, INTBIG*, INTBIG*);
+static INTSML us_checktextdescript(UINTBIG *descript);
 
 void us_checkdatabase(INTSML verbose)
 {
@@ -51,7 +53,7 @@ void us_checkdatabase(INTSML verbose)
 	INTBIG warnings, errors;
 	REGISTER CELL *c, *oc;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER AIDENTRY *aid;
+	REGISTER TOOL *tool;
 	REGISTER ARCPROTO *ap;
 	REGISTER VIEW *v;
 	REGISTER char *ch;
@@ -108,6 +110,7 @@ void us_checkdatabase(INTSML verbose)
 		{
 			ttyputmsg(_("Facet %s: says %ld nodes, has %ld"), describenodeproto(np), co, np->temp1);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 	}
 
@@ -144,22 +147,22 @@ void us_checkdatabase(INTSML verbose)
 	{
 		if (us_checkvariables(&tech->numvar, tech->firstvar, NOLIBRARY) != 0)
 		{
-			warnings++;
 			ttyputmsg(_("    Technology %s"), tech->techname);
+			warnings++;
 		}
 		for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 			if (us_checkvariables(&ap->numvar, ap->firstvar, NOLIBRARY) != 0)
 		{
-			warnings++;
 			ttyputmsg(_("    Arc %s"), describearcproto(ap));
+			warnings++;
 		}
 
 		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			if (us_checkvariables(&np->numvar, np->firstvar, NOLIBRARY) != 0)
 			{
-				warnings++;
 				ttyputmsg(_("    Technology %s, node %s"), tech->techname, np->primname);
+				warnings++;
 			}
 			if (np->tech != tech)
 			{
@@ -170,14 +173,14 @@ void us_checkdatabase(INTSML verbose)
 		}
 	}
 
-	/* check variables in the aids */
-	for(i=0; i<el_maxaid; i++)
+	/* check variables in the tools */
+	for(i=0; i<el_maxtools; i++)
 	{
-		aid = &el_aids[i];
-		if (us_checkvariables(&aid->numvar, aid->firstvar, NOLIBRARY) != 0)
+		tool = &el_tools[i];
+		if (us_checkvariables(&tool->numvar, tool->firstvar, NOLIBRARY) != 0)
 		{
+			ttyputmsg(_("    Tool %s"), tool->toolname);
 			warnings++;
-			ttyputmsg(_("    Aid %s"), aid->aidname);
 		}
 	}
 
@@ -186,24 +189,24 @@ void us_checkdatabase(INTSML verbose)
 	{
 		if (us_checkvariables(&v->numvar, v->firstvar, NOLIBRARY) != 0)
 		{
-			warnings++;
 			ttyputmsg(_("    View %s"), v->viewname);
+			warnings++;
 		}
 		if ((v->viewstate&MULTIPAGEVIEW) != 0)
 		{
 			if (namesamen(v->viewname, "schematic-page-", 15) != 0)
 			{
-				warnings++;
 				ttyputmsg(_("    View %s should not be multipage"), v->viewname);
 				v->viewstate &= ~MULTIPAGEVIEW;
+				warnings++;
 			}
 		} else
 		{
 			if (namesamen(v->viewname, "schematic-page-", 15) == 0)
 			{
-				warnings++;
 				ttyputmsg(_("    View %s should be multipage"), v->viewname);
 				v->viewstate |= MULTIPAGEVIEW;
+				warnings++;
 			}
 		}
 	}
@@ -220,6 +223,7 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("Library %s: null cell name; renamed to 'NULL'"), lib->libname);
 			(void)setval((INTBIG)c, VCELL, "cellname", (INTBIG)"NULL", VSTRING);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* make sure cell name has no blanks, tabs, colons, etc in it */
@@ -241,6 +245,7 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("...renamed to '%s'"), c->cellname);
 			db_buildcellhashtable(lib);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* make sure cell name is unique */
@@ -258,6 +263,7 @@ void us_checkdatabase(INTSML verbose)
 			nextchangequiet();
 			(void)setval((INTBIG)c, VCELL, "cellname", (INTBIG)returninfstr(), VSTRING);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* make sure the cell has facets */
@@ -278,18 +284,21 @@ void us_checkdatabase(INTSML verbose)
 					ttyputmsg(_("Facet %s: wrong cell pointer"), describenodeproto(np));
 					onp->cell = c;
 					warnings++;
+					lib->userbits |= LIBCHANGEDMAJOR;
 				}
 				if (onp->newestversion != np)
 				{
 					ttyputmsg(_("Facet %s: wrong newest version"), describenodeproto(onp));
 					onp->newestversion = np;
 					warnings++;
+					lib->userbits |= LIBCHANGEDMAJOR;
 				}
 				if (onp->cellview != np->cellview)
 				{
 					ttyputmsg(_("Facet %s: wrong view for old version"), describenodeproto(onp));
 					onp->cellview = np->cellview;
 					warnings++;
+					lib->userbits |= LIBCHANGEDMAJOR;
 				}
 				if (lastnp != NONODEPROTO)
 				{
@@ -298,12 +307,14 @@ void us_checkdatabase(INTSML verbose)
 						ttyputmsg(_("Facet %s: nonascending version order"), describenodeproto(lastnp));
 						lastnp->version = onp->version + 1;
 						warnings++;
+						lib->userbits |= LIBCHANGEDMAJOR;
 					}
 					if (onp->nextincell != NONODEPROTO)
 					{
 						ttyputmsg(_("Facet %s: old version has bad link"), describenodeproto(onp));
 						lastnp->nextincell = NONODEPROTO;
 						warnings++;
+						lib->userbits |= LIBCHANGEDMAJOR;
 					}
 				}
 				lastnp = onp;
@@ -316,6 +327,7 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("Library %s, cell %s: wrong library"), lib->libname, c->cellname);
 			c->lib = lib;
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check that cell is in cell hash table */
@@ -324,13 +336,15 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("Library %c, cell %s: not in cell hash"), lib->libname, c->cellname);
 			db_buildcellhashtable(lib);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check variables in the cell */
 		if (us_checkvariables(&c->numvar, c->firstvar, lib) != 0)
 		{
-			warnings++;
 			ttyputmsg(_("    Library %s, cell %s"), lib->libname, c->cellname);
+			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 	}
 
@@ -345,6 +359,7 @@ void us_checkdatabase(INTSML verbose)
 				ttyputmsg(_("Library %s: invalid lastnodeproto"), lib->libname);
 				np->lastnodeproto = lastnp;
 				warnings++;
+				lib->userbits |= LIBCHANGEDMAJOR;
 			}
 			lastnp = np;
 		}
@@ -353,6 +368,7 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("Library %s: invalid tailnodeproto"), lib->libname);
 			lib->tailnodeproto = lastnp;
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check cell list */
@@ -372,6 +388,7 @@ void us_checkdatabase(INTSML verbose)
 			ttyputmsg(_("Library %s: invalid tailcell"), lib->libname);
 			lib->tailcell = c;
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 		if (co != lib->numcells)
 		{
@@ -379,6 +396,7 @@ void us_checkdatabase(INTSML verbose)
 				lib->libname, co, lib->numcells);
 			db_buildcellhashtable(lib);
 			warnings++;
+			lib->userbits |= LIBCHANGEDMAJOR;
 		}
 		if (lib->cellhashtablesize > 0)
 		{
@@ -391,6 +409,7 @@ void us_checkdatabase(INTSML verbose)
 					lib->libname, lib->numcells, co);
 				db_buildcellhashtable(lib);
 				warnings++;
+				lib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 	}
@@ -417,6 +436,7 @@ void us_checkdatabase(INTSML verbose)
 				onp->nextnodeproto = lib->firstnodeproto;
 				lib->firstnodeproto = onp;
 				warnings++;
+				lib->userbits |= LIBCHANGEDMAJOR;
 				continue;
 			}
 			if (onp->temp1 != (INTBIG)NOCELL)
@@ -440,6 +460,7 @@ void us_checkdatabase(INTSML verbose)
 				if (lastnp == NONODEPROTO) lib->firstnodeproto = np->nextnodeproto; else
 					lastnp->nextnodeproto = np->nextnodeproto;
 				warnings++;
+				lib->userbits |= LIBCHANGEDMAJOR;
 				continue;
 			}
 			lastnp = np;
@@ -468,6 +489,7 @@ void us_checkdatabase(INTSML verbose)
 								describenodeproto(np), pp->protoname, opp->protoname);
 						}
 						warnings++;
+						lib->userbits |= LIBCHANGEDMAJOR;
 						break;
 					}
 					ni = opp->subnodeinst;
@@ -481,6 +503,7 @@ void us_checkdatabase(INTSML verbose)
 						pp->protoname);
 					pp->connects = gen_upconn;
 					warnings++;
+					lib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 		}
@@ -529,15 +552,16 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	if (verbose) ttyputmsg(_("***** Checking library %s"), curlib->libname);
 
 	/* check variables in the library */
 	if (us_checkvariables(&curlib->numvar, curlib->firstvar, curlib) != 0)
 	{
-		(*warnings)++;
 		ttyputmsg(_("    Library %s"), curlib->libname);
+		(*warnings)++;
+		curlib->userbits |= LIBCHANGEDMAJOR;
 	}
 
 	/* check every facet in the library */
@@ -550,8 +574,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 		/* check variables in the facet */
 		if (us_checkvariables(&np->numvar, np->firstvar, curlib) != 0)
 		{
-			(*warnings)++;
 			ttyputmsg(_("    Facet %s"), describenodeproto(np));
+			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check specific variables */
@@ -577,11 +602,12 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			}
 			if (i != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("Facet %s: bad frame size info (was '%s', now '%s')"),
 					describenodeproto(np), (char *)var->addr, newframeinfo);
 				setvalkey((INTBIG)np, VNODEPROTO, el_schematic_page_size,
 					(INTBIG)newframeinfo, VSTRING);
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 
@@ -592,6 +618,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			ttyputmsg(_("Facet %s: flagged as primitive"), describenodeproto(np));
 			np->primindex = 0;
 			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* make sure there is no technology */
@@ -601,6 +628,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			ttyputmsg(_("Facet %s: has wrong technology"), describenodeproto(np));
 			np->tech = tech;
 			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check the port protos on this facet */
@@ -617,6 +645,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ttyputmsg(_("Facet %s, port %s: bad port name (has character 0%o)"),
 							describenodeproto(np), pp->protoname, (*ch)&0377);
 						(*warnings)++;
+						curlib->userbits |= LIBCHANGEDMAJOR;
 					}
 					found++;
 					*ch = 'X';
@@ -624,8 +653,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			}
 			if (found != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("...renamed to '%s'"), pp->protoname);
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 				break;
 			}
 
@@ -635,6 +665,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s: null port name, renamed to 'NULL'"), describenodeproto(np));
 				(void)allocstring(&pp->protoname, "NULL", np->cell->cluster);
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure port name is unique */
@@ -649,6 +680,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					(void)reallocstring(&pp->protoname, us_uniqueportname(pp->protoname, np),
 						np->cell->cluster);
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					break;
 				}
 				if (opp == NOPORTPROTO) break;
@@ -661,6 +693,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					pp->protoname, pp->connects, pp->subportproto->connects);
 				pp->connects = pp->subportproto->connects;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure parent information in port is right */
@@ -669,6 +702,15 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s, port %s: bad parent"), describenodeproto(np), pp->protoname);
 				pp->parent = np;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
+			}
+
+			/* check the text descriptor */
+			if (us_checktextdescript(pp->textdescript) != 0)
+			{
+				ttyputmsg(_("   Facet %s, port %s"), describenodeproto(np), pp->protoname);
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure userbits of parent matches that of child */
@@ -682,17 +724,19 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenodeproto(np), pp->protoname, pp->userbits, j);
 				pp->userbits = j;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* ports on invisible pins must not have an offset */
 			if (pp->subnodeinst->proto == gen_invispinprim)
 			{
-				if ((pp->textdescript&(VTXOFF|VTXOFFNEG|VTYOFF|VTYOFFNEG)) != 0)
+				if (TDGETXOFF(pp->textdescript) != 0 || TDGETYOFF(pp->textdescript) != 0)
 				{
-					pp->textdescript &= ~(VTXOFF|VTXOFFNEG|VTYOFF|VTYOFFNEG);
+					TDSETOFF(pp->textdescript, 0, 0);
 					ttyputmsg(_("Facet %s, export %s: should not have offset (on invisible pin)"),
 						describenodeproto(np), pp->protoname);
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 
@@ -706,6 +750,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				if (lpp == NOPORTPROTO) np->firstportproto = pp->nextportproto; else
 					lpp->nextportproto = pp->nextportproto;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 				continue;
 			}
 
@@ -717,6 +762,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s, port %s: subportproto not there"), describenodeproto(np),
 					pp->protoname);
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 				if (ni->proto->firstportproto == NOPORTPROTO)
 				{
 					/* subnodeinst has no ports: delete this export */
@@ -739,6 +785,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s: invalid view"), describenodeproto(np));
 				np->cellview = el_views;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check variables in the port */
@@ -746,6 +793,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				ttyputmsg(_("    Facet %s, port %s"), describenodeproto(np), pp->protoname);
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 
@@ -783,6 +831,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 								describenodeproto(np), pp->protoname, describenodeproto(onp));
 							pp->userbits = (pp->userbits & ~STATEBITS) | (opp->userbits&STATEBITS);
 							(*warnings)++;
+							curlib->userbits |= LIBCHANGEDMAJOR;
 						}
 					}
 				}
@@ -821,6 +870,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s: node instance with no prototype"), describenodeproto(np));
 				ni->proto = gen_univpinprim;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* see if a "facet-center" primitive is in the facet */
@@ -832,6 +882,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s: multiple facet-center primitives"), describenodeproto(np));
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 				facetcenters++;
 
@@ -843,6 +894,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					(void)setvalkey((INTBIG)np, VNODEPROTO, el_prototype_center,
 						(INTBIG)position, VINTEGER|VISARRAY|(2<<VLENGTHSH));
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				} else if (((INTBIG *)var->addr)[0] != position[0] ||
 					((INTBIG *)var->addr)[1] != position[1])
 				{
@@ -850,6 +902,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					(void)setvalkey((INTBIG)np, VNODEPROTO, el_prototype_center,
 						(INTBIG)position, VINTEGER|VISARRAY|(2<<VLENGTHSH));
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 
@@ -869,6 +922,16 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					ni->lowy += ((ni->highy-ni->lowy) - (ni->proto->highy-ni->proto->lowy))/2;
 					ni->highy = ni->lowy + ni->proto->highy-ni->proto->lowy;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
+				}
+
+				/* check text descriptor on these instances */
+				if (us_checktextdescript(ni->textdescript) != 0)
+				{
+					ttyputmsg(_("  Facet %s, node %s"),
+						describenodeproto(np), describenodeinst(ni));
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			} else
 			{
@@ -886,6 +949,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						i = ni->lowy;   ni->lowy = ni->highy;   ni->highy = i;
 					}
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 
 				/* check trace information for validity */
@@ -897,9 +961,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					{
 						ttyputmsg(_("Facet %s, node %s: cannot hold outline information"),
 							describenodeproto(np), describenodeinst(ni));
-						(*warnings)++;
 						nextchangequiet();
 						(void)delvalkey((INTBIG)ni, VNODEINST, el_trace);
+						(*warnings)++;
+						curlib->userbits |= LIBCHANGEDMAJOR;
 					} else
 					{
 						/* ensure points in different locations */
@@ -911,9 +976,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						{
 							ttyputmsg(_("Facet %s, node %s: zero-size outline (has %ld points)"),
 								describenodeproto(np), describenodeinst(ni), len);
-							(*warnings)++;
 							nextchangequiet();
 							(void)delvalkey((INTBIG)ni, VNODEINST, el_trace);
+							(*warnings)++;
+							curlib->userbits |= LIBCHANGEDMAJOR;
 						}
 					}
 				}
@@ -924,8 +990,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s, node %s: incorrect visibility"),
 						describenodeproto(np), describenodeinst(ni));
-					(*warnings)++;
 					ni->userbits = (ni->userbits & ~WIPED) | wiped;
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 
@@ -935,10 +1002,11 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				ttyputmsg(_("Facet %s, node %s: strange orientation"), describenodeproto(np),
 					describenodeinst(ni));
-				(*warnings)++;
 				if (ni->transpose != 0) ni->transpose = 1;
 				ni->rotation = ni->rotation % 3600;
 				if (ni->rotation < 0) ni->rotation += 3600;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check the arc connections on this nodeinst */
@@ -954,6 +1022,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportarcinst = pi->nextportarcinst; else
 							lpi->nextportarcinst = pi->nextportarcinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -968,6 +1037,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportarcinst = pi->nextportarcinst; else
 							lpi->nextportarcinst = pi->nextportarcinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -980,6 +1050,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportarcinst = pi->nextportarcinst; else
 							lpi->nextportarcinst = pi->nextportarcinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -994,6 +1065,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportarcinst = pi->nextportarcinst; else
 							lpi->nextportarcinst = pi->nextportarcinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 				lpi = pi;
@@ -1001,9 +1073,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				/* check variables in the portarcinst */
 				if (us_checkvariables(&pi->numvar, pi->firstvar, curlib) != 0)
 				{
-					(*warnings)++;
 					ttyputmsg(_("    Facet %s, node %s, port %s"), describenodeproto(np),
 						describenodeinst(ni), pp->protoname);
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 
@@ -1026,6 +1099,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						db_addportarcinst(ni, lpi);
 					}
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					break;
 				}
 			}
@@ -1043,6 +1117,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportexpinst = pe->nextportexpinst; else
 							lpe->nextportexpinst = pe->nextportexpinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -1057,6 +1132,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportexpinst = pe->nextportexpinst; else
 							lpe->nextportexpinst = pe->nextportexpinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -1069,6 +1145,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ni->firstportexpinst = pe->nextportexpinst; else
 							lpe->nextportexpinst = pe->nextportexpinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 
@@ -1079,12 +1156,12 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s, node %s: export %s bad"), describenodeproto(np),
 						describenodeinst(ni), pe->exportproto->protoname);
-					(*warnings)++;
 					if (lpe == NOPORTEXPINST)
 						ni->firstportexpinst = pe->nextportexpinst; else
 							lpe->nextportexpinst = pe->nextportexpinst;
 					lpe = pe->nextportexpinst;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					continue;
 				}
 				lpe = pe;
@@ -1092,9 +1169,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				/* check variables in the portexpinst */
 				if (us_checkvariables(&pe->numvar, pe->firstvar, curlib) != 0)
 				{
-					(*warnings)++;
 					ttyputmsg(_("    Facet %s, node %s, export %s"), describenodeproto(np),
 						describenodeinst(ni), pe->exportproto->protoname);
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 
@@ -1117,6 +1195,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						db_addportexpinst(ni, lpe);
 					}
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 					break;
 				}
 			}
@@ -1128,6 +1207,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenodeinst(ni));
 				ni->parent = np;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure geometry module pointer is right */
@@ -1138,6 +1218,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenodeinst(ni));
 				ni->geom->entryaddr.ni = ni;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure the geometry module is the right size */
@@ -1149,9 +1230,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenodeproto(np), describenodeinst(ni), latoa(ni->geom->lowx),
 						latoa(ni->geom->highx), latoa(ni->geom->lowy), latoa(ni->geom->highy),
 							latoa(lx), latoa(hx), latoa(ly), latoa(hy));
-				(*warnings)++;
 				ni->geom->lowx = lx;   ni->geom->highx = hx;
 				ni->geom->lowy = ly;   ni->geom->highy = hy;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* accumulate facet size information if not a "facet-center" primitive */
@@ -1163,7 +1245,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					var = &ni->firstvar[i];
 					if ((var->type&VDISPLAY) != 0 &&
-						(var->textdescript&VTINTERIOR) != 0)
+						TDGETINTERIOR(var->textdescript) != 0)
 					{
 						accumulatesize = 0;
 						break;
@@ -1203,18 +1285,21 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenodeinst(ni));
 				ni->userbits &= ~DEADN;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check variables in the nodeinst */
 			if (us_checkvariables(&ni->numvar, ni->firstvar, curlib) != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("    Facet %s, node %s"), describenodeproto(np), describenodeinst(ni));
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 			if (us_checkvariables(&ni->geom->numvar, ni->geom->firstvar, curlib) != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("    Facet %s, node geom %s"), describenodeproto(np), describenodeinst(ni));
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 
@@ -1228,31 +1313,16 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				/* make sure it has a nodeinst and portarcinst */
 				ni = ai->end[i].nodeinst;
-				if (ai->end[i].portarcinst->proto->connects == 0) ni = NONODEINST;
-				if (ni == NONODEINST)
+				pi = ai->end[i].portarcinst;
+				if (ni == NONODEINST && pi != NOPORTARCINST && pi->proto != NOPORTPROTO &&
+					pi->proto->connects != 0)
 				{
 					/* try to repair */
 					for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 					{
-						if (ai->end[i].portarcinst != NOPORTARCINST)
-						{
-							for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-							{
-								if (pi == ai->end[i].portarcinst) break;
-							}
-							if (pi != NOPORTARCINST) break;
-						} else
-						{
-							for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-							{
-								for(j=0; pp->connects[j] != NOARCPROTO; j++)
-									if (pp->connects[j] == ai->proto) break;
-								if (pp->connects[j] == NOARCPROTO) continue;
-								shapeportpoly(ni, pp, poly, 0);
-								if (isinside(ai->end[i].xpos, ai->end[i].ypos, poly) != 0) break;
-							}
-							if (pp != NOPORTPROTO) break;
-						}
+						for(lpi = ni->firstportarcinst; lpi != NOPORTARCINST; lpi = lpi->nextportarcinst)
+							if (lpi == pi) break;
+						if (lpi != NOPORTARCINST) break;
 					}
 					if (ni != NONODEINST)
 					{
@@ -1260,11 +1330,43 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ttyputmsg(_("Facet %s, arc %s: bad node end"), describenodeproto(np),
 							describearcinst(ai));
 						(*warnings)++;
-					} else
+						curlib->userbits |= LIBCHANGEDMAJOR;
+					}
+				}
+
+				if (ni == NONODEINST || pi == NOPORTARCINST || pi->proto == NOPORTPROTO ||
+					pi->proto->connects == 0)
+				{
+					/* try to repair */
+					for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+					{
+						for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+						{
+							for(j=0; pp->connects[j] != NOARCPROTO; j++)
+								if (pp->connects[j] == ai->proto) break;
+							if (pp->connects[j] == NOARCPROTO) continue;
+							shapeportpoly(ni, pp, poly, 0);
+							if (isinside(ai->end[i].xpos, ai->end[i].ypos, poly) != 0) break;
+						}
+						if (pp != NOPORTPROTO)
+						{
+							ai->end[i].nodeinst = ni;
+							if (pi == NOPORTARCINST) pi = allocportarcinst(np->cell->cluster);
+							if (pi->proto == NOPORTPROTO) pi->proto = pp;
+							if (pi->conarcinst == NOARCINST) pi->conarcinst = ai;
+							pi->nextportarcinst = ni->firstportarcinst;
+							ni->firstportarcinst = pi;
+							ttyputmsg(_("Facet %s, arc %s: bad node end port"), describenodeproto(np),
+								describearcinst(ai));
+							(*warnings)++;
+							curlib->userbits |= LIBCHANGEDMAJOR;
+							break;
+						}
+					}
+					if (ni == NONODEINST)
 					{
 						ttyputmsg(_("Facet %s, arc %s: bad node end, deleting arc"), describenodeproto(np),
 							describearcinst(ai));
-						(*warnings)++;
 						lastai = NOARCINST;
 						for(oai = np->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 						{
@@ -1273,6 +1375,8 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						}
 						if (lastai == NOARCINST) np->firstarcinst = ai->nextarcinst; else
 							lastai->nextarcinst = ai->nextarcinst;
+						(*warnings)++;
+						curlib->userbits |= LIBCHANGEDMAJOR;
 						break;
 					}
 					continue;
@@ -1317,6 +1421,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					ttyputmsg(_("Facet %s, arc %s, end %ld: missing portarcinst"),
 						describenodeproto(np), describearcinst(ai), i);
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 
 				/* make sure nodeinst is not dead */
@@ -1326,6 +1431,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						describearcinst(ai));
 					ai->end[i].nodeinst->userbits &= ~DEADN;
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 
 				/* make sure the nodeinst resides in this facet */
@@ -1365,6 +1471,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ai->proto = el_technologies->firstarcproto;
 					}
 					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 
 				shapeportpoly(ai->end[i].nodeinst, ai->end[i].portarcinst->proto, poly, 0);
@@ -1385,6 +1492,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 						ttyputmsg(_("Facet %s, arc %s: end %ld not in port"), describenodeproto(np),
 							describearcinst(ai), i);
 						(*warnings)++;
+						curlib->userbits |= LIBCHANGEDMAJOR;
 					}
 				}
 			}
@@ -1397,6 +1505,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describearcinst(ai));
 				ai->geom->entryaddr.ai = ai;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check arcinst length */
@@ -1407,6 +1516,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describearcinst(ai), latoa(ai->length));
 				ai->length = i;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check arcinst width */
@@ -1416,6 +1526,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describearcinst(ai));
 				ai->width = -ai->width;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check arcinst end shrinkage value */
@@ -1424,6 +1535,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s, arc %s: bad endshrink value"), describenodeproto(np),
 					describearcinst(ai));
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure the geometry module is the right size */
@@ -1433,9 +1545,10 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				ttyputmsg(_("Facet %s, arc %s: geometry size bad"), describenodeproto(np),
 					describearcinst(ai));
-				(*warnings)++;
 				ai->geom->lowx = lx;   ai->geom->highx = hx;
 				ai->geom->lowy = ly;   ai->geom->highy = hy;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* accumulate facet size information */
@@ -1464,6 +1577,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describearcinst(ai));
 				ai->parent = np;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* make sure the arcinst isn't dead */
@@ -1472,18 +1586,21 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				ttyputmsg(_("Facet %s, arc %s: dead arc"), describenodeproto(np), describearcinst(ai));
 				ai->userbits &= ~DEADA;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
 			/* check variables in the arcinst */
 			if (us_checkvariables(&ai->numvar, ai->firstvar, curlib) != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("    Facet %s, arc %s"), describenodeproto(np), describearcinst(ai));
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 			if (us_checkvariables(&ai->geom->numvar, ai->geom->firstvar, curlib) != 0)
 			{
-				(*warnings)++;
 				ttyputmsg(_("    Facet %s, arc geom %s"), describenodeproto(np), describearcinst(ai));
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 
@@ -1496,10 +1613,13 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			np->lowx = totlx;   np->highx = tothx;
 			np->lowy = totly;   np->highy = tothy;
 			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* check the R-tree in this facet */
 		problems = us_checkrtree(NORTNODE, np->rtree, np, warnings, errors);
+		if (problems != 0)
+			curlib->userbits |= LIBCHANGEDMAJOR;
 
 		/* complete R-tree check by ensuring that all "temp1" were set */
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1531,8 +1651,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			np->rtree->highx = truehx;
 			np->rtree->lowy = truely;
 			np->rtree->highy = truehy;
-			(*warnings)++;
 			problems++;
+			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* if there were R-Tree problems, rebuild it */
@@ -1552,7 +1673,7 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 	}
 
 	/* check network information */
-	if ((net_aid->aidstate&AIDON) == 0) return;
+	if ((net_tool->toolstate&TOOLON) == 0) return;
 	neterrors = 0;
 	for(np = curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
@@ -1569,8 +1690,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			if (pp->network == NONETWORK)
 			{
 				ttyputmsg(_("Facet %s, port %s: no network"), describenodeproto(np), pp->protoname);
-				(*warnings)++;
 				neterrors++;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			} else pp->network->temp2++;
 		}
 
@@ -1583,8 +1705,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s, arc %s: no network"), describenodeproto(np),
 						describearcinst(ai));
-					(*warnings)++;
 					neterrors++;
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			} else
 			{
@@ -1593,12 +1716,36 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s, arc %s: not a bus but network %s is"), describenodeproto(np),
 						describearcinst(ai), describenetwork(ai->network));
-					(*warnings)++;
 					neterrors++;
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 				ai->network->temp1++;
 			}
 			ai->temp1 = 0;
+
+			/* make sure width of bus is the same as the port */
+			if (ai->proto == sch_busarc)
+			{
+				for(i=0; i<2; i++)
+				{
+					ni = ai->end[i].nodeinst;
+					if (ni->proto->primindex == 0)
+					{
+						pi = ai->end[i].portarcinst;
+						if (ai->network->signals !=
+							pi->proto->network->signals)
+						{
+							ttyputmsg(_("Facet %s, arc %s: is %d wide but port is %d"),
+								describenodeproto(np), describearcinst(ai), ai->network->signals,
+									pi->proto->network->signals);
+							neterrors++;
+							(*warnings)++;
+							curlib->userbits |= LIBCHANGEDMAJOR;
+						}
+					}
+				}
+			}
 		}
 
 		/* check port and arc reference counts, prepare for arc counts */
@@ -1611,15 +1758,17 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				ttyputmsg(_("Facet %s, network %s: reference count wrong"), describenodeproto(np),
 					describenetwork(net));
-				(*warnings)++;
 				neterrors++;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 			if (net->portcount != net->temp2)
 			{
 				ttyputmsg(_("Facet %s, network %s: port count wrong"), describenodeproto(np),
 					describenetwork(net));
-				(*warnings)++;
 				neterrors++;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 
@@ -1631,8 +1780,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 			{
 				ttyputmsg(_("Facet %s, arc %s: described by %ld networks"), describenodeproto(np),
 					describearcinst(ai), ai->temp1);
-				(*warnings)++;
 				neterrors++;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 			if (ai->network->namecount > 0)
 			{
@@ -1640,8 +1790,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 				{
 					ttyputmsg(_("Facet %s, arc %s: on network but has no name"), describenodeproto(np),
 						describearcinst(ai));
-					(*warnings)++;
 					neterrors++;
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
 				}
 			}
 		}
@@ -1659,8 +1810,9 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 		{
 			ttyputmsg(_("Facet %s, network %s: bus link count wrong"), describenodeproto(np),
 				describenetwork(net));
-			(*warnings)++;
 			neterrors++;
+			(*warnings)++;
+			curlib->userbits |= LIBCHANGEDMAJOR;
 		}
 
 		/* miscellaneous checks */
@@ -1672,16 +1824,18 @@ void us_checklibrary(LIBRARY *curlib, INTSML verbose, INTBIG *warnings, INTBIG *
 					describenetwork(net));
 				neterrors++;
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 			if (us_checkvariables(&net->numvar, net->firstvar, curlib) != 0)
 			{
 				ttyputmsg(_("    Facet %s, network %s"), describenodeproto(np), describenetwork(net));
 				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 		}
 	}
 
-	if (neterrors != 0) (void)askaid(net_aid, "total-re-number", (INTBIG)curlib);
+	if (neterrors != 0) (void)asktool(net_tool, "total-re-number");
 }
 
 INTSML us_checkvariables(INTSML *numvar, VARIABLE *firstvar, LIBRARY *olib)
@@ -1713,6 +1867,7 @@ INTSML us_checkvariables(INTSML *numvar, VARIABLE *firstvar, LIBRARY *olib)
 				firstvar[j].addr = firstvar[j+1].addr;
 			}
 			errors++;
+			continue;
 		}
 
 		/* check validity of certain pointer variables */
@@ -1759,11 +1914,38 @@ INTSML us_checkvariables(INTSML *numvar, VARIABLE *firstvar, LIBRARY *olib)
 				}
 			}
 		}
+		if ((ty&VDISPLAY) != 0 &&
+			us_checktextdescript(firstvar[i].textdescript) != 0)
+		{
+			ttyputmsg(_("  Field '%s' of:"), makename(firstvar[i].key));
+			errors++;
+		}
 	}
 	if (errors != 0) return(1);
 	return(0);
 }
 
+/*
+ * Routine to check the text descriptor field in "descript" and return nonzero if there
+ * are errors.
+ */
+INTSML us_checktextdescript(UINTBIG *descript)
+{
+	INTBIG face, maxfaces;
+	char **facelist;
+
+	if (graphicshas(CANCHOOSEFACES) == 0) return(0);
+	face = TDGETFACE(descript);
+	maxfaces = screengetfacelist(&facelist);
+	if (face >= maxfaces)
+	{
+		TDSETFACE(descript, 0);
+		ttyputmsg(_("Bad face part of textdescript (%d) on:"), face);
+		return(1);
+	}
+	return(0);
+}
+
 /*
  * routine to recursively check the R-tree structure at "rtn".  The expected
  * R-tree parent is "expectedparent" and the facet containing this structure
