@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomab.c
- * User interface aid: command handler for A through B
+ * User interface tool: command handler for A through B
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -298,7 +298,7 @@ void us_arc(INTSML count, char *par[])
 	} else if (namesamen(pp, "shorten", l) == 0 && l >= 2)
 	{
 		/* get the necessary polygon */
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 		l = 0;
 		for(i=0; list[i] != NOGEOM; i++)
@@ -487,13 +487,6 @@ void us_array(INTSML count, char *par[])
 		us_abortcommand(_("Diagonal arrays need one dimension to be 1"));
 		return;
 	}
-#if 0
-	if ((centerx != 0 && (xsize&1) == 0) || (centery != 0 && (ysize&1) == 0))
-	{
-		us_abortcommand(_("When centering the array, the size must be odd"));
-		return;
-	}
-#endif
 
 	/* mark the list of nodes and arcs in the facet that will be arrayed */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -695,9 +688,9 @@ void us_array(INTSML count, char *par[])
 				(void)us_pophighlight(0);
 				return;
 			}
-			keepbits = NEXPAND | HARDSELECTN;
+			keepbits = NEXPAND | HARDSELECTN | NTECHBITS;
 			newno->userbits = (newno->userbits & ~keepbits) | (ni->userbits & keepbits);
-			(void)copyvars((INTBIG)ni, VNODEINST, (INTBIG)newno, VNODEINST);
+			(void)us_copyvars((INTBIG)ni, VNODEINST, (INTBIG)newno, VNODEINST);
 			if (noname == 0)
 			{
 				objname = "";
@@ -714,13 +707,12 @@ void us_array(INTSML count, char *par[])
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
 				{
-					var->textdescript = (var->textdescript & ~VTSIZE) |
-						(defaulttextsize(3) << VTSIZESH);
+					defaulttextsize(3, var->textdescript);
 
 					/* shift text down if on a facet instance */
 					if (ni->proto->primindex == 0)
 					{
-						var->textdescript = us_setdescriptoffset(var->textdescript,
+						us_setdescriptoffset(var->textdescript,
 							0, (ni->highy-ni->lowy) / el_curlib->lambda[el_curtech->techindex]);
 					}
 				}
@@ -782,7 +774,7 @@ void us_array(INTSML count, char *par[])
 				(void)us_pophighlight(0);
 				return;
 			}
-			(void)copyvars((INTBIG)ai, VARCINST, (INTBIG)newai, VARCINST);
+			(void)us_copyvars((INTBIG)ai, VARCINST, (INTBIG)newai, VARCINST);
 			if (noname == 0)
 			{
 				objname = "";
@@ -798,8 +790,7 @@ void us_array(INTSML count, char *par[])
 				var = setvalkey((INTBIG)newai, VARCINST, el_arc_name,
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
-					var->textdescript = (var->textdescript & ~VTSIZE) |
-						(defaulttextsize(4) << VTSIZESH);
+					defaulttextsize(4, var->textdescript);
 			}
 			endobjectchange((INTBIG)newai, VARCINST);
 		}
@@ -826,13 +817,12 @@ void us_array(INTSML count, char *par[])
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 			{
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 
 				/* shift text down if on a facet instance */
 				if (ni->proto->primindex == 0)
 				{
-					var->textdescript = us_setdescriptoffset(var->textdescript,
+					us_setdescriptoffset(var->textdescript,
 						0, (ni->highy-ni->lowy) / el_curlib->lambda[el_curtech->techindex]);
 				}
 			}
@@ -855,8 +845,7 @@ void us_array(INTSML count, char *par[])
 				(void)sprintf(totalname, "%s%ld-%ld", objname, originalx, originaly);
 			var = setvalkey((INTBIG)ai, VARCINST, el_arc_name, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(4) << VTSIZESH);
+				defaulttextsize(4, var->textdescript);
 			endobjectchange((INTBIG)ai, VARCINST);
 		}
 	}
@@ -911,11 +900,11 @@ void us_bind(INTSML count, char *par[])
 	{
 		if (negated == 0)
 		{
-			us_aid->aidstate |= ECHOBIND;
+			us_tool->toolstate |= ECHOBIND;
 			ttyputverbose(M_("Key/menu/button commands echoed"));
 		} else
 		{
-			us_aid->aidstate &= ~ECHOBIND;
+			us_tool->toolstate &= ~ECHOBIND;
 			ttyputverbose(M_("Key/menu/button commands not echoed"));
 		}
 		return;
@@ -960,11 +949,11 @@ void us_bind(INTSML count, char *par[])
 				us_abortcommand(_("Button %s unknown"), pp);
 				return;
 			}
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_buttons);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_buttons);
 			if (var == NOVARIABLE) return;
 			us_parsebinding(((char **)var->addr)[but], &commandbinding);
 			if (*commandbinding.command == 0) commandbinding.command = "-";
-			(void)setval((INTBIG)us_aid, VAID, us_commandvarname(*letter),
+			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
@@ -978,11 +967,11 @@ void us_bind(INTSML count, char *par[])
 			}
 			pp = par[3];
 			key = *pp & 255;
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_keys);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_keys);
 			if (var == NOVARIABLE) return;
 			us_parsebinding(((char **)var->addr)[key], &commandbinding);
 			if (*commandbinding.command == 0) commandbinding.command = "-";
-			(void)setval((INTBIG)us_aid, VAID, us_commandvarname(*letter),
+			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
@@ -1001,14 +990,14 @@ void us_bind(INTSML count, char *par[])
 				us_abortcommand(_("Index of menu entry out of range"));
 				return;
 			}
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 			if (var == NOVARIABLE) return;
 			if (us_menupos <= 1)
 				str = ((char **)var->addr)[y * us_menux + x]; else
 					str = ((char **)var->addr)[x * us_menuy + y];
 			us_parsebinding(str, &commandbinding);
 			if (*commandbinding.command == 0) commandbinding.command = "-";
-			(void)setval((INTBIG)us_aid, VAID, us_commandvarname(*letter),
+			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
@@ -1042,7 +1031,7 @@ void us_bind(INTSML count, char *par[])
 				(void)us_appendargs(rb);
 				pp = returninfstr();
 			}
-			(void)setval((INTBIG)us_aid, VAID, us_commandvarname(*letter),
+			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)pp, VSTRING|VDONTSAVE);
 			return;
 		}
@@ -1068,7 +1057,7 @@ void us_bind(INTSML count, char *par[])
 		arcglyph = NOARCPROTO;
 		backgroundcolor = 0;
 		menumessage = 0;
-		menumessagesize = TXT20P;
+		menumessagesize = TXTSETPOINTS(20);
 
 		if (namesamen(pp, "button", l) == 0 && l >= 1)
 		{
@@ -1198,7 +1187,7 @@ void us_bind(INTSML count, char *par[])
 				}
 				if (namesamen(pp, "textsize", l) == 0)
 				{
-					menumessagesize = (INTSML)us_gettextsize(par[3], TXT4L);
+					menumessagesize = (INTSML)us_gettextsize(par[3], TXTSETQLAMBDA(12));
 					count -= 2;
 					par += 2;
 					continue;
@@ -1290,7 +1279,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (key != 0 && us_islasteval(key))
 			{
-				us_abortcommand(_("Cannot un-bind the last 'tellaid user' key"));
+				us_abortcommand(_("Cannot un-bind the last 'telltool user' key"));
 				return;
 			}
 			(void)initinfstr();
@@ -1312,7 +1301,7 @@ void us_bind(INTSML count, char *par[])
 				(void)addstringtoinfstr("\" ");
 			}
 			(void)addstringtoinfstr("command=");
-			(void)setindkey((INTBIG)us_aid, VAID, varkey, bindex, (INTBIG)returninfstr());
+			(void)setindkey((INTBIG)us_tool, VTOOL, varkey, bindex, (INTBIG)returninfstr());
 			return;
 		}
 
@@ -1323,13 +1312,13 @@ void us_bind(INTSML count, char *par[])
 			return;
 		}
 
-		/* special case: cannot rebind the last "tellaid user" */
-		if (i >= us_longcount || strcmp(us_lcommand[i].name, "tellaid") != 0 ||
+		/* special case: cannot rebind the last "telltool user" */
+		if (i >= us_longcount || strcmp(us_lcommand[i].name, "telltool") != 0 ||
 			newcount != 1 || strcmp(a[1], "user") != 0)
 		{
 			if (key != 0 && us_islasteval(key))
 			{
-				us_abortcommand(_("Cannot re-bind the last 'tellaid user' key"));
+				us_abortcommand(_("Cannot re-bind the last 'telltool user' key"));
 				return;
 			}
 		}
@@ -1396,7 +1385,7 @@ void us_bind(INTSML count, char *par[])
 			if (j != important) (void)addtoinfstr(' ');
 			(void)addstringtoinfstr(par[j]);
 		}
-		(void)setindkey((INTBIG)us_aid, VAID, varkey, bindex, (INTBIG)returninfstr());
+		(void)setindkey((INTBIG)us_tool, VTOOL, varkey, bindex, (INTBIG)returninfstr());
 		if (popup > 0) us_setkeyequiv(pm, bindex);
 		return;
 	}
