@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomcd.c
- * User interface aid: command handler for C through D
+ * User interface tool: command handler for C through D
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -41,7 +41,7 @@
 #include <math.h>
 
 #define MAXLINE	   200		/* max characters on color map input line */
-struct {
+static struct {
 	INTSML bits;
 	INTSML set;
 } us_overlappables[] =
@@ -146,9 +146,9 @@ void us_color(INTSML count, char *par[])
 		}
 
 		/* get the color map */
-		varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-		vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-		varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+		varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+		vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+		varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputerr(_("Cannot get current color map"));
@@ -182,14 +182,14 @@ void us_color(INTSML count, char *par[])
 		}
 
 		/* set the new color map */
-		startobjectchange((INTBIG)us_aid, VAID);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_red, (INTBIG)redt,
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_red, (INTBIG)redt,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_green, (INTBIG)greent,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_green, (INTBIG)greent,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_blue, (INTBIG)bluet,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_blue, (INTBIG)bluet,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 		return;
 	}
 
@@ -230,9 +230,9 @@ void us_color(INTSML count, char *par[])
 		}
 
 		/* get color arrays */
-		varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-		vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-		varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+		varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+		vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+		varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputerr(_("Cannot get current color map"));
@@ -393,14 +393,14 @@ void us_color(INTSML count, char *par[])
 		}
 
 		/* set the color map */
-		startobjectchange((INTBIG)us_aid, VAID);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_red, (INTBIG)redt,
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_red, (INTBIG)redt,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_green, (INTBIG)greent,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_green, (INTBIG)greent,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_blue, (INTBIG)bluet,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_blue, (INTBIG)bluet,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* now get the bit-map information */
 		if (xfgets(line, MAXLINE, f))
@@ -459,9 +459,9 @@ void us_color(INTSML count, char *par[])
 		orig = par[1];
 
 		/* get color arrays */
-		varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-		vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-		varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+		varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+		vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+		varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputerr(_("Cannot get current color map"));
@@ -585,7 +585,7 @@ void us_constraint(INTSML count, char *par[])
 			return;
 		}
 		us_clearhighlightcount();
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_constraint,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_constraint,
 			(INTBIG)&el_constraints[c], VCONSTRAINT|VDONTSAVE);
 		ttyputmsg(M_("Switching to %s"), _(el_constraints[c].condesc));
 		return;
@@ -687,7 +687,7 @@ void us_copyfacet(INTSML count, char *par[])
 		}
 
 		/* generate the icon */
-		onp = us_makeiconfacet(np->firstportproto, np->cell->cellname, pt, np->tech, tolib);
+		onp = us_makeiconfacet(np->firstportproto, np->cell->cellname, pt, tolib);
 		if (onp == NONODEPROTO) return;
 		if (quiet == 0)
 			ttyputmsg(_("Facet %s created with an iconic representation of %s"),
@@ -778,22 +778,22 @@ void us_create(INTSML count, char *par[])
 	REGISTER INTSML ang, l, remainhighlighted, ishor, isver, getcontents,
 		pangle, join, waitfordown, angledcreate;
 	REGISTER INTBIG bestdist, bestdist1, bestdist2, wid, truewid, i, j, k,
-		bits1, bits2, dist, overcount;
+		bits1, bits2, dist;
 	INTBIG px, py, nx, ny, cx, cy, x, y, xp[2], yp[2], xcur, ycur, otheralign, pxs, pys,
-		cornerx[4], cornery[4], overx[2], overy[2], lx, hx, ly, hy, flx, fhx, fly, fhy,
-		tlx, tly, thx, thy;
+		lx, hx, ly, hy;
 	PORTPROTO *app[2];
 	REGISTER VARIABLE *var;
-	static POLYGON *poly = NOPOLYGON;
+	static POLYGON *poly = NOPOLYGON, *poly2 = NOPOLYGON;
 	ARCINST *alt1, *alt2;
 	extern COMCOMP us_createxp, us_createyp;
-	char *oldarcname;
+	char *oldarcname, *newpar[2];
 	HIGHLIGHT newhigh;
 	REGISTER GEOM *foundgeom, *geom;
 	GEOM *fromgeom, *togeom;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
+	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, us_tool->cluster);
 
 	/* make sure there is a facet being edited */
 	if (us_needwindow() != 0) return;
@@ -907,9 +907,9 @@ void us_create(INTSML count, char *par[])
 			/* get placement angle */
 			pangle = us_getplacementangle(np);
 
-			if ((us_aid->aidstate&INTERACTIVE) != 0)
+			if ((us_tool->toolstate&INTERACTIVE) != 0)
 			{
-				us_createinit(0, 0, np, pangle, 0);
+				us_createinit(0, 0, np, pangle, 0, NOGEOM, NOPORTPROTO);
 				trackcursor(waitfordown, us_ignoreup, us_createbegin, us_dragdown,
 					us_stoponchar, us_dragup, TRACKDRAGGING);
 				if (el_pleasestop != 0) return;
@@ -968,7 +968,7 @@ void us_create(INTSML count, char *par[])
 		if (us_canedit(curfacet, NONODEPROTO, 1) != 0) return;
 
 		/* find the closest port to the cursor */
-		var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 		if (var != NOVARIABLE)
 			(void)us_makehighlight(((char **)var->addr)[0], &newhigh);
 		bestdist1 = bestdist2 = MAXINTBIG;
@@ -1099,122 +1099,24 @@ void us_create(INTSML count, char *par[])
 				closestpoint(poly, &x, &y);
 				break;
 		}
-		if ((us_aid->aidstate&INTERACTIVE) != 0)
+		if ((us_tool->toolstate&INTERACTIVE) != 0)
 		{
-			us_createinit(x-px+cx, y-py+cy, np, ang, join);
+			fromgeom = ni->geom;
+			us_createinit(x-px+cx, y-py+cy, np, ang, join, fromgeom, ppt);
 			trackcursor(waitfordown, us_ignoreup, us_createabegin, us_createadown,
 				us_stoponchar, us_createaup, TRACKDRAGGING);
 			if (el_pleasestop != 0) return;
 			if (us_demandxy(&xcur, &ycur) != 0) return;
-			gridalign(&xcur, &ycur, us_alignment);
 			if (join != 0)
 			{
 				us_createajoinedobject(&togeom, &toport);
 				if (togeom != NOGEOM)
 				{
-					/* user dragged over another object: connect them */
-					fromgeom = ni->geom;
-					if (us_getnodeonarcinst(&togeom, &toport, fromgeom,
-						ppt, xcur, ycur) == NONODEINST) return;
-					if (toport == NOPORTPROTO)
-					{
-						us_abortcommand(_("Cannot connect to %s: it has no ports"),
-							geomname(togeom));
+					if (us_figuredrawpath(fromgeom, ppt, togeom, toport, &xcur, &ycur) != 0)
 						return;
-					}
 					us_clearhighlightcount();
-
-					/* change cursor according to port angle */
-					lx = mini(fromgeom->lowx, togeom->lowx);
-					hx = maxi(fromgeom->highx, togeom->highx);
-					ly = mini(fromgeom->lowy, togeom->lowy);
-					hy = maxi(fromgeom->highy, togeom->highy);
-					dist = maxi(hx-lx, hy-ly);
-					overcount = 0;
-					if (((ppt->userbits&PORTARANGE) >> PORTARANGESH) != 180)
-					{
-						k = us_bottomrecurse(fromgeom->entryaddr.ni, ppt) % 3600;
-						if (k < 0) k += 3600;
-						overx[overcount] = (fromgeom->lowx+fromgeom->highx)/2 + mult(cosine((INTSML)k), dist);
-						overy[overcount] = (fromgeom->lowy+fromgeom->highy)/2 + mult(sine((INTSML)k), dist);
-						overcount++;
-					}
-					if (((toport->userbits&PORTARANGE) >> PORTARANGESH) != 180)
-					{
-						k = us_bottomrecurse(togeom->entryaddr.ni, toport) % 3600;
-						if (k < 0) k += 3600;
-						overx[overcount] = (togeom->lowx+togeom->highx)/2 + mult(cosine((INTSML)k), dist);
-						overy[overcount] = (togeom->lowy+togeom->highy)/2 + mult(sine((INTSML)k), dist);
-						overcount++;
-					}
-					if (overcount == 2)
-					{
-						pxs = (overx[0] + overx[1]) / 2;
-						pys = (overy[0] + overy[1]) / 2;
-					} else
-					{
-						pxs = (fromgeom->lowx + fromgeom->highx) / 2;
-						pys = (togeom->lowy + togeom->highy) / 2;
-						if (overcount > 0)
-						{
-							pxs = overx[0];   pys = overy[0];
-						}
-						cornerx[0] = lx-1;   cornery[0] = ly-1;
-						cornerx[1] = lx-1;   cornery[1] = hy+1;
-						cornerx[2] = hx+1;   cornery[2] = hy+1;
-						cornerx[3] = hx+1;   cornery[3] = ly-1;
-						for(i=0; i<4; i++)
-						{
-							dist = abs(cornerx[i]-pxs) + abs(cornery[i]-pys);
-							if (i == 0 || dist < bestdist)
-							{
-								bestdist = dist;
-								j = i;
-							}
-						}
-						pxs = cornerx[j]*2 - (lx+hx)/2;
-						pys = cornery[j]*2 - (ly+hy)/2;
-
-						/* set coordinate in the center if the ports overlap in either axis */
-						if (newhigh.fromport != NOPORTPROTO)
-						{
-							shapeportpoly(ni, newhigh.fromport, poly, 0);
-							getbbox(poly, &flx, &fhx, &fly, &fhy);
-							shapeportpoly(togeom->entryaddr.ni, toport, poly, 0);
-							getbbox(poly, &tlx, &thx, &tly, &thy);
-							lx = maxi(flx, tlx);   hx = mini(fhx, thx);
-							ly = maxi(fly, tly);   hy = mini(fhy, thy);
-							if (lx <= hx || ly <= hy)
-							{
-								pxs = (lx + hx) / 2;
-								pys = (ly + hy) / 2;
-							}
-						}
-					}
-
-					/* isolated ports simply use cursor location */
-					if ((newhigh.fromport != NOPORTPROTO &&
-						(newhigh.fromport->userbits&PORTISOLATED) != 0) ||
-							(toport->userbits&PORTISOLATED) != 0)
-					{
-						portposition(ni, newhigh.fromport, &lx, &ly);
-						portposition(togeom->entryaddr.ni, toport, &hx, &hy);
-						if (hx < lx)
-						{
-							x = lx;   lx = hx;   hx = x;
-						}
-						if (hy < ly)
-						{
-							y = ly;   ly = hy;   hy = y;
-						}
-
-						/* if cursor location is within range of ports, use it */
-						if (xcur >= lx && xcur <= hx) pxs = xcur;
-						if (ycur >= ly && ycur <= hy) pys = ycur;
-					}
-
 					ai = aconnect(fromgeom, ppt, togeom, toport, us_curarcproto,
-						pxs, pys, &alt1, &alt2, ang, 0);
+						xcur, ycur, &alt1, &alt2, ang, 0);
 					if (ai == NOARCINST) return;
 
 					/* if an arc was highlighted and it got broken, fix the highlight */
@@ -1232,6 +1134,7 @@ void us_create(INTSML count, char *par[])
 					return;
 				}
 			}
+			gridalign(&xcur, &ycur, us_alignment);
 		}
 
 		/* determine the proper point on the polygon to draw radials */
@@ -1398,6 +1301,63 @@ void us_create(INTSML count, char *par[])
 		return;
 	}
 
+	/* handle the creation of an icon */
+	if (namesamen(par[0], "icon", l) == 0 && l >= 2)
+	{
+		/* find the icon for the current facet */
+		np = iconview(curfacet);
+		if (np == NONODEPROTO)
+		{
+			us_abortcommand(_("No icon view for facet %s"),
+				describenodeproto(curfacet));
+			return;
+		}
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_icon_style");
+		if (var != NOVARIABLE) j = var->addr; else j = ICONSTYLEDEFAULT;
+		i = (j & ICONINSTLOC) >> ICONINSTLOCSH;
+		px = np->highx - np->lowx;
+		py = np->highy - np->lowy;
+		switch (i)
+		{
+			case 0:		/* upper-right */
+				hx = curfacet->highx;   lx = hx - px;
+				hy = curfacet->highy;   ly = hy - py;
+				break;
+			case 1:		/* upper-left */
+				lx = curfacet->lowx;    hx = lx + px;
+				hy = curfacet->highy;   ly = hy - py;
+				break;
+			case 2:		/* lower-right */
+				hx = curfacet->highx;   lx = hx - px;
+				ly = curfacet->lowy;    hy = ly + py;
+				break;
+			case 3:		/* lower-left */
+				lx = curfacet->lowx;    hx = lx + px;
+				ly = curfacet->lowy;    hy = ly + py;
+				break;
+		}
+		ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, curfacet);
+		if (ni != NONODEINST)
+		{
+			ni->userbits |= NEXPAND;
+			endobjectchange((INTBIG)ni, VNODEINST);
+			us_clearhighlightcount();
+			newhigh.status = HIGHFROM;
+			newhigh.facet = curfacet;
+			newhigh.fromgeom = ni->geom;
+			newhigh.fromport = NOPORTPROTO;
+			newhigh.frompoint = 0;
+			(void)us_addhighlight(&newhigh);
+			if (lx > el_curwindowpart->screenhx || hx < el_curwindowpart->screenlx ||
+				ly > el_curwindowpart->screenhy || hy < el_curwindowpart->screenly)
+			{
+				newpar[0] = "center-highlight";
+				us_window(1, newpar);
+			}
+		}
+		return;
+	}
+
 	/* handle the absolute placement option */
 	if (namesamen(par[0], "to", l) == 0 && l >= 1)
 	{
@@ -1457,7 +1417,7 @@ void us_create(INTSML count, char *par[])
 		return;
 	}
 
-	if (namesamen(par[0], "insert", l) == 0 && l >= 1)
+	if (namesamen(par[0], "insert", l) == 0 && l >= 2)
 	{
 		if (us_demandxy(&xcur, &ycur)) return;
 		gridalign(&xcur, &ycur, us_alignment);
@@ -1479,7 +1439,7 @@ void us_create(INTSML count, char *par[])
 		if ((us_state&NONPERSISTENTCURNODE) != 0) us_setnodeproto(np);
 
 		/* adjust position interactively if possible */
-		if ((us_aid->aidstate&INTERACTIVE) != 0)
+		if ((us_tool->toolstate&INTERACTIVE) != 0)
 		{
 			us_createinsinit(ai, np);
 			trackcursor(waitfordown, us_ignoreup, us_createabegin, us_createinsdown,
@@ -1599,7 +1559,7 @@ void us_create(INTSML count, char *par[])
 		if (var == NOVARIABLE) oldarcname = 0; else
 		{
 			(void)allocstring(&oldarcname, (char *)var->addr, el_tempcluster);
-			(void)askaid(net_aid, "delname", (INTBIG)oldarcname,
+			(void)asktool(net_tool, "delname", (INTBIG)oldarcname,
 				(INTBIG)curfacet);
 		}
 		startobjectchange((INTBIG)ai, VARCINST);
@@ -1609,11 +1569,10 @@ void us_create(INTSML count, char *par[])
 		newai = newarcinst(ap, wid, bits1, ani[0], app[0], xp[0], yp[0], ni, pp1, nx, ny, curfacet);
 		if (oldarcname != 0 && newai != NOARCINST)
 		{
-			(void)askaid(net_aid, "setname", (INTBIG)newai, (INTBIG)oldarcname);
+			(void)asktool(net_tool, "setname", (INTBIG)newai, (INTBIG)oldarcname);
 			var = setvalkey((INTBIG)newai, VARCINST, el_arc_name, (INTBIG)oldarcname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(4) << VTSIZESH);
+				defaulttextsize(4, var->textdescript);
 			efree(oldarcname);
 		}
 		if (newai != NOARCINST) endobjectchange((INTBIG)newai, VARCINST);
@@ -1653,7 +1612,7 @@ void us_create(INTSML count, char *par[])
 		if ((us_state&NONPERSISTENTCURNODE) != 0) us_setnodeproto(np);
 
 		/* adjust position interactively if possible */
-		if ((us_aid->aidstate&INTERACTIVE) != 0)
+		if ((us_tool->toolstate&INTERACTIVE) != 0)
 		{
 			us_createinsinit(ai, np);
 			trackcursor(waitfordown, us_ignoreup, us_createabegin, us_createinsdown,
@@ -1735,7 +1694,7 @@ void us_create(INTSML count, char *par[])
 		if (var == NOVARIABLE) oldarcname = 0; else
 		{
 			(void)allocstring(&oldarcname, (char *)var->addr, el_tempcluster);
-			(void)askaid(net_aid, "delname", (INTBIG)oldarcname,
+			(void)asktool(net_tool, "delname", (INTBIG)oldarcname,
 				(INTBIG)curfacet);
 		}
 		startobjectchange((INTBIG)ai, VARCINST);
@@ -1745,11 +1704,10 @@ void us_create(INTSML count, char *par[])
 		newai = newarcinst(ap, wid, bits1, ani[0], app[0], xp[0], yp[0], ni, ppt, nx, ny, curfacet);
 		if (oldarcname != 0 && newai != NOARCINST)
 		{
-			(void)askaid(net_aid, "setname", (INTBIG)newai, (INTBIG)oldarcname);
+			(void)asktool(net_tool, "setname", (INTBIG)newai, (INTBIG)oldarcname);
 			var = setvalkey((INTBIG)newai, VARCINST, el_arc_name, (INTBIG)oldarcname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(4) << VTSIZESH);
+				defaulttextsize(4, var->textdescript);
 			efree(oldarcname);
 		}
 		if (newai != NOARCINST) endobjectchange((INTBIG)newai, VARCINST);
@@ -1837,6 +1795,60 @@ void us_debug(INTSML count, char *par[])
 	if (count == 0) return;
 	l = strlen(par[0]);
 
+#if 1	/* reverse length and width on schematic transistors */
+	if (namesamen(par[0], "ivan", l) == 0)
+	{
+		VARIABLE *varl, *varw;
+		INTBIG type, addr, ltype, wtype;
+		char lenstr[200], widstr[200];
+		UINTBIG ldescript[TEXTDESCRIPTSIZE], wdescript[TEXTDESCRIPTSIZE];
+
+		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+		{
+			for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			{
+				for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				{
+					if (ni->proto != sch_transistorprim) continue;
+					varl = getvalkey((INTBIG)ni, VNODEINST, -1, el_attr_length);
+					varw = getvalkey((INTBIG)ni, VNODEINST, -1, el_attr_width);
+					if (varl != NOVARIABLE)
+					{
+						strcpy(lenstr, describesimplevariable(varl));
+						ltype = varl->type;
+						TDCOPY(ldescript, varl->textdescript);
+					}
+					if (varw != NOVARIABLE)
+					{
+						strcpy(widstr, describesimplevariable(varw));
+						wtype = varw->type;
+						TDCOPY(wdescript, varw->textdescript);
+					}
+					if (varl != NOVARIABLE)
+					{
+						us_getsimpletype(lenstr, &type, &addr);
+						type |= (ltype & ~VTYPE);
+						var = setvalkey((INTBIG)ni, VNODEINST, el_attr_width, addr, type);
+						if (var != NOVARIABLE)
+							TDCOPY(var->textdescript, ldescript);
+					}
+					if (varw != NOVARIABLE)
+					{
+						us_getsimpletype(widstr, &type, &addr);
+						type |= (wtype & ~VTYPE);
+						var = setvalkey((INTBIG)ni, VNODEINST, el_attr_length, addr, type);
+						if (var != NOVARIABLE)
+							TDCOPY(var->textdescript, wdescript);
+					}
+				}
+			}
+		}
+		ttyputmsg("Lengths and Widths swapped: redisplay to see them");
+		return;
+	}
+#endif
+
+#if 0		/* Harvey Mudd hack */
 	if (namesamen(par[0], "mudd", l) == 0)
 	{
 #include "tecmocmos.h"
@@ -1888,13 +1900,14 @@ void us_debug(INTSML count, char *par[])
 		}
 		return;
 	}
+#endif
 
-#if 0		/* "debug million" */
+#if 0		/* place 1 million parts */
 	if (namesamen(par[0], "million", l) == 0)
 	{
 #include "edialogs.h"
 		NODEPROTO *item;
-		extern AIDENTRY *dr_aid;
+		extern TOOL *dr_tool;
 		REGISTER ARCPROTO *apwire;
 		REGISTER PORTPROTO *ppy, *ppa;
 		float duration;
@@ -1902,8 +1915,8 @@ void us_debug(INTSML count, char *par[])
 		INTBIG lx, hx, ly, hy, wid, hei, maxy, maxx, nilastx, nilasty, nix, niy;
 		extern DIALOG us_progressdialog;
 
-		aidturnoff(dr_aid, 0);
-		aidturnoff(us_aid, 0);
+		toolturnoff(dr_tool, 0);
+		toolturnoff(us_tool, 0);
 		apwire = getarcproto("schematic:wire");
 		item = getnodeproto("schematic:Buffer");
 		if (item == NONODEPROTO) return;
@@ -1937,7 +1950,7 @@ void us_debug(INTSML count, char *par[])
 		duration = endtimer();
 		ttyputmsg("Took %s", explainduration(duration));
 		DiaDoneDialog();
-		aidturnon(us_aid, 0);
+		toolturnon(us_tool, 0);
 		return;
 	}
 #endif
@@ -1961,7 +1974,7 @@ void us_debug(INTSML count, char *par[])
 						for(pt = line; *pt != 0; pt++)
 							if (*pt == '-') *pt = '_';
 						pt = us_uniqueportname(line, np);
-						(void)reallocstring(&pp->protoname, pt, us_aid->cluster);
+						(void)reallocstring(&pp->protoname, pt, us_tool->cluster);
 					}
 				}
 			}
@@ -1977,7 +1990,7 @@ void us_debug(INTSML count, char *par[])
 		NODEINST **nilist;
 		INTBIG total, done, thisx, thisy, lastx, lasty;
 
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 		np = us_needfacet();
 		if (np == NONODEPROTO) return;
 		us_debugmergeoffset = np->highy - np->lowy +
@@ -2035,7 +2048,7 @@ void us_debug(INTSML count, char *par[])
 		INTSML total;
 		char **filelist, libfile[200], libname[50];
 		LIBRARY *leflib, *gdslib, *prepfile;
-		extern AIDENTRY *dr_aid;
+		extern TOOL *dr_tool;
 
 #define TSMCELECDIRECTORY "E:\\DevelE\\Artisan\\TPZ872G_150C\\ELIB\\"
 #define TSMCGDSDIRECTORY  "E:\\DevelE\\Artisan\\TPZ872G_150C\\GDS\\"
@@ -2043,14 +2056,14 @@ void us_debug(INTSML count, char *par[])
 #define TSMCPREPFILE      "E:\\DevelE\\Artisan\\tsmc25m4.txt"
 
 		/* turn off DRC */
-		aidturnoff(dr_aid, 1);
+		toolturnoff(dr_tool, 1);
 
 		/* read the TSMC preparation file */
 		strcpy(libname, "prep");
 		strcpy(libfile, TSMCPREPFILE);
 		prepfile = newlibrary(libname, libfile);
 		ttyputmsg("Reading Preparation file %s", libfile);
-		if (askaid(io_aid, "read", (INTBIG)prepfile, (INTBIG)"text", 0) != 0)
+		if (asktool(io_tool, "read", (INTBIG)prepfile, (INTBIG)"text", 0) != 0)
 		{
 			ttyputerr("Cannot find TSMC preparation file %s", libfile);
 			return;
@@ -2061,7 +2074,7 @@ void us_debug(INTSML count, char *par[])
 		strcpy(libfile, TSMCLEFFILE);
 		leflib = newlibrary(libname, libfile);
 		ttyputmsg("Reading LEF file %s", libfile);
-		if (askaid(io_aid, "read", (INTBIG)leflib, (INTBIG)"lef", 0) != 0)
+		if (asktool(io_tool, "read", (INTBIG)leflib, (INTBIG)"lef", 0) != 0)
 		{
 			ttyputerr("Cannot find LEF file %s", libfile);
 			return;
@@ -2084,7 +2097,7 @@ void us_debug(INTSML count, char *par[])
 			strcat(libfile, filelist[i]);
 			(void)reallocstring(&gdslib->libfile, libfile, gdslib->cluster);
 			ttyputmsg("Reading GDS file %s", libfile);
-			if (askaid(io_aid, "read", (INTBIG)gdslib, (INTBIG)"gds", 0) != 0) break;
+			if (asktool(io_tool, "read", (INTBIG)gdslib, (INTBIG)"gds", 0) != 0) break;
 
 			/* synchronize the ports */
 			us_portsynchronize(leflib);
@@ -2100,7 +2113,7 @@ void us_debug(INTSML count, char *par[])
 			if (namesame(&libfile[j-4], ".gds") == 0) libfile[j-4] = 0;
 			(void)reallocstring(&gdslib->libfile, libfile, gdslib->cluster);
 			gdslib->userbits |= READFROMDISK;
-			if (askaid(io_aid, "write", (INTBIG)gdslib, (INTBIG)"binary") != 0) break;
+			if (asktool(io_tool, "write", (INTBIG)gdslib, (INTBIG)"binary") != 0) break;
 		}
 		prepfile->userbits &= ~(LIBCHANGEDMAJOR|LIBCHANGEDMINOR);
 		leflib->userbits &= ~(LIBCHANGEDMAJOR|LIBCHANGEDMINOR);
@@ -2149,7 +2162,7 @@ void us_debug(INTSML count, char *par[])
 				}
 			}
 		}
-		ttyputmsg("All aid words reset");
+		ttyputmsg("All tool words reset");
 		return;
 	}
 
@@ -2165,8 +2178,7 @@ void us_debug(INTSML count, char *par[])
 			line[2] = (char)let3;   line[3] = 0;
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)line, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 			let1++;
 			if (let1 > 'Z')
 			{
@@ -2183,12 +2195,11 @@ void us_debug(INTSML count, char *par[])
 		for(ai = np->firstarcinst; ai != NOARCINST;
 			ai = ai->nextarcinst)
 		{
-			(void)sprintf(line, "%d", i++);
+			(void)sprintf(line, "%ld", i++);
 			var = setvalkey((INTBIG)ai, VARCINST, el_arc_name, (INTBIG)line,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(4) << VTSIZESH);
+				defaulttextsize(4, var->textdescript);
 		}
 		us_redisplay(el_curwindowpart);
 		return;
@@ -2254,8 +2265,8 @@ void us_debug(INTSML count, char *par[])
 		{
 			lib = newlibrary(libname, libfile);
 			if (lib == NOLIBRARY) return;
-			(void)askaid(io_aid, "read", (INTBIG)lib, (INTBIG)"binary");
-			(void)askaid(io_aid, "write", (INTBIG)lib, (INTBIG)"text");
+			(void)asktool(io_tool, "read", (INTBIG)lib, (INTBIG)"binary");
+			(void)asktool(io_tool, "write", (INTBIG)lib, (INTBIG)"text");
 			killlibrary(lib);
 		}
 		return;
@@ -2264,9 +2275,9 @@ void us_debug(INTSML count, char *par[])
 	if (namesamen(par[0], "freeze-user-interface", l) == 0 && l >= 1)
 	{
 		j = l = 0;
-		for(i=0; i<us_aid->numvar; i++)
+		for(i=0; i<us_tool->numvar; i++)
 		{
-			var = &us_aid->firstvar[i];
+			var = &us_tool->firstvar[i];
 			pt = makename(var->key);
 			if (namesamen(pt, "USER_binding_", 13) == 0)
 			{
@@ -2282,7 +2293,7 @@ void us_debug(INTSML count, char *par[])
 				 * is the address of the parsing structures: these cannot
 				 * be valid when read back in.
 				 */
-				setindkey((INTBIG)us_aid, VAID, var->key, 2, (INTBIG)"");
+				setindkey((INTBIG)us_tool, VTOOL, var->key, 2, (INTBIG)"");
 				l++;
 			}
 		}
@@ -2375,7 +2386,7 @@ void us_defarc(INTSML count, char *par[])
 			if (var != NOVARIABLE) style = var->addr; else style = ap->userbits;
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = -1;
 			if (style == -1)
 			{
@@ -2433,7 +2444,7 @@ void us_defarc(INTSML count, char *par[])
 			ttyputverbose(M_("%s arcs drawn in default style"), describearcproto(ap));
 			return;
 		}
-		(void)delvalkey((INTBIG)us_aid, VAID, us_arcstyle);
+		(void)delvalkey((INTBIG)us_tool, VTOOL, us_arcstyle);
 		ttyputverbose(M_("All arcs drawn in default style"));
 		return;
 	}
@@ -2450,10 +2461,10 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = 0;
 			if (negate != 0) style &= ~WANTFIXANG; else style |= WANTFIXANG;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs drawn not fixed-angle"), aname); else
 			ttyputverbose(M_("%s arcs drawn fixed-angle"), aname);
@@ -2470,10 +2481,10 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = WANTFIXANG;
 			if (negate != 0) style &= ~WANTFIX; else style |= WANTFIX;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs drawn un-rigid"), aname); else
 			ttyputverbose(M_("%s arcs drawn rigid"), aname);
@@ -2491,11 +2502,11 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = WANTFIXANG;
 			if (negate != 0) style &= ~WANTDIRECTIONAL; else
 				style |= WANTDIRECTIONAL;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs drawn nondirectional"), aname); else
 			ttyputverbose(M_("%s arcs drawn directional"), aname);
@@ -2513,11 +2524,11 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = WANTFIXANG;
 			if (negate == 0) style &= ~WANTCANTSLIDE; else
 				style |= WANTCANTSLIDE;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs can not slide in their ports"), aname); else
 			ttyputverbose(M_("%s arcs can slide in their ports"), aname);
@@ -2534,10 +2545,10 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = WANTFIXANG;
 			if (negate != 0) style &= ~WANTNEGATED; else style |= WANTNEGATED;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs drawn un-negated"), aname); else
 			ttyputverbose(M_("%s arcs drawn negated"), aname);
@@ -2554,10 +2565,10 @@ void us_defarc(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, style, VINTEGER);
 		} else
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_arcstyle);
 			if (var != NOVARIABLE) style = var->addr; else style = WANTFIXANG;
 			if (negate != 0) style |= WANTNOEXTEND; else style &= ~WANTNOEXTEND;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, style, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_arcstyle, style, VINTEGER|VDONTSAVE);
 		}
 		if (negate != 0) ttyputverbose(M_("%s arcs drawn with ends not extended"), aname); else
 			ttyputverbose(M_("%s arcs drawn with ends extended by half-width"), aname);
@@ -2703,7 +2714,7 @@ void us_defnode(INTSML count, char *par[])
 	{
 		if (np == NONODEPROTO)
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_placement_angle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_placement_angle);
 			if (var == NOVARIABLE) pangle = 0; else pangle = (INTSML)var->addr;
 			ttyputmsg(_("Nodes are created with %s degrees rotation%s"),
 				frtoa(pangle%3600*WHOLE/10), (pangle >= 3600 ? _(", transposed") : ""));
@@ -2808,14 +2819,14 @@ void us_defnode(INTSML count, char *par[])
 			if ((us_useroptions&CHECKDATE) != 0)
 				ttyputverbose(M_("Facet revision dates already being checked")); else
 					ttyputverbose(M_("Facet revision date errors will be identified"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | CHECKDATE, VINTEGER);
 		} else
 		{
 			if ((us_useroptions&CHECKDATE) == 0)
 				ttyputverbose(M_("Facet revision dates already being ignored")); else
 					ttyputverbose(M_("Facet revision date errors will be ignored"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~CHECKDATE, VINTEGER);
 		}
 		return;
@@ -2833,14 +2844,14 @@ void us_defnode(INTSML count, char *par[])
 			if ((us_useroptions&CENTEREDPRIMITIVES) != 0)
 				ttyputverbose(M_("Primitives are already being placed by their center")); else
 					ttyputverbose(M_("Primitives will be placed by their center"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | CENTEREDPRIMITIVES, VINTEGER);
 		} else
 		{
 			if ((us_useroptions&CENTEREDPRIMITIVES) == 0)
 				ttyputverbose(M_("Primitives are already being placed by edges")); else
 					ttyputverbose(M_("Primitives will be placed by edges"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~CENTEREDPRIMITIVES, VINTEGER);
 		}
 		return;
@@ -2858,14 +2869,14 @@ void us_defnode(INTSML count, char *par[])
 			if ((us_useroptions&DUPCOPIESPORTS) != 0)
 				ttyputverbose(M_("Ports are already being copied by duplicate/array/yanknode")); else
 					ttyputverbose(M_("Ports will be copied by duplicate/array/yanknode"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | DUPCOPIESPORTS, VINTEGER);
 		} else
 		{
 			if ((us_useroptions&DUPCOPIESPORTS) == 0)
 				ttyputverbose(M_("Ports are already not being copied by duplicate/array/yanknode")); else
 					ttyputverbose(M_("Ports will not be copied by duplicate/array/yanknode"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~DUPCOPIESPORTS, VINTEGER);
 		}
 		return;
@@ -2950,14 +2961,14 @@ void us_defnode(INTSML count, char *par[])
 				if ((us_useroptions&NOFACETCHANGES) == 0)
 					ttyputverbose(M_("Facets are already able to be freely altered")); else
 						ttyputverbose(M_("Facets may now be freely edited"));
-				(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 					us_useroptions & ~NOFACETCHANGES, VINTEGER);
 			} else
 			{
 				if ((us_useroptions&NOFACETCHANGES) != 0)
 					ttyputverbose(M_("Facet changes are already being disallowed")); else
 						ttyputverbose(M_("Facet changes will not be allowed"));
-				(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 					us_useroptions | NOFACETCHANGES, VINTEGER);
 			}
 		}
@@ -2976,14 +2987,14 @@ void us_defnode(INTSML count, char *par[])
 			if ((us_useroptions&NOPRIMCHANGES) == 0)
 				ttyputverbose(M_("Locked primitives are already able to be freely altered")); else
 					ttyputverbose(M_("Locked primitives may now be freely edited"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~NOPRIMCHANGES, VINTEGER);
 		} else
 		{
 			if ((us_useroptions&NOPRIMCHANGES) != 0)
 				ttyputverbose(M_("Locked primitive changes are already being disallowed")); else
 					ttyputverbose(M_("Locked primitive changes will not be allowed"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | NOPRIMCHANGES, VINTEGER);
 		}
 		return;
@@ -3089,7 +3100,7 @@ void us_defnode(INTSML count, char *par[])
 		} else
 		{
 			/* get placement angle for all nodes */
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_placement_angle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_placement_angle);
 			if (var == NOVARIABLE) pangle = 0; else pangle = (INTSML)var->addr;
 
 			if (count > 2)
@@ -3099,7 +3110,7 @@ void us_defnode(INTSML count, char *par[])
 				if (namesame(&par[2][strlen(par[2])-1], "t") == 0) pangle += 3600;
 			} else if (pangle >= 6300) pangle = 0; else
 				pangle += 900;
-			(void)setvalkey((INTBIG)us_aid, VAID, us_placement_angle, pangle, VINTEGER);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_placement_angle, pangle, VINTEGER);
 		}
 		return;
 	}
