@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomek.c
- * User interface aid: command handler for E through K
+ * User interface tool: command handler for E through K
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -82,9 +82,9 @@ void us_echo(INTSML count, char *par[])
 
 void us_editfacet(INTSML count, char *par[])
 {
-	REGISTER INTBIG implicit, i, len, newwindow, nonredundant, newframe, push;
+	REGISTER INTBIG implicit, i, len, newwindow, nonredundant, newframe, push,
+		intoicon, lambda;
 	INTBIG lx, hx, ly, hy;
-	REGISTER INTBIG lambda;
 	REGISTER NODEPROTO *np, *onp, *np1, *curfacet;
 	REGISTER NODEINST *ni, *stacknodeinst;
 	REGISTER LIBRARY *lib, *olib;
@@ -99,6 +99,7 @@ void us_editfacet(INTSML count, char *par[])
 	/* find the nodeinst in this window to go "down into" (if any) */
 	newwindow = 0;
 	nonredundant = 0;
+	intoicon = 0;
 	if (count == 0)
 	{
 		implicit = 1;
@@ -110,11 +111,14 @@ void us_editfacet(INTSML count, char *par[])
 		/* translate this reference if this is an icon facet */
 		if (np->cellview == el_iconview)
 		{
-			onp = contentsview(np);
-			if (onp != NONODEPROTO)
+			implicit = 0;
+			if (np->cell != ni->parent->cell)
 			{
-				np = onp;
-				implicit = 0;
+				onp = contentsview(np);
+				if (onp != NONODEPROTO) np = onp;
+			} else
+			{
+				intoicon = 1;
 			}
 		}
 	} else
@@ -191,7 +195,7 @@ void us_editfacet(INTSML count, char *par[])
 	{
 		push = 1;
 		onp = contentsview(np);
-		if (onp == NONODEPROTO) onp = np;
+		if (onp == NONODEPROTO || intoicon != 0) onp = np;
 		(void)setvalkey((INTBIG)onp, VNODEPROTO, us_facet_descent_path, (INTBIG)stacknodeinst,
 			VNODEINST|VDONTSAVE);
 	}
@@ -302,7 +306,7 @@ void us_erase(INTSML count, char *par[])
 
 	np = us_needfacet();
 	if (np == NONODEPROTO) return;
-	highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (highvar == NOVARIABLE)
 	{
 		us_abortcommand(_("First highlight something to erase"));
@@ -403,26 +407,28 @@ void us_erase(INTSML count, char *par[])
 	/* look for option to re-connect arcs into an erased node */
 	if (count > 0 && namesamen(par[0], "pass-through", strlen(par[0])) == 0)
 	{
-		if (list[1] != NOGEOM || list[0]->entrytype != OBJNODEINST)
+		for(i=0; list[i] != NOGEOM; i++)
 		{
-			us_abortcommand(_("Must erase a single node to pass arcs through"));
-			return;
-		}
-		us_clearhighlightcount();
-		j = us_erasepassthru(list[0]->entryaddr.ni, 1);
-		switch (j)
-		{
-			case 2:
-				break;
-			case -1:
-				us_abortcommand(_("Arcs to this node are of different type"));
-				break;
-			case -5:
-				us_abortcommand(_("Cannot create connecting arc"));
-				break;
-			default:
-				us_abortcommand(_("Must be 2 arcs on this node (it has %d)"), j);
-				break;
+			if (list[i]->entrytype != OBJNODEINST) continue;
+			us_clearhighlightcount();
+			ni = list[i]->entryaddr.ni;
+			j = us_erasepassthru(ni, 1);
+			switch (j)
+			{
+				case 2:
+					break;
+				case -1:
+					us_abortcommand(_("Arcs to node %s are of different type"),
+						describenodeinst(ni));
+					break;
+				case -5:
+					us_abortcommand(_("Cannot create connecting arc"));
+					break;
+				default:
+					us_abortcommand(_("Must be 2 arcs on node %s (it has %d)"),
+						describenodeinst(ni), j);
+					break;
+			}
 		}
 		return;
 	}
@@ -436,7 +442,7 @@ void us_find(INTSML count, char *par[])
 {
 	REGISTER INTBIG i, j, l, findport, findpoint, findexclusively, findangle,
 		findwithin, findstill, findspecial, size, findconstrained,
-		findeasy, findhard, total, type, addr, len;
+		findeasy, findhard, total, type, addr, len, first;
 	REGISTER INTBIG areasizex, areasizey, x, y, *newlist, extrainfo, findmore, findnobox;
 	INTBIG xcur, ycur;
 	XARRAY trans;
@@ -449,6 +455,7 @@ void us_find(INTSML count, char *par[])
 	REGISTER NETWORK *net;
 	REGISTER VARIABLE *var, *highvar;
 	REGISTER char *pt, **list;
+	REGISTER HIGHLIGHT *high;
 	HIGHLIGHT newhigh;
 
 	if (count >= 1)
@@ -458,10 +465,10 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count >= 2)
 			{
-				(void)setvalkey((INTBIG)us_aid, VAID, us_interactiveangle,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_interactiveangle,
 					atofr(par[1])*10/WHOLE, VINTEGER|VDONTSAVE);
 			}
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_interactiveangle);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_interactiveangle);
 			if (var == NOVARIABLE) findangle = 0; else
 				findangle = (INTSML)var->addr;
 			if (findangle == 0)
@@ -481,12 +488,12 @@ void us_find(INTSML count, char *par[])
 				l = strlen(pt = par[1]);
 				if (namesamen(pt, "on", l) == 0 && l >= 2)
 				{
-					(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+					(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 						us_useroptions | FLIPINTERACTIVECON, VINTEGER);
 				}
 				if (namesamen(pt, "off", l) == 0 && l >= 2)
 				{
-					(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+					(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 						us_useroptions & ~FLIPINTERACTIVECON, VINTEGER);
 				}
 			}
@@ -514,17 +521,17 @@ void us_find(INTSML count, char *par[])
 			us_highlightline(el_curwindowpart, 0, i-1);
 			return;
 		}
-		us_abortcommand(_("There are no components to select in a text-only facet"));
+		us_abortcommand(M_("There are no components to select in a text-only facet"));
 		return;
 	}
 	if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
 	{
-		us_abortcommand(_("Cannot select objects in a 3D window"));
+		us_abortcommand(M_("Cannot select objects in a 3D window"));
 		return;
 	}
 
 	/* establish the default highlight environment */
-	highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (highvar != NOVARIABLE)
 		(void)us_makehighlight(((char **)highvar->addr)[0], &newhigh); else
 	{
@@ -582,12 +589,12 @@ void us_find(INTSML count, char *par[])
 		{
 			if (newhigh.status == 0)
 			{
-				us_abortcommand(_("Find an object before working 'within' it"));
+				us_abortcommand(M_("Find an object before working 'within' it"));
 				return;
 			}
 			if ((newhigh.status&HIGHTYPE) != HIGHFROM || newhigh.fromgeom->entrytype != OBJNODEINST)
 			{
-				us_abortcommand(_("Must find a node before working 'within'"));
+				us_abortcommand(M_("Must find a node before working 'within'"));
 				return;
 			}
 
@@ -599,7 +606,7 @@ void us_find(INTSML count, char *par[])
 			findport = 1;
 			count--;   par++;   continue;
 		}
-		if (namesamen(pt, "vertex", l) == 0 && l >= 1)
+		if (namesamen(pt, "vertex", l) == 0 && l >= 2)
 		{
 			findpoint = 1;
 			count--;   par++;   continue;
@@ -616,7 +623,7 @@ void us_find(INTSML count, char *par[])
 			if (findpoint != 0 || findwithin != 0 || findmore != 0 ||
 				findexclusively != 0 || findstill != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find all'"));
+				us_abortcommand(M_("Illegal options given to 'find all'"));
 				return;
 			}
 			findeasy = findhard = 1;
@@ -680,7 +687,7 @@ void us_find(INTSML count, char *par[])
 			}
 			if (total == 0) us_clearhighlightcount(); else
 			{
-				(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)list,
 					VSTRING|VISARRAY|(total<<VLENGTHSH)|VDONTSAVE);
 			}
 			for(i=0; i<total; i++) efree(list[i]);
@@ -699,12 +706,12 @@ void us_find(INTSML count, char *par[])
 			}
 			if (findport != 0 || findpoint != 0 || findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find arc'"));
+				us_abortcommand(M_("Illegal options given to 'find arc'"));
 				return;
 			}
 			if (findexclusively != 0 && us_curarcproto == NOARCPROTO)
 			{
-				us_abortcommand(_("Must select an arc for exclusive finding"));
+				us_abortcommand(M_("Must select an arc for exclusive finding"));
 				return;
 			}
 			for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -733,7 +740,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find area-define'"));
+				us_abortcommand(M_("Illegal options given to 'find area-define'"));
 				return;
 			}
 
@@ -763,7 +770,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find area-move'"));
+				us_abortcommand(M_("Illegal options given to 'find area-move'"));
 				return;
 			}
 			if (us_demandxy(&xcur, &ycur)) return;
@@ -783,7 +790,7 @@ void us_find(INTSML count, char *par[])
 			us_clearhighlightcount();
 
 			/* adjust the cursor position if selecting interactively */
-			if ((us_aid->aidstate&INTERACTIVE) != 0)
+			if ((us_tool->toolstate&INTERACTIVE) != 0)
 			{
 				us_findinit(areasizex, areasizey);
 				trackcursor(0, us_ignoreup, us_findmbegin, us_dragdown, us_stoponchar,
@@ -806,7 +813,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find area-size'"));
+				us_abortcommand(M_("Illegal options given to 'find area-size'"));
 				return;
 			}
 			if (us_demandxy(&xcur, &ycur)) return;
@@ -814,19 +821,19 @@ void us_find(INTSML count, char *par[])
 
 			if (newhigh.status != HIGHBBOX)
 			{
-				us_abortcommand(_("Use 'find area-move' first, then this"));
+				us_abortcommand(M_("Use 'find area-move' first, then this"));
 				return;
 			}
 			if (np != newhigh.facet)
 			{
-				us_abortcommand(_("Not in same facet as highlight area"));
+				us_abortcommand(M_("Not in same facet as highlight area"));
 				return;
 			}
 
 			us_clearhighlightcount();
 
 			/* adjust the cursor position if selecting interactively */
-			if ((us_aid->aidstate&INTERACTIVE) != 0)
+			if ((us_tool->toolstate&INTERACTIVE) != 0)
 			{
 				us_findinit(newhigh.stalx, newhigh.staly);
 				trackcursor(0, us_ignoreup, us_findsbegin, us_stretchdown,
@@ -857,7 +864,7 @@ void us_find(INTSML count, char *par[])
 		{
 			if (findpoint != 0 || findexclusively != 0 || extrainfo != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find comp-interactive'"));
+				us_abortcommand(M_("Illegal options given to 'find comp-interactive'"));
 				return;
 			}
 
@@ -865,7 +872,7 @@ void us_find(INTSML count, char *par[])
 				findconstrained = 1 - findconstrained;
 			if (findconstrained == 0) findangle = 0; else
 			{
-				var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_interactiveangle);
+				var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_interactiveangle);
 				if (var == NOVARIABLE) findangle = 0; else
 					findangle = (INTSML)var->addr;
 			}				
@@ -878,7 +885,7 @@ void us_find(INTSML count, char *par[])
 
 		if (namesamen(pt, "deselect-arcs", l) == 0 && l >= 2)
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 			if (var == NOVARIABLE) return;
 			len = getlength(var);
 			list = (char **)emalloc(len * (sizeof (char *)), el_tempcluster);
@@ -894,10 +901,10 @@ void us_find(INTSML count, char *par[])
 			}
 			if (j == 0)
 			{
-				(void)delvalkey((INTBIG)us_aid, VAID, us_highlighted);
+				(void)delvalkey((INTBIG)us_tool, VTOOL, us_highlighted);
 			} else
 			{
-				(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)list,
 					VSTRING|VISARRAY|(j<<VLENGTHSH)|VDONTSAVE);
 			}
 			for(i=0; i<j; i++)
@@ -911,7 +918,7 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find down-stack'"));
+				us_abortcommand(M_("Illegal options given to 'find down-stack'"));
 				return;
 			}
 			us_pushhighlight();
@@ -929,7 +936,7 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 || findwithin != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand(_("'find export' cannot accept other control"));
+				us_abortcommand(M_("'find export' cannot accept other control"));
 				return;
 			}
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -951,7 +958,7 @@ void us_find(INTSML count, char *par[])
 		{
 			if (findexclusively != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find interactively'"));
+				us_abortcommand(M_("Illegal options given to 'find interactively'"));
 				return;
 			}
 
@@ -964,7 +971,7 @@ void us_find(INTSML count, char *par[])
 					us_stoponchar, us_dragup, TRACKDRAGGING);
 				if (el_pleasestop != 0) return;
 
-				highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+				highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 				if (highvar == NOVARIABLE) return;
 				(void)us_makehighlight(((char **)highvar->addr)[0], &newhigh);
 				if (us_demandxy(&xcur, &ycur) != 0) return;
@@ -1001,7 +1008,7 @@ void us_find(INTSML count, char *par[])
 				findconstrained = 1 - findconstrained;
 			if (findconstrained == 0) findangle = 0; else
 			{
-				var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_interactiveangle);
+				var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_interactiveangle);
 				if (var == NOVARIABLE) findangle = 0; else
 					findangle = (INTSML)var->addr;
 			}				
@@ -1022,20 +1029,20 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find name'"));
+				us_abortcommand(M_("Illegal options given to 'find name'"));
 				return;
 			}
 			(void)initinfstr();
 			(void)addstringtoinfstr("USER_highlight_");
 			(void)addstringtoinfstr(par[1]);
-			var = getval((INTBIG)us_aid, VAID, VSTRING|VISARRAY, returninfstr());
+			var = getval((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, returninfstr());
 			if (var == NOVARIABLE)
 			{
 				us_abortcommand(_("Cannot find saved highlight '%s'"), par[1]);
 				return;
 			}
 
-			(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, var->addr, var->type|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, var->addr, var->type|VDONTSAVE);
 			if ((us_state&NONPERSISTENTCURNODE) != 0) us_setnodeproto(NONODEPROTO);
 			return;
 		}
@@ -1049,12 +1056,12 @@ void us_find(INTSML count, char *par[])
 			}
 			if (findport != 0 || findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find node'"));
+				us_abortcommand(M_("Illegal options given to 'find node'"));
 				return;
 			}
 			if (findexclusively != 0 && us_curnodeproto == NONODEPROTO)
 			{
-				us_abortcommand(_("Must select a node for exclusive finding"));
+				us_abortcommand(M_("Must select a node for exclusive finding"));
 				return;
 			}
 			for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1176,7 +1183,7 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find object'"));
+				us_abortcommand(M_("Illegal options given to 'find object'"));
 				return;
 			}
 
@@ -1303,10 +1310,10 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find save'"));
+				us_abortcommand(M_("Illegal options given to 'find save'"));
 				return;
 			}
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 			if (var == NOVARIABLE)
 			{
 				us_abortcommand(_("Highlight something before saving highlight"));
@@ -1315,7 +1322,7 @@ void us_find(INTSML count, char *par[])
 			(void)initinfstr();
 			(void)addstringtoinfstr("USER_highlight_");
 			(void)addstringtoinfstr(par[1]);
-			(void)setval((INTBIG)us_aid, VAID, returninfstr(), var->addr, var->type|VDONTSAVE);
+			(void)setval((INTBIG)us_tool, VTOOL, returninfstr(), var->addr, var->type|VDONTSAVE);
 			ttyputverbose(M_("%s saved"), par[1]);
 			return;
 		}
@@ -1368,12 +1375,59 @@ void us_find(INTSML count, char *par[])
 			return;
 		}
 
+		if (namesamen(pt, "similar", l) == 0 && l >= 2)
+		{
+			if (findpoint != 0 || findwithin != 0 || findmore != 0 ||
+				findexclusively != 0 || findstill != 0 || findspecial != 0)
+			{
+				us_abortcommand(M_("Illegal options given to 'find similar'"));
+				return;
+			}
+
+			high = us_getonehighlight();
+			if (high == NOHIGHLIGHT)
+			{
+				us_abortcommand(_("Must select a single object before selecting all like it"));
+				return;
+			}
+			if ((high->status&HIGHTYPE) != HIGHFROM)
+			{
+				us_abortcommand(_("Must select a node or arc before selecting all like it"));
+				return;
+			}
+			(void)initinfstr();
+			first = 0;
+			if (high->fromgeom->entrytype == OBJNODEINST)
+			{
+				for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				{
+					if (ni->proto != high->fromgeom->entryaddr.ni->proto) continue;
+					if (first != 0) (void)addtoinfstr('\n');
+					first++;
+					(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+						describenodeproto(np), (INTBIG)ni->geom);
+				}
+			} else
+			{
+				for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+				{
+					if (ai->proto != high->fromgeom->entryaddr.ai->proto) continue;
+					if (first != 0) (void)addtoinfstr('\n');
+					first++;
+					(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+						describenodeproto(np), (INTBIG)ai->geom);
+				}
+			}
+			us_setmultiplehighlight(returninfstr(), 0);
+			return;
+		}
+
 		if (namesamen(pt, "snap-mode", l) == 0 && l >= 2)
 		{
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find snap-mode'"));
+				us_abortcommand(M_("Illegal options given to 'find snap-mode'"));
 				return;
 			}
 
@@ -1441,7 +1495,7 @@ void us_find(INTSML count, char *par[])
 				ttyputverbose(M_("Snapping mode: any intersection"));
 				return;
 			}
-			us_abortcommand(_("Unknown snapping mode: %s"), pt);
+			us_abortcommand(M_("Unknown snapping mode: %s"), pt);
 			return;
 		}
 
@@ -1450,12 +1504,48 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand(_("Illegal options given to 'find up-stack'"));
+				us_abortcommand(M_("Illegal options given to 'find up-stack'"));
 				return;
 			}
 			if (us_pophighlight(0) != 0) us_abortcommand(_("The stack is empty"));
 			return;
 		}
+
+		if (namesamen(pt, "variable", l) == 0 && l >= 2)
+		{
+			if (count <= 1)
+			{
+				ttyputusage("find variable VARNAME");
+				return;
+			}
+			if (findport != 0 || findpoint != 0 || findexclusively != 0 || findwithin != 0 ||
+				findspecial != 0)
+			{
+				us_abortcommand(M_("'find variable' cannot accept other control"));
+				return;
+			}
+			ni = (NODEINST *)us_getobject(OBJNODEINST, 1);
+			if (ni == NONODEINST) return;
+			for(i=0; i<ni->numvar; i++)
+			{
+				var = &ni->firstvar[i];
+				if ((var->type&VDISPLAY) == 0) continue;
+				if (namesame(par[1], makename(var->key)) == 0) break;
+			}
+			if (i >= ni->numvar)
+			{
+				us_abortcommand(_("Sorry, no variable named '%s' on the current node"),
+					par[1]);
+				return;
+			}
+			newhigh.status = HIGHTEXT;
+			newhigh.fromgeom = ni->geom;
+			newhigh.fromport = NOPORTPROTO;
+			newhigh.fromvar = var;
+			newhigh.facet = np;
+			us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
+			return;
+		}
 		ttyputbadusage("find");
 		return;
 	}
@@ -1476,13 +1566,19 @@ void us_getproto(INTSML count, char *par[])
 {
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap, *lat;
-	REGISTER INTSML doarc, l;
+	REGISTER INTBIG cellcount, facetcount, doarc, i, l, firstinpass;
+	INTSML butstate;
 	REGISTER char *pp;
+	REGISTER CELL *cell;
 	HIGHLIGHT high;
 	extern COMCOMP us_getproto1p;
 	REGISTER VARIABLE *highvar;
 	GEOM *fromgeom, *togeom;
 	PORTPROTO *fromport, *toport;
+	REGISTER USERCOM *uc, *ucsub;
+	POPUPMENU *pm, *cpm, *pmsub;
+	REGISTER POPUPMENUITEM *mi, *miret, *misub;
+	extern COMCOMP us_userp;
 
 	if (count == 0)
 	{
@@ -1495,6 +1591,137 @@ void us_getproto(INTSML count, char *par[])
 	}
 	l = strlen(pp = par[0]);
 
+	if (namesamen(pp, "instance", l) == 0)
+	{
+		/* show a popup menu with instances */
+		cellcount = 0;
+		for(cell = el_curlib->firstcell; cell != NOCELL; cell = cell->nextcell)
+			cellcount++;
+		pm = (POPUPMENU *)emalloc(sizeof(POPUPMENU), us_tool->cluster);
+		if (pm == 0) return;
+		mi = (POPUPMENUITEM *)emalloc(cellcount * sizeof(POPUPMENUITEM), us_tool->cluster);
+		if (mi == 0) return;
+		pm->name = "x";
+		(void)initinfstr();
+		if (cellcount != 0) (void)formatinfstr(_("Facets in %s"), el_curlib->libname); else
+			(void)formatinfstr(_("No facets in %s"), el_curlib->libname);
+		(void)allocstring(&pm->header, returninfstr(), us_tool->cluster);
+		pm->list = mi;
+		pm->total = (INTSML)cellcount;
+
+		/* fill the menu */
+		cellcount = 0;
+		for(cell = el_curlib->firstcell; cell != NOCELL; cell = cell->nextcell)
+		{
+			uc = us_allocusercom();
+			mi[cellcount].response = uc;
+			mi[cellcount].response->active = -1;
+			mi[cellcount].value = 0;
+
+			facetcount = 0;
+			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+				if (np->cell == cell) facetcount++;
+			if (facetcount == 1)
+			{
+				/* only one facet of this cell: create it directly */
+				uc->active = parse("getproto", &us_userp, 1);
+				(void)allocstring(&uc->comname, "getproto", us_tool->cluster);
+				uc->count = 2;
+				(void)allocstring(&uc->word[0], "node", us_tool->cluster);
+				(void)allocstring(&uc->word[1], describenodeproto(cell->firstincell),
+					us_tool->cluster);
+				mi[cellcount].attribute = uc->word[1];
+			} else
+			{
+				/* multiple facets of this cell: make a submenu */
+				mi[cellcount].attribute = cell->cellname;
+				mi[cellcount].value = ">>";
+				mi[cellcount].maxlen = -1;
+				pmsub = (POPUPMENU *)emalloc(sizeof(POPUPMENU), us_tool->cluster);
+				if (pmsub == 0) return;
+				misub = (POPUPMENUITEM *)emalloc(facetcount * sizeof(POPUPMENUITEM), us_tool->cluster);
+				if (misub == 0) return;
+				pmsub->name = "x";
+				pmsub->header = 0;
+				pmsub->list = misub;
+				pmsub->total = (INTSML)facetcount;
+				facetcount = 0;
+				for(i=0; i<2; i++)
+				{
+					firstinpass = facetcount;
+					for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+					{
+						if (np->cell != cell) continue;
+
+						/* see if this facet should be included on this pass */
+						if (i == 0)
+						{
+							/* first pass: only include facets that match the current view */
+							if (us_facetfromtech(np, el_curtech) == 0) continue;
+						} else
+						{
+							/* first pass: only include facets that don't match the current view */
+							if (us_facetfromtech(np, el_curtech) != 0) continue;
+						}
+
+						ucsub = us_allocusercom();
+						misub[facetcount].response = ucsub;
+						misub[facetcount].response->active = -1;
+						(void)allocstring(&misub[facetcount].attribute, describenodeproto(np),
+							us_tool->cluster);
+						misub[facetcount].value = 0;
+
+						/* only one facet of this cell: create it directly */
+						ucsub->active = parse("getproto", &us_userp, 1);
+						(void)allocstring(&ucsub->comname, "getproto", us_tool->cluster);
+						ucsub->count = 2;
+						(void)allocstring(&ucsub->word[0], "node", us_tool->cluster);
+						(void)allocstring(&ucsub->word[1], describenodeproto(np),
+							us_tool->cluster);
+						facetcount++;
+					}
+					esort(&misub[firstinpass], facetcount-firstinpass,
+						sizeof (POPUPMENUITEM), us_sortpopupmenuascending);
+				}
+				uc->menu = pmsub;
+			}
+			cellcount++;
+		}
+
+		/* invoke the popup menu */
+		esort(mi, cellcount, sizeof (POPUPMENUITEM), us_sortpopupmenuascending);
+		butstate = 1;
+		cpm = pm;
+		miret = us_popupmenu(&cpm, &butstate, 1, -1, -1, 4);
+		if (miret == 0)
+		{
+			us_abortcommand(_("Sorry, popup menus are not available"));
+		} else
+		{
+			if (miret != NOPOPUPMENUITEM)
+				us_execute(miret->response, 0, 0, 0);
+		}
+		for(i=0; i<cellcount; i++)
+		{
+			uc = mi[i].response;
+			if (uc->menu != NOPOPUPMENU)
+			{
+				for(l=0; l<uc->menu->total; l++)
+				{
+					efree((char *)uc->menu->list[l].attribute);
+					us_freeusercom(uc->menu->list[l].response);
+				}
+				efree((char *)uc->menu->list);
+				efree((char *)uc->menu);
+			}
+			us_freeusercom(uc);
+		}
+		efree((char *)mi);
+		efree((char *)pm->header);
+		efree((char *)pm);
+		return;
+	}
+
 	if (namesamen(pp, "node", l) == 0 && l >= 2 && count > 1)
 	{
 		np = getnodeproto(par[1]);
@@ -1516,7 +1743,6 @@ void us_getproto(INTSML count, char *par[])
 
 	if (namesamen(pp, "this-proto", l) == 0 && l >= 1)
 	{
-/*		if (us_demandxy(&xcur, &ycur)) return; */
 		np = us_needfacet();
 		if (np == NONODEPROTO) return;
 		us_setnodeproto(np);
@@ -1527,7 +1753,7 @@ void us_getproto(INTSML count, char *par[])
 	doarc = 0;
 	if (us_gettwoobjects(&fromgeom, &fromport, &togeom, &toport) == 0) doarc = 1; else
 	{
-		highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+		highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 		if (highvar != NOVARIABLE && getlength(highvar) == 1)
 		{
 			(void)us_makehighlight(((char **)highvar->addr)[0], &high);
@@ -1617,6 +1843,11 @@ void us_grid(INTSML count, char *par[])
 	if (count == 0)
 	{
 		if (us_needwindow()) return;
+		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
+		{
+			us_abortcommand(_("Cannot show grid in this type of window"));
+			return;
+		}
 
 		/* save highlight */
 		us_pushhighlight();
@@ -1642,7 +1873,7 @@ void us_grid(INTSML count, char *par[])
 				us_abortcommand(_("Alignment must be positive"));
 				return;
 			}
-			(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_obj, i, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_alignment_obj, i, VINTEGER|VDONTSAVE);
 		}
 		ttyputverbose(M_("Cursor alignment is %s lambda"), latoa(us_alignment));
 		return;
@@ -1658,7 +1889,7 @@ void us_grid(INTSML count, char *par[])
 				us_abortcommand(_("Alignment must be positive"));
 				return;
 			}
-			(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_edge, i, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_alignment_edge, i, VINTEGER|VDONTSAVE);
 		}
 		if (us_edgealignment == 0) ttyputverbose(M_("No edge alignment done")); else
 			ttyputverbose(M_("Edge alignment is %s lambda"), latoa(us_edgealignment));
@@ -2022,7 +2253,8 @@ void us_interpret(INTSML count, char *par[])
 			ttyputusage("interpret file LANGUAGE FILENAME");
 			return;
 		}
-		loadcode(par[0], language);
+		if (loadcode(par[0], language) != 0)
+			ttyputerr(_("Error loading code"));
 		return;
 	}
 
@@ -2088,14 +2320,14 @@ void us_iterate(INTSML count, char *par[])
 			return;
 		}
 		for(i=0; i<us_lastcom->count; i++)
-			if (allocstring(&uc->word[i], us_lastcom->word[i], us_aid->cluster) != 0)
+			if (allocstring(&uc->word[i], us_lastcom->word[i], us_tool->cluster) != 0)
 		{
 			ttyputnomemory();
 			return;
 		}
 		uc->active = us_lastcom->active;
 		uc->count = us_lastcom->count;
-		(void)allocstring(&uc->comname, us_lastcom->comname, us_aid->cluster);
+		(void)allocstring(&uc->comname, us_lastcom->comname, us_tool->cluster);
 		uc->menu = us_lastcom->menu;
 
 		/* execute this command */
