@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomln.c
- * User interface aid: command handler for L through N
+ * User interface tool: command handler for L through N
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -37,7 +37,8 @@
 #include "conlay.h"
 #include "tecart.h"
 #include "tecgen.h"
-#if SIMAID
+#include "tecschem.h"
+#if SIMTOOL
 #  include "sim.h"
 #endif
 
@@ -76,7 +77,7 @@ void us_lambda(INTSML count, char *par[])
 					us_abortcommand(_("Unknown display unit: %s"), pp);
 					return;
 				}
-				setvalkey((INTBIG)us_aid, VAID, us_displayunits, newunit, VINTEGER);
+				setvalkey((INTBIG)us_tool, VTOOL, us_displayunits, newunit, VINTEGER);
 			}
 			switch (el_units&DISPLAYUNITS)
 			{
@@ -210,9 +211,9 @@ void us_lambda(INTSML count, char *par[])
 
 void us_library(INTSML count, char *par[])
 {
-	REGISTER LIBRARY *lib, *olib, *lastlib, *mergelib;
-	REGISTER INTSML i, l, makecurrent, multifile, found, total, stripopts;
-	REGISTER INTBIG retval, arg;
+	REGISTER LIBRARY *lib, *olib, *lastlib, *mergelib, **libsave, *deplib;
+	REGISTER INTBIG i, l, makecurrent, multifile, found, total, stripopts,
+		retval, arg;
 	REGISTER char *pp, *pt, *style, *libf, *oldlibfile, save;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
@@ -474,7 +475,7 @@ void us_library(INTSML count, char *par[])
 					if (i == multifile) arg = 3;
 			}
 			if (mergelib == NOLIBRARY) changesquiet(1);
-			if (askaid(io_aid, "read", (INTBIG)lib, (INTBIG)style, arg) != 0)
+			if (asktool(io_tool, "read", (INTBIG)lib, (INTBIG)style, arg) != 0)
 				retval = 1;
 			if (mergelib == NOLIBRARY) changesquiet(0);
 			if (multifile != 0 || mergelib != NOLIBRARY) lib->libfile = oldlibfile;
@@ -494,15 +495,15 @@ void us_library(INTSML count, char *par[])
 				us_alignment = muldiv(us_alignment, lib->lambda[el_curtech->techindex],
 					el_curtech->deflambda);
 				nextchangequiet();
-				(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_obj, us_alignment,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_alignment_obj, us_alignment,
 					VINTEGER|VDONTSAVE);
 				us_edgealignment = muldiv(us_edgealignment, lib->lambda[el_curtech->techindex],
 					el_curtech->deflambda);
 				nextchangequiet();
-				(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_edge, us_edgealignment,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_alignment_edge, us_edgealignment,
 					VINTEGER|VDONTSAVE);
 				us_setalignment(NOWINDOWFRAME);
-#if SIMAID
+#if SIMTOOL
 				sim_window_stopsimulation();
 #endif
 
@@ -511,7 +512,7 @@ void us_library(INTSML count, char *par[])
 				if (us_curnodeproto == NONODEPROTO || us_curnodeproto->primindex == 0)
 				{
 					nextchangequiet();
-					(void)setvalkey((INTBIG)us_aid, VAID, us_current_node,
+					(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_node,
 						(INTBIG)el_curtech->firstnodeproto, VNODEPROTO|VDONTSAVE);
 					us_shadownodeproto(NOWINDOWFRAME, el_curtech->firstnodeproto);
 				}
@@ -743,19 +744,61 @@ void us_library(INTSML count, char *par[])
 
 	if (namesamen(pp, "save", l) == 0 && l >= 2)
 	{
-		/* save every library that has been modified */
+		/* see which libraries need to be saved */
+		total = 0;
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		{
 			if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
 			if ((lib->userbits&(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) == 0) continue;
+			total++;
+		}
+		if (total == 0) return;
+		libsave = (LIBRARY **)emalloc(total * (sizeof (LIBRARY *)), el_tempcluster);
+		if (libsave == 0) return;
+
+		/* make a list of the libraries to save */
+		total = 0;
+		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+		{
+			if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
+			if ((lib->userbits&(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) == 0) continue;
+			libsave[total++] = lib;
+		}
+
+		/* be sure the most referenced libraries are saved first */
+		for(i=0; i<total; i++) libsave[i]->temp1 = i;
+		for(i=0; i<total; i++)
+		{
+			lib = libsave[i];
+			for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			{
+				for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				{
+					if (ni->proto->primindex != 0) continue;
+					deplib = ni->proto->cell->lib;
+					if (deplib == lib) continue;
+					if (deplib->temp1 <= lib->temp1) continue;
+					l = deplib->temp1;   deplib->temp1 = lib->temp1;   lib->temp1 = l;
+				}
+			}
+		}
+		esort(libsave, total, sizeof (LIBRARY *), us_librarytemp1ascending);
+
+		/* now save every library that needs it */
+		for(i=0; i<total; i++)
+		{
+			lib = libsave[i];
 
 			/* save the library in binary format */
 			makeoptionstemporary(lib);
-			retval = askaid(io_aid, "write", (INTBIG)lib, (INTBIG)"binary");
-			restoreoptionstate();
-			if (retval != 0) return;
+			retval = asktool(io_tool, "write", (INTBIG)lib, (INTBIG)"binary");
+			restoreoptionstate(lib);
+			if (retval != 0) break;
 		}
 
+		/* clean up */
+		efree((char *)libsave);
+
 		/* rewind session logging if it is on */
 		if (us_logrecord != NULL)
 		{
@@ -812,8 +855,8 @@ void us_library(INTSML count, char *par[])
 		if (namesame(style, "binary") == 0 || namesame(style, "text") == 0) stripopts = 1; else
 			stripopts = 0;
 		if (stripopts != 0) makeoptionstemporary(lib);
-		retval = askaid(io_aid, "write", (INTBIG)lib, (INTBIG)style);
-		if (stripopts != 0) restoreoptionstate();
+		retval = asktool(io_tool, "write", (INTBIG)lib, (INTBIG)style);
+		if (stripopts != 0) restoreoptionstate(lib);
 		if (retval != 0) return;
 
 		/* rewind session recording if writing in permanent format */
@@ -854,8 +897,8 @@ void us_library(INTSML count, char *par[])
 				i = ttygetparam(returninfstr(), &us_yesnop, 3, newpar);
 				if (i == 1 && newpar[0][0] == 'n') continue;
 				makeoptionstemporary(olib);
-				(void)askaid(io_aid, "write", (INTBIG)olib, (INTBIG)style);
-				restoreoptionstate();
+				(void)asktool(io_tool, "write", (INTBIG)olib, (INTBIG)style);
+				restoreoptionstate(olib);
 			}
 		}
 		return;
@@ -873,7 +916,7 @@ void us_macbegin(INTSML count, char *par[])
 	extern COMCOMP us_macbeginnp;
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 	if (var != NOVARIABLE)
 	{
 		us_abortcommand(_("Already defining a macro"));
@@ -943,21 +986,21 @@ void us_macbegin(INTSML count, char *par[])
 	newmacro[0] = returninfstr();
 	newmacro[1] = "";		/* no parameters yet */
 	newmacro[2] = "";		/* no parsing structures yet */
-	(void)setvalkey((INTBIG)us_aid, VAID, key, (INTBIG)newmacro,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, key, (INTBIG)newmacro,
 		VSTRING|VISARRAY|(3<<VLENGTHSH)|VDONTSAVE);
 
 	/* turn on macro remembering */
-	(void)setvalkey((INTBIG)us_aid, VAID, us_macrobuilding, (INTBIG)pp, VSTRING|VDONTSAVE);
-	(void)setvalkey((INTBIG)us_aid, VAID, us_macrorunning, (INTBIG)pp, VSTRING|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_macrobuilding, (INTBIG)pp, VSTRING|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_macrorunning, (INTBIG)pp, VSTRING|VDONTSAVE);
 
-	ttyputverbose(M_("Remembering %s..."), pp);
+	ttyputmsg(_("Remembering %s..."), pp);
 }
 
 void us_macdone(INTSML count, char *par[])
 {
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrorunning);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrorunning);
 	if (var == NOVARIABLE)
 	{
 		us_abortcommand(_("Can only stop execution of a macro if one is running"));
@@ -970,16 +1013,16 @@ void us_macend(INTSML count, char *par[])
 {
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 	if (var == NOVARIABLE)
 	{
 		us_abortcommand(_("Not in a macro"));
 		return;
 	}
-	ttyputverbose(M_("%s defined"), (char *)var->addr);
-	(void)delvalkey((INTBIG)us_aid, VAID, us_macrobuilding);
-	if (getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrorunning) != NOVARIABLE)
-		(void)delvalkey((INTBIG)us_aid, VAID, us_macrorunning);
+	ttyputmsg(_("%s defined"), (char *)var->addr);
+	(void)delvalkey((INTBIG)us_tool, VTOOL, us_macrobuilding);
+	if (getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrorunning) != NOVARIABLE)
+		(void)delvalkey((INTBIG)us_tool, VTOOL, us_macrorunning);
 }
 
 void us_menu(INTSML count, char *par[])
@@ -988,6 +1031,7 @@ void us_menu(INTSML count, char *par[])
 		j, len, arctot, pintot, comptot, puretot, fun;
 	REGISTER INTSML autoset, coms;
 	INTSML butstate, wid, hei;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER char *pp, **temp;
 	char number[10], *pt, *implicit[6];
 	POPUPMENU *pm, *cpm;
@@ -1016,7 +1060,7 @@ void us_menu(INTSML count, char *par[])
 	l = strlen(pp = par[0]);
 	if (namesamen(pp, "on", l) == 0 && l >= 2)
 	{
-		if ((us_aid->aidstate&MENUON) != 0)
+		if ((us_tool->toolstate&MENUON) != 0)
 		{
 			us_abortcommand(_("Menu is already displayed"));
 			return;
@@ -1026,10 +1070,10 @@ void us_menu(INTSML count, char *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		startobjectchange((INTBIG)us_aid, VAID);
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate|MENUON,
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate|MENUON,
 			VINTEGER);
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* restore highlighting */
 		(void)us_pophighlight(0);
@@ -1038,7 +1082,7 @@ void us_menu(INTSML count, char *par[])
 
 	if (namesamen(pp, "off", l) == 0 && l >= 2)
 	{
-		if ((us_aid->aidstate&MENUON) == 0)
+		if ((us_tool->toolstate&MENUON) == 0)
 		{
 			us_abortcommand(_("Menu is not displayed"));
 			return;
@@ -1048,9 +1092,9 @@ void us_menu(INTSML count, char *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		startobjectchange((INTBIG)us_aid, VAID);
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~MENUON, VINTEGER);
-		endobjectchange((INTBIG)us_aid, VAID);
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~MENUON, VINTEGER);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* restore highlighting */
 		(void)us_pophighlight(0);
@@ -1061,7 +1105,7 @@ void us_menu(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			implicit[0] = "tellaid";
+			implicit[0] = "telltool";
 			implicit[1] = "user";
 			uc = us_buildcommand(2, implicit);
 		} else uc = us_buildcommand((INTSML)(count-1), &par[1]);
@@ -1095,7 +1139,7 @@ void us_menu(INTSML count, char *par[])
 				(void)addstringtoinfstr(": ");
 				pp = ttygetline(returninfstr());
 				if (pp == 0) break;
-				(void)allocstring(&uc->word[uc->count], pp, us_aid->cluster);
+				(void)allocstring(&uc->word[uc->count], pp, us_tool->cluster);
 				uc->count++;
 				continue;
 			}
@@ -1195,11 +1239,11 @@ void us_menu(INTSML count, char *par[])
 				for(i=0; i<pm->total; i++) if (mi[i].changed != 0)
 				{
 					if (uc->count >= MAXPARS-1) break;
-					(void)allocstring(&uc->word[uc->count++], mi[i].attribute, us_aid->cluster);
-					(void)allocstring(&uc->word[uc->count++], mi[i].value, us_aid->cluster);
+					(void)allocstring(&uc->word[uc->count++], mi[i].attribute, us_tool->cluster);
+					(void)allocstring(&uc->word[uc->count++], mi[i].value, us_tool->cluster);
 				}
 				if (miret->changed == 0 && uc->count < MAXPARS)
-					(void)allocstring(&uc->word[uc->count++], miret->attribute, us_aid->cluster);
+					(void)allocstring(&uc->word[uc->count++], miret->attribute, us_tool->cluster);
 
 				for(i=0; i<pm->total; i++)
 					if (mi[i].maxlen >= 0) efree(mi[i].value);
@@ -1212,12 +1256,12 @@ void us_menu(INTSML count, char *par[])
 			if (miret == mi && miret->changed != 0 &&
 				(comarray[uc->count]->interpret&INCLUDENOISE) != 0)
 			{
-				(void)allocstring(&uc->word[uc->count++], miret->value, us_aid->cluster);
+				(void)allocstring(&uc->word[uc->count++], miret->value, us_tool->cluster);
 			} else
 			{
-				(void)allocstring(&uc->word[uc->count++], miret->attribute, us_aid->cluster);
+				(void)allocstring(&uc->word[uc->count++], miret->attribute, us_tool->cluster);
 				if (miret->changed != 0)
-					(void)allocstring(&uc->word[uc->count++], miret->value, us_aid->cluster);
+					(void)allocstring(&uc->word[uc->count++], miret->value, us_tool->cluster);
 			}
 			for(i=0; i<pm->total; i++)
 				if (mi[i].maxlen >= 0) efree(mi[i].value);
@@ -1226,7 +1270,7 @@ void us_menu(INTSML count, char *par[])
 		}
 
 		/* issue the completed command */
-		us_execute(uc, us_aid->aidstate&ECHOBIND, 0, 1);
+		us_execute(uc, us_tool->toolstate&ECHOBIND, 0, 1);
 		us_freeusercom(uc);
 		return;
 	}
@@ -1261,13 +1305,13 @@ void us_menu(INTSML count, char *par[])
 			(void)addstringtoinfstr("USER_binding_popup_");
 			(void)addstringtoinfstr(par[1]);
 			varkey = makekey(returninfstr());
-			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, varkey);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, varkey);
 			if (var == NOVARIABLE)
 			{
 				us_abortcommand(_("Cannot find the menu"));
 				return;
 			}
-			(void)setindkey((INTBIG)us_aid, VAID, varkey, 0, (INTBIG)par[3]);
+			(void)setindkey((INTBIG)us_tool, VTOOL, varkey, 0, (INTBIG)par[3]);
 			return;
 		}
 		if (namesamen(pp, "size", l) == 0 && l >= 1)
@@ -1298,7 +1342,7 @@ void us_menu(INTSML count, char *par[])
 					(void)addstringtoinfstr(par[1]);
 					(void)addstringtoinfstr(" command=bind set popup ");
 					(void)addstringtoinfstr(par[1]);
-					(void)sprintf(number, " %d", i);
+					(void)sprintf(number, " %ld", i);
 					(void)addstringtoinfstr(number);
 					(void)allocstring(&temp[i+1], returninfstr(), el_tempcluster);
 				}
@@ -1306,7 +1350,7 @@ void us_menu(INTSML count, char *par[])
 				(void)addstringtoinfstr("USER_binding_popup_");
 				(void)addstringtoinfstr(par[1]);
 				varkey = makekey(returninfstr());
-				(void)setvalkey((INTBIG)us_aid, VAID, varkey, (INTBIG)temp,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, varkey, (INTBIG)temp,
 					VSTRING|VISARRAY|VDONTSAVE|((s+1)<<VLENGTHSH));
 				for(i=0; i<=s; i++) efree(temp[i]);
 				efree((char *)temp);
@@ -1317,7 +1361,7 @@ void us_menu(INTSML count, char *par[])
 				(void)addstringtoinfstr("USER_binding_popup_");
 				(void)addstringtoinfstr(par[1]);
 				varkey = makekey(returninfstr());
-				var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, varkey);
+				var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, varkey);
 				if (var == NOVARIABLE)
 				{
 					us_abortcommand(_("Cannot find popup menu %s"), par[1]);
@@ -1357,11 +1401,11 @@ void us_menu(INTSML count, char *par[])
 					(void)addstringtoinfstr(par[1]);
 					(void)addstringtoinfstr(" command=bind set popup ");
 					(void)addstringtoinfstr(par[1]);
-					(void)sprintf(number, " %d", j);
+					(void)sprintf(number, " %ld", j);
 					(void)addstringtoinfstr(number);
 					(void)allocstring(&temp[j], returninfstr(), el_tempcluster);
 				}
-				(void)setvalkey((INTBIG)us_aid, VAID, varkey, (INTBIG)temp,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, varkey, (INTBIG)temp,
 					VSTRING|VISARRAY|VDONTSAVE|((s+1)<<VLENGTHSH));
 				for(i=0; i<=s; i++) efree(temp[i]);
 				efree((char *)temp);
@@ -1385,8 +1429,8 @@ void us_menu(INTSML count, char *par[])
 		/* allocate new menubar information */
 		if (count > 1)
 		{
-			us_pulldowns = (POPUPMENU **)emalloc((count-1) * (sizeof (POPUPMENU *)), us_aid->cluster);
-			us_pulldownmenupos = (INTSML *)emalloc((count-1) * SIZEOFINTSML, us_aid->cluster);
+			us_pulldowns = (POPUPMENU **)emalloc((count-1) * (sizeof (POPUPMENU *)), us_tool->cluster);
+			us_pulldownmenupos = (INTSML *)emalloc((count-1) * SIZEOFINTSML, us_tool->cluster);
 			if (us_pulldowns == 0 || us_pulldownmenupos == 0) return;
 			us_pulldownmenucount = count-1;
 		}
@@ -1416,7 +1460,9 @@ void us_menu(INTSML count, char *par[])
 				us_menubarsize = MENUBARHEIGHT;
 
 				/* load the information */
-				screensettextsize(el_curwindowpart, TXTMENU);
+				TDCLEAR(descript);
+				TDSETSIZE(descript, TXTMENU);
+				screensettextinfo(el_curwindowpart, NOTECHNOLOGY, descript);
 				x = 0;
 				for(i=1; i<count; i++)
 				{
@@ -1475,6 +1521,7 @@ void us_menu(INTSML count, char *par[])
 			arctot = pintot = comptot = puretot = 0;
 			for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 			{
+				if ((ap->userbits&ANOTUSED) != 0) continue;
 				np = getpinproto(ap);
 				if (np != NONODEPROTO && (np->userbits & NNOTUSED) != 0) continue;
 				arctot++;
@@ -1488,7 +1535,7 @@ void us_menu(INTSML count, char *par[])
 						comptot++;
 			}
 			if (pintot + comptot == 0) pintot = puretot;
-			x = arctot + pintot + comptot;   y = 1;
+			x = arctot + pintot + comptot + 1;   y = 1;
 			if (x > 40)
 			{
 				x = (x+2) / 3;
@@ -1517,19 +1564,19 @@ void us_menu(INTSML count, char *par[])
 
 	/* set the fixed menu up */
 	if (x == us_menux && y == us_menuy && position == us_menupos &&
-		(us_aid->aidstate&MENUON) != 0 && autoset == 0)
+		(us_tool->toolstate&MENUON) != 0 && autoset == 0)
 	{
 		ttyputverbose(M_("Menu has not changed"));
 		return;
 	}
 
 	if (position != us_menupos) resetpaletteparameters();
-	startobjectchange((INTBIG)us_aid, VAID);
+	startobjectchange((INTBIG)us_tool, VTOOL);
 	if (x != us_menux || y != us_menuy || position != us_menupos || autoset != 0)
 		(void)us_setmenusize((INTSML)x, (INTSML)y, (INTSML)position, autoset);
-	if ((us_aid->aidstate&MENUON) == 0)
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate|MENUON, VINTEGER);
-	endobjectchange((INTBIG)us_aid, VAID);
+	if ((us_tool->toolstate&MENUON) == 0)
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate|MENUON, VINTEGER);
+	endobjectchange((INTBIG)us_tool, VTOOL);
 }
 
 void us_mirror(INTSML count, char *par[])
@@ -1538,14 +1585,14 @@ void us_mirror(INTSML count, char *par[])
 	REGISTER INTSML amt, gamt, i;
 	REGISTER INTBIG nicount, lx, hx, ly, hy, dist, bestdist, aicount, newnicount;
 	REGISTER char *pt;
-	REGISTER VARIABLE *var;
+	REGISTER VARIABLE *var, *tempvar;
 	REGISTER ARCINST *ai, **ailist, **newailist;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *thepp, *pp;
 	REGISTER GEOM **list, *geom;
 	REGISTER HIGHLIGHT *high;
 	XARRAY transtz, rot, transfz, t1, t2;
-	INTBIG gx, gy, cx, cy, x, y, thex, they;
+	INTBIG gx, gy, cx, cy, x, y, thex, they, tempcenter[2];
 	extern COMCOMP us_mirrorp;
 
 	list = us_gethighlighted(OBJARCINST|OBJNODEINST, 0, 0);
@@ -1604,6 +1651,8 @@ void us_mirror(INTSML count, char *par[])
 			if (ni->temp1 == 0) continue;
 			dist = computedistance((lx+hx)/2, (ly+hy)/2, (ni->lowx+ni->highx)/2,
 				(ni->lowy+ni->highy)/2);
+
+			/* LINTED "bestdist" used in proper order */
 			if (theni == NONODEINST || dist < bestdist)
 			{
 				theni = ni;
@@ -1639,16 +1688,35 @@ void us_mirror(INTSML count, char *par[])
 
 	/* determine translation when mirroring about grab or trace point */
 	if (count >= 2) i = strlen(par[1]);
+	tempvar = NOVARIABLE;
 	if (count >= 2 && namesamen(par[1], "sensibly", i) == 0)
 	{
 		if (nicount == 1)
 		{
-			if (theni->proto->primindex == 0)
+			var = getvalkey((INTBIG)theni->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
+			if (var != NOVARIABLE)
 			{
-				var = getvalkey((INTBIG)theni->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
-				if (var != NOVARIABLE)
+				par[1] = "about-grab-point";
+			} else
+			{
+				/* special cases: schematic primitives should mirror sensibly */
+				if (theni->proto->primindex != 0 && theni->proto->tech == sch_tech)
 				{
-					par[1] = "about-grab-point";
+					if (theni->proto == sch_transistorprim)
+					{
+						tempcenter[0] = 0;
+						tempcenter[1] = -(theni->proto->highy - theni->proto->lowy) / 2;
+						tempvar = setvalkey((INTBIG)theni->proto, VNODEPROTO, el_prototype_center,
+							(INTBIG)tempcenter, VINTEGER|VISARRAY|(2<<VLENGTHSH));
+						par[1] = "about-grab-point";
+					} else if (theni->proto == sch_gndprim)
+					{
+						tempcenter[0] = 0;
+						tempcenter[1] = (theni->proto->highy - theni->proto->lowy) / 2;
+						tempvar = setvalkey((INTBIG)theni->proto, VNODEPROTO, el_prototype_center,
+							(INTBIG)tempcenter, VINTEGER|VISARRAY|(2<<VLENGTHSH));
+						par[1] = "about-grab-point";
+					}
 				}
 			}
 		}
@@ -1677,6 +1745,8 @@ void us_mirror(INTSML count, char *par[])
 		cx = (theni->lowx+theni->highx)/2;   cy = (theni->lowy+theni->highy)/2;
 		xform(cx, cy, &gx, &gy, t2);
 		gx -= cx;   gy -= cy;
+		if (tempvar != NOVARIABLE)
+			delvalkey((INTBIG)theni->proto, VNODEPROTO, el_prototype_center);
 	} else if (count >= 2 && namesamen(par[1], "about-trace-point", i) == 0 && i >= 7)
 	{
 		if (nicount != 1)
@@ -1744,6 +1814,8 @@ void us_mirror(INTSML count, char *par[])
 			/* add to the list of temporary nodes */
 			newnilist = (NODEINST **)emalloc((newnicount+1) * (sizeof (NODEINST *)), el_tempcluster);
 			if (newnilist == 0) break;
+
+			/* LINTED "nilist" used in proper order */
 			for(i=0; i<newnicount; i++) newnilist[i] = nilist[i];
 			if (newnicount > 0) efree((char *)nilist);
 			nilist = newnilist;
@@ -1760,6 +1832,8 @@ void us_mirror(INTSML count, char *par[])
 		/* add to the list of temporary arcs */
 		newailist = (ARCINST **)emalloc((aicount+1) * (sizeof (ARCINST *)), el_tempcluster);
 		if (newailist == 0) break;
+
+		/* LINTED "ailist" used in proper order */
 		for(i=0; i<aicount; i++) newailist[i] = ailist[i];
 		if (aicount > 0) efree((char *)ailist);
 		ailist = newailist;
@@ -1815,7 +1889,7 @@ static DIALOGITEM us_movetodialogitems[] =
  /*  5 */ {0, {32,48,48,142}, EDITTEXT, ""},
  /*  6 */ {0, {32,20,48,42}, MESSAGE, N_("Y:")}
 };
-DIALOG us_movetodialog = {{50,75,147,244}, N_("Move To Location"), 0, 6, us_movetodialogitems};
+static DIALOG us_movetodialog = {{50,75,147,244}, N_("Move To Location"), 0, 6, us_movetodialogitems};
 
 /* special items for the "move to" dialog: */
 #define DMVT_XPOS       3		/* X position (edit text) */
@@ -1840,7 +1914,7 @@ void us_move(INTSML count, char *par[])
 	REGISTER VARIABLE *var;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* make sure there is a current facet */
 	np = us_needfacet();
@@ -1955,7 +2029,7 @@ void us_move(INTSML count, char *par[])
 	/* special case if two objects are selected with snap points */
 	if (count == 0)
 	{
-		var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 		if (var != NOVARIABLE)
 		{
 			len = getlength(var);
@@ -1998,7 +2072,7 @@ void us_move(INTSML count, char *par[])
 	/* no arguments: simple motion */
 	if (count == 0)
 	{
-		if ((us_aid->aidstate&INTERACTIVE) != 0)
+		if ((us_tool->toolstate&INTERACTIVE) != 0)
 		{
 			/* interactive motion: track cursor */
 			us_multidraginit(bestlx, bestly, list, nodelist, total, 0);
@@ -2151,7 +2225,7 @@ void us_move(INTSML count, char *par[])
 		ang = atofr(par[1])*10/WHOLE;
 
 		/* adjust the cursor position if selecting interactively */
-		if ((us_aid->aidstate&INTERACTIVE) != 0)
+		if ((us_tool->toolstate&INTERACTIVE) != 0)
 		{
 			us_multidraginit(bestlx, bestly, list, nodelist, total, ang);
 			trackcursor(0, us_ignoreup, us_multidragbegin, us_multidragdown,
@@ -2353,13 +2427,12 @@ void us_node(INTSML count, char *par[])
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)ch, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 			{
-				var->textdescript = (var->textdescript & ~VTSIZE) |
-					(defaulttextsize(3) << VTSIZESH);
+				defaulttextsize(3, var->textdescript);
 
 				/* shift text down if on a facet instance */
 				if (ni->proto->primindex == 0)
 				{
-					var->textdescript = us_setdescriptoffset(var->textdescript,
+					us_setdescriptoffset(var->textdescript,
 						0, (ni->highy-ni->lowy) / el_curlib->lambda[el_curtech->techindex]);
 				}
 			}
@@ -2401,12 +2474,13 @@ void us_node(INTSML count, char *par[])
 		l = strlen(pt = par[1]);
 		if (namesamen(pt, "place-text", l) == 0 && l >= 2)
 		{
-			if (count < 6)
+			if (count < 9)
 			{
-				ttyputusage("node trace place-text LAYER FONT SCALE MESSAGE");
+				ttyputusage("node trace place-text LAYER SIZE FONT ITALIC BOLD UNDERLINE MESSAGE");
 				return;
 			}
-			us_layouttext(par[2], atoi(par[3]), atoi(par[4]), par[5]);
+			us_layouttext(par[2], atoi(par[3]), 1, atoi(par[4]), atoi(par[5]),
+				atoi(par[6]), atoi(par[7]), par[8]);
 			return;
 		}
 
@@ -2636,7 +2710,7 @@ void us_node(INTSML count, char *par[])
 			if (el_pleasestop != 0) return;
 
 			/* get the trace data in the "%T" variable */
-			var = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_commandvarname('T'));
+			var = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_commandvarname('T'));
 			if (var == NOVARIABLE)
 			{
 				us_abortcommand(_("Invalid outline information"));
@@ -2695,7 +2769,7 @@ void us_node(INTSML count, char *par[])
 				gridalign(&xcur, &ycur, us_alignment);
 
 				/* adjust the cursor position if selecting interactively */
-				if ((us_aid->aidstate&INTERACTIVE) != 0)
+				if ((us_tool->toolstate&INTERACTIVE) != 0)
 				{
 					us_pointinit(store, whichpoint);
 					trackcursor(0, us_ignoreup, us_pointbegin, us_addpdown,
@@ -2835,7 +2909,7 @@ void us_node(INTSML count, char *par[])
 				gridalign(&xcur, &ycur, us_alignment);
 
 				/* adjust the cursor position if selecting interactively */
-				if ((us_aid->aidstate&INTERACTIVE) != 0)
+				if ((us_tool->toolstate&INTERACTIVE) != 0)
 				{
 					us_pointinit(store, whichpoint);
 					trackcursor(0, us_ignoreup, us_pointbegin, us_movepdown,
