@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomoq.c
- * User interface aid: command handler for O through Q
+ * User interface tool: command handler for O through Q
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -32,7 +32,7 @@
 #include "usr.h"
 #include "egraphics.h"
 
-void us_offaid(INTSML count, char *par[])
+void us_offtool(INTSML count, char *par[])
 {
 	REGISTER INTSML permanently;
 
@@ -41,10 +41,10 @@ void us_offaid(INTSML count, char *par[])
 		count--;
 		permanently = 1;
 	} else permanently = 0;
-	us_setaid(count, par, permanently);
+	us_settool(count, par, permanently);
 }
 
-void us_onaid(INTSML count, char *par[])
+void us_ontool(INTSML count, char *par[])
 {
 	REGISTER INTSML catchup;
 
@@ -53,7 +53,7 @@ void us_onaid(INTSML count, char *par[])
 		count--;
 		catchup = 3;
 	} else catchup = 2;
-	us_setaid(count, par, catchup);
+	us_settool(count, par, catchup);
 }
 
 void us_outhier(INTSML count, char *par[])
@@ -89,7 +89,7 @@ void us_outhier(INTSML count, char *par[])
 
 	/* see if a node with an export is highlighted */
 	curpp = NOPORTPROTO;
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var != NOVARIABLE)
 	{
 		len = (INTSML)getlength(var);
@@ -289,7 +289,7 @@ void us_package(INTSML count, char *par[])
 		}
 		ni->temp1 = (INTBIG)newni;
 		newni->userbits = ni->userbits;
-		newni->textdescript = ni->textdescript;
+		TDCOPY(newni->textdescript, ni->textdescript);
 		if (copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST) != 0)
 		{
 			ttyputnomemory();
@@ -302,13 +302,15 @@ void us_package(INTSML count, char *par[])
 		{
 			if (ppt->subnodeinst != ni) continue;
 			npt = newportproto(np, newni, ppt->subportproto, ppt->protoname);
-			npt->userbits = (npt->userbits & ~STATEBITS) | (ppt->userbits & STATEBITS);
-			npt->textdescript = (ppt->textdescript & ~VTSIZE) |
-				(defaulttextsize(1) << VTSIZESH);
-			if (copyvars((INTBIG)ppt, VPORTPROTO, (INTBIG)npt, VPORTPROTO) != 0)
+			if (npt != NOPORTPROTO)
 			{
-				ttyputnomemory();
-				return;
+				npt->userbits = (npt->userbits & ~STATEBITS) | (ppt->userbits & STATEBITS);
+				TDCOPY(npt->textdescript, ppt->textdescript);
+				if (copyvars((INTBIG)ppt, VPORTPROTO, (INTBIG)npt, VPORTPROTO) != 0)
+				{
+					ttyputnomemory();
+					return;
+				}
 			}
 		}
 	}
@@ -394,8 +396,10 @@ void us_port(INTSML count, char *par[])
 				ttyputusage("port labels none|short|long|crosses");
 				return;
 			}
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			startobjectchange((INTBIG)us_tool, VTOOL);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				(us_useroptions & ~PORTLABELS) | labels, VINTEGER);
+			endobjectchange((INTBIG)us_tool, VTOOL);
 		}
 		switch (us_useroptions&PORTLABELS)
 		{
@@ -420,8 +424,10 @@ void us_port(INTSML count, char *par[])
 				ttyputusage("port export-labels none|short|long|crosses");
 				return;
 			}
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			startobjectchange((INTBIG)us_tool, VTOOL);
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				(us_useroptions & ~EXPORTLABELS) | labels, VINTEGER);
+			endobjectchange((INTBIG)us_tool, VTOOL);
 		}
 		switch (us_useroptions&EXPORTLABELS)
 		{
@@ -581,6 +587,9 @@ void us_port(INTSML count, char *par[])
 			/* only look for facets, not primitives */
 			if (ni->proto->primindex != 0) continue;
 
+			/* ignore recursive references (showing icon in contents) */
+			if (ni->proto->cell == np->cell) continue;
+
 			/* clear marks on the ports of this node */
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				pp->temp1 = 0;
@@ -614,7 +623,7 @@ void us_port(INTSML count, char *par[])
 	if (namesamen(pt, "highlighted-re-export", l) == 0 && l >= 1)
 	{
 		/* get the necessary polygon */
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 		/* get the bounds of the selected area */
 		np = us_getareabounds(&lx, &hx, &ly, &hy);
@@ -699,7 +708,7 @@ void us_port(INTSML count, char *par[])
 			}
 
 			/* get the necessary polygon */
-			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 			/* remove highlighting */
 			us_pushhighlight();
