@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomtz.c
- * User interface aid: command handler for T through V
+ * User interface tool: command handler for T through V
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -107,14 +107,14 @@ void us_technology(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "on", l) == 0 && l >= 2)
 		{
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | AUTOSWITCHTECHNOLOGY, VINTEGER);
 			ttyputverbose(M_("Technology will automatically switch to match facet"));
 			return;
 		}
 		if (namesamen(pp, "off", l) == 0 && l >= 2)
 		{
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~AUTOSWITCHTECHNOLOGY, VINTEGER);
 			ttyputverbose(M_("Automatic technology changing disabled"));
 			return;
@@ -170,7 +170,7 @@ void us_technology(INTSML count, char *par[])
 		us_setarcproto(NOARCPROTO, 1);
 		oldlam = el_curlib->lambda[el_curtech->techindex];
 		us_getcolormap(tech, COLORSEXISTING, 1);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_technology, (INTBIG)tech,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_technology, (INTBIG)tech,
 			VTECHNOLOGY|VDONTSAVE);
 		us_adjustlambda(oldlam, el_curlib->lambda[el_curtech->techindex]);
 
@@ -229,7 +229,7 @@ void us_technology(INTSML count, char *par[])
 			us_adjustlambda(el_curlib->lambda[el_curtech->techindex],
 				el_curlib->lambda[newtech->techindex]);
 			us_getcolormap(newtech, COLORSEXISTING, 1);
-			(void)setvalkey((INTBIG)us_aid, VAID, us_current_technology,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_technology,
 				(INTBIG)newtech, VTECHNOLOGY|VDONTSAVE);
 
 			/* fix up the menu entries */
@@ -253,32 +253,32 @@ void us_technology(INTSML count, char *par[])
 	ttyputbadusage("technology");
 }
 
-void us_tellaid(INTSML count, char *par[])
+void us_telltool(INTSML count, char *par[])
 {
-	extern COMCOMP us_tellaidp;
-	REGISTER AIDENTRY *aid;
+	extern COMCOMP us_telltoolp;
+	REGISTER TOOL *tool;
 
 	if (count == 0)
 	{
-		count = ttygetparam(M_("Which aid: "), &us_tellaidp, MAXPARS, par);
+		count = ttygetparam(M_("Which tool: "), &us_telltoolp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
 			return;
 		}
 	}
-	aid = getaid(par[0]);
-	if (aid == NOAID)
+	tool = gettool(par[0]);
+	if (tool == NOTOOL)
 	{
-		us_abortcommand(_("No aid called %s"), par[0]);
+		us_abortcommand(_("No tool called %s"), par[0]);
 		return;
 	}
-	if (aid->setmode == 0)
+	if (tool->setmode == 0)
 	{
-		us_abortcommand(_("Aid %s cannot take commands"), aid->aidname);
+		us_abortcommand(_("Tool %s cannot take commands"), tool->toolname);
 		return;
 	}
-	(*aid->setmode)((INTSML)(count-1), &par[1]);
+	(*tool->setmode)((INTSML)(count-1), &par[1]);
 }
 
 void us_terminal(INTSML count, char *par[])
@@ -287,7 +287,11 @@ void us_terminal(INTSML count, char *par[])
 	REGISTER char *pt, *pp;
 	REGISTER VARIABLE *err;
 	REGISTER char *varname;
+	INTSML top, left, bottom, right;
+	INTBIG msgcoord[4];
 	char *truename;
+	REGISTER COMCOMP *comcomp;
+	float newfloat;
 	extern COMCOMP us_libraryup,
 		us_colorreadp, us_helpp, us_technologyup, us_technologyeenp, us_viewfp,
 		us_technologyeeap, us_technologyeelp, us_arrayxp, us_colorentryp, us_viewc2p,
@@ -298,14 +302,12 @@ void us_terminal(INTSML count, char *par[])
 		us_varvep, us_nodetp, us_technologyedlp, us_librarydp, us_technologyctdp,
 		us_textdsp, us_noyesp, us_librarywriteformatp, us_windowrnamep, us_defnodep,
 		us_technologyclsrp, us_technologyclscp, us_technologyclsecp, us_technologyclip,
-		us_technologycnsp, us_technologyclgp, us_technologyclsp, us_showdp,
+		us_technologycnsp, us_technologyclsp, us_showdp, sim_spiceformp,
 		us_colorhighp, us_bindgkeyp, us_gridp, us_technologytp, us_nodetcaip,
 		us_librarykp, us_findobjap, us_window3dp, us_nodetptlp, us_renamecp,
 		us_findexportp, us_findnnamep, us_showup, us_varop, us_copyfacetdp,
-		us_findnodep, us_technologycnnp, us_showep, us_textfp, us_textsp, us_viewdp;
-
-	REGISTER COMCOMP *comcomp;
-	float newfloat;
+		us_findnodep, us_technologycnnp, us_showep, us_textfp, us_textsp, us_viewdp,
+		us_interpretcp;
 
 	if (count == 0)
 	{
@@ -324,44 +326,44 @@ void us_terminal(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesame(pp, "lock-keys-on-error") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | NOKEYLOCK, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | NOKEYLOCK, VINTEGER);
 			ttyputverbose(M_("Command errors will not lockout single-key commands"));
 			return;
 		}
 		if (namesame(pp, "only-informative-messages") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~JUSTTHEFACTS, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~JUSTTHEFACTS, VINTEGER);
 			ttyputverbose(M_("All messages will be displayed"));
 			return;
 		}
 		if (namesame(pp, "use-electric-commands") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | NODETAILS, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | NODETAILS, VINTEGER);
 			ttyputverbose(M_("Messages will not mention specific commands"));
 			return;
 		}
 		if (namesame(pp, "display-dialogs") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~USEDIALOGS, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~USEDIALOGS, VINTEGER);
 			ttyputverbose(M_("Dialogs will not be used"));
 			return;
 		}
 		if (namesame(pp, "permanent-menu-highlighting") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | ONESHOTMENU, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | ONESHOTMENU, VINTEGER);
 			ttyputverbose(M_("Menu highlighting will clear after each command"));
 			return;
 		}
 		if (namesame(pp, "track-cursor-coordinates") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~SHOWXY, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~SHOWXY, VINTEGER);
 			ttyputverbose(M_("Technology and Lambda will be displayed where cursor coordinates are"));
 			us_redostatus(NOWINDOWFRAME);
 			return;
 		}
 		if (namesame(pp, "beep") == 0)
 		{
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~TERMBEEP, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~TERMBEEP, VINTEGER);
 			ttyputverbose(M_("Terminal beep disabled"));
 			return;
 		}
@@ -369,7 +371,7 @@ void us_terminal(INTSML count, char *par[])
 		{
 			if (us_termaudit != NULL) xclose(us_termaudit);
 			us_termaudit = NULL;
-			(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~TTYAUDIT, VINTEGER);
+			(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~TTYAUDIT, VINTEGER);
 			ttyputverbose(M_("No longer saving messages"));
 			return;
 		}
@@ -377,37 +379,49 @@ void us_terminal(INTSML count, char *par[])
 		return;
 	}
 
+	if (namesamen(pp, "get-location", l) == 0)
+	{
+		getmessagesframeinfo(&top, &left, &bottom, &right);
+		msgcoord[0] = top;
+		msgcoord[1] = left;
+		msgcoord[2] = bottom;
+		msgcoord[3] = right;
+		(void)setval((INTBIG)us_tool, VTOOL, "USER_messages_position",
+			(INTBIG)msgcoord, VINTEGER|VISARRAY|(4<<VLENGTHSH));
+		return;
+	}
+
 	if (namesamen(pp, "lock-keys-on-error", l) == 0 && l >= 2)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~NOKEYLOCK, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~NOKEYLOCK, VINTEGER);
 		ttyputverbose(M_("Command errors will lockout single-key commands"));
 		return;
 	}
 
 	if (namesamen(pp, "only-informative-messages", l) == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | JUSTTHEFACTS, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | JUSTTHEFACTS, VINTEGER);
 		ttyputverbose(M_("Nonessential messages will be supressed"));
 		return;
 	}
 
 	if (namesamen(pp, "display-dialogs", l) == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | USEDIALOGS, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | USEDIALOGS, VINTEGER);
 		ttyputverbose(M_("Dialogs will be use where appropriate"));
 		return;
 	}
 
 	if (namesamen(pp, "permanent-menu-highlighting", l) == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~ONESHOTMENU, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~ONESHOTMENU, VINTEGER);
 		ttyputverbose(M_("Menu highlighting will show current node/arc"));
 		return;
 	}
 
 	if (namesame(pp, "track-cursor-coordinates") == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | SHOWXY, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | SHOWXY, VINTEGER);
 		ttyputverbose(M_("Cursor coordinates will be displayed where TECH/LAMBDA are"));
 		us_redostatus(NOWINDOWFRAME);
 		return;
@@ -415,13 +429,13 @@ void us_terminal(INTSML count, char *par[])
 
 	if (namesamen(pp, "use-electric-commands", l) == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~NODETAILS, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~NODETAILS, VINTEGER);
 		ttyputverbose(M_("Messages will use specific Electric commands"));
 		return;
 	}
 	if (namesamen(pp, "beep", l) == 0)
 	{
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | TERMBEEP, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | TERMBEEP, VINTEGER);
 		ttyputverbose(M_("Terminal beep enabled"));
 		return;
 	}
@@ -435,7 +449,7 @@ void us_terminal(INTSML count, char *par[])
 			return;
 		}
 		ttyputmsg(_("Saving messages to '%s'"), truename);
-		(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | TTYAUDIT, VINTEGER);
+		(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | TTYAUDIT, VINTEGER);
 		return;
 	}
 
@@ -504,6 +518,7 @@ void us_terminal(INTSML count, char *par[])
 			if (namesame(par[3], "help") == 0)          comcomp = &us_helpp; else
 			if (namesame(par[3], "highlayer") == 0)     comcomp = &us_colorhighp; else
 			if (namesame(par[3], "iconopt") == 0)       comcomp = &us_copyfacetdp; else
+			if (namesame(par[3], "javaopt") == 0)       comcomp = &us_interpretcp; else
 			if (namesame(par[3], "inductance") == 0)    comcomp = &us_technologyclsecp; else
 			if (namesame(par[3], "labels") == 0)        comcomp = &us_portlp; else
 			if (namesame(par[3], "lambda") == 0)        comcomp = &us_lambdachp; else
@@ -532,6 +547,7 @@ void us_terminal(INTSML count, char *par[])
 			if (namesame(par[3], "showdetail") == 0)    comcomp = &us_showop; else
 			if (namesame(par[3], "show") == 0)          comcomp = &us_showp; else
 			if (namesame(par[3], "siemens") == 0)       comcomp = &us_technologyclip; else
+			if (namesame(par[3], "spicemodel") == 0)    comcomp = &sim_spiceformp; else
 			if (namesame(par[3], "spread") == 0)        comcomp = &us_spreaddp; else
 			if (namesame(par[3], "technology") == 0)    comcomp = &us_technologyup; else
 			if (namesame(par[3], "techopt") == 0)       comcomp = &us_technologytp; else
@@ -541,7 +557,6 @@ void us_terminal(INTSML count, char *par[])
 			if (namesame(par[3], "variable") == 0)      comcomp = &us_varvep; else
 			if (namesame(par[3], "view") == 0)          comcomp = &us_viewc2p; else
 			if (namesame(par[3], "visiblelayers") == 0) comcomp = &us_visiblelayersp; else
-			if (namesame(par[3], "widlen") == 0)        comcomp = &us_technologyclgp; else
 			if (namesame(par[3], "windowview") == 0)    comcomp = &us_windowrnamep; else
 				comcomp = us_getcomcompfromkeyword(par[3]);
 			if (comcomp == NOCOMCOMP)
@@ -554,8 +569,8 @@ void us_terminal(INTSML count, char *par[])
 		}
 		if (*pt == 0)
 		{
-			if (getval((INTBIG)us_aid, VAID, -1, varname) != NOVARIABLE)
-				(void)delval((INTBIG)us_aid, VAID, varname);
+			if (getval((INTBIG)us_tool, VTOOL, -1, varname) != NOVARIABLE)
+				(void)delval((INTBIG)us_tool, VTOOL, varname);
 			return;
 		}
 
@@ -565,12 +580,12 @@ void us_terminal(INTSML count, char *par[])
 			for(pp = pt; *pp != 0; pp++) if (*pp == '.')
 			{
 				newfloat = (float)atof(pt);
-				err = setval((INTBIG)us_aid, VAID, varname, castint(newfloat), VFLOAT|VDONTSAVE);
+				err = setval((INTBIG)us_tool, VTOOL, varname, castint(newfloat), VFLOAT|VDONTSAVE);
 				break;
 			}
 			if (*pp == 0)
-				err = setval((INTBIG)us_aid, VAID, varname, myatoi(pt), VINTEGER|VDONTSAVE);
-		} else err = setval((INTBIG)us_aid, VAID, varname, (INTBIG)pt, VSTRING|VDONTSAVE);
+				err = setval((INTBIG)us_tool, VTOOL, varname, myatoi(pt), VINTEGER|VDONTSAVE);
+		} else err = setval((INTBIG)us_tool, VTOOL, varname, (INTBIG)pt, VSTRING|VDONTSAVE);
 		if (err == NOVARIABLE)
 		{
 			us_abortcommand(_("Problem setting variable %s"), par[1]);
@@ -655,9 +670,10 @@ void us_terminal(INTSML count, char *par[])
 
 void us_text(INTSML count, char *par[])
 {
-	REGISTER INTBIG descript, grabpoint, newgrabpoint, olddescript, len, font;
+	REGISTER INTBIG grabpoint, newgrabpoint, len, font;
 	REGISTER INTSML i, l;
 	INTBIG xw, yw, xcur, ycur, adjxc, adjyc;
+	UINTBIG descript[TEXTDESCRIPTSIZE], olddescript[TEXTDESCRIPTSIZE];
 	INTSML tsx, tsy, style;
 	REGISTER char *pp, *str;
 	REGISTER NODEINST *ni;
@@ -670,7 +686,7 @@ void us_text(INTSML count, char *par[])
 	static char *smartstyle[3] = {N_("off"), N_("inside"), N_("outside")};
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	if (count == 0)
 	{
@@ -830,7 +846,7 @@ void us_text(INTSML count, char *par[])
 			return;
 		}
 		ttyputverbose(M_("Now using %s editor for text"), us_editortable[i].editorname);
-		setvalkey((INTBIG)us_aid, VAID, us_text_editor, (INTBIG)us_editortable[i].editorname,
+		setvalkey((INTBIG)us_tool, VTOOL, us_text_editor, (INTBIG)us_editortable[i].editorname,
 			VSTRING);
 		return;
 	}
@@ -841,7 +857,7 @@ void us_text(INTSML count, char *par[])
 			ttyputverbose(M_("Annotation text is already easy to select")); else
 		{
 			ttyputverbose(M_("Annotation text will be easily selectable"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions | NOTEXTSELECT, VINTEGER);
 		}
 		return;
@@ -853,7 +869,7 @@ void us_text(INTSML count, char *par[])
 			ttyputverbose(M_("Annotation text is already hard to select")); else
 		{
 			ttyputverbose(M_("Annotation text will be hard to select (only when the 'find' command does NOT have the 'port' option)"));
-			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 				us_useroptions & ~NOTEXTSELECT, VINTEGER);
 		}
 		return;
@@ -868,11 +884,14 @@ void us_text(INTSML count, char *par[])
 			ttyputusage("text default-export-size SIZE");
 			return;
 		}
-		font = us_gettextsize(par[1], defaulttextsize(1));
+		defaulttextsize(1, descript);
+		font = us_gettextsize(par[1], TDGETSIZE(descript));
 		if (font < 0) return;
+		TDSETSIZE(descript, font);
 
 		/* set the default text size */
-		setval((INTBIG)us_aid, VAID, "USER_default_export_text_size", font, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_export_text_size",
+			(INTBIG)descript, VINTEGER|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Default export text size is now %s"), us_describefont(font));
 		return;
 	}
@@ -886,11 +905,14 @@ void us_text(INTSML count, char *par[])
 			ttyputusage("text default-node-size SIZE");
 			return;
 		}
-		font = us_gettextsize(par[1], defaulttextsize(3));
+		defaulttextsize(3, descript);
+		font = us_gettextsize(par[1], TDGETSIZE(descript));
 		if (font < 0) return;
+		TDSETSIZE(descript, font);
 
 		/* set the default text size */
-		setval((INTBIG)us_aid, VAID, "USER_default_node_text_size", font, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_node_text_size",
+			(INTBIG)descript, VINTEGER|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Default node text size is now %s"), us_describefont(font));
 		return;
 	}
@@ -904,11 +926,14 @@ void us_text(INTSML count, char *par[])
 			ttyputusage("text default-arc-size SIZE");
 			return;
 		}
-		font = us_gettextsize(par[1], defaulttextsize(4));
+		defaulttextsize(4, descript);
+		font = us_gettextsize(par[1], TDGETSIZE(descript));
 		if (font < 0) return;
+		TDSETSIZE(descript, font);
 
 		/* set the default text size */
-		setval((INTBIG)us_aid, VAID, "USER_default_arc_text_size", font, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_arc_text_size",
+			(INTBIG)descript, VINTEGER|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Default arc text size is now %s"), us_describefont(font));
 		return;
 	}
@@ -922,11 +947,14 @@ void us_text(INTSML count, char *par[])
 			ttyputusage("text default-facet-size SIZE");
 			return;
 		}
-		font = us_gettextsize(par[1], defaulttextsize(5));
+		defaulttextsize(5, descript);
+		font = us_gettextsize(par[1], TDGETSIZE(descript));
 		if (font < 0) return;
+		TDSETSIZE(descript, font);
 
 		/* set the default text size */
-		setval((INTBIG)us_aid, VAID, "USER_default_facet_text_size", font, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_facet_text_size",
+			(INTBIG)descript, VINTEGER|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Default facet text size is now %s"), us_describefont(font));
 		return;
 	}
@@ -940,11 +968,14 @@ void us_text(INTSML count, char *par[])
 			ttyputusage("text default-nonlayout-text-size SIZE");
 			return;
 		}
-		font = us_gettextsize(par[1], defaulttextsize(2));
+		defaulttextsize(2, descript);
+		font = us_gettextsize(par[1], TDGETSIZE(descript));
 		if (font < 0) return;
+		TDSETSIZE(descript, font);
 
 		/* set the default text size */
-		setval((INTBIG)us_aid, VAID, "USER_default_nonlayout_text_size", font, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_nonlayout_text_size",
+			(INTBIG)descript, VINTEGER|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Default nonlayout text size is now %s"), us_describefont(font));
 		return;
 	}
@@ -953,11 +984,11 @@ void us_text(INTSML count, char *par[])
 	if (namesamen(pp, "default-interior-only", l) == 0 && l >= 9)
 	{
 		/* get current value */
-		var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_default_text_style");
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_default_text_style");
 		if (var == NOVARIABLE) grabpoint = VTPOSCENT; else grabpoint = var->addr;
 
 		/* set the default interior style */
-		setval((INTBIG)us_aid, VAID, "USER_default_text_style",
+		setval((INTBIG)us_tool, VTOOL, "USER_default_text_style",
 			grabpoint|VTINTERIOR, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Default text is only visible inside facet"));
 		return;
@@ -965,11 +996,11 @@ void us_text(INTSML count, char *par[])
 	if (namesamen(pp, "default-exterior", l) == 0 && l >= 11)
 	{
 		/* get current value */
-		var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_default_text_style");
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_default_text_style");
 		if (var == NOVARIABLE) grabpoint = VTPOSCENT; else grabpoint = var->addr;
 
 		/* set the default interior style */
-		setval((INTBIG)us_aid, VAID, "USER_default_text_style",
+		setval((INTBIG)us_tool, VTOOL, "USER_default_text_style",
 			grabpoint & ~VTINTERIOR, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Default text is visible outside of facet"));
 		return;
@@ -979,7 +1010,7 @@ void us_text(INTSML count, char *par[])
 	if (namesamen(pp, "default-style", l) == 0 && l >= 9)
 	{
 		/* get current value */
-		var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_default_text_style");
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_default_text_style");
 		if (var == NOVARIABLE) grabpoint = VTPOSCENT; else grabpoint = var->addr;
 
 		/* if no argument provided, show current value */
@@ -994,11 +1025,10 @@ void us_text(INTSML count, char *par[])
 
 		/* get new value */
 		newgrabpoint = us_gettextposition(par[1]);
-		if (newgrabpoint < 0) return;
 		grabpoint = (grabpoint & ~VTPOSITION) | newgrabpoint;
 
 		/* set the default text style */
-		setval((INTBIG)us_aid, VAID, "USER_default_text_style",
+		setval((INTBIG)us_tool, VTOOL, "USER_default_text_style",
 			grabpoint, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Default text style is now %s"), us_describestyle(grabpoint));
 		return;
@@ -1008,7 +1038,7 @@ void us_text(INTSML count, char *par[])
 	if (namesamen(pp, "default-horizontal-style", l) == 0 && l >= 9)
 	{
 		/* get current value */
-		var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_default_text_smart_style");
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_default_text_smart_style");
 		if (var == NOVARIABLE) grabpoint = 0; else grabpoint = var->addr;
 
 		/* if no argument provided, show current value */
@@ -1030,14 +1060,14 @@ void us_text(INTSML count, char *par[])
 		}
 
 		/* set the default text style */
-		setval((INTBIG)us_aid, VAID, "USER_default_text_smart_style", grabpoint, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_text_smart_style", grabpoint, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Default horizontal text style is now %s"), _(smartstyle[grabpoint&03]));
 		return;
 	}
 	if (namesamen(pp, "default-vertical-style", l) == 0 && l >= 9)
 	{
 		/* get current value */
-		var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_default_text_smart_style");
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_default_text_smart_style");
 		if (var == NOVARIABLE) grabpoint = 0; else grabpoint = var->addr;
 
 		/* if no argument provided, show current value */
@@ -1059,7 +1089,7 @@ void us_text(INTSML count, char *par[])
 		}
 
 		/* set the default text style */
-		setval((INTBIG)us_aid, VAID, "USER_default_text_smart_style", grabpoint, VINTEGER|VDONTSAVE);
+		setval((INTBIG)us_tool, VTOOL, "USER_default_text_smart_style", grabpoint, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Default vertical text style is now %s"), _(smartstyle[(grabpoint>>2)&03]));
 		return;
 	}
@@ -1090,7 +1120,7 @@ void us_text(INTSML count, char *par[])
 
 		/* get the text and current descriptor */
 		str = us_gethighstring(high);
-		olddescript = us_gethighdescript(high);
+		us_gethighdescript(high, olddescript);
 
 		/* get size of text */
 		len = 1;
@@ -1105,8 +1135,7 @@ void us_text(INTSML count, char *par[])
 			if (high->fromgeom->entrytype == OBJARCINST)
 				tech = high->fromgeom->entryaddr.ai->proto->tech; else
 					tech = high->fromgeom->entryaddr.ni->proto->tech;
-			screensettextsize(el_curwindowpart, truefontsize((olddescript&VTSIZE)>>VTSIZESH,
-				el_curwindowpart, tech));
+			screensettextinfo(el_curwindowpart, tech, olddescript);
 			screengettextsize(el_curwindowpart, str, &tsx, &tsy);
 			xw = muldiv(tsx, el_curwindowpart->screenhx-el_curwindowpart->screenlx,
 				el_curwindowpart->usehx-el_curwindowpart->uselx);
@@ -1122,12 +1151,8 @@ void us_text(INTSML count, char *par[])
 		if (count >= 2)
 		{
 			grabpoint = us_gettextposition(par[1]);
-			if (grabpoint < 0)
-			{
-				(void)us_pophighlight(0);
-				return;
-			}
-			descript = (olddescript & ~VTPOSITION) | grabpoint;
+			TDCOPY(descript, olddescript);
+			TDSETPOS(descript, grabpoint);
 		} else
 		{
 			/* get co-ordinates of cursor */
@@ -1139,7 +1164,7 @@ void us_text(INTSML count, char *par[])
 			gridalign(&xcur, &ycur, us_alignment);
 
 			/* adjust the cursor position if selecting interactively */
-			if ((us_aid->aidstate&INTERACTIVE) != 0)
+			if ((us_tool->toolstate&INTERACTIVE) != 0)
 			{
 				us_textgrabinit(olddescript, xw, yw, adjxc, adjyc, high->fromgeom);
 				trackcursor(0, us_ignoreup, us_textgrabbegin, us_textgrabdown,
@@ -1149,18 +1174,14 @@ void us_text(INTSML count, char *par[])
 			}
 
 			/* determine grab point from current cursor location */
-			descript = us_figuregrabpoint(olddescript, xcur, ycur, adjxc, adjyc, xw, yw);
-			if (descript == -1)
-			{
-				(void)us_pophighlight(0);
-				return;
-			}
+			TDCOPY(descript, olddescript);
+			us_figuregrabpoint(descript, xcur, ycur, adjxc, adjyc, xw, yw);
 		}
 
 		/* set the new descriptor */
 		startobjectchange((INTBIG)high->fromgeom->entryaddr.blind,
 			high->fromgeom->entrytype == OBJNODEINST ? VNODEINST : VARCINST);
-		descript = us_rotatedescriptI(high->fromgeom, descript);
+		us_rotatedescriptI(high->fromgeom, descript);
 		us_modifytextdescript(high, descript);
 
 		/* redisplay the text */
@@ -1182,14 +1203,17 @@ void us_text(INTSML count, char *par[])
 
 		/* get old descriptor */
 		if (high->fromvar != NOVARIABLE)
-			olddescript = high->fromvar->textdescript; else
-				if (high->fromport != NOPORTPROTO) olddescript = high->fromport->textdescript; else
-					if (high->fromgeom->entrytype == OBJNODEINST)
+		{
+			TDCOPY(olddescript, high->fromvar->textdescript);
+		} else if (high->fromport != NOPORTPROTO)
+		{
+			TDCOPY(olddescript, high->fromport->textdescript);
+		} else if (high->fromgeom->entrytype == OBJNODEINST)
 		{
 			ni = high->fromgeom->entryaddr.ni;
-			olddescript = ni->textdescript;
+			TDCOPY(olddescript, ni->textdescript);
 		}
-		font = (olddescript & VTSIZE) >> VTSIZESH;
+		font = TDGETSIZE(olddescript);
 		font = us_gettextsize(par[1], font);
 		if (font < 0) return;
 
@@ -1201,7 +1225,8 @@ void us_text(INTSML count, char *par[])
 		startobjectchange((INTBIG)high->fromgeom->entryaddr.blind,
 			high->fromgeom->entrytype == OBJNODEINST ? VNODEINST : VARCINST);
 
-		us_modifytextdescript(high, (olddescript & ~VTSIZE) | (font << VTSIZESH));
+		TDSETSIZE(olddescript, font);
+		us_modifytextdescript(high, olddescript);
 
 		/* redisplay the text */
 		endobjectchange((INTBIG)high->fromgeom->entryaddr.blind,
@@ -1227,7 +1252,9 @@ void us_text(INTSML count, char *par[])
 
 		ni = high->fromgeom->entryaddr.ni;
 		startobjectchange((INTBIG)ni, VNODEINST);
-		us_modifytextdescript(high, high->fromvar->textdescript | VTINTERIOR);
+		TDCOPY(descript, high->fromvar->textdescript);
+		TDSETINTERIOR(descript, VTINTERIOR);
+		us_modifytextdescript(high, descript);
 		endobjectchange((INTBIG)ni, VNODEINST);
 		return;
 	}
@@ -1246,7 +1273,9 @@ void us_text(INTSML count, char *par[])
 		}
 		ni = high->fromgeom->entryaddr.ni;
 		startobjectchange((INTBIG)ni, VNODEINST);
-		us_modifytextdescript(high, high->fromvar->textdescript & ~VTINTERIOR);
+		TDCOPY(descript, high->fromvar->textdescript);
+		TDSETINTERIOR(descript, 0);
+		us_modifytextdescript(high, descript);
 		endobjectchange((INTBIG)ni, VNODEINST);
 		return;
 	}
@@ -1259,11 +1288,17 @@ void us_undo(INTSML count, char *par[])
 	REGISTER INTBIG i, j;
 	REGISTER INTSML ret, majorchange, doingundo;
 	REGISTER char *direction;
-	AIDENTRY *aid;
+	TOOL *tool;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *lib;
 	INTSML *totals;
 
+	if (count > 0 && namesamen(par[0], "clear", strlen(par[0])) == 0)
+	{
+		noundoallowed();
+		return;
+	}
+
 	if (count > 0 && namesamen(par[0], "save", strlen(par[0])) == 0)
 	{
 		if (count < 2)
@@ -1315,27 +1350,27 @@ void us_undo(INTSML count, char *par[])
 	} else i = -1;
 
 	/* do the undo */
-	totals = (INTSML *)emalloc((el_maxaid * SIZEOFINTSML), el_tempcluster);
+	totals = (INTSML *)emalloc((el_maxtools * SIZEOFINTSML), el_tempcluster);
 	if (totals == 0)
 	{
 		ttyputnomemory();
 		return;
 	}
-	for(j=0; j<el_maxaid; j++) totals[j] = 0;
+	for(j=0; j<el_maxtools; j++) totals[j] = 0;
 
 	/* do the undo/redo */
 	majorchange = 0;
 	for(j=0; ; j++)
 	{
-		if (doingundo != 0) ret = undoabatch(&aid); else
-			ret = redoabatch(&aid);
+		if (doingundo != 0) ret = undoabatch(&tool); else
+			ret = redoabatch(&tool);
 		if (ret == 0)
 		{
 			if (j != 0) ttyputmsg(_("Partial change %sne"), direction); else
 				us_abortcommand(_("No changes to %s"), direction);
 			break;
 		}
-		totals[aid->aidindex]++;
+		totals[tool->toolindex]++;
 		if (i < 0)
 		{
 			/* no batch count specified: go back to significant change */
@@ -1348,7 +1383,7 @@ void us_undo(INTSML count, char *par[])
 					for(;;)
 					{
 						if (undonature(0) >= 0) break;
-						(void)redoabatch(&aid);
+						(void)redoabatch(&tool);
 					}
 				}
 				break;
@@ -1360,8 +1395,8 @@ void us_undo(INTSML count, char *par[])
 		}
 	}
 
-	for(j=0; j<el_maxaid; j++) if (totals[j] != 0)
-		ttyputverbose("%d %s %s %sne", totals[j], el_aids[j].aidname,
+	for(j=0; j<el_maxtools; j++) if (totals[j] != 0)
+		ttyputverbose("%d %s %s %sne", totals[j], el_tools[j].toolname,
 			makeplural(_("change"), totals[j]), direction);
 	efree((char *)totals);
 
@@ -1385,8 +1420,8 @@ void us_undo(INTSML count, char *par[])
  * routine to determine whether the string "testcase" satisfies the pattern "pattern".
  * Returns nonzero if it matches.
  */
-INTSML us_patternmatch(char *pattern, char *testcase);
-INTSML us_patternmatchhere(char *pattern, char *testcase);
+static INTSML us_patternmatch(char *pattern, char *testcase);
+static INTSML us_patternmatchhere(char *pattern, char *testcase);
 
 INTSML us_patternmatch(char *pattern, char *testcase)
 {
@@ -1431,8 +1466,9 @@ void us_var(INTSML count, char *par[])
 {
 	REGISTER INTSML l, maxleng, annotate, negated, inplace;
 	REGISTER INTBIG i, j, k, function, newval, search, oldaddr, language,
-		*newarray, oldlen, newdescript, len1, len2, count1, count2, count3;
+		*newarray, oldlen, len1, len2, count1, count2, count3;
 	INTBIG objaddr, objaddr1, objaddr2, objtype, objtype1, objtype2, newtype, newaddr;
+	UINTBIG newdescript[TEXTDESCRIPTSIZE];
 	INTSML aindex, dummy, comvar, but, x, y;
 	REGISTER VARIABLE *var, *tvar, *res, *var1, *var2;
 	static VARIABLE fvar;
@@ -1459,7 +1495,7 @@ void us_var(INTSML count, char *par[])
 		{
 			if (i < 26) l = (INTSML)('a' + i); else
 				l = (INTSML)('A' + i - 26);
-			var = getval((INTBIG)us_aid, VAID, -1, us_commandvarname(l));
+			var = getval((INTBIG)us_tool, VTOOL, -1, us_commandvarname(l));
 			if (var == NOVARIABLE) continue;
 			(void)sprintf(varname, "%%%c", l);
 			ttyputmsg(_("%s variable '%s' is %s"), us_variableattributes(var, -1),
@@ -1477,7 +1513,7 @@ void us_var(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_ignoreoptionchanges);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_ignoreoptionchanges);
 			if (var == NOVARIABLE)
 				ttyputmsg(_("Option changes are being tracked")); else
 					ttyputmsg(_("Option changes are being ignored"));
@@ -1486,20 +1522,26 @@ void us_var(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "ignore", l) == 0)
 		{
-			(void)setvalkey((INTBIG)us_aid, VAID, us_ignoreoptionchanges, 1,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_ignoreoptionchanges, 1,
 				VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Option changes are being ignored"));
 			return;
 		}
 		if (namesamen(pp, "track", l) == 0)
 		{
-			var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_ignoreoptionchanges);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_ignoreoptionchanges);
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)us_aid, VAID, us_ignoreoptionchanges);
+				delvalkey((INTBIG)us_tool, VTOOL, us_ignoreoptionchanges);
 			ttyputverbose(M_("Option changes are being tracked"));
 			return;
 		}
-		ttyputusage("var options [ignore | track]");
+		if (namesamen(pp, "save", l) == 0)
+		{
+			us_saveoptions();
+			ttyputmsg(_("Options have been saved"));
+			return;
+		}
+		ttyputusage("var options [ignore | track | save]");
 		return;
 	}
 
@@ -1563,7 +1605,7 @@ void us_var(INTSML count, char *par[])
 				code = (char *)evar->addr;
 				fvar.key = evar->key;
 				fvar.type = evar->type;
-				fvar.textdescript = evar->textdescript;
+				TDCOPY(fvar.textdescript, evar->textdescript);
 				if (doquerry(code, language, fvar.type, &fvar.addr) == 0) evar = &fvar; else
 					code = 0;
 			}
@@ -1645,8 +1687,8 @@ void us_var(INTSML count, char *par[])
 		if (namesamen(pp, "display", l) == 0 && l >= 1)
 		{
 			/* compute the new type field */
-			newdescript = us_figurevariableplace(var->textdescript, (INTSML)(count-3), &par[3]);
-			if (newdescript == -1) return;
+			TDCOPY(newdescript, var->textdescript);
+			us_figurevariableplace(newdescript, (INTSML)(count-3), &par[3]);
 
 			/* signal start of change to nodes and arcs */
 			if (objtype == VNODEINST || objtype == VARCINST)
@@ -1823,7 +1865,7 @@ void us_var(INTSML count, char *par[])
 				ttyputverbose(M_("Creating %s on the object"), qual);
 			}
 			fvar.addr = var->addr;   fvar.type = var->type;
-			fvar.key = var->key;     fvar.textdescript = var->textdescript;
+			fvar.key = var->key;     TDCOPY(fvar.textdescript, var->textdescript);
 		} else
 		{
 			fvar.addr = objaddr;   fvar.type = objtype;
@@ -1865,8 +1907,8 @@ void us_var(INTSML count, char *par[])
 			}
 
 			/* save the information about this variable */
-			if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, qual, us_aid->cluster); else
-				(void)reallocstring(&us_varqualsave, qual, us_aid->cluster);
+			if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, qual, us_tool->cluster); else
+				(void)reallocstring(&us_varqualsave, qual, us_tool->cluster);
 
 			/* create the editor window and load it with the variable */
 			if (header == 0)
@@ -1915,9 +1957,9 @@ void us_var(INTSML count, char *par[])
 			(void)allocstring(&pp, us_getline(wpop, 0), el_tempcluster);
 
 			/* terminate this popup window */
-			startobjectchange((INTBIG)us_aid, VAID);
+			startobjectchange((INTBIG)us_tool, VTOOL);
 			killwindowpart(wpop);
-			endobjectchange((INTBIG)us_aid, VAID);
+			endobjectchange((INTBIG)us_tool, VTOOL);
 
 			/* signal start of change to nodes and arcs */
 			if ((objtype&VTYPE) == VNODEINST || (objtype&VTYPE) == VARCINST)
@@ -1968,8 +2010,8 @@ void us_var(INTSML count, char *par[])
 		if (aindex >= 0) ttyputmsg(_("WARNING: index specification being ignored"));
 
 		/* save the information about this variable */
-		if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, qual, us_aid->cluster); else
-			(void)reallocstring(&us_varqualsave, qual, us_aid->cluster);
+		if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, qual, us_tool->cluster); else
+			(void)reallocstring(&us_varqualsave, qual, us_tool->cluster);
 
 		/* get a new window, put an editor in it */
 		w = us_wantnewwindow(0);
@@ -2033,7 +2075,9 @@ void us_var(INTSML count, char *par[])
 				namesame(us_varqualsave, "DRC_min_connected_distances_multi") == 0 ||
 				namesame(us_varqualsave, "DRC_min_connected_distances_multi_rule") == 0 ||
 				namesame(us_varqualsave, "DRC_min_unconnected_distances_multi") == 0 ||
-				namesame(us_varqualsave, "DRC_min_unconnected_distances_multi_rule") == 0)
+				namesame(us_varqualsave, "DRC_min_unconnected_distances_multi_rule") == 0 ||
+				namesame(us_varqualsave, "DRC_min_edge_distances") == 0 ||
+				namesame(us_varqualsave, "DRC_min_edge_distances_rule") == 0)
 			{
 				annotate = 4;
 				maxleng = ((TECHNOLOGY *)objaddr)->layercount;
@@ -2357,8 +2401,8 @@ void us_var(INTSML count, char *par[])
 			us_abortcommand(_("Use 'var set' to assign values to array entries, not 'var vector'"));
 			return;
 		}
-		if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, pp, us_aid->cluster); else
-			(void)reallocstring(&us_varqualsave, pp, us_aid->cluster);
+		if (us_varqualsave == 0) (void)allocstring(&us_varqualsave, pp, us_tool->cluster); else
+			(void)reallocstring(&us_varqualsave, pp, us_tool->cluster);
 
 		/* get the first source variable */
 		if (us_getvar(par[2], &objaddr1, &objtype1, &qual1, &comvar, &aindex) != 0)
@@ -2612,7 +2656,7 @@ void us_var(INTSML count, char *par[])
 	if (var != NOVARIABLE)
 	{
 		newtype = var->type;
-		newdescript = var->textdescript;
+		TDCOPY(newdescript, var->textdescript);
 
 		/* do some pre-computation on existing variables */
 		if ((newtype&VCANTSET) != 0)
@@ -2723,7 +2767,8 @@ void us_var(INTSML count, char *par[])
 			if (objtype == VARCINST) geom = ((ARCINST *)objaddr)->geom; else
 				if (objtype == VNODEINST) geom = ((NODEINST *)objaddr)->geom; else
 					geom = NOGEOM;
-			newdescript = defaulttextdescript(geom);
+			TDCLEAR(newdescript);
+			defaulttextdescript(newdescript, geom);
 		}
 	}
 
@@ -2735,8 +2780,7 @@ void us_var(INTSML count, char *par[])
 		{
 			/* compute the new type field */
 			newtype |= VDISPLAY;
-			newdescript = us_figurevariableplace(newdescript, (INTSML)(count-4), &par[4]);
-			if (newdescript == -1) return;
+			us_figurevariableplace(newdescript, (INTSML)(count-4), &par[4]);
 			l = 0;
 		} else if (namesamen(pp, "lisp", l) == 0 && l >= 1)
 		{
@@ -2909,7 +2953,10 @@ void us_var(INTSML count, char *par[])
 		ttyputnomemory();
 		return;
 	}
-	if (res != (VARIABLE *)1) res->textdescript = newdescript;
+	if (res != (VARIABLE *)1)
+	{
+		TDCOPY(res->textdescript, newdescript);
+	}
 
 	/* signal end of change to nodes and arcs */
 	if (objtype == VNODEINST || objtype == VARCINST)
@@ -3138,7 +3185,7 @@ void us_view(INTSML count, char *par[])
 					ed = w->editor;
 					if (ed != NOEDITOR)
 					{
-						(void)reallocstring(&ed->header, describenodeproto(np), us_aid->cluster);
+						(void)reallocstring(&ed->header, describenodeproto(np), us_tool->cluster);
 						(*w->redisphandler)(w);
 					}
 				}
