@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrcomtz.c
- * User interface aid: command handler for W through Z
+ * User interface tool: command handler for W through Z
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -34,7 +34,7 @@
 #include "usrtrack.h"
 #include "efunction.h"
 
-struct
+static struct
 {
 	char         *keyword;
 	short         unique;
@@ -71,8 +71,8 @@ void us_window(INTSML count, char *par[])
 	REGISTER STATUSFIELD *sf, **whichstatus;
 	char *newpar[4], *fieldname, line[50];
 	WINDOWFRAME *wf;
-#if SIMAID
-	extern AIDENTRY *sim_aid;
+#if SIMTOOL
+	extern TOOL *sim_tool;
 #endif
 	REGISTER char *pp, *win;
 	REGISTER VARIABLE *var;
@@ -81,7 +81,7 @@ void us_window(INTSML count, char *par[])
 	extern COMCOMP us_windowp, us_windowup, us_windowmp;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	if (count == 0)
 	{
@@ -125,14 +125,14 @@ void us_window(INTSML count, char *par[])
 	{
 		if (us_needwindow()) return;
 
-#if SIMAID
+#if SIMTOOL
 		/* special case for waveform window */
 		if ((el_curwindowpart->state&WINDOWTYPE) == WAVEFORMWINDOW)
 		{
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "all-displayed";
-			(void)tellaid(sim_aid, 3, newpar);
+			(void)telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -309,7 +309,7 @@ void us_window(INTSML count, char *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		startobjectchange((INTBIG)us_aid, VAID);
+		startobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* kill all editor windows on this frame */
 		neww = NOWINDOWPART;
@@ -325,11 +325,11 @@ void us_window(INTSML count, char *par[])
 			/* kill this window */
 			killwindowpart(w);
 		}
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* if (neww == NOWINDOWPART) */
 		el_curwindowpart = NOWINDOWPART;
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
 		if (neww != NOWINDOWPART) np = neww->curnodeproto; else np = NONODEPROTO;
 		(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)np, VNODEPROTO);
 
@@ -356,14 +356,14 @@ void us_window(INTSML count, char *par[])
 			case TEXTWINDOW:
 				us_pantext(el_curwindowpart, 0, -1);
 				return;
-#if SIMAID
+#if SIMTOOL
 			case WAVEFORMWINDOW:
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "down";
-				sprintf(line, "%d", (INTBIG)(atof(pp)*20.0));
+				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
 				newpar[3] = line;
-				(void)tellaid(sim_aid, 4, newpar);
+				(void)telltool(sim_tool, 4, newpar);
 				return;
 #endif
 			case EXPLORERWINDOW:
@@ -380,16 +380,16 @@ void us_window(INTSML count, char *par[])
 		{
 			pp = par[1];
 			if (namesame(pp, "on") == 0)
-				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | INTERACTIVE, VINTEGER);
+				(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | INTERACTIVE, VINTEGER);
 			else if (namesamen(pp, "of", 2) == 0)
-				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~INTERACTIVE, VINTEGER);
+				(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~INTERACTIVE, VINTEGER);
 			else
 			{
 				ttyputusage("window dragging on|off");
 				return;
 			}
 		}
-		if ((us_aid->aidstate&INTERACTIVE) == 0)
+		if ((us_tool->toolstate&INTERACTIVE) == 0)
 			ttyputverbose(M_("Cursor-based commands will act immediately")); else
 				ttyputverbose(M_("Cursor-based commands will drag their objects"));
 		return;
@@ -423,7 +423,7 @@ void us_window(INTSML count, char *par[])
 		}
 		if (strcmp(w->location, "entire") == 0)
 		{
-			w = us_splitcurrentwindow(2, 0);
+			w = us_splitcurrentwindow(2, 0, 0);
 			if (w == NOWINDOWPART) return;
 		}
 
@@ -446,25 +446,35 @@ void us_window(INTSML count, char *par[])
 
 		if (oldw != NOWINDOWPART)
 		{
-			(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)oldw,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)oldw,
 				VWINDOWPART|VDONTSAVE);
 			us_setfacetname(oldw);
 		}
 		return;
 	}
 
-	if (namesamen(pp, "highlight-displayed", l) == 0 && l >= 1)
+	if (namesamen(pp, "hide-attributes", l) == 0 && l >= 3)
+	{
+		if ((us_useroptions&HIDEATTRIBUTES) != 0) return;
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+			us_useroptions | HIDEATTRIBUTES, VINTEGER);
+		endobjectchange((INTBIG)us_tool, VTOOL);
+		return;
+	}
+
+	if (namesamen(pp, "highlight-displayed", l) == 0 && l >= 3)
 	{
 		if (us_needwindow()) return;
 
-#if SIMAID
+#if SIMTOOL
 		/* special case for waveform window */
 		if ((el_curwindowpart->state&WINDOWTYPE) == WAVEFORMWINDOW)
 		{
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "cursor";
-			(void)tellaid(sim_aid, 3, newpar);
+			(void)telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -532,14 +542,14 @@ void us_window(INTSML count, char *par[])
 	{
 		if (us_needwindow()) return;
 
-#if SIMAID
+#if SIMTOOL
 		/* special case for waveform window */
 		if ((el_curwindowpart->state&WINDOWTYPE) == WAVEFORMWINDOW)
 		{
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "in";
-			(void)tellaid(sim_aid, 3, newpar);
+			(void)telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -630,14 +640,14 @@ void us_window(INTSML count, char *par[])
 			case TEXTWINDOW:
 				us_pantext(el_curwindowpart, 1, 0);
 				return;
-#if SIMAID
+#if SIMTOOL
 			case WAVEFORMWINDOW:
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "left";
-				sprintf(line, "%d", (INTBIG)(atof(pp)*20.0));
+				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
 				newpar[3] = line;
-				(void)tellaid(sim_aid, 4, newpar);
+				(void)telltool(sim_tool, 4, newpar);
 				return;
 #endif
 		}
@@ -773,7 +783,7 @@ void us_window(INTSML count, char *par[])
 		(void)initinfstr();
 		(void)addstringtoinfstr("USER_windowview_");
 		(void)addstringtoinfstr(par[1]);
-		var = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, returninfstr());
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, returninfstr());
 		if (var == NOVARIABLE)
 		{
 			us_abortcommand(_("Cannot find saved window view '%s'"), par[1]);
@@ -841,14 +851,14 @@ void us_window(INTSML count, char *par[])
 	{
 		if (us_needwindow()) return;
 
-#if SIMAID
+#if SIMTOOL
 		/* special case for waveform window */
 		if ((el_curwindowpart->state&WINDOWTYPE) == WAVEFORMWINDOW)
 		{
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "out";
-			(void)tellaid(sim_aid, 3, newpar);
+			(void)telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -1001,14 +1011,14 @@ void us_window(INTSML count, char *par[])
 			case TEXTWINDOW:
 				us_pantext(el_curwindowpart, -1, 0);
 				return;
-#if SIMAID
+#if SIMTOOL
 			case WAVEFORMWINDOW:
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "right";
-				sprintf(line, "%d", (INTBIG)(atof(pp)*20.0));
+				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
 				newpar[3] = line;
-				(void)tellaid(sim_aid, 4, newpar);
+				(void)telltool(sim_tool, 4, newpar);
 				return;
 #endif
 		}
@@ -1035,12 +1045,22 @@ void us_window(INTSML count, char *par[])
 		(void)initinfstr();
 		(void)addstringtoinfstr("USER_windowview_");
 		(void)addstringtoinfstr(par[1]);
-		(void)setval((INTBIG)us_aid, VAID, returninfstr(), (INTBIG)windowView,
+		(void)setval((INTBIG)us_tool, VTOOL, returninfstr(), (INTBIG)windowView,
 			VINTEGER|VISARRAY|(8<<VLENGTHSH)|VDONTSAVE);
 		ttyputverbose(M_("Window view %s saved"), par[1]);
 		return;
 	}
 
+	if (namesamen(pp, "show-attributes", l) == 0 && l >= 3)
+	{
+		if ((us_useroptions&HIDEATTRIBUTES) == 0) return;
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+			us_useroptions & ~HIDEATTRIBUTES, VINTEGER);
+		endobjectchange((INTBIG)us_tool, VTOOL);
+		return;
+	}
+
 	if (namesamen(pp, "split", l) == 0 && l >= 2)
 	{
 		if (us_needwindow()) return;
@@ -1057,7 +1077,7 @@ void us_window(INTSML count, char *par[])
 		}
 
 		/* split the window */
-		(void)us_splitcurrentwindow(splitkey, 1);
+		(void)us_splitcurrentwindow(splitkey, 1, 0);
 		return;
 	}
 
@@ -1177,22 +1197,22 @@ void us_window(INTSML count, char *par[])
 			l = strlen(pp = par[1]);
 			if (namesamen(pp, "draw", l) == 0)
 			{
-				startobjectchange((INTBIG)us_aid, VAID);
-				(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+				startobjectchange((INTBIG)us_tool, VTOOL);
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 					us_useroptions | DRAWTINYFACETS, VINTEGER);
 				if (count >= 3)
 				{
 					i = atofr(par[2]);
-					(void)setvalkey((INTBIG)us_aid, VAID, us_tinylambdaperpixel,
+					(void)setvalkey((INTBIG)us_tool, VTOOL, us_tinylambdaperpixel,
 						i, VFRACT);
 				}
-				endobjectchange((INTBIG)us_aid, VAID);
+				endobjectchange((INTBIG)us_tool, VTOOL);
 			} else if (namesamen(pp, "hash-out", l) == 0)
 			{
-				startobjectchange((INTBIG)us_aid, VAID);
-				(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
+				startobjectchange((INTBIG)us_tool, VTOOL);
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
 					us_useroptions & ~DRAWTINYFACETS, VINTEGER);
-				endobjectchange((INTBIG)us_aid, VAID);
+				endobjectchange((INTBIG)us_tool, VTOOL);
 			} else
 			{
 				ttyputusage("window tiny-facets draw|(hash-out [LAMBDAPERPIXEL])");
@@ -1226,7 +1246,7 @@ void us_window(INTSML count, char *par[])
 		curwx = el_curwindowpart->screenhx - el_curwindowpart->screenlx;
 		curwy = el_curwindowpart->screenhy - el_curwindowpart->screenly;
 
-		var = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_commandvarname('T'));
+		var = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_commandvarname('T'));
 		if (var == NOVARIABLE)
 		{
 			us_abortcommand(_("Issue an outline before zooming into that area"));
@@ -1293,14 +1313,14 @@ void us_window(INTSML count, char *par[])
 			case TEXTWINDOW:
 				us_pantext(el_curwindowpart, 0, 1);
 				return;
-#if SIMAID
+#if SIMTOOL
 			case WAVEFORMWINDOW:
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "up";
-				sprintf(line, "%d", (INTBIG)(atof(pp)*20.0));
+				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
 				newpar[3] = line;
-				(void)tellaid(sim_aid, 4, newpar);
+				(void)telltool(sim_tool, 4, newpar);
 				return;
 #endif
 			case EXPLORERWINDOW:
@@ -1336,7 +1356,7 @@ void us_window(INTSML count, char *par[])
 			us_abortcommand(_("No window named '%s'"), par[1]);
 			return;
 		}
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)w, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)w, VWINDOWPART|VDONTSAVE);
 		(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)w->curnodeproto, VNODEPROTO);
 		return;
 	}
@@ -1347,16 +1367,16 @@ void us_window(INTSML count, char *par[])
 		{
 			l = strlen(pp = par[1]);
 			if (namesamen(pp, "integral", l) == 0 && l >= 1)
-				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate | INTEGRAL, VINTEGER);
+				(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate | INTEGRAL, VINTEGER);
 			else if (namesamen(pp, "nonintegral", l) == 0 && l >= 1)
-				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~INTEGRAL, VINTEGER);
+				(void)setval((INTBIG)us_tool, VTOOL, "toolstate", us_tool->toolstate & ~INTEGRAL, VINTEGER);
 			else
 			{
 				ttyputusage("window zoom-scale integral|nonintegral");
 				return;
 			}
 		}
-		if ((us_aid->aidstate&INTEGRAL) == 0)
+		if ((us_tool->toolstate&INTEGRAL) == 0)
 			ttyputverbose(M_("Window scaling will be continuous")); else
 				ttyputverbose(M_("Window scaling will force integral pixel alignment"));
 		return;
@@ -1378,9 +1398,9 @@ void us_window(INTSML count, char *par[])
 		/* turn off highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)NOWINDOWPART, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)NOWINDOWPART, VWINDOWPART|VDONTSAVE);
 
-		startobjectchange((INTBIG)us_aid, VAID);
+		startobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* create a new window */
 		neww = newwindowpart("entire", oldw);
@@ -1408,10 +1428,10 @@ void us_window(INTSML count, char *par[])
 
 		/* set the window extents */
 		us_windowfit(NOWINDOWFRAME, 0, 1);
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* restore highlighting */
-		(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
 		(void)us_pophighlight(0);
 		return;
 	}
