@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrctech.c
- * User interface aid: technology translation module
+ * User interface tool: technology translation module
  * Written by: Steven M. Rubin, Static Free Software
  * Schematic conversion written by: Nora Ryan, Schlumberger Palo Alto Research
  *
@@ -44,26 +44,21 @@
 #define TRAN_FACET -2
 
 /* prototypes for local routines */
-NODEPROTO *us_tran_linkage(char*, VIEW*, NODEPROTO*);
-void us_tran_logmakenodes(NODEPROTO*, NODEPROTO*, TECHNOLOGY*);
-NODEINST *us_tran_logmakenode(NODEPROTO*, NODEINST*, INTSML, INTSML, NODEPROTO*, TECHNOLOGY*);
-void us_tran_logmakearcs(NODEPROTO*, NODEPROTO*);
-void us_tran_logadjustnodes(NODEPROTO*);
-void us_tran_makemanhattan(NODEPROTO*);
-PORTPROTO *us_tranconvpp(NODEINST*, PORTPROTO*);
-INTBIG us_tranismos(NODEINST*);
-PORTPROTO *us_trangetproto(NODEINST*, INTSML);
-NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, char*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
-INTSML us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
-void us_tran_convertuniversals(NODEPROTO*, TECHNOLOGY*);
-void us_tran_replacenodeinst(NODEINST*, NODEPROTO*);
-void us_tran_replacearcinst(ARCINST*, ARCPROTO*);
-INTSML us_tran_validstate(ARCINST*, INTSML, TECHNOLOGY*, ARCPROTO**);
-void us_tranplacenode(NODEINST*, NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*);
-PORTPROTO *us_convport(NODEINST*, NODEINST*, PORTPROTO*);
-ARCPROTO *us_figurenewaproto(ARCPROTO*, TECHNOLOGY*);
-NODEPROTO *us_figurenewnproto(NODEINST*, TECHNOLOGY*);
-void us_dumpfields(char***, INTSML, INTSML, FILE*, char*);
+static PORTPROTO *us_convport(NODEINST*, NODEINST*, PORTPROTO*);
+static void       us_dumpfields(char***, INTSML, INTSML, FILE*, char*);
+static ARCPROTO  *us_figurenewaproto(ARCPROTO*, TECHNOLOGY*);
+static NODEPROTO *us_figurenewnproto(NODEINST*, TECHNOLOGY*);
+static PORTPROTO *us_tranconvpp(NODEINST*, PORTPROTO*);
+static PORTPROTO *us_trangetproto(NODEINST*, INTSML);
+static INTBIG     us_tranismos(NODEINST*);
+static void       us_tranplacenode(NODEINST*, NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*);
+static NODEPROTO *us_tran_linkage(char*, VIEW*, NODEPROTO*);
+static void       us_tran_logmakearcs(NODEPROTO*, NODEPROTO*);
+static NODEINST  *us_tran_logmakenode(NODEPROTO*, NODEINST*, INTSML, INTSML, NODEPROTO*, TECHNOLOGY*);
+static void       us_tran_logmakenodes(NODEPROTO*, NODEPROTO*, TECHNOLOGY*);
+static NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, char*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
+static INTSML     us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
+static void       us_tran_makemanhattan(NODEPROTO*);
 
 /*
  * this routine converts facet "oldfacet" to one of technology "newtech".
@@ -75,7 +70,6 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 	NODEPROTO *(*localconversion)(NODEPROTO*, TECHNOLOGY*);
 	REGISTER TECHNOLOGY *oldtech, *tech;
 	REGISTER ARCINST *ai;
-	REGISTER LIBRARY *lib;
 	VARIABLE *var;
 
 	/* cannot convert text-only views */
@@ -109,10 +103,7 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 			us_tran_logmakearcs(oldfacet, newfacet);
 
 			/* now make adjustments for manhattan-ness */
-			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
-				for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-					np->temp1 = 0;
-			us_tran_logadjustnodes(newfacet);
+			us_tran_makemanhattan(newfacet);
 
 			/* set "FIXANG" if reasonable */
 			for(ai = newfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -177,8 +168,10 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 	PORTEXPINST *pexp;
 	REGISTER PORTPROTO *pp, *pp2;
 	REGISTER PORTARCINST *pi;
+	REGISTER VARIABLE *var;
 	INTSML rotate, trans;
-	INTBIG type, len, wid, lambda;
+	INTBIG type, len, wid, lambda, xoff, yoff;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/*
 	 * for each node, create a new node in the newfacet, of the correct
@@ -242,17 +235,39 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 				transistorsize(ni, &len, &wid);
 				if (len >= 0 && wid >= 0)
 				{
-					(void)initinfstr();
+					TDCLEAR(descript);
+					defaulttextsize(3, descript);
 					lambda = lambdaofnode(ni);
-					len /= lambda;
-					wid /= lambda;
-					if (type == NPTRAPMOS || type == NPTRANMOS || type == NPTRADMOS)
-						(void)formatinfstr("%ld/%ld", wid, len); else
-							(void)formatinfstr("%ld", len*wid);
-
-					/* store this information on the transistor */
-					us_setvariablevalue(schemni, sch_transistortypekey,
-						returninfstr(), VSTRING|VDISPLAY);
+					if (type == NPTRAPMOS || type == NPTRANMOS || type == NPTRADMOS ||
+						type == NPTRANJFET || type == NPTRAPJFET ||
+						type == NPTRADMES || type == NPTRAEMES)
+					{
+						/* set length/width */
+						us_getlenwidoffset(schemni, descript, &xoff, &yoff);
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_length,
+							len*WHOLE/lambda, VFRACT|VDISPLAY);
+						if (var != NOVARIABLE)
+						{
+							TDCOPY(var->textdescript, descript);
+							TDSETOFF(var->textdescript, TDGETXOFF(descript)+xoff,
+								TDGETYOFF(descript)+yoff);
+						}
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_width,
+							wid*WHOLE/lambda, VFRACT|VDISPLAY);
+						if (var != NOVARIABLE)
+						{
+							TDCOPY(var->textdescript, descript);
+							TDSETOFF(var->textdescript, TDGETXOFF(descript)-xoff,
+								TDGETYOFF(descript)-yoff);
+						}
+					} else
+					{
+						/* set area */
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_area,
+							len*WHOLE/lambda, VFRACT|VDISPLAY);
+						if (var != NOVARIABLE)
+							TDCOPY(var->textdescript, descript);
+					}
 				}
 		}
 
@@ -270,11 +285,11 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 				if (pp2 == NOPORTPROTO) return;
 				pp2->userbits = (pp2->userbits & ~STATEBITS) |
 					(pexp->exportproto->userbits & STATEBITS);
-				pp2->textdescript = (pexp->exportproto->textdescript & ~VTSIZE) |
-					(defaulttextsize(1) << VTSIZESH);
+				TDCOPY(pp2->textdescript, pexp->exportproto->textdescript);
 				if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO) != 0)
 					return;
 			}
+			endobjectchange((INTBIG)schemni, VNODEINST);
 		}
 	}
 }
@@ -337,24 +352,7 @@ void us_tran_logmakearcs(NODEPROTO *facet, NODEPROTO *newfacet)
 	}
 }
 
-/*
- * routine to adjust the pin nodes in facet "newfacet" so that there is maximum
- * "manhattan"ness
- */
-void us_tran_logadjustnodes(NODEPROTO *newfacet)
-{
-	REGISTER NODEINST *ni;
-
-	/* handle recursion */
-	if (newfacet->temp1 != 0) return;
-	newfacet->temp1++;
-	for(ni = newfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-		if (ni->proto->primindex == 0) us_tran_logadjustnodes(ni->proto);
-
-	us_tran_makemanhattan(newfacet);
-}
-
-#define MAXADJUST        5
+#define MAXADJUST 5
 
 void us_tran_makemanhattan(NODEPROTO *newfacet)
 {
@@ -507,6 +505,9 @@ NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, char *newfacetname,
 		/* ignore primitives */
 		if (ni->proto->primindex != 0) continue;
 
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == oldfacet->cell) continue;
+
 		/* ignore facets with associations */
 		for(rnp = ni->proto->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
 			if (rnp->cellview == nview) break;
@@ -559,8 +560,8 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	static POLYGON *poly1 = NOPOLYGON, *poly2 = NOPOLYGON;
 
 	/* get a polygon */
-	if (poly1 == NOPOLYGON) poly1 = allocstaticpolygon(4, us_aid->cluster);
-	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, us_aid->cluster);
+	if (poly1 == NOPOLYGON) poly1 = allocstaticpolygon(4, us_tool->cluster);
+	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, us_tool->cluster);
 
 	/* get lambda values */
 	oldlambda = el_curlib->lambda[oldtech->techindex];
@@ -789,8 +790,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 		pp2 = newportproto(newfacet, newni, pp, pexp->exportproto->protoname);
 		if (pp2 == NOPORTPROTO) return;
 		pp2->userbits = (pp2->userbits & ~STATEBITS) | (pexp->exportproto->userbits & STATEBITS);
-		pp2->textdescript = (pexp->exportproto->textdescript & ~VTSIZE) |
-			(defaulttextsize(1) << VTSIZESH);
+		TDCOPY(pp2->textdescript, pexp->exportproto->textdescript);
 		if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO) != 0)
 			return;
 	}
@@ -883,14 +883,14 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get a polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* easy translation if complex or already in the proper technology */
 	oldnp = oldni->proto;
 	if (oldnp->primindex == 0 || oldnp->tech == newtech) return(oldnp);
 
 	/* if this is a layer node, check the layer functions */
-	type = nodefunction(oldni, 0);
+	type = nodefunction(oldni);
 	if (type == NPNODE)
 	{
 		/* get the polygon describing the first box of the old node */
@@ -996,7 +996,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	extern INTBIG tech_realpolys;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	(void)initinfstr();
 	(void)addstringtoinfstr(tech->techname);
