@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrdisp.c
- * User interface aid: miscellaneous display control
+ * User interface tool: miscellaneous display control
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -34,7 +34,7 @@
 #include "tech.h"
 #include "tecgen.h"
 
-INTBIG us_stopevent = 0;
+static INTBIG us_stopevent = 0;
 
 /* for drawing facet name, outline or instance name (color changes) */
 GRAPHICS us_facetgra = {LAYERO, 0, SOLIDC, SOLIDC,
@@ -69,7 +69,7 @@ GRAPHICS us_egbox = {LAYERG, ALLOFF, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* for drawing patterned facet contents (when resolution is too small, color changes) */
-GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
+static GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
 					{0x0000, /*                  */
 					0x0303,  /*       XX      XX */
 					0x4848,  /*  X  X    X  X    */
@@ -80,19 +80,17 @@ GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
 					0x3030}, /*   XX      XX     */
 					NOVARIABLE, 0};
 
-#define MAXGRID        75
-#define MINGRID         4	/* the minimum grid has 4 pixels spacing */
+#define MAXGRID         75
+#define MINGRID          4	/* the minimum grid has 4 pixels spacing */
+#define TXTMAXFACETSIZE 36	/* maximum point size of facet text */
 
 /* prototypes for local routines */
-void us_showemptywindow(WINDOWPART*);
-void us_graphicsarcs(PORTPROTO*, INTSML*, INTSML*);
-void us_combinelayers(ARCINST*, INTSML*, INTSML*);
-POLYGON *us_makeprotopoly(PORTPROTO*, XARRAY, WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML us_drawall(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, XARRAY, INTSML);
-INTSML us_drawarcinstpeek(ARCINST*, XARRAY, INTSML);
-INTSML us_drawnodeinstpeek(NODEINST*, XARRAY, INTSML);
-void us_peeksetlayer(INTSML, TECHNOLOGY*);
-void us_peekwritepolygon(INTBIG*, INTBIG*, INTSML, float);
+static void us_showemptywindow(WINDOWPART*);
+static void us_graphicsarcs(PORTPROTO*, INTSML*, INTSML*);
+static void us_combinelayers(ARCINST*, INTSML*, INTSML*);
+static INTSML us_drawall(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, XARRAY, INTSML);
+static INTSML us_drawarcinstpeek(ARCINST*, XARRAY, INTSML);
+static INTSML us_drawnodeinstpeek(NODEINST*, XARRAY, INTSML);
 
 /******************** WINDOW CONTROL ********************/
 
@@ -106,7 +104,7 @@ void us_drawwindow(WINDOWPART *w, INTSML color)
 	INTBIG lx, hx, ly, hy;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_tool->cluster);
 
 	/* don't draw window border if it is a whole-screen window */
 	if (strcmp(w->location, "entire") == 0) return;
@@ -164,10 +162,22 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 	INTBIG *screenhy)
 {
 	INTBIG x, y, nlx, nhx, nly, nhy;
-	REGISTER INTBIG lambda, first;
+	REGISTER INTBIG lambda, first, oldlx, oldhx, oldly, oldhy;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 
+	if (el_curwindowpart != NOWINDOWPART)
+	{
+		oldlx = el_curwindowpart->screenlx;
+		oldhx = el_curwindowpart->screenhx;
+		oldly = el_curwindowpart->screenly;
+		oldhy = el_curwindowpart->screenhy;
+		el_curwindowpart->screenlx = np->lowx;
+		el_curwindowpart->screenhx = np->highx;
+		el_curwindowpart->screenly = np->lowy;
+		el_curwindowpart->screenhy = np->highy;
+		computewindowscale(el_curwindowpart);
+	}
 	if (framesize(&x, &y, np) == 0)
 	{
 		/* only one size allowed in schematics window */
@@ -226,6 +236,14 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 			*screenhy += 25 * lambda;
 		}
 	}
+	if (el_curwindowpart != NOWINDOWPART)
+	{
+		el_curwindowpart->screenlx = oldlx;
+		el_curwindowpart->screenhx = oldhx;
+		el_curwindowpart->screenly = oldly;
+		el_curwindowpart->screenhy = oldhy;
+		computewindowscale(el_curwindowpart);
+	}
 }
 
 /*
@@ -234,7 +252,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
  */
 void us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBIG *nhy)
 {
-	REGISTER INTBIG i, nodexfvalid, lambda, font, shei, swid, tf, portstyle;
+	REGISTER INTBIG i, nodexfvalid, lambda, shei, swid, portstyle;
 	INTBIG lx, hx, ly, hy, xp, yp, newxc, newyc;
 	INTSML wid, hei;
 	REGISTER VARIABLE *var;
@@ -256,7 +274,7 @@ void us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBI
 			var = &ni->firstvar[i];
 			if ((var->type&VDISPLAY) == 0) continue;
 
-			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 			makedisparrayvarpoly(ni->geom, el_curwindowpart, var, poly);
 			getbbox(poly, &lx, &hx, &ly, &hy);
 			*nlx = mini(*nlx, lx);
@@ -277,11 +295,9 @@ void us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBI
 			makeangle(ni->rotation, ni->transpose, trans);
 			lambda = figurelambda(ni->geom);
 		}
-		newxc = (pp->textdescript&VTXOFF)>>VTXOFFSH;
-		if ((pp->textdescript&VTXOFFNEG) != 0) newxc = -newxc;
+		newxc = TDGETXOFF(pp->textdescript);
 		newxc = newxc * lambda / 4;
-		newyc = (pp->textdescript&VTYOFF)>>VTYOFFSH;
-		if ((pp->textdescript&VTYOFFNEG) != 0) newyc = -newyc;
+		newyc = TDGETYOFF(pp->textdescript);
 		newyc = newyc * lambda / 4;
 		xform(newxc, newyc, &newxc, &newyc, trans);
 		portposition(ni, pe->proto, &xp, &yp);
@@ -293,33 +309,12 @@ void us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBI
 			(portstyle == EXPORTSFULL || portstyle == EXPORTSSHORT))
 		{
 			/* adjust for size of port text */
-			font = (pp->textdescript&VTSIZE)>>VTSIZESH;
-			if (font >= TXTHL && font <= TXT6L)
-			{
-				screensettextsize(el_curwindowpart, 20);
-				screengettextsize(el_curwindowpart,
-					us_displayedportname(pp, portstyle >> EXPORTLABELSSH), &wid, &hei);
-				switch (font)
-				{
-					case TXTHL: shei = lambda / 2;   break;
-					case TXT1L: shei = lambda;       break;
-					case TXT2L: shei = lambda * 2;   break;
-					case TXT3L: shei = lambda * 3;   break;
-					case TXT4L: shei = lambda * 4;   break;
-					case TXT5L: shei = lambda * 5;   break;
-					case TXT6L: shei = lambda * 6;   break;
-				}
-				swid = shei * wid / hei * 5 / 4;
-			} else
-			{
-				tf = truefontsize(font, el_curwindowpart, pp->parent->tech);
-				screensettextsize(el_curwindowpart, tf);
-				screengettextsize(el_curwindowpart,
-					us_displayedportname(pp, portstyle >> EXPORTLABELSSH), &wid, &hei);
-				swid = roundfloat((float)wid / el_curwindowpart->scalex);
-				shei = roundfloat((float)hei / el_curwindowpart->scaley);
-			}
-			switch (pp->textdescript&VTPOSITION)
+			screensettextinfo(el_curwindowpart, pp->parent->tech, pp->textdescript);
+			screengettextsize(el_curwindowpart,
+				us_displayedportname(pp, portstyle >> EXPORTLABELSSH), &wid, &hei);
+			swid = roundfloat((float)wid / el_curwindowpart->scalex);
+			shei = roundfloat((float)hei / el_curwindowpart->scaley);
+			switch (TDGETPOS(pp->textdescript))
 			{
 				case VTPOSCENT:     case VTPOSDOWN:       case VTPOSUP:
 					lx -= swid/2;   hx += swid/2;         break;
@@ -328,7 +323,7 @@ void us_getnodebounds(NODEINST *ni, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBI
 				case VTPOSLEFT:     case VTPOSDOWNLEFT:   case VTPOSUPLEFT:
 					lx -= swid;     break;
 			}
-			switch (pp->textdescript&VTPOSITION)
+			switch (TDGETPOS(pp->textdescript))
 			{
 				case VTPOSCENT:     case VTPOSRIGHT:      case VTPOSLEFT:
 					ly -= shei/2;   hy += shei/2;         break;
@@ -368,7 +363,7 @@ void us_getarcbounds(ARCINST *ai, INTBIG *nlx, INTBIG *nhx, INTBIG *nly, INTBIG
 		{
 			var = &ai->firstvar[i];
 			if ((var->type&VDISPLAY) == 0) continue;
-			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 			makedisparrayvarpoly(ai->geom, el_curwindowpart, var, poly);
 			getbbox(poly, &lx, &hx, &ly, &hy);
 			*nlx = mini(*nlx, lx);
@@ -450,7 +445,7 @@ void us_squarescreen(WINDOWPART *w, WINDOWPART *formerw, INTSML largescale, INTB
 		if (fshy >  MAXINTBIG/2) *screenhy =  MAXINTBIG/2; else *screenhy = (INTBIG)fshy;
 	}
 
-	if ((us_aid->aidstate&INTEGRAL) != 0)
+	if ((us_tool->toolstate&INTEGRAL) != 0)
 	{
 		/* adjust window so that it matches well with screen pixels */
 		if (*screenhx == *screenlx) return;
@@ -521,7 +516,7 @@ void us_redisplay(WINDOWPART *w)
 	INTBIG lx, hx, ly, hy;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_tool->cluster);
 
 	/* draw fat red border if simulating */
 	if ((w->state&WINDOWSIMULATING) != 0)
@@ -582,7 +577,7 @@ void us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBI
 	WINDOWPART ww;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	ww.screenlx = ww.uselx = (INTSML)lx;
 	ww.screenhx = ww.usehx = (INTSML)hx;
@@ -700,7 +695,7 @@ void us_drawverticalslider(WINDOWPART *w, INTSML lx, INTSML ly, INTSML hy, INTSM
 	WINDOWPART ww;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_tool->cluster);
 
 	ww.screenlx = ww.uselx = w->uselx;
 	ww.screenhx = ww.usehx = w->usehx;
@@ -770,7 +765,7 @@ void us_drawhorizontalslider(WINDOWPART *w, INTSML hy, INTSML lx, INTSML hx)
 	WINDOWPART ww;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_tool->cluster);
 
 	ww.screenlx = ww.uselx = w->uselx;
 	ww.screenhx = ww.usehx = w->usehx;
@@ -833,7 +828,7 @@ void us_drawverticalsliderthumb(WINDOWPART *w, INTBIG hx, INTBIG ly, INTBIG hy,
 	WINDOWPART ww;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_tool->cluster);
 
 	ww.screenlx = ww.uselx = w->uselx;
 	ww.screenhx = ww.usehx = w->usehx;
@@ -881,7 +876,7 @@ void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx
 	WINDOWPART ww;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(7, us_tool->cluster);
 
 	ww.screenlx = ww.uselx = w->uselx;
 	ww.screenhx = ww.usehx = w->usehx;
@@ -955,7 +950,7 @@ void us_redisplaynow(WINDOWPART *w, INTSML now)
 		if (j != 0)
 		{
 			/* get polygon */
-			if (poly == NOPOLYGON) poly = allocstaticpolygon(6, us_aid->cluster);
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(6, us_tool->cluster);
 			for(i=0; i<j; i++)
 			{
 				framepoly(i, poly, facet);
@@ -991,21 +986,21 @@ void us_redisplaynow(WINDOWPART *w, INTSML now)
 	}
 
 	/* show this facet and export variables */
-	us_drawnodeprotovariables(facet, el_matid, w);
+	us_drawnodeprotovariables(facet, el_matid, w, 0);
 
 	/* re-draw grid if on */
 	if ((w->state&(GRIDON|GRIDTOOSMALL)) == GRIDON &&
 		(w->state&WINDOWTYPE) != DISP3DWINDOW)
 	{
 		/* get polygon */
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(6, us_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(6, us_tool->cluster);
 
 		/* grid spacing */
 		poly->xv[0] = w->gridx;
 		poly->yv[0] = w->gridy;
 
 		/* initial grid location */
-		var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_gridfloats);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloats);
 		if (var == NOVARIABLE || var->addr == 0)
 		{
 			poly->xv[1] = w->screenlx / w->gridx * w->gridx;
@@ -1046,7 +1041,7 @@ void us_erasescreen(WINDOWFRAME *mw)
 	REGISTER WINDOWFRAME *frame;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	for(frame = el_firstwindowframe; frame != NOWINDOWFRAME; frame = frame->nextwindowframe)
 	{
@@ -1072,13 +1067,14 @@ void us_showemptywindow(WINDOWPART *w)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	if ((w->state&WINDOWTYPE) == DISP3DWINDOW) return;
 	makerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 	poly->style = TEXTBOX;
 	poly->string = _("No facet in this window");
-	poly->font = TXT20P;
+	TDCLEAR(poly->textdescript);
+	TDSETSIZE(poly->textdescript, TXTSETPOINTS(20));
 	poly->tech = el_curtech;
 	poly->desc = &us_box;
 	us_box.col = MENTXT;
@@ -1149,8 +1145,8 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on, INTSML usenumbers)
 	static POLYGON *poly = NOPOLYGON, *ppoly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
-	if (ppoly == NOPOLYGON) ppoly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
+	if (ppoly == NOPOLYGON) ppoly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* determine the window to use */
 	if (ni == NONODEINST) parent = np; else parent = ni->parent;
@@ -1294,7 +1290,7 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on, INTSML usenumbers)
 		}
 		if (usenumbers != 0)
 		{
-			(void)sprintf(line, "%d", portused[i]);
+			(void)sprintf(line, "%ld", portused[i]);
 			poly->string = line;
 		} else poly->string = portpp[i]->protoname;
 
@@ -1302,7 +1298,8 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on, INTSML usenumbers)
 		poly->xv[0] = portx[i];   poly->yv[0] = porty[i];   poly->count = 1;
 		poly->desc = &us_hbox;
 		poly->style = TEXTCENT;
-		poly->font = TXT20P;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTSETPOINTS(20));
 		poly->tech = subni->proto->tech;
 		us_hbox.col = HIGHLIT&on;
 		(void)us_showpoly(poly, w);
@@ -1378,12 +1375,12 @@ INTSML us_drawfacet(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers, WI
  */
 INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers, WINDOWPART *w)
 {
-	REGISTER INTBIG i, j, res, displaytotal, low, high, cutsizex, cutsizey, portstyle;
+	REGISTER INTBIG i, j, res, displaytotal, low, high, cutsizex, cutsizey, portstyle,
+		ratio, swap, lambda, size;
 	INTSML color, bits, moretodo;
-	XARRAY localtran, subrot, trans;
+	XARRAY localtran, subrot, trans, *xptr;
 	INTBIG bx, by, ux, uy, portcliplx, portcliphx, portcliply, portcliphy, drawport,
 		reasonable;
-	REGISTER INTBIG ratio, swap, lambda;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER GRAPHICS *gra;
 	REGISTER NODEPROTO *np;
@@ -1400,7 +1397,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 		if (stopping(STOPREASONDISPLAY)) return(-2);
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	moretodo = 0;
 	np = ni->proto;
@@ -1534,7 +1531,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 				}
 
 				/* write the facet name */
-				if ((ni->textdescript&VTPOSITION) == VTPOSBOXED)
+				if (TDGETPOS(ni->textdescript) == VTPOSBOXED)
 				{
 					makerectpoly(ni->lowx, ni->highx, ni->lowy, ni->highy, poly);
 					poly->style = FILLED;
@@ -1548,6 +1545,13 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 				xformpoly(poly, prevtrans);
 				poly->desc = &us_facetgra;   us_facetgra.col = el_colfacettxt;
 				poly->string = describenodeproto(ni->proto);
+				size = TDGETSIZE(poly->textdescript);
+				if (TXTGETQLAMBDA(size) != 0)
+				{
+					size = truefontsize(size, w, poly->tech);
+					if (size > TXTMAXFACETSIZE) size = TXTMAXFACETSIZE;
+					TDSETSIZE(poly->textdescript, TXTSETPOINTS(size));
+				}
 				if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 					(*us_displayroutine)(poly, w);
 
@@ -1576,34 +1580,39 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 						(*us_displayroutine)(poly, w);
 				}
 			} else moretodo |= 2;
-			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			if (ni->parent == w->curnodeproto)
 			{
-				if ((pp->userbits&PORTDRAWN) == 0)
+				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				{
-					/* if there is an arc on this port, don't draw the port */
-					for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-						if (pi->proto == pp) break;
-					if (pi != NOPORTARCINST) continue;
-				}
+					portstyle = (us_useroptions&PORTLABELS) >> PORTLABELSSH;
+					if ((pp->userbits&PORTDRAWN) == 0)
+					{
+						/* if there is an arc or further export on this port, don't draw it */
+						for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+							if (pi->proto == pp) break;
+						for (pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+							if (pe->proto == pp) break;
+						if (pi != NOPORTARCINST || pe != NOPORTEXPINST) continue;
+					}
 
-				/* don't bother plotting if no bits are to be drawn */
-				us_graphicsarcs(pp, &bits, &color);
-				if ((bits&LAYEROE) != 0 && (layers&2) == 0)
-				{ moretodo |= 2;  continue; }
-				if ((bits&LAYEROE) == 0 && (layers&1) == 0)
-				{ moretodo |= 1;  continue; }
+					/* don't bother plotting if no bits are to be drawn */
+					us_graphicsarcs(pp, &bits, &color);
+					if ((bits&LAYEROE) != 0 && (layers&2) == 0)
+					{ moretodo |= 2;  continue; }
+					if ((bits&LAYEROE) == 0 && (layers&1) == 0)
+					{ moretodo |= 1;  continue; }
 
-				portstyle = (us_useroptions&PORTLABELS) >> PORTLABELSSH;
-				if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
-				{
-					us_writeprotoname(pp, LAYERA, subrot, bits, color, w, portcliplx,
-						portcliphx, portcliply, portcliphy, portstyle);
-				} else
-				{
-					makerot(pp->subnodeinst, localtran);
-					transmult(localtran, subrot, trans);
-					us_writeprotoname(pp, LAYERA, trans, bits, color, w, portcliplx,
-						portcliphx, portcliply, portcliphy, portstyle);
+					if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
+					{
+						us_writeprotoname(pp, LAYERA, subrot, bits, color, w, portcliplx,
+							portcliphx, portcliply, portcliphy, portstyle);
+					} else
+					{
+						makerot(pp->subnodeinst, localtran);
+						transmult(localtran, subrot, trans);
+						us_writeprotoname(pp, LAYERA, trans, bits, color, w, portcliplx,
+							portcliphx, portcliply, portcliphy, portstyle);
+					}
 				}
 			}
 		} else
@@ -1635,34 +1644,39 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 			if ((layers&2) == 0) moretodo |= 2; else
 			{
 				/* write ports that must always be displayed */
-				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				if (ni->parent == w->curnodeproto)
 				{
-					drawport = 0;
-					portstyle = (us_useroptions&PORTLABELS) >> PORTLABELSSH;
-					if ((pp->userbits&PORTDRAWN) != 0) drawport = 1;
-					for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-						if (pi->proto == pp) break;
-					for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
-						if (pe->proto == pp) break;
-					if (pi == NOPORTARCINST && pe == NOPORTEXPINST)
+					for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					{
-						if (drawport == 0)
-							portstyle = PORTSCROSS >> PORTLABELSSH;
-						drawport = 1;
-					}
-					if (drawport != 0)
-					{
-						if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
+						drawport = 0;
+						portstyle = (us_useroptions&PORTLABELS) >> PORTLABELSSH;
+						if ((pp->userbits&PORTDRAWN) != 0) drawport = 1;
+						for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+							if (pi->proto == pp) break;
+						for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+							if (pe->proto == pp) break;
+						if (pi == NOPORTARCINST && pe == NOPORTEXPINST)
+							drawport = 1;
+
+						/* determine the transformation for the instance */
+						ino = pp->subnodeinst;
+						if (ino->rotation == 0 && ino->transpose == 0)
 						{
-							us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colfacettxt, w,
-								portcliplx, portcliphx, portcliply, portcliphy, portstyle);
+							xptr = (XARRAY *)subrot;
 						} else
 						{
-							makerot(pp->subnodeinst, localtran);
+							makerot(ino, localtran);
 							transmult(localtran, subrot, trans);
-							us_writeprotoname(pp, LAYERA, trans, LAYERO, el_colfacettxt, w,
-								portcliplx, portcliphx, portcliply, portcliphy, portstyle);
+							xptr = (XARRAY *)trans;
 						}
+
+						/* draw the export if requested */
+						if (drawport != 0)
+							us_writeprotoname(pp, LAYERA, *xptr, LAYERO, el_colfacettxt, w,
+								portcliplx, portcliphx, portcliply, portcliphy, portstyle);
+
+						/* draw attributes on exported ports */
+						us_drawportprotovariables(pp, LAYERA, *xptr, w, 1);
 					}
 				}
 
@@ -1676,10 +1690,8 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 						(*us_displayroutine)(poly, w);
 				}
 
-				/* 
-				 * draw facet variables on expanded facets
-				 * us_drawnodeprotovariables(ni->proto, prevtrans, w);
-				 */
+				/* draw facet variables on expanded facets */
+				us_drawnodeprotovariables(ni->proto, subrot, w, 1);
 			}
 
 			/* search through facet */
@@ -1709,43 +1721,59 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 				us_writeprotoname(pe->exportproto, on, prevtrans, LAYERO,
 					(INTSML)(el_colfacettxt&on), w, 0, 0, 0, 0,
 						(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
-				us_drawportprotovariables(pe->exportproto, on, prevtrans, w);
+				us_drawportprotovariables(pe->exportproto, on, prevtrans, w, 0);
 			}
 		}
 	}
 	return(moretodo);
 }
 
-void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w)
+/*
+ * Routine to draw all attributes on facet "np".  The facet is in window "w"
+ * and is transformed by "trans".  If "ignoreinherit" is nonzero, ignore inheritable
+ * attributes (because this is a subfacet, and the inherited instance attributes are to be
+ * shown).
+ */
+void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, INTSML ignoreinherit)
 {
 	REGISTER INTBIG i, displaytotal;
+	REGISTER VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	displaytotal = tech_displayablefacetvars(np, w);
 	for(i = 0; i < displaytotal; i++)
 	{
-		(void)tech_filldisplayablefacetvar(np, poly, w, 0);
+		var = tech_filldisplayablefacetvar(np, poly, w, 0);
+		if (ignoreinherit != 0 && TDGETINHERIT(var->textdescript) != 0) continue;
 		xformpoly(poly, trans);
 		if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 			(*us_displayroutine)(poly, w);
 	}
 }
 
-void us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w)
+/*
+ * Routine to draw all attributes on port "pp" with color "on".  The port is in window "w"
+ * and is transformed by "trans".  If "ignoreinherit" is nonzero, ignore inheritable
+ * attributes (because this is a subfacet, and the inherited instance attributes are to be
+ * shown).
+ */
+void us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w, INTSML ignoreinherit)
 {
 	REGISTER INTBIG i, displaytotal;
+	REGISTER VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	displaytotal = tech_displayableportvars(pp, w);
 	for(i = 0; i < displaytotal; i++)
 	{
-		(void)tech_filldisplayableportvar(pp, poly, w, 0);
+		var = tech_filldisplayableportvar(pp, poly, w, 0);
+		if (ignoreinherit != 0 && TDGETINHERIT(var->textdescript) != 0) continue;
 		xformpoly(poly, trans);
 		if (on == 0)
 		{
@@ -1807,7 +1835,7 @@ void us_combinelayers(ARCINST *ai, INTSML *bitplanes, INTSML *color)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	k = arcpolys(ai, NOWINDOWPART);
 	for(j=0; j<k; j++)
@@ -1837,7 +1865,7 @@ INTSML us_drawarcinst(ARCINST *ai, INTSML on, XARRAY trans, INTSML layers, WINDO
 		if (stopping(STOPREASONDISPLAY)) return(-1);
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	ap = ai->proto;
 	i = arcpolys(ai, NOWINDOWPART);
@@ -1902,7 +1930,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 	XARRAY localtran, tempt1, tempt2, *t1, *t2, *swapt;
 	INTBIG px, py;
 	INTSML wid, hei;
-	REGISTER INTBIG sx, sy, lambda, tf;
+	REGISTER INTBIG sx, sy, lambda;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *facet;
@@ -1913,7 +1941,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 	if (dispstyle == 2) return;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* get technology and lambda */
 	facet = pp->subnodeinst->parent;
@@ -1922,14 +1950,13 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 
 	/* account for port offset */
 	t1 = (XARRAY *)tempt1;   t2 = (XARRAY *)tempt2;
-	if (dispstyle != 1 && (pp->textdescript&(VTXOFF|VTYOFF)) != 0)
+	if (dispstyle != 1 &&
+		(TDGETXOFF(pp->textdescript) != 0 || TDGETYOFF(pp->textdescript) != 0))
 	{
 		transid(localtran);
-		localtran[2][0] = (pp->textdescript&VTXOFF)>>VTXOFFSH;
-		if ((pp->textdescript&VTXOFFNEG) != 0) localtran[2][0] = -localtran[2][0];
+		localtran[2][0] = TDGETXOFF(pp->textdescript);
 		localtran[2][0] = localtran[2][0] * lambda / 4;
-		localtran[2][1] = (pp->textdescript&VTYOFF)>>VTYOFFSH;
-		if ((pp->textdescript&VTYOFFNEG) != 0) localtran[2][1] = -localtran[2][1];
+		localtran[2][1] = TDGETYOFF(pp->textdescript);
 		localtran[2][1] = localtran[2][1] * lambda / 4;
 		transmult(localtran, prevtrans, *t1);
 	} else transcpy(prevtrans, *t1);
@@ -1951,14 +1978,12 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 			swapt = t1;   t1 = t2;   t2 = swapt;
 		}
 		if (dispstyle != 1 && ni->proto->primindex == 0 &&
-			(rpp->textdescript&(VTXOFF|VTYOFF)) != 0)
+			(TDGETXOFF(rpp->textdescript) != 0 || TDGETYOFF(rpp->textdescript) != 0))
 		{
 			transid(localtran);
-			localtran[2][0] = (rpp->textdescript&VTXOFF)>>VTXOFFSH;
-			if ((rpp->textdescript&VTXOFFNEG) != 0) localtran[2][0] = -localtran[2][0];
+			localtran[2][0] = TDGETXOFF(rpp->textdescript);
 			localtran[2][0] = localtran[2][0] * lambda / 4;
-			localtran[2][1] = (rpp->textdescript&VTYOFF)>>VTYOFFSH;
-			if ((rpp->textdescript&VTYOFFNEG) != 0) localtran[2][1] = -localtran[2][1];
+			localtran[2][1] = TDGETYOFF(rpp->textdescript);
 			localtran[2][1] = localtran[2][1] * lambda / 4;
 			transmult(localtran, *t1, *t2);
 			swapt = t1;   t1 = t2;   t2 = swapt;
@@ -1967,7 +1992,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 
 	/* get the center position of the port */
 	shapetransportpoly(ni, rpp, poly, *t1);
-	if (dispstyle == 1 || (pp->textdescript&VTPOSITION) != VTPOSBOXED)
+	if (dispstyle == 1 || TDGETPOS(pp->textdescript) != VTPOSBOXED)
 	{
 		getcenter(poly, &px, &py);
 		poly->xv[0] = px;   poly->yv[0] = py;   poly->count = 1;
@@ -1977,11 +2002,11 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 	if (dispstyle == 1) poly->style = CROSS; else
 	{
 		/* writing text name: setup polygon */
-		poly->font = (INTSML)((pp->textdescript & VTSIZE) >> VTSIZESH);
+		TDCOPY(poly->textdescript, pp->textdescript);
 		poly->tech = pp->parent->tech;
 
 		/* convert text description to polygon description */
-		switch (pp->textdescript&VTPOSITION)
+		switch (TDGETPOS(pp->textdescript))
 		{
 			case VTPOSCENT:      poly->style = TEXTCENT;      break;
 			case VTPOSBOXED:     poly->style = TEXTBOX;       break;
@@ -2008,8 +2033,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 			sy = applyyscale(w, py-w->screenly) + w->usely;
 			if (sx < portcliplx || sx > portcliphx || sy < portcliply || sy > portcliphy)
 				return;
-			tf = truefontsize(poly->font, w, tech);
-			screensettextsize(w, tf);
+			screensettextinfo(w, tech, poly->textdescript);
 			screengettextsize(w, poly->string, &wid, &hei);   wid++;   hei++;
 			switch (poly->style)
 			{
@@ -2109,7 +2133,7 @@ char *us_displayedportname(PORTPROTO *pp, INTBIG dispstyle)
 
 /******************** PEEK DISPLAY ********************/
 
-WINDOWPART *us_peekwindow;
+static WINDOWPART *us_peekwindow;
 
 void us_dopeek(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *np, WINDOWPART *w)
 {
@@ -2218,7 +2242,7 @@ INTSML us_drawarcinstpeek(ARCINST *ai, XARRAY trans, INTSML layers)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* determine which polygons to draw */
 	ap = ai->proto;
@@ -2273,7 +2297,7 @@ INTSML us_drawnodeinstpeek(NODEINST *ni, XARRAY prevtrans, INTSML layers)
 	REGISTER NODEPROTO *np;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	np = ni->proto;
 
