@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usreditemacs.c
- * User interface aid: EMACS-like text window handler
+ * User interface tool: EMACS-like text window handler
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -112,31 +112,31 @@ static INTBIG   us_killbufchars = 0;	/* characters in kill buffer */
 static char    *us_searchbuf = 0;		/* search string for ^S and ^R */
 
 /* prototypes for local routines */
-void us_editemacsgotbutton(WINDOWPART*, INTSML, INTSML, INTSML);
-void us_editemacsredraweditor(WINDOWPART*);
-INTSML us_editemacsimplementchar(WINDOWPART*, INTBIG, INTSML, INTSML);
-INTSML us_editemacsbackupchar(WINDOWPART*, INTSML);
-INTSML us_editemacsadvancechar(WINDOWPART*, INTSML);
-void us_editemacsdeletechar(WINDOWPART*);
-void us_editemacsshiftscreenup(WINDOWPART*);
-void us_editemacsshiftscreendown(WINDOWPART*);
-void us_editemacsensuretextshown(WINDOWPART*, INTBIG);
-void us_editemacsredrawscreen(WINDOWPART*);
-void us_editemacsredrawline(WINDOWPART*, INTBIG);
-void us_editemacssetheader(WINDOWPART*, char*);
-void us_editemacsflashcursor(WINDOWPART*);
-void us_editemacsoffhighlight(WINDOWPART*);
-void us_editemacscleanupline(WINDOWPART*, INTBIG);
-void us_editemacsworkingoncurline(EDITOR*);
-void us_editemacsaddmorelines(EDITOR*);
-void us_editemacsaddmorechars(EDITOR*, INTBIG);
-void us_editemacsgetbuffers(EDITOR*);
-void us_editemacsmovebox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-void us_editemacsclearbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
-void us_editemacsinvertbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
-void us_editemacstext(WINDOWPART*, char*, INTBIG, INTBIG);
-void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
-	INTSML fromtop, INTSML casesensitive, INTSML fromuser);
+static void us_editemacsgotbutton(WINDOWPART*, INTSML, INTSML, INTSML);
+static void us_editemacsredraweditor(WINDOWPART*);
+static INTSML us_editemacsimplementchar(WINDOWPART*, INTBIG, INTSML, INTSML);
+static INTSML us_editemacsbackupchar(WINDOWPART*, INTSML);
+static INTSML us_editemacsadvancechar(WINDOWPART*, INTSML);
+static void us_editemacsdeletechar(WINDOWPART*);
+static void us_editemacsshiftscreenup(WINDOWPART*);
+static void us_editemacsshiftscreendown(WINDOWPART*);
+static void us_editemacsensuretextshown(WINDOWPART*, INTBIG);
+static void us_editemacsredrawscreen(WINDOWPART*);
+static void us_editemacsredrawline(WINDOWPART*, INTBIG);
+static void us_editemacssetheader(WINDOWPART*, char*);
+static void us_editemacsflashcursor(WINDOWPART*);
+static void us_editemacsoffhighlight(WINDOWPART*);
+static void us_editemacscleanupline(WINDOWPART*, INTBIG);
+static void us_editemacsworkingoncurline(EDITOR*);
+static void us_editemacsaddmorelines(EDITOR*);
+static void us_editemacsaddmorechars(EDITOR*, INTBIG);
+static void us_editemacsgetbuffers(EDITOR*);
+static void us_editemacsmovebox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void us_editemacsclearbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
+static void us_editemacsinvertbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
+static void us_editemacstext(WINDOWPART*, char*, INTBIG, INTBIG);
+static void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
+			INTSML fromtop, INTSML casesensitive, INTSML fromuser);
 
 /******************** INTERFACE FOR TEXT WINDOW ********************/
 
@@ -149,6 +149,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
 WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars, INTSML *lines)
 {
 	INTBIG i, x, y;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTSML swid, shei, pwid;
 	REGISTER EDITOR *e;
 	REGISTER VARIABLE *var;
@@ -173,7 +174,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 		}
 
 		/* create a window that covers the popup */
-		startobjectchange((INTBIG)us_aid, VAID);
+		startobjectchange((INTBIG)us_tool, VTOOL);
 		win = newwindowpart("popup", el_curwindowpart);
 		win->uselx = (INTSML)maxi(x-200, 0);
 		win->usely = (INTSML)maxi(y-us_thei-1, 0);
@@ -207,23 +208,25 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 
 	/*
 	 * the font that is used by the editor is the fixed-width font, TXTEDITOR.
-	 * This can be changed by setting the variable "USER_textedit_font" on the user aid
+	 * This can be changed by setting the variable "USER_textedit_font" on the user tool
 	 * object.  The value is the point size minus 4 divided by 2 (the value 0 is the
 	 * default font TXTEDITOR).  For example, to set the font to be 14 points, type:
-	 *     -var set aid:user.USER_textedit_font 5
+	 *     -var set tool:user.USER_textedit_font 5
 	 */
 	us_editemacsfont = TXTEDITOR;
-	var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_textedit_font");
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_textedit_font");
 	if (var != NOVARIABLE && var->addr >= 4)
 		us_editemacsfont = var->addr;
-	screensettextsize(win, us_editemacsfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editemacsfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	screengettextsize(win, "X", &us_twid, &us_thei);
 
 	/* create a new editor object */
 	e = us_alloceditor();
 	if (e == NOEDITOR) return(NOWINDOWPART);
 	e->state = (e->state & ~(EDITORTYPE|EGRAPHICSOFF|LINESFIXED)) | EMACSEDITOR;
-	(void)allocstring(&e->header, header, us_aid->cluster);
+	(void)allocstring(&e->header, header, us_tool->cluster);
 	e->highlightedline = -1;
 	us_lastemacschar = 0;
 	e->curline = e->curchar = 0;
@@ -244,14 +247,14 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 		e->maxlines = e->screenlines;
 		e->mostchars = e->screenchars;
 		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))),
-			us_aid->cluster);
+			us_tool->cluster);
 		if (e->textarray == 0) ttyputnomemory();
-		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
+		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
 		if (e->maxchars == 0) ttyputnomemory();
 		us_editemacsgetbuffers(e);
 		for(i=0; i<e->maxlines; i++)
 		{
-			e->textarray[i] = (char *)emalloc((e->screenchars+1), us_aid->cluster);
+			e->textarray[i] = (char *)emalloc((e->screenchars+1), us_tool->cluster);
 			if (e->textarray[i] == 0) ttyputnomemory();
 			e->textarray[i][0] = 0;
 			e->maxchars[i] = e->screenchars;
@@ -283,7 +286,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 		e->savedbox = screensavebox(win, (INTSML)maxi(e->offx-2,0),
 			(INTSML)(e->offx+e->swid+2), (INTSML)maxi(e->revy-e->shei-2,0),
 				(INTSML)(e->revy+us_thei*HEADERLINES+1));
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 	}
 	return(win);
 }
@@ -833,7 +836,7 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		} else
 		{
 			if (us_searchbuf != 0) efree(us_searchbuf);
-			(void)allocstring(&us_searchbuf, pt, us_aid->cluster);
+			(void)allocstring(&us_searchbuf, pt, us_tool->cluster);
 		}
 		us_editemacsdosearch(win, us_searchbuf, 0, 0, 0, fromuser);
 		return(0);
@@ -863,7 +866,7 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		} else
 		{
 			if (us_searchbuf != 0) efree(us_searchbuf);
-			(void)allocstring(&us_searchbuf, pt, us_aid->cluster);
+			(void)allocstring(&us_searchbuf, pt, us_tool->cluster);
 		}
 		us_editemacsdosearch(win, us_searchbuf, 1, 0, 0, fromuser);
 		return(0);
@@ -1806,9 +1809,9 @@ void us_editemacsaddmorelines(EDITOR *e)
 	e->maxlines *= 2;
 
 	/* allocate new arrays */
-	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
+	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
 	if (maxchars == 0) ttyputnomemory();
-	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_aid->cluster);
+	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_tool->cluster);
 	if (textarray == 0) ttyputnomemory();
 
 	/* copy old information */
@@ -1816,13 +1819,13 @@ void us_editemacsaddmorelines(EDITOR *e)
 	{
 		if (i >= oldlines)
 		{
-			textarray[i] = (char *)emalloc((e->screenchars+1), us_aid->cluster);
+			textarray[i] = (char *)emalloc((e->screenchars+1), us_tool->cluster);
 			if (textarray[i] == 0) ttyputnomemory();
 			textarray[i][0] = 0;
 			maxchars[i] = e->screenchars;
 		} else
 		{
-			textarray[i] = (char *)emalloc((e->maxchars[i]+1), us_aid->cluster);
+			textarray[i] = (char *)emalloc((e->maxchars[i]+1), us_tool->cluster);
 			if (textarray[i] == 0) ttyputnomemory();
 			(void)strcpy(textarray[i], e->textarray[i]);
 			maxchars[i] = e->maxchars[i];
@@ -1848,7 +1851,7 @@ void us_editemacsaddmorechars(EDITOR *e, INTBIG line)
 
 	oldline = e->textarray[line];
 	e->maxchars[line] *= 2;
-	e->textarray[line] = (char *)emalloc((e->maxchars[line]+1), us_aid->cluster);
+	e->textarray[line] = (char *)emalloc((e->maxchars[line]+1), us_tool->cluster);
 	(void)strcpy(e->textarray[line], oldline);
 	if (e->maxchars[line] > e->mostchars)
 	{
@@ -1863,12 +1866,12 @@ void us_editemacsaddmorechars(EDITOR *e, INTBIG line)
  */
 void us_editemacsgetbuffers(EDITOR *e)
 {
-	e->formerline = (char *)emalloc((e->mostchars+1), us_aid->cluster);
+	e->formerline = (char *)emalloc((e->mostchars+1), us_tool->cluster);
 	if (e->formerline == 0) ttyputnomemory();
 	if (e->mostchars > us_killbufchars)
 	{
 		if (us_killbufchars != 0) efree(us_killbuf);
-		us_killbuf = (char *)emalloc(e->mostchars, us_aid->cluster);
+		us_killbuf = (char *)emalloc(e->mostchars, us_tool->cluster);
 		if (us_killbuf == 0) ttyputnomemory();
 		us_killbufchars = e->mostchars;
 	}
@@ -1930,11 +1933,14 @@ void us_editemacsinvertbox(WINDOWPART *win, INTBIG dx, INTBIG dy, INTBIG wid, IN
 void us_editemacstext(WINDOWPART *win, char *str, INTBIG x, INTBIG y)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
 
-	screensettextsize(win, us_editemacsfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editemacsfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_menutext.col = el_colmentxt;
 	screendrawtext(win, (INTSML)(x*us_twid + e->offx), (INTSML)(e->revy-(y+1)*us_thei),
 		str, &us_menutext);
