@@ -46,7 +46,8 @@ static char    *us_editpacbuffer = 0;	/* the cut/copy/paste buffer */
 
 /* variables for cursor tracking */
 static WINDOWPART *us_editpaccurrentwin;
-static INTSML      us_editpacoffset;
+static INTBIG      us_editpacdeltasofar;
+static INTBIG      us_editpacinitialthumb;
 static INTBIG      us_originalcurline, us_originalcurchar;
 static INTBIG      us_originalendline, us_originalendchar;
 static INTBIG      us_editpaclastc, us_editpaclastl;
@@ -59,50 +60,49 @@ static char       *us_editpacundobuffer;
 static INTBIG      us_editpacundobuffersize = 0;
 
 extern GRAPHICS us_ebox, us_menutext, us_menufigs;
-GRAPHICS us_drawgray = {LAYERA, DGRAY, SOLIDC, SOLIDC,
-	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* prototypes for local routines */
-void us_editpacredraweditor(WINDOWPART*);
-void us_editpacgotbutton(WINDOWPART*, INTSML, INTSML, INTSML);
-INTSML us_editpacclickdown(INTBIG, INTBIG);
-INTSML us_editpacdclickdown(INTBIG, INTBIG);
-INTSML us_editpacdoclickdown(INTBIG, INTBIG, INTSML);
-INTSML us_editpacdownarrow(INTBIG, INTBIG);
-INTSML us_editpacuparrow(INTBIG, INTBIG);
-INTSML us_editpacdownpage(INTBIG, INTBIG);
-INTSML us_editpacuppage(INTBIG, INTBIG);
-INTSML us_editpacrightarrow(INTBIG, INTBIG);
-INTSML us_editpacleftarrow(INTBIG, INTBIG);
-INTSML us_editpacrightpage(INTBIG, INTBIG);
-INTSML us_editpacleftpage(INTBIG, INTBIG);
-INTSML us_editpacimplementchar(WINDOWPART*, INTSML, INTSML);
-void us_editpacremoveselection(WINDOWPART*);
-void us_editpacredrawscreen(WINDOWPART*);
-void us_drawsliders(WINDOWPART*);
-void us_editpacdrawhscroll(WINDOWPART*);
-void us_editpacdrawvscroll(WINDOWPART*);
-void us_editpaccleanupline(WINDOWPART*, INTBIG);
-void us_editpacredrawlines(WINDOWPART*);
-void us_editpacsetheader(WINDOWPART*, char*);
-void us_editpacinvertselection(WINDOWPART*);
-void us_editpacdonetyping(EDITOR*);
-void us_editpacamtyping(EDITOR*);
-void us_editpactypeddelete(EDITOR*);
-INTBIG us_editpaccharstocurrent(EDITOR*, INTBIG, INTBIG);
-void us_editpacloadselection(EDITOR*, char*);
-void us_editpaccomputebounds(WINDOWPART*, EDITOR*);
-void us_editpacbeginwork(WINDOWPART*);
-void us_editpacaddmorelines(EDITOR*);
-void us_editpacaddmorechars(EDITOR*, INTBIG, INTBIG);
-void us_editpacmovebox(WINDOWPART*, INTSML, INTSML, INTSML, INTSML, INTSML, INTSML);
-void us_editpacclearbox(WINDOWPART*, INTSML, INTSML, INTSML, INTSML);
-void us_editpacinvertrectframe(WINDOWPART*, INTSML, INTSML);
-void us_editpactext(WINDOWPART*, char*, INTSML, INTSML);
-void us_editpacbackupposition(EDITOR *e, INTBIG *chr, INTBIG *lne);
-void us_editpacadvanceposition(EDITOR *e, INTBIG *chr, INTBIG *lne);
-INTSML us_editpacsinglesearch(WINDOWPART *win, char *str, char *replace, INTBIG bits);
-void us_editpanwindow(WINDOWPART *w, INTBIG dx, INTBIG dy);
+static void us_editpacredraweditor(WINDOWPART*);
+static void us_editpacgotbutton(WINDOWPART*, INTSML, INTSML, INTSML);
+static INTSML us_editpacclickdown(INTBIG, INTBIG);
+static INTSML us_editpacdclickdown(INTBIG, INTBIG);
+static INTSML us_editpacdoclickdown(INTBIG, INTBIG, INTSML);
+static INTSML us_editpacdownarrow(INTBIG, INTBIG);
+static INTSML us_editpacuparrow(INTBIG, INTBIG);
+static INTSML us_editpacdownpage(INTBIG, INTBIG);
+static INTSML us_editpacuppage(INTBIG, INTBIG);
+static INTSML us_editpacrightarrow(INTBIG, INTBIG);
+static INTSML us_editpacleftarrow(INTBIG, INTBIG);
+static INTSML us_editpacrightpage(INTBIG, INTBIG);
+static INTSML us_editpacleftpage(INTBIG, INTBIG);
+static INTSML us_editpacimplementchar(WINDOWPART*, INTSML, INTSML);
+static void us_editpacremoveselection(WINDOWPART*);
+static void us_editpacredrawscreen(WINDOWPART*);
+static void us_drawsliders(WINDOWPART*);
+static void us_editpacdrawhscroll(WINDOWPART*);
+static void us_editpacdrawvscroll(WINDOWPART*);
+static void us_editpaccleanupline(WINDOWPART*, INTBIG);
+static void us_editpacredrawlines(WINDOWPART*);
+static void us_editpacsetheader(WINDOWPART*, char*);
+static void us_editpacinvertselection(WINDOWPART*);
+static void us_editpacdonetyping(EDITOR*);
+static void us_editpacamtyping(EDITOR*);
+static void us_editpactypeddelete(EDITOR*);
+static INTBIG us_editpaccharstocurrent(EDITOR*, INTBIG, INTBIG);
+static void us_editpacloadselection(EDITOR*, char*);
+static void us_editpaccomputebounds(WINDOWPART*, EDITOR*);
+static void us_editpacbeginwork(WINDOWPART*);
+static void us_editpacaddmorelines(EDITOR*);
+static void us_editpacaddmorechars(EDITOR*, INTBIG, INTBIG);
+static void us_editpacmovebox(WINDOWPART*, INTSML, INTSML, INTSML, INTSML, INTSML, INTSML);
+static void us_editpacclearbox(WINDOWPART*, INTSML, INTSML, INTSML, INTSML);
+static void us_editpactext(WINDOWPART*, char*, INTSML, INTSML);
+static void us_editpacbackupposition(EDITOR *e, INTBIG *chr, INTBIG *lne);
+static void us_editpacadvanceposition(EDITOR *e, INTBIG *chr, INTBIG *lne);
+static INTSML us_editpacsinglesearch(WINDOWPART *win, char *str, char *replace, INTBIG bits);
+static void us_editpanwindow(WINDOWPART *w, INTBIG dx, INTBIG dy);
+static void us_hthumbtrackingtextcallback(INTBIG delta);
+static void us_vthumbtrackingtextcallback(INTBIG delta);
 
 /******************** ROUTINES IN THE EDITOR TABLE ********************/
 
@@ -115,6 +115,7 @@ void us_editpanwindow(WINDOWPART *w, INTBIG dx, INTBIG dy);
 WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars, INTSML *lines)
 {
 	INTBIG x, y;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTSML i, xs, ys, swid, shei, pwid;
 	REGISTER EDITOR *e;
 	REGISTER VARIABLE *var;
@@ -122,13 +123,13 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 
 	/*
 	 * the font that is used by the editor is the fixed-width font, TXTEDITOR.
-	 * This can be changed by setting the variable "USER_textedit_font" on the user aid
+	 * This can be changed by setting the variable "USER_textedit_font" on the user tool
 	 * object.  The value is the point size minus 4 divided by 2 (the value 0 is the
 	 * default font TXTEDITOR).  For example, to set the font to be 14 points, type:
-	 *     -var set aid:user.USER_textedit_font 5
+	 *     -var set tool:user.USER_textedit_font 5
 	 */
 	us_editpacfont = TXTEDITOR;
-	var = getval((INTBIG)us_aid, VAID, VINTEGER, "USER_textedit_font");
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_textedit_font");
 	if (var != NOVARIABLE && var->addr >= 4)
 		us_editpacfont = var->addr;
 
@@ -149,9 +150,11 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 		}
 
 		/* create a window that covers the popup */
-		startobjectchange((INTBIG)us_aid, VAID);
+		startobjectchange((INTBIG)us_tool, VTOOL);
 		win = newwindowpart("popup", el_curwindowpart);
-		screensettextsize(win, us_editpacfont);
+		TDCLEAR(descript);
+		TDSETSIZE(descript, us_editpacfont);
+		screensettextinfo(win, NOTECHNOLOGY, descript);
 		screengettextsize(win, "X", &us_twid, &us_thei);
 		xs = 400;   ys = us_thei*(HEADERLINES+1)+DISPLAYSLIDERSIZE+4;
 		win->uselx = (INTSML)maxi(x-xs/2, 0);
@@ -176,7 +179,9 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 			win->usely -= DISPLAYSLIDERSIZE;
 		}
 		win->state = (win->state & ~(WINDOWTYPE|WINDOWSIMULATING)) | TEXTWINDOW;
-		screensettextsize(win, us_editpacfont);
+		TDCLEAR(descript);
+		TDSETSIZE(descript, us_editpacfont);
+		screensettextinfo(win, NOTECHNOLOGY, descript);
 		screengettextsize(win, "X", &us_twid, &us_thei);
 	}
 
@@ -194,7 +199,7 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 	e = us_alloceditor();
 	if (e == NOEDITOR) return(NOWINDOWPART);
 	e->state = (e->state & ~(EDITORTYPE|EGRAPHICSOFF|LINESFIXED|TEXTTYPING|TEXTTYPED)) | PACEDITOR;
-	(void)allocstring(&e->header, header, us_aid->cluster);
+	(void)allocstring(&e->header, header, us_tool->cluster);
 	e->curline = e->curchar = 0;
 	e->endline = e->endchar = 0;
 	e->firstline = 0;
@@ -213,15 +218,15 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 		e->maxlines = e->screenlines;
 		if (e->maxlines <= 0) e->maxlines = 1;
 		e->mostchars = e->screenchars;
-		e->formerline = (char *)emalloc(e->mostchars+1, us_aid->cluster);
+		e->formerline = (char *)emalloc(e->mostchars+1, us_tool->cluster);
 		if (e->formerline == 0) ttyputnomemory();
-		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_aid->cluster);
+		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_tool->cluster);
 		if (e->textarray == 0) ttyputnomemory();
-		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
+		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
 		if (e->maxchars == 0) ttyputnomemory();
 		for(i=0; i<e->maxlines; i++)
 		{
-			e->textarray[i] = (char *)emalloc(DEFAULTWID, us_aid->cluster);
+			e->textarray[i] = (char *)emalloc(DEFAULTWID, us_tool->cluster);
 			if (e->textarray[i] == 0) ttyputnomemory();
 			e->maxchars[i] = DEFAULTWID;
 		}
@@ -246,7 +251,7 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 	{
 		/* finish initializing popup text window */
 		e->savedbox = screensavebox(win, win->uselx, win->usehx, win->usely, win->usehy);
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 	}
 	return(win);
 }
@@ -313,10 +318,16 @@ void us_editpacaddline(WINDOWPART *win, INTBIG lindex, char *str)
 	REGISTER char *pt;
 	REGISTER INTBIG savedsline, savedschar, savedeline, savedechar;
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	if ((e->state&EGRAPHICSOFF) == 0) screensettextsize(win, us_editpacfont);
+	if ((e->state&EGRAPHICSOFF) == 0)
+	{
+		TDCLEAR(descript);
+		TDSETSIZE(descript, us_editpacfont);
+		screensettextinfo(win, NOTECHNOLOGY, descript);
+	}
 
 	/* send out any pending changes */
 	us_editpacshipchanges(win);
@@ -331,6 +342,7 @@ void us_editpacaddline(WINDOWPART *win, INTBIG lindex, char *str)
 	/* fake the characters */
 	for(pt = str; *pt != 0; pt++) (void)us_editpacimplementchar(win, *pt, 0);
 	(void)us_editpacimplementchar(win, '\n', 0);
+	e->state &= ~TEXTTYPED;
 
 	/* send out pending changes */
 	us_editpacshipchanges(win);
@@ -350,10 +362,16 @@ void us_editpacreplaceline(WINDOWPART *win, INTBIG lindex, char *str)
 	REGISTER char *pt;
 	REGISTER INTBIG savedsline, savedschar, savedeline, savedechar;
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	if ((e->state&EGRAPHICSOFF) == 0) screensettextsize(win, us_editpacfont);
+	if ((e->state&EGRAPHICSOFF) == 0)
+	{
+		TDCLEAR(descript);
+		TDSETSIZE(descript, us_editpacfont);
+		screensettextinfo(win, NOTECHNOLOGY, descript);
+	}
 
 	/* send out any pending changes */
 	us_editpacshipchanges(win);
@@ -368,6 +386,7 @@ void us_editpacreplaceline(WINDOWPART *win, INTBIG lindex, char *str)
 
 	/* fake the characters */
 	for(pt = str; *pt != 0; pt++) (void)us_editpacimplementchar(win, *pt, 0);
+	e->state &= ~TEXTTYPED;
 
 	/* send out pending changes */
 	us_editpacshipchanges(win);
@@ -386,10 +405,16 @@ void us_editpacdeleteline(WINDOWPART *win, INTBIG lindex)
 {
 	REGISTER INTBIG savedsline, savedschar, savedeline, savedechar;
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	if ((e->state&EGRAPHICSOFF) == 0) screensettextsize(win, us_editpacfont);
+	if ((e->state&EGRAPHICSOFF) == 0)
+	{
+		TDCLEAR(descript);
+		TDSETSIZE(descript, us_editpacfont);
+		screensettextinfo(win, NOTECHNOLOGY, descript);
+	}
 
 	/* send out any pending changes */
 	us_editpacshipchanges(win);
@@ -404,6 +429,7 @@ void us_editpacdeleteline(WINDOWPART *win, INTBIG lindex)
 
 	/* fake the deletion character */
 	(void)us_editpacimplementchar(win, BACKSPACEKEY, 0);
+	e->state &= ~TEXTTYPED;
 
 	/* send out pending changes */
 	us_editpacshipchanges(win);
@@ -421,10 +447,13 @@ void us_editpacdeleteline(WINDOWPART *win, INTBIG lindex)
 void us_editpachighlightline(WINDOWPART *win, INTBIG lindex, INTBIG hindex)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacinvertselection(win);
 	e->curline = lindex;
 	e->curchar = 0;
@@ -461,11 +490,14 @@ void us_editpacsuspendgraphics(WINDOWPART *win)
 void us_editpacresumegraphics(WINDOWPART *win)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
 	e->state &= ~EGRAPHICSOFF;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacredrawscreen(win);
 }
 
@@ -510,6 +542,7 @@ void us_editpacreadtextfile(WINDOWPART *win, char *file)
 	REGISTER INTBIG i, filelength, charsread;
 	REGISTER INTSML c;
 	REGISTER FILE *f;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	char *filename;
 	extern DIALOG us_progressdialog;
 
@@ -588,7 +621,9 @@ void us_editpacreadtextfile(WINDOWPART *win, char *file)
 
 	/* restore the display */
 	e->state &= ~EGRAPHICSOFF;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	e->curline = e->curchar = 0;
 	e->endline = e->endchar = 0;
 	us_editpacbeginwork(win);
@@ -637,6 +672,7 @@ void us_editpacshipchanges(WINDOWPART *win)
 INTSML us_editpacgotchar(WINDOWPART *win, INTSML i)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	if ((i&0200) != 0)
 	{
@@ -645,7 +681,9 @@ INTSML us_editpacgotchar(WINDOWPART *win, INTSML i)
 
 	e = win->editor;
 	if (e == NOEDITOR) return(1);
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacinvertselection(win);
 	if (us_editpacimplementchar(win, i, 1) != 0) return(1);
 	us_editpacinvertselection(win);
@@ -656,6 +694,7 @@ INTSML us_editpacgotchar(WINDOWPART *win, INTSML i)
 void us_editpaccut(WINDOWPART *win)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
@@ -664,7 +703,9 @@ void us_editpaccut(WINDOWPART *win)
 	us_editpaccopy(win);
 
 	/* remove the selection from the edit buffer */
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacinvertselection(win);
 	(void)us_editpacimplementchar(win, BACKSPACEKEY, 1);
 	us_editpacinvertselection(win);
@@ -690,7 +731,7 @@ void us_editpaccopy(WINDOWPART *win)
 	if (len <= 0) return;
 
 	/* allocate a new cut/copy buffer */
-	us_editpacbuffer = (char *)emalloc(len+1, us_aid->cluster);
+	us_editpacbuffer = (char *)emalloc(len+1, us_tool->cluster);
 	if (us_editpacbuffer == 0) return;
 
 	/* fill the buffer */
@@ -704,7 +745,7 @@ void us_editpacpaste(WINDOWPART *win)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG i;
-
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTBIG len;
 	char *str;
 
@@ -715,7 +756,7 @@ void us_editpacpaste(WINDOWPART *win)
 	len = strlen(str);
 	if (len > 0)
 	{
-		us_editpacbuffer = (char *)emalloc(len+1, us_aid->cluster);
+		us_editpacbuffer = (char *)emalloc(len+1, us_tool->cluster);
 		if (us_editpacbuffer == 0) return;
 		strcpy(us_editpacbuffer, str);
 	}
@@ -723,7 +764,9 @@ void us_editpacpaste(WINDOWPART *win)
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 
 	us_editpacinvertselection(win);
 	for(i=0; us_editpacbuffer[i] != 0; i++)
@@ -742,6 +785,7 @@ void us_editpacundo(WINDOWPART *win)
 	char *savebuffer;
 	REGISTER EDITOR *e;
 	REGISTER INTBIG i;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
@@ -756,7 +800,9 @@ void us_editpacundo(WINDOWPART *win)
 	(void)allocstring(&savebuffer, us_editpacundobuffer, el_tempcluster);
 
 	/* replace what was typed */
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacinvertselection(win);
 	e->curline = us_editpacundonewcurline;    e->curchar = us_editpacundonewcurchar;
 	e->endline = us_editpacundonewendline;    e->endchar = us_editpacundonewendchar;
@@ -804,6 +850,7 @@ INTSML us_editpacsinglesearch(WINDOWPART *win, char *str, char *replace, INTBIG
 {
 	REGISTER INTBIG i, want, mchr, mlne;
 	INTBIG startchr, startlne, chr, lne;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER EDITOR *e;
 
 	e = win->editor;
@@ -872,7 +919,9 @@ INTSML us_editpacsinglesearch(WINDOWPART *win, char *str, char *replace, INTBIG
 	}
 
 	/* string found */
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpacdonetyping(e);
 	us_editpacinvertselection(win);
 	e->curline = lne;   e->curchar = chr;
@@ -912,10 +961,13 @@ INTSML us_editpacsinglesearch(WINDOWPART *win, char *str, char *replace, INTBIG
 void us_editpacredraweditor(WINDOWPART *win)
 {
 	REGISTER EDITOR *e;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 
 	/* compute window extents */
 	us_editpaccomputebounds(win, e);
@@ -928,8 +980,9 @@ void us_editpacredraweditor(WINDOWPART *win)
 void us_editpacgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
 {
 	REGISTER EDITOR *e;
-	REGISTER INTBIG xc, yc, len, i;
+	REGISTER INTBIG xc, yc, len;
 	INTSML (*clickroutine)(INTBIG, INTBIG);
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/* changes to the mouse-wheel are handled by the user interface */
 	if (wheelbutton(but) != 0)
@@ -941,7 +994,9 @@ void us_editpacgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	screensettextsize(win, us_editpacfont);
+	TDCLEAR(descript);
+	TDSETSIZE(descript, us_editpacfont);
+	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_editpaccurrentwin = win;
 
 	if ((win->state&WINDOWTYPE) != POPTEXTWINDOW && x > e->offx + e->swid)
@@ -979,17 +1034,15 @@ void us_editpacgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
 		if (y >= e->vthumbpos-THUMBSIZE/2 && y <= e->vthumbpos+THUMBSIZE/2)
 		{
 			/* drag slider appropriately */
+			us_editpacdeltasofar = 0;
+			us_editpacinitialthumb = e->vthumbpos;
 			us_vthumbbegin(y, win, win->usehx-DISPLAYSLIDERSIZE, win->usely+DISPLAYSLIDERSIZE,
-				win->usehy-us_thei*HEADERLINES, e->linecount, 0);
+				win->usehy-us_thei*HEADERLINES, 0, us_vthumbtrackingtextcallback);
 			trackcursor(0, us_nullup, us_nullvoid, us_vthumbdown, us_nullchar,
-				us_evthumbdone, TRACKNORMAL);
-			e->firstline = (INTSML)us_evthumbend();
-			us_editpacredrawlines(win);
-			us_editpacdrawvscroll(win);
+				us_vthumbdone, TRACKNORMAL);
 			return;
 		}
 	}
-
 	if (y <= e->revy - e->shei)
 	{
 		/* cursor in horizontal slider */
@@ -1024,18 +1077,12 @@ void us_editpacgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
 		if (x >= e->hthumbpos-THUMBSIZE/2 && x <= e->hthumbpos+THUMBSIZE/2)
 		{
 			/* drag slider appropriately */
+			us_editpacdeltasofar = 0;
+			us_editpacinitialthumb = (win->thumblx + win->thumbhx) / 2;
 			us_hthumbbegin(x, win, win->usely+DISPLAYSLIDERSIZE, win->uselx,
-				win->usehx-DISPLAYSLIDERSIZE);
+				win->usehx-DISPLAYSLIDERSIZE, us_hthumbtrackingtextcallback);
 			trackcursor(0, us_nullup, us_nullvoid, us_hthumbdown, us_nullchar,
-				us_ehthumbdone, TRACKNORMAL);
-			i = e->swid - DISPLAYSLIDERSIZE*2 + LEFTINDENT - THUMBSIZE;
-			i = ((us_ehthumbend() - (e->offx+DISPLAYSLIDERSIZE-LEFTINDENT+THUMBSIZE/2)) *
-				e->screenchars*10 + i/2) / i;
-			if (i < 0) i = 0;
-			if (i == e->horizfactor) return;
-			e->horizfactor = (INTSML)i;
-			us_editpacredrawlines(win);
-			us_editpacdrawhscroll(win);
+				us_hthumbdone, TRACKNORMAL);
 			return;
 		}
 	}
@@ -1101,6 +1148,41 @@ void us_editpacgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
 
 /******************** TRACKING ROUTINES ********************/
 
+void us_hthumbtrackingtextcallback(INTBIG delta)
+{
+	REGISTER INTBIG point, i;
+	REGISTER EDITOR *e;
+
+	us_editpacdeltasofar += delta;
+	e = us_editpaccurrentwin->editor;
+	point = us_editpacinitialthumb + us_editpacdeltasofar;
+	i = e->swid - DISPLAYSLIDERSIZE*2 + LEFTINDENT - THUMBSIZE;
+	i = ((point - (e->offx+DISPLAYSLIDERSIZE-LEFTINDENT+THUMBSIZE/2)) *
+		e->screenchars*10 + i/2) / i;
+	if (i < 0) i = 0;
+	if (i == e->horizfactor) return;
+	e->horizfactor = (INTSML)i;
+	us_editpacredrawlines(us_editpaccurrentwin);
+	us_editpacdrawhscroll(us_editpaccurrentwin);
+}
+
+void us_vthumbtrackingtextcallback(INTBIG delta)
+{
+	REGISTER INTBIG point, thumbarea, thumbpos;
+	REGISTER EDITOR *e;
+
+	us_editpacdeltasofar += delta;
+	e = us_editpaccurrentwin->editor;
+	thumbarea = e->linecount - e->screenlines;
+	thumbpos = us_editpacinitialthumb + us_editpacdeltasofar;
+	point = ((e->revy - DISPLAYSLIDERSIZE - THUMBSIZE/2 - thumbpos) * thumbarea - thumbarea/2) /
+		(e->shei-DISPLAYSLIDERSIZE*2-THUMBSIZE);
+	if (point < 0) point = 0;
+	e->firstline = point;
+	us_editpacredrawlines(us_editpaccurrentwin);
+	us_editpacdrawvscroll(us_editpaccurrentwin);
+}
+
 INTSML us_editpacclickdown(INTBIG x, INTBIG y)
 {
 	return(us_editpacdoclickdown(x, y, 0));
@@ -2014,7 +2096,7 @@ void us_editpacamtyping(EDITOR *e)
 	{
 		if (us_editpacundobuffersize != 0) efree(us_editpacundobuffer);
 		us_editpacundobuffersize = 0;
-		us_editpacundobuffer = (char *)emalloc(len, us_aid->cluster);
+		us_editpacundobuffer = (char *)emalloc(len, us_tool->cluster);
 		if (us_editpacundobuffer == 0) return;
 		us_editpacundobuffersize = len;
 	}
@@ -2038,7 +2120,7 @@ void us_editpactypeddelete(EDITOR *e)
 		us_editpaccharstocurrent(e, us_editpacundooldcurchar, us_editpacundooldcurline) + 1;
 	if (len > us_editpacundobuffersize)
 	{
-		newbuffer = (char *)emalloc(len, us_aid->cluster);
+		newbuffer = (char *)emalloc(len, us_tool->cluster);
 		if (newbuffer == 0) return;
 		(void)strcpy(newbuffer, us_editpacundobuffer);
 		if (us_editpacundobuffersize > 0) efree(us_editpacundobuffer);
@@ -2157,7 +2239,7 @@ void us_editpacbeginwork(WINDOWPART *win)
 	len = strlen(e->textarray[e->working]);
 	if (len >= e->mostchars)
 	{
-		newline = (char *)emalloc(len+1, us_aid->cluster);
+		newline = (char *)emalloc(len+1, us_tool->cluster);
 		if (newline == 0) return;
 		efree(e->formerline);
 		e->formerline = newline;
@@ -2183,9 +2265,9 @@ void us_editpacaddmorelines(EDITOR *e)
 	if (e->maxlines <= 0) e->maxlines = 1;
 
 	/* allocate new arrays */
-	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
+	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
 	if (maxchars == 0) ttyputnomemory();
-	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_aid->cluster);
+	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_tool->cluster);
 	if (textarray == 0) ttyputnomemory();
 
 	/* copy old information */
@@ -2193,7 +2275,7 @@ void us_editpacaddmorelines(EDITOR *e)
 	{
 		if (i >= oldlines)
 		{
-			textarray[i] = (char *)emalloc(DEFAULTWID, us_aid->cluster);
+			textarray[i] = (char *)emalloc(DEFAULTWID, us_tool->cluster);
 			if (textarray[i] == 0) ttyputnomemory();
 			textarray[i][0] = 0;
 			maxchars[i] = DEFAULTWID;
@@ -2224,7 +2306,7 @@ void us_editpacaddmorechars(EDITOR *e, INTBIG line, INTBIG need)
 	if (line >= e->maxlines) return;
 	oldline = e->textarray[line];
 	e->maxchars[line] = need+1;
-	e->textarray[line] = (char *)emalloc(need+1, us_aid->cluster);
+	e->textarray[line] = (char *)emalloc(need+1, us_tool->cluster);
 	(void)strcpy(e->textarray[line], oldline);
 	efree(oldline);
 }
@@ -2262,18 +2344,6 @@ void us_editpacclearbox(WINDOWPART *win, INTSML dx, INTSML dy, INTSML wid, INTSM
 		&us_ebox);
 }
 
-/*
- * routine to invert a box about the dragged thumb point
- */
-void us_editpacinvertrectframe(WINDOWPART *win, INTSML x, INTSML y)
-{
-	screeninvertbox(win, x, (INTSML)(x+THUMBSIZE), y, y);
-	screeninvertbox(win, x, (INTSML)(x+THUMBSIZE), (INTSML)(y+THUMBSIZE), (INTSML)(y+THUMBSIZE));
-	screeninvertbox(win, (INTSML)(x+THUMBSIZE), (INTSML)(x+THUMBSIZE), (INTSML)(y+1),
-		(INTSML)(y+THUMBSIZE-1));
-	screeninvertbox(win, x, x, (INTSML)(y+1), (INTSML)(y+THUMBSIZE-1));
-}
-
 /*
  * write text "str" starting at character position (x,y)
  */
