@@ -221,50 +221,49 @@ LIST us_tecnode_functions[] =
 	{NULL, NULL, 0}
 };
 
-GRAPHICS us_edtechigh = {LAYERH, HIGHLIT, SOLIDC, SOLIDC,
+static GRAPHICS us_edtechigh = {LAYERH, HIGHLIT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* prototypes for local routines */
-void us_teceditdrc(void);
-void us_teceditcolormap(void);
-void us_teceditcreat(INTSML, char*[]);
-void us_teceditidentify(INTSML);
-void us_teceditinquire(void);
-void us_teceditmodobject(INTSML, char*[]);
-void us_tecedlayer3dheight(NODEINST*, INTSML, char*[]);
-void us_tecedlayer3dthick(NODEINST*, INTSML, char*[]);
-void us_tecedlayercolor(NODEINST*, INTSML, char*[]);
-void us_tecedlayerdrcminwid(NODEINST*, INTSML, char*[]);
-void us_tecedlayerstyle(NODEINST*, INTSML, char*[]);
-void us_tecedlayercif(NODEINST*, INTSML, char*[]);
-void us_tecedlayerdxf(NODEINST*, INTSML, char*[]);
-void us_tecedlayergds(NODEINST*, INTSML, char*[]);
-void us_tecedlayerspires(NODEINST*, INTSML, char*[]);
-void us_tecedlayerspicap(NODEINST*, INTSML, char*[]);
-void us_tecedlayerspiecap(NODEINST*, INTSML, char*[]);
-void us_tecedlayerfunction(NODEINST*, INTSML, char*[]);
-void us_tecedlayerletters(NODEINST*, INTSML, char*[]);
-void us_tecedlayerpattern(NODEINST*);
-void us_tecedlayertype(NODEINST*, INTSML, char*[]);
-void us_tecedmodport(NODEINST*, INTSML, char*[]);
-void us_tecedarcfunction(NODEINST*, INTSML, char*[]);
-void us_tecedarcfixang(NODEINST*, INTSML, char*[]);
-void us_tecedarcwipes(NODEINST*, INTSML, char*[]);
-void us_tecedarcnoextend(NODEINST*, INTSML, char*[]);
-void us_tecedarcinc(NODEINST*, INTSML, char*[]);
-void us_tecednodefunction(NODEINST*, INTSML, char*[]);
-void us_tecednodeserpentine(NODEINST*, INTSML, char*[]);
-void us_tecednodesquare(NODEINST*, INTSML, char*[]);
-void us_tecednodewipes(NODEINST*, INTSML, char*[]);
-void us_tecednodelockable(NODEINST*, INTSML, char*[]);
-void us_tecedinfolambda(NODEINST*, INTSML, char*[]);
-void us_tecedinfodescript(NODEINST*, INTSML, char*[]);
-void us_tecedinfounits(NODEINST*, INTSML, char*[]);
-void us_tecedsetnode(NODEINST*, char*);
-NODEPROTO *us_tecedenterfacet(char*);
-void us_tecedredolayergraphics(NODEPROTO*);
-void us_tecedloadlibmap(LIBRARY*);
-INTSML us_teceditparsefun(char*);
+static void us_teceditdrc(void);
+static void us_teceditcolormap(void);
+static void us_teceditcreat(INTSML, char*[]);
+static void us_teceditidentify(INTSML);
+static void us_teceditinquire(void);
+static void us_teceditmodobject(INTSML, char*[]);
+static void us_tecedlayer3dheight(NODEINST*, INTSML, char*[]);
+static void us_tecedlayer3dthick(NODEINST*, INTSML, char*[]);
+static void us_tecedlayercolor(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerdrcminwid(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerstyle(NODEINST*, INTSML, char*[]);
+static void us_tecedlayercif(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerdxf(NODEINST*, INTSML, char*[]);
+static void us_tecedlayergds(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerspires(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerspicap(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerspiecap(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerfunction(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerletters(NODEINST*, INTSML, char*[]);
+static void us_tecedlayerpattern(NODEINST*);
+static void us_tecedlayertype(NODEINST*, INTSML, char*[]);
+static void us_tecedmodport(NODEINST*, INTSML, char*[]);
+static void us_tecedarcfunction(NODEINST*, INTSML, char*[]);
+static void us_tecedarcfixang(NODEINST*, INTSML, char*[]);
+static void us_tecedarcwipes(NODEINST*, INTSML, char*[]);
+static void us_tecedarcnoextend(NODEINST*, INTSML, char*[]);
+static void us_tecedarcinc(NODEINST*, INTSML, char*[]);
+static void us_tecednodefunction(NODEINST*, INTSML, char*[]);
+static void us_tecednodeserpentine(NODEINST*, INTSML, char*[]);
+static void us_tecednodesquare(NODEINST*, INTSML, char*[]);
+static void us_tecednodewipes(NODEINST*, INTSML, char*[]);
+static void us_tecednodelockable(NODEINST*, INTSML, char*[]);
+static void us_tecedinfolambda(NODEINST*, INTSML, char*[]);
+static void us_tecedinfodescript(NODEINST*, INTSML, char*[]);
+static void us_tecedsetnode(NODEINST*, char*);
+static NODEPROTO *us_tecedenterfacet(char*);
+static void us_tecedredolayergraphics(NODEPROTO*);
+static void us_tecedloadlibmap(LIBRARY*);
+static INTSML us_teceditparsefun(char*);
 
 /*
  * the entry routine for all technology editing
@@ -625,11 +624,11 @@ void us_tecedgetlayernamelist(void)
 	}
 
 	/* build and fill array of layers for DRC parsing */
-	us_teceddrclayernames = (char **)emalloc(us_teceddrclayers * (sizeof (char *)), us_aid->cluster);
+	us_teceddrclayernames = (char **)emalloc(us_teceddrclayers * (sizeof (char *)), us_tool->cluster);
 	if (us_teceddrclayernames == 0) return;
 	for(i = 0, np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (namesamen(np->cell->cellname, "layer-", 6) == 0)
-			(void)allocstring(&us_teceddrclayernames[i++], &np->cell->cellname[6], us_aid->cluster);
+			(void)allocstring(&us_teceddrclayernames[i++], &np->cell->cellname[6], us_tool->cluster);
 }
 
 /*
@@ -639,7 +638,7 @@ INTSML us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules)
 {
 	REGISTER INTBIG i, l;
 	INTBIG amt;
-	INTSML connected, wide, multi, widrule, layer1, layer2, j;
+	INTSML connected, wide, multi, widrule, edge, layer1, layer2, j;
 	REGISTER char *str;
 	char *rule;
 
@@ -653,7 +652,7 @@ INTSML us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules)
 			str = ((char **)var->addr)[i];
 			while (*str == ' ') str++;
 			if (*str == 0) continue;
-			if (us_tecedgetdrc(str, &connected, &wide, &multi, &widrule,
+			if (us_tecedgetdrc(str, &connected, &wide, &multi, &widrule, &edge,
 				&amt, &layer1, &layer2, &rule, (INTSML)rules->numlayers, rules->layernames) != 0)
 			{
 				ttyputmsg(_("DRC line %d is: %s"), i+1, str);
@@ -674,7 +673,12 @@ INTSML us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules)
 				if (layer1 > layer2) { j = layer1;  layer1 = layer2;  layer2 = j; }
 				j = (layer1+1) * (layer1/2) + (layer1&1) * ((layer1+1)/2);
 				j = layer2 + rules->numlayers * layer1 - j;
-				if (wide != 0)
+				if (edge != 0)
+				{
+					rules->edgelist[j] = amt;
+					if (*rule != 0)
+						(void)reallocstring(&rules->edgelistR[j], rule, el_tempcluster);
+				} else if (wide != 0)
 				{
 					if (connected != 0)
 					{
@@ -739,6 +743,7 @@ void us_tecedloaddrcmessage(DRCRULES *rules, LIBRARY *lib)
 		if (rules->unconlistW[i] >= 0) drccount++;
 		if (rules->conlistM[i] >= 0) drccount++;
 		if (rules->unconlistM[i] >= 0) drccount++;
+		if (rules->edgelist[i] >= 0) drccount++;
 	}
 	for(i=0; i<rules->numlayers; i++)
 	{
@@ -822,6 +827,14 @@ void us_tecedloaddrcmessage(DRCRULES *rules, LIBRARY *lib)
 						rules->unconlistMR[k]);
 				(void)allocstring(&drclist[drcindex++], returninfstr(), el_tempcluster);
 			}
+			if (rules->edgelist[k] >= 0)
+			{
+				(void)initinfstr();
+				(void)formatinfstr("e%s %s %s %s", frtoa(rules->edgelist[k]),
+					us_tecedstripdash(rules->layernames[i]), us_tecedstripdash(rules->layernames[j]),
+						rules->edgelistR[k]);
+				(void)allocstring(&drclist[drcindex++], returninfstr(), el_tempcluster);
+			}
 			k++;
 		}
 
@@ -920,9 +933,9 @@ void us_teceditcolormap(void)
 	for(i=0; i<5; i++) efree(layerabbrev[i]);
 
 	/* save the map on the library */
-	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 	if (varred != NOVARIABLE && vargreen != NOVARIABLE && varblue != NOVARIABLE)
 	{
 		newmap = emalloc(256*3*SIZEOFINTBIG, el_tempcluster);
@@ -984,7 +997,7 @@ void us_teceditcreat(INTSML count, char *par[])
 		namesamen(facet->cell->cellname, "arc-", 4) != 0)
 	{
 		us_abortcommand(_("Must be editing a node or arc to place geometry"));
-		if ((us_aid->aidstate&NODETAILS) == 0)
+		if ((us_tool->toolstate&NODETAILS) == 0)
 			ttyputmsg(_("Use 'edit-node' or 'edit-arc' options"));
 		return;
 	}
@@ -992,7 +1005,7 @@ void us_teceditcreat(INTSML count, char *par[])
 		namesamen(facet->cell->cellname, "node-", 5) != 0)
 	{
 		us_abortcommand(_("Can only place ports in node descriptions"));
-		if ((us_aid->aidstate&NODETAILS) == 0)
+		if ((us_tool->toolstate&NODETAILS) == 0)
 			ttyputmsg(_("Use the 'edit-node' options"));
 		return;
 	}
@@ -1005,7 +1018,7 @@ void us_teceditcreat(INTSML count, char *par[])
 	us_create(1, dummy);
 	us_curnodeproto = savenp;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE) return;
 	(void)us_makehighlight(((char **)var->addr)[0], &high);
 	if (high.fromgeom == NOGEOM) return;
@@ -1027,8 +1040,8 @@ void us_teceditcreat(INTSML count, char *par[])
 			}
 		} else name = par[1];
 		var = setval((INTBIG)ni, VNODEINST, "EDTEC_portname", (INTBIG)name, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextdescript(ni->geom);
-		if ((us_aid->aidstate&NODETAILS) == 0)
+		if (var != NOVARIABLE) defaulttextdescript(var->textdescript, ni->geom);
+		if ((us_tool->toolstate&NODETAILS) == 0)
 			ttyputmsg(_("Use 'change' option to set arc connectivity and port angle"));
 	}
 	if (namesamen(pp, "highlight", l) == 0 && l >= 1)
@@ -1040,7 +1053,7 @@ void us_teceditcreat(INTSML count, char *par[])
 	}
 	if (namesamen(pp, "circle-half", l) == 0 && l >= 8)
 		setarcdegrees(ni, 0.0, 180.0*EPI/180.0);
-	if ((us_aid->aidstate&NODETAILS) == 0)
+	if ((us_tool->toolstate&NODETAILS) == 0)
 	{
 		if (namesamen(pp, "rectangle-", 10) == 0)
 			ttyputmsg(_("Use 'change' option to set a layer for this shape"));
@@ -1063,7 +1076,7 @@ void us_teceditcreat(INTSML count, char *par[])
 	if (namesamen(pp, "circle-arc", l) == 0 && l >= 8)
 	{
 		setarcdegrees(ni, 0.0, 45.0*EPI/180.0);
-		if ((us_aid->aidstate&NODETAILS) == 0)
+		if ((us_tool->toolstate&NODETAILS) == 0)
 			ttyputmsg(_("Use 'setarc' command to set portion of circle"));
 	}
 }
@@ -1091,7 +1104,7 @@ void us_teceditidentify(INTSML doports)
 		if (namesamen(np->cell->cellname, "node-", 5) != 0)
 		{
 			us_abortcommand(_("Must be editing a node to identify ports"));
-			if ((us_aid->aidstate&NODETAILS) == 0)
+			if ((us_tool->toolstate&NODETAILS) == 0)
 				ttyputmsg(M_("Use the 'edit-node' option"));
 			return;
 		}
@@ -1101,7 +1114,7 @@ void us_teceditidentify(INTSML doports)
 			namesamen(np->cell->cellname, "arc-", 4) != 0)
 		{
 			us_abortcommand(_("Must be editing a node or arc to identify layers"));
-			if ((us_aid->aidstate&NODETAILS) == 0)
+			if ((us_tool->toolstate&NODETAILS) == 0)
 				ttyputmsg(M_("Use 'edit-node' or 'edit-arc' options"));
 			return;
 		}
@@ -1218,7 +1231,7 @@ void us_teceditidentify(INTSML doports)
 	}
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(2, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(2, us_tool->cluster);
 
 	/* draw the highlighting */
 	us_clearhighlightcount();
@@ -1242,7 +1255,8 @@ void us_teceditidentify(INTSML doports)
 		} else poly->string = &ns->layer->cell->cellname[6];
 		poly->desc = &us_hbox;
 		poly->style = (INTSML)style[i];
-		poly->font = TXT1L;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(4));
 		poly->tech = el_curtech;
 		us_hbox.col = HIGHLIT;
 
@@ -1832,7 +1846,7 @@ void us_tecedlayertype(NODEINST *ni, INTSML count, char *par[])
 		if (namesamen(np->cell->cellname, "node-", 5) != 0)
 		{
 			us_abortcommand(_("Can only set minimum size in node descriptions"));
-			if ((us_aid->aidstate&NODETAILS) == 0) ttyputmsg(_("Use 'edit-node' option"));
+			if ((us_tool->toolstate&NODETAILS) == 0) ttyputmsg(_("Use 'edit-node' option"));
 			return;
 		}
 		startobjectchange((INTBIG)ni, VNODEINST);
@@ -2121,29 +2135,16 @@ void us_tecedinfodescript(NODEINST *ni, INTSML count, char *par[])
 	us_tecedsetnode(ni, returninfstr());
 }
 
-void us_tecedinfounits(NODEINST *ni, INTSML count, char *par[])
-{
-	if (par[0][0] == 0)
-	{
-		us_abortcommand(_("Requires units for this technology"));
-		return;
-	}
-	(void)initinfstr();
-	(void)addstringtoinfstr("Units: ");
-	(void)addstringtoinfstr(par[0]);
-	us_tecedsetnode(ni, returninfstr());
-}
-
 /****************************** UTILITIES ******************************/
 
 void us_tecedsetnode(NODEINST *ni, char *chr)
 {
-	REGISTER INTBIG descript;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER VARIABLE *var;
 
 	startobjectchange((INTBIG)ni, VNODEINST);
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, art_messagekey);
-	if (var == NOVARIABLE) descript = 0; else descript = var->textdescript;
+	if (var == NOVARIABLE) TDCLEAR(descript); else TDCOPY(descript, var->textdescript);
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)chr, VSTRING|VDISPLAY);
 	if (var != NOVARIABLE) modifydescript((INTBIG)ni, VNODEINST, var, descript);
 	endobjectchange((INTBIG)ni, VNODEINST);
@@ -2163,7 +2164,7 @@ NODEPROTO *us_tecedenterfacet(char *facetname)
 	{
 		newpar[0] = "editfacet";
 		newpar[1] = facetname;
-		(void)tellaid(us_aid, 2, newpar);
+		(void)telltool(us_tool, 2, newpar);
 		return(NONODEPROTO);
 	}
 
@@ -2174,7 +2175,7 @@ NODEPROTO *us_tecedenterfacet(char *facetname)
 	/* now edit the facet */
 	newpar[0] = "editfacet";
 	newpar[1] = facetname;
-	(void)tellaid(us_aid, 2, newpar);
+	(void)telltool(us_tool, 2, newpar);
 	return(np);
 }
 
@@ -2274,22 +2275,22 @@ void us_tecedloadlibmap(LIBRARY *lib)
 		}
 
 		/* disable option tracking */
-		(void)setvalkey((INTBIG)us_aid, VAID, us_ignoreoptionchanges, 1,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_ignoreoptionchanges, 1,
 			VINTEGER|VDONTSAVE);
 
-		startobjectchange((INTBIG)us_aid, VAID);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_red, (INTBIG)redmap,
+		startobjectchange((INTBIG)us_tool, VTOOL);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_red, (INTBIG)redmap,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_green, (INTBIG)greenmap,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_green, (INTBIG)greenmap,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_blue, (INTBIG)bluemap,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_colormap_blue, (INTBIG)bluemap,
 			VINTEGER|VISARRAY|(256<<VLENGTHSH));
-		endobjectchange((INTBIG)us_aid, VAID);
+		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* re-enable option tracking */
-		var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_ignoreoptionchanges);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_ignoreoptionchanges);
 		if (var != NOVARIABLE)
-			delvalkey((INTBIG)us_aid, VAID, us_ignoreoptionchanges);
+			delvalkey((INTBIG)us_tool, VTOOL, us_ignoreoptionchanges);
 	}
 }
 
@@ -2369,13 +2370,13 @@ INTSML us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG
 			l = strlen(TECEDNODETEXTCIF);
 			if (namesamen(str, TECEDNODETEXTCIF, l) == 0)
 			{
-				if (allocstring(cif, &str[l], us_aid->cluster) != 0) return(1);
+				if (allocstring(cif, &str[l], us_tool->cluster) != 0) return(1);
 				continue;
 			}
 			l = strlen(TECEDNODETEXTDXF);
 			if (namesamen(str, TECEDNODETEXTDXF, l) == 0)
 			{
-				if (allocstring(dxf, &str[l], us_aid->cluster) != 0) return(1);
+				if (allocstring(dxf, &str[l], us_tool->cluster) != 0) return(1);
 				continue;
 			}
 			l = strlen(TECEDNODETEXTGDS);
@@ -2399,7 +2400,7 @@ INTSML us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG
 			l = strlen(TECEDNODETEXTLETTERS);
 			if (namesamen(str, TECEDNODETEXTLETTERS, l) == 0)
 			{
-				if (allocstring(layerletters, &str[l], us_aid->cluster) != 0) return(1);
+				if (allocstring(layerletters, &str[l], us_tool->cluster) != 0) return(1);
 				continue;
 			}
 			l = strlen(TECEDNODETEXTSPICERES);
@@ -2593,7 +2594,7 @@ void us_tecedpointout(NODEINST *ni, NODEPROTO *np)
 	if (ni != NONODEINST)
 	{
 		us_clearhighlightcount();
-		(void)askaid(us_aid, "show-object", (INTBIG)ni->geom);
+		(void)asktool(us_tool, "show-object", (INTBIG)ni->geom);
 	}
 }
 
