@@ -39,8 +39,8 @@
 #include "usredtec.h"
 
 /* prototypes for local routines */
-NODEINST *us_tecedplacegeom(POLYGON*, NODEPROTO*);
-void us_tecedsetlist(NODEINST*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
+static NODEINST *us_tecedplacegeom(POLYGON*, NODEPROTO*);
+static void us_tecedsetlist(NODEINST*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
 
 /*
  * convert technology "tech" into a library and return that library.
@@ -51,11 +51,12 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	REGISTER LIBRARY *lib;
 	REGISTER char *lay, *dxf, **sequence, **varnames, *fname;
 	REGISTER INTBIG i, j, k, total, e, xs, ys, oldlam, *newmap, *mapptr,
-		tcon, func, serp, gds, nodexpos, portdescript, bits,
+		tcon, func, serp, gds, nodexpos, bits,
 		height3d, thick3d, lambda, min2x, min2y;
 	REGISTER INTSML first;
 	INTBIG lx, hx, ly, hy, xpos[4], ypos[4], xsc[4], ysc[4], lxo, hxo, lyo, hyo,
 		lxp, hxp, lyp, hyp;
+	UINTBIG portdescript[TEXTDESCRIPTSIZE];
 	REGISTER NODEPROTO *np, **nplist, *pnp, **aplist;
 	float spires, spicap, spiecap;
 	REGISTER VARIABLE *var, *var2, *var3, *var5, *var6, *var7, *var8,
@@ -73,16 +74,16 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	REGISTER TECH_COLORMAP *colmap;
 
 	/* make sure network tool is on */
-	if ((net_aid->aidstate&AIDON) == 0)
+	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		aidturnon(net_aid, 0);
+		toolturnon(net_tool, 0);
 		ttyputerr(_("...now reissue the technology editing command"));
 		return(NOLIBRARY);
 	}
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	lib = newlibrary(tech->techname, tech->techname);
 	if (lib == NOLIBRARY)
@@ -204,9 +205,9 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	/* create the color map information */
 	ttyputmsg(_("Adding color map and design rules..."));
 	var2 = getval((INTBIG)tech, VTECHNOLOGY, VCHAR|VISARRAY, "USER_color_map");
-	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 	if (varred != NOVARIABLE && vargreen != NOVARIABLE && varblue != NOVARIABLE &&
 		var2 != NOVARIABLE)
 	{
@@ -285,6 +286,13 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	if (var != NOVARIABLE)
 		for(i=0; i<rules->utsize; i++)
 			(void)reallocstring(&rules->unconlistMR[i], ((char **)var->addr)[i], el_tempcluster);
+	var = getvalkey((INTBIG)tech, VTECHNOLOGY, VFRACT|VISARRAY, dr_edge_distanceskey);
+	if (var != NOVARIABLE)
+		for(i=0; i<rules->utsize; i++) rules->edgelist[i] = ((INTBIG *)var->addr)[i];
+	var = getvalkey((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, dr_edge_distances_rulekey);
+	if (var != NOVARIABLE)
+		for(i=0; i<rules->utsize; i++)
+			(void)reallocstring(&rules->edgelistR[i], ((char **)var->addr)[i], el_tempcluster);
 	var = getvalkey((INTBIG)tech, VTECHNOLOGY, VFRACT, dr_wide_limitkey);
 	if (var != NOVARIABLE) rules->widelimit = var->addr;
 
@@ -373,7 +381,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 
 	/* create the node nodes */
 	ttyputmsg(_("Creating the nodes..."));
-	portdescript = defaulttextdescript(NOGEOM);
+	TDCLEAR(portdescript);
+	defaulttextdescript(portdescript, NOGEOM);
 	total = 0;
 	for(pnp = tech->firstnodeproto; pnp != NONODEPROTO; pnp = pnp->nextnodeproto)
 	{
@@ -489,7 +498,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				if (ll == 0) continue;
 				if (ll[i].representation != MINBOX) continue;
 				var = setval((INTBIG)ni, VNODEINST, "EDTEC_minbox", (INTBIG)"MIN", VSTRING|VDISPLAY);
-				if (var != NOVARIABLE) var->textdescript = defaulttextsize(3) << VTSIZESH;
+				if (var != NOVARIABLE)
+					defaulttextsize(3, var->textdescript);
 			}
 			if (first != 0) continue;
 
@@ -538,7 +548,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERPATCH, VINTEGER);
 				var = setval((INTBIG)ni, VNODEINST, "EDTEC_portname", (INTBIG)pp->protoname,
 					VSTRING|VDISPLAY);
-				if (var != NOVARIABLE) var->textdescript = portdescript;
+				if (var != NOVARIABLE)
+					TDCOPY(var->textdescript, portdescript);
 
 				/* on the first sample, also show angle and connection */
 				if (e != 0) continue;
@@ -682,7 +693,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(colorname);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERCOLOR, VINTEGER);
 	}
 
@@ -710,7 +722,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (ni == NONODEINST) return;
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)"Stipple Pattern",
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 	}
 
 	/* create the color style object */
@@ -727,7 +740,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		}
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSTYLE, VINTEGER);
 	}
 
@@ -741,7 +755,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(ciflayer);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERCIF, VINTEGER);
 	}
 
@@ -755,7 +770,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(dxf);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERDXF, VINTEGER);
 	}
 
@@ -770,7 +786,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERGDS, VINTEGER);
 	}
 
@@ -784,7 +801,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		us_tecedaddfunstring(functionindex);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERFUNCTION, VINTEGER);
 	}
 
@@ -798,7 +816,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(layerletters);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERLETTERS, VINTEGER);
 	}
 
@@ -813,7 +832,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPIRES, VINTEGER);
 	}
 
@@ -828,7 +848,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPICAP, VINTEGER);
 	}
 
@@ -843,7 +864,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPIECAP, VINTEGER);
 	}
 
@@ -858,7 +880,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYER3DHEIGHT, VINTEGER);
 	}
 
@@ -873,7 +896,8 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		(void)addstringtoinfstr(line);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYER3DTHICK, VINTEGER);
 	}
 }
@@ -919,7 +943,8 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	(void)addstringtoinfstr(TECEDNODETEXTFUNCTION);
 	(void)addstringtoinfstr(us_tecarc_functions[func].name);
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(), VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+	if (var != NOVARIABLE)
+		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCFUNCTION, VINTEGER);
 
 	/* create the Fixed-angle object */
@@ -927,7 +952,8 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	if (ni == NONODEINST) return;
 	if (fixang != 0) str = "Fixed-angle: Yes"; else str = "Fixed-angle: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+	if (var != NOVARIABLE)
+		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCFIXANG, VINTEGER);
 
 	/* create the Wipe object */
@@ -935,7 +961,8 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	if (ni == NONODEINST) return;
 	if (wipes != 0) str = "Wipes pins: Yes"; else str = "Wipes pins: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+	if (var != NOVARIABLE)
+		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCWIPESPINS, VINTEGER);
 
 	/* create the Noextend object */
@@ -943,7 +970,8 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	if (ni == NONODEINST) return;
 	if (noextend == 0) str = "Extend arcs: Yes"; else str = "Extend arcs: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+	if (var != NOVARIABLE)
+		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCNOEXTEND, VINTEGER);
 
 	/* create the Angle Increment object */
@@ -951,7 +979,8 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	if (ni == NONODEINST) return;
 	(void)sprintf(line, "Angle increment: %ld", anginc);
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)line, VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+	if (var != NOVARIABLE)
+		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCINC, VINTEGER);
 }
 
@@ -994,7 +1023,8 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 		(void)addstringtoinfstr(us_tecnode_functions[func].name);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODEFUNCTION, VINTEGER);
 	}
 
@@ -1006,7 +1036,8 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 		if (serp != 0) str = "Serpentine transistor: yes"; else
 			str = "Serpentine transistor: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODESERPENTINE, VINTEGER);
 	}
 
@@ -1018,7 +1049,8 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 		if (square != 0) str = "Square node: yes"; else
 			str = "Square node: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODESQUARE, VINTEGER);
 	}
 
@@ -1030,7 +1062,8 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 		if (wipes != 0) str = "Invisible with 1 or 2 arcs: yes"; else
 			str = "Invisible with 1 or 2 arcs: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODEWIPES, VINTEGER);
 	}
 
@@ -1041,7 +1074,8 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 		if (ni == NONODEINST) return;
 		if (lockable != 0) str = "Lockable: yes"; else str = "Lockable: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODELOCKABLE, VINTEGER);
 	}
 }
@@ -1075,7 +1109,8 @@ void us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description)
 		if (ni == NONODEINST) return;
 		(void)sprintf(line, "Lambda: %ld", lambda);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)line, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", TECHLAMBDA, VINTEGER);
 	}
 
@@ -1089,7 +1124,8 @@ void us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description)
 		(void)addstringtoinfstr(description);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", TECHDESCRIPT, VINTEGER);
 	}
 }
@@ -1133,6 +1169,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 				endobjectchange((INTBIG)nni, VNODEINST);
 				return(nni);
 			}
+			/* FALLTHROUGH */ 
 		case FILLEDRECT:
 			nni = newnodeinst(art_filledboxprim, lx, hx, ly, hy, 0, 0, np);
 			if (nni == NONODEINST) return(NONODEINST);
@@ -1147,6 +1184,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 				endobjectchange((INTBIG)nni, VNODEINST);
 				return(nni);
 			}
+			/* FALLTHROUGH */ 
 		case CLOSEDRECT:
 			nni = newnodeinst(art_boxprim, lx, hx, ly, hy, 0, 0, np);
 			if (nni == NONODEINST) return(NONODEINST);
@@ -1202,7 +1240,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			if (nni == NONODEINST) return(NONODEINST);
 			var = setvalkey((INTBIG)nni, VNODEINST, art_messagekey,
 				(INTBIG)poly->string, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = VTPOSCENT;
+			if (var != NOVARIABLE) TDSETPOS(var->textdescript, VTPOSCENT);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
 		case TEXTBOTLEFT:
@@ -1210,7 +1248,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			if (nni == NONODEINST) return(NONODEINST);
 			var = setvalkey((INTBIG)nni, VNODEINST, art_messagekey,
 				(INTBIG)poly->string, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = VTPOSUPRIGHT;
+			if (var != NOVARIABLE) TDSETPOS(var->textdescript, VTPOSUPRIGHT);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
 		case TEXTBOTRIGHT:
@@ -1218,7 +1256,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			if (nni == NONODEINST) return(NONODEINST);
 			var = setvalkey((INTBIG)nni, VNODEINST, art_messagekey,
 				(INTBIG)poly->string, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = VTPOSUPLEFT;
+			if (var != NOVARIABLE) TDSETPOS(var->textdescript, VTPOSUPLEFT);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
 		case TEXTBOX:
@@ -1226,7 +1264,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			if (nni == NONODEINST) return(NONODEINST);
 			var = setvalkey((INTBIG)nni, VNODEINST, art_messagekey,
 				(INTBIG)poly->string, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE) var->textdescript = VTPOSBOXED;
+			if (var != NOVARIABLE) TDSETPOS(var->textdescript, VTPOSBOXED);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
 	}
