@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrgraph.c
- * User interface aid: structure graphing module
+ * User interface tool: structure graphing module
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -43,7 +43,7 @@ typedef struct
 	NODEINST *pin;
 } NODEDESCR;
 
-NODEPROTO *us_graphmainview(NODEPROTO *np);
+static NODEPROTO *us_graphmainview(NODEPROTO *np);
 
 void us_graphfacets(void)
 {
@@ -91,6 +91,9 @@ void us_graphfacets(void)
 			{
 				sub = ni->proto;
 				if (sub->primindex != 0) continue;
+
+				/* ignore recursive references (showing icon in contents) */
+				if (sub->cell == np->cell) continue;
 				if (sub->temp1 <= np->temp1)
 				{
 					sub->temp1 = np->temp1 + 1;
@@ -144,7 +147,7 @@ void us_graphfacets(void)
 			continue;
 		}
 
-		nd = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_aid->cluster);
+		nd = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_tool->cluster);
 		nd->pin = NONODEINST;
 
 		nd->x = xval[np->temp1];
@@ -197,7 +200,7 @@ void us_graphfacets(void)
 		if (truenp->temp1 == -1) continue;
 
 		nd = (NODEDESCR *)truenp->temp1;
-		ndsub = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_aid->cluster);
+		ndsub = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_tool->cluster);
 		ndsub->pin = NONODEINST;
 		nd->yoff += yoffset*2;
 		ndsub->x = nd->x;   ndsub->y = nd->y + nd->yoff;
@@ -214,7 +217,7 @@ void us_graphfacets(void)
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 		VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
-		var->textdescript = TXT6L << VTSIZESH;
+		TDSETSIZE(var->textdescript, TXTSETQLAMBDA(24));
 
 	/* place the components */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -237,7 +240,7 @@ void us_graphfacets(void)
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)describenodeproto(truenp),
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
-			var->textdescript = TXT1L << VTSIZESH;
+			TDSETSIZE(var->textdescript, TXTSETQLAMBDA(4));
 	}
 
 	/* build wires between the hierarchical levels */
@@ -263,6 +266,9 @@ void us_graphfacets(void)
 			sub = ni->proto;
 			if (sub->primindex != 0) continue;
 
+			/* ignore recursive references (showing icon in contents) */
+			if (sub->cell == truenp->cell) continue;
+
 			truesubnp = contentsview(sub);
 			if (truesubnp == NONODEPROTO) truesubnp = sub;
 
@@ -366,15 +372,15 @@ typedef struct Icomill
 	NODEINST *real;
 } COMILL;
 
-COMILL *us_comilllist[MAXILLUSTRATEWIDTH];
-COMILL *us_allcomill;
+static COMILL *us_comilllist[MAXILLUSTRATEWIDTH];
+static COMILL *us_allcomill;
 
-INTSML us_maxillustratedepth, us_maxcommandentries;
-INTBIG us_illustrateXpos[MAXILLUSTRATEDEPTH];		/* current build-out X position */
-COMCOMP *us_illustrateparam[MAXILLUSTRATEDEPTH];	/* current parameter type */
+static INTSML us_maxillustratedepth, us_maxcommandentries;
+static INTBIG us_illustrateXpos[MAXILLUSTRATEDEPTH];		/* current build-out X position */
+static COMCOMP *us_illustrateparam[MAXILLUSTRATEDEPTH];	/* current parameter type */
 
 /* prototypes for local routines */
-COMILL *us_illustratecommand(char*, INTSML, COMILL*);
+static COMILL *us_illustratecommand(char*, INTSML, COMILL*);
 
 void us_illustratecommandset(void)
 {
@@ -424,7 +430,8 @@ void us_illustratecommandset(void)
 	endobjectchange((INTBIG)ni, VNODEINST);
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)_("Structure of commands"),
 		VSTRING|VDISPLAY);
-	if (var != NOVARIABLE) var->textdescript = TXT20P << VTSIZESH;
+	if (var != NOVARIABLE)
+		TDSETSIZE(var->textdescript, TXTSETPOINTS(20));
 
 	/* make the name spacing uniform */
 	for(ci = us_allcomill; ci != NOCOMILL; ci = ci->nextcomill)
@@ -455,7 +462,8 @@ void us_illustratecommandset(void)
 
 		/* set the node name, color, font */
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)ci->name, VSTRING|VDISPLAY);
-		if (var != NOVARIABLE) var->textdescript = defaulttextsize(2) << VTSIZESH;
+		if (var != NOVARIABLE)
+			defaulttextsize(2, var->textdescript);
 		(void)setvalkey((INTBIG)ni, VNODEINST, art_colorkey, RED, VINTEGER);
 	}
 
@@ -526,7 +534,7 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 		if (cc->toplist == topoflibfile) arg = "LIBRARY"; else
 		if (cc->toplist == topoftechs) arg = "TECH"; else
 		if (cc->toplist == topoflibs) arg = "LIB"; else
-		if (cc->toplist == topofaids) arg = "AID"; else
+		if (cc->toplist == topoftools) arg = "TOOL"; else
 		if (cc->toplist == topofcells) arg = "CELL"; else
 		if (cc->toplist == topofviews) arg = "VIEW"; else
 		if (cc->toplist == topofnets) arg = "NET"; else
@@ -584,7 +592,7 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 /****************************** PULLDOWN MENU DUMPING ******************************/
 
 /* prototypes for local routines */
-void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix);
+static void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix);
 
 /*
  * Routine to dump the pulldown menus to an indented text file.
