@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrhigh.c
- * User interface aid: object highlighting
+ * User interface tool: object highlighting
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -49,8 +49,8 @@ static INTBIG  *us_getallhighlist;
 static INTSML   us_getallhighlistsize = 0;
 
 /* prototypes for local routines */
-void us_makecurrentobject(void);
-void us_highlightverbose(GEOM*, PORTPROTO*, INTSML, NODEPROTO*, POLYGON*);
+static void us_makecurrentobject(void);
+static void us_highlightverbose(GEOM*, PORTPROTO*, INTSML, NODEPROTO*, POLYGON*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -78,10 +78,10 @@ void us_highlightmenu(INTBIG x, INTBIG y, INTSML color)
 	WINDOWPART ww;
 	static POLYGON *poly = NOPOLYGON;
 
-	if ((us_aid->aidstate&MENUON) == 0) return;
+	if ((us_tool->toolstate&MENUON) == 0) return;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_tool->cluster);
 
 	/* set drawing bounds to include menu */
 	if (us_menuframe == NOWINDOWFRAME)
@@ -139,20 +139,20 @@ INTSML us_addhighlight(HIGHLIGHT *thishigh)
 	HIGHLIGHT oldhigh;
 
 	/* see if anything is currently highlighted */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
 		/* nothing highlighted: add this one line */
 		onelist[0] = us_makehighlightstring(thishigh);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)onelist,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)onelist,
 			VSTRING|VISARRAY|(1<<VLENGTHSH)|VDONTSAVE);
 
-#if SIMAID
+#if SIMTOOL
 		/* if current window is simulating, show equivalent elsewhere */
 		if (el_curwindowpart != NOWINDOWPART && (el_curwindowpart->state&WINDOWSIMULATING) != 0)
 		{
 			onelist[0] = "show-equivalent";
-			tellaid(net_aid, 1, onelist);
+			telltool(net_tool, 1, onelist);
 		}
 #endif
 
@@ -214,7 +214,7 @@ INTSML us_addhighlight(HIGHLIGHT *thishigh)
 	(void)allocstring(&list[len], str, el_tempcluster);
 
 	/* save the new list */
-	(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)list,
 		VSTRING|VISARRAY|((len+1)<<VLENGTHSH)|VDONTSAVE);
 
 	/* clean up */
@@ -238,7 +238,7 @@ INTSML us_delhighlight(HIGHLIGHT *thishigh)
 	HIGHLIGHT oldhigh;
 
 	/* see if anything is currently highlighted */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE) return(1);
 
 	/* see if it is highlighted */
@@ -265,7 +265,7 @@ INTSML us_delhighlight(HIGHLIGHT *thishigh)
 	/* removing highlight: build a new list */
 	if (len <= 1)
 	{
-		(void)delvalkey((INTBIG)us_aid, VAID, us_highlighted);
+		(void)delvalkey((INTBIG)us_tool, VTOOL, us_highlighted);
 		if ((us_state&NONPERSISTENTCURNODE) != 0) us_setnodeproto(NONODEPROTO);
 		return(0);
 	}
@@ -279,7 +279,7 @@ INTSML us_delhighlight(HIGHLIGHT *thishigh)
 	}
 
 	/* save the new list */
-	(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)list,
 		VSTRING|VISARRAY|((len-1)<<VLENGTHSH)|VDONTSAVE);
 	us_makecurrentobject();
 
@@ -291,8 +291,8 @@ INTSML us_delhighlight(HIGHLIGHT *thishigh)
 
 void us_clearhighlightcount(void)
 {
-	if (getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted) != NOVARIABLE)
-		(void)delvalkey((INTBIG)us_aid, VAID, us_highlighted);
+	if (getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted) != NOVARIABLE)
+		(void)delvalkey((INTBIG)us_tool, VTOOL, us_highlighted);
 	if ((us_state&NONPERSISTENTCURNODE) != 0) us_setnodeproto(NONODEPROTO);
 }
 
@@ -359,7 +359,7 @@ UINTBIG us_getobject(INTSML type, INTSML canbetext)
 	REGISTER VARIABLE *var;
 	REGISTER INTSML len;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
 		us_abortcommand(_("Nothing is highlighted"));
@@ -402,7 +402,7 @@ HIGHLIGHT *us_getonehighlight(void)
 	REGISTER VARIABLE *var;
 	REGISTER INTSML len;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
 		us_abortcommand(_("Nothing is highlighted"));
@@ -434,7 +434,7 @@ INTSML us_gettwoobjects(GEOM **firstgeom, PORTPROTO **firstport, GEOM **secondge
 	REGISTER VARIABLE *var;
 	HIGHLIGHT newhigh;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE) return(1);
 	if (getlength(var) != 2) return(1);
 
@@ -476,7 +476,7 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 	XARRAY trans;
 
 	if (textcount != 0) *textcount = 0;
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
 		nulllist[0] = NOGEOM;
@@ -513,7 +513,7 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 	{
 		if (us_gethighlistsize != 0) efree((char *)us_gethighlist);
 		us_gethighlist = (GEOM **)emalloc(((total+1) * (sizeof (GEOM *))),
-			us_aid->cluster);
+			us_tool->cluster);
 		if (us_gethighlist == 0)
 		{
 			ttyputnomemory();
@@ -556,7 +556,7 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 				{
 					ni = geom->entryaddr.ni;
 					k = nodepolys(ni, 0, NOWINDOWPART);
-					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 					makerot(ni, trans);
 					for(j=0; j<k; j++)
 					{
@@ -574,7 +574,7 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 				{
 					ai = geom->entryaddr.ai;
 					k = arcpolys(ai, NOWINDOWPART);
-					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 					for(j=0; j<k; j++)
 					{
 						shapearcpoly(ai, j, poly);
@@ -605,7 +605,7 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 					{
 						newcount = numtext + 5;
 						newtext = (char **)emalloc(newcount * (sizeof (char *)),
-							us_aid->cluster);
+							us_tool->cluster);
 						if (newtext == 0)
 						{
 							nulllist[0] = NOGEOM;
@@ -621,11 +621,11 @@ GEOM **us_gethighlighted(INTSML type, INTBIG *textcount, char ***textinfo)
 					if (us_selectedtextlist[numtext] == 0)
 					{
 						allocstring(&us_selectedtextlist[numtext],
-							((char **)var->addr)[i], us_aid->cluster);
+							((char **)var->addr)[i], us_tool->cluster);
 					} else
 					{
 						reallocstring(&us_selectedtextlist[numtext],
-							((char **)var->addr)[i], us_aid->cluster);
+							((char **)var->addr)[i], us_tool->cluster);
 					}
 					numtext++;
 				}
@@ -659,7 +659,7 @@ INTBIG *us_getallhighlighted(void)
 	static POLYGON *poly = NOPOLYGON;
 	XARRAY trans;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
 		nulllist[0] = nulllist[1] = 0;
@@ -692,7 +692,7 @@ INTBIG *us_getallhighlighted(void)
 	if (total*2 >= us_getallhighlistsize)
 	{
 		if (us_getallhighlistsize != 0) efree((char *)us_getallhighlist);
-		us_getallhighlist = (INTBIG *)emalloc((total+1)*2 * SIZEOFINTBIG, us_aid->cluster);
+		us_getallhighlist = (INTBIG *)emalloc((total+1)*2 * SIZEOFINTBIG, us_tool->cluster);
 		if (us_getallhighlist == 0)
 		{
 			ttyputnomemory();
@@ -740,7 +740,7 @@ INTBIG *us_getallhighlighted(void)
 				{
 					ni = geom->entryaddr.ni;
 					k = nodepolys(ni, 0, NOWINDOWPART);
-					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 					makerot(ni, trans);
 					for(j=0; j<k; j++)
 					{
@@ -757,7 +757,7 @@ INTBIG *us_getallhighlighted(void)
 				{
 					ai = geom->entryaddr.ai;
 					k = arcpolys(ai, NOWINDOWPART);
-					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 					for(j=0; j<k; j++)
 					{
 						shapearcpoly(ai, j, poly);
@@ -808,7 +808,7 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 {
 	HIGHLIGHT high;
 	REGISTER NODEINST *ni;
-	REGISTER INTSML len, pointlen, i;
+	REGISTER INTSML len, pointlen, i, good, bad;
 	INTBIG tlx, thx, tly, thy, xc, yc;
 	XARRAY trans;
 	static POLYGON *poly = NOPOLYGON;
@@ -817,21 +817,23 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	REGISTER VARIABLE *var;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE) return(NONODEPROTO);
 
+	thisfacet = getcurfacet();
+	good = bad = 0;
 	(void)us_makehighlight(((char **)var->addr)[0], &high);
-	thisfacet = high.facet;
 	len = (INTSML)getlength(var);
 	for(i=0; i<len; i++)
 	{
 		(void)us_makehighlight(((char **)var->addr)[i], &high);
-		if (high.facet != thisfacet)
+		if (thisfacet == NONODEPROTO) thisfacet = high.facet;
+		if (high.facet == thisfacet) good++; else
 		{
-			us_abortcommand(_("Highlighted areas must be in one facet"));
-			return(NONODEPROTO);
+			bad++;
+			continue;
 		}
 		if ((high.status&HIGHTYPE) == HIGHTEXT)
 		{
@@ -905,6 +907,11 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 			*ly = mini(*ly, tly);   *hy = maxi(*hy, thy);
 		}
 	}
+	if (good == 0 && bad != 0)
+	{
+		us_abortcommand(_("Highlighted areas must be in the current facet"));
+		return(NONODEPROTO);
+	}
 	return(thisfacet);
 }
 
@@ -914,8 +921,9 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
  */
 void us_moveselectedtext(INTBIG numtexts, char **textlist, INTBIG odx, INTBIG ody)
 {
-	REGISTER INTBIG i, lambda, descript;
+	REGISTER INTBIG i, lambda;
 	INTBIG dx, dy, addr, type;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER NODEINST *ni;
 	XARRAY trans;
 	HIGHLIGHT high;
@@ -968,12 +976,10 @@ void us_moveselectedtext(INTBIG numtexts, char **textlist, INTBIG odx, INTBIG od
 		/* set the new descriptor on the text */
 		lambda = el_curlib->lambda[us_hightech(&high)->techindex];
 		dx = dx*4/lambda;   dy = dy*4/lambda;
-		descript = us_gethighdescript(&high);
-		if ((descript&VTXOFFNEG) != 0) dx -= (descript&VTXOFF) >> VTXOFFSH; else
-			dx += (descript&VTXOFF) >> VTXOFFSH;
-		if ((descript&VTYOFFNEG) != 0) dy -= (descript&VTYOFF) >> VTYOFFSH; else
-			dy += (descript&VTYOFF) >> VTYOFFSH;
-		descript = us_setdescriptoffset(descript, dx, dy);
+		us_gethighdescript(&high, descript);
+		dx += TDGETXOFF(descript);
+		dy += TDGETYOFF(descript);
+		us_setdescriptoffset(descript, dx, dy);
 		us_modifytextdescript(&high, descript);
 
 		/* redisplay the text */
@@ -1014,7 +1020,7 @@ INTSML us_getonesnappoint(INTBIG *x, INTBIG *y)
 	HIGHLIGHT thishigh;
 
 	snapcount = 0;
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var != NOVARIABLE)
 	{
 		len = getlength(var);
@@ -1041,8 +1047,9 @@ INTSML us_getonesnappoint(INTBIG *x, INTBIG *y)
 void us_sethighlight(HIGHLIGHT *high, INTSML on)
 {
 	REGISTER INTSML len;
-	REGISTER INTBIG xw, yw, descript;
+	REGISTER INTBIG xw, yw;
 	INTBIG xc, yc, lx, hx, ly, hy, addr, type;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTSML tsx, tsy, style;
 	REGISTER WINDOWPART *w;
 	REGISTER TECHNOLOGY *tech;
@@ -1050,7 +1057,7 @@ void us_sethighlight(HIGHLIGHT *high, INTSML on)
 	REGISTER char *str;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, us_tool->cluster);
 
 	/* handle drawing bounding boxes */
 	if ((high->status&HIGHTYPE) == HIGHBBOX)
@@ -1089,7 +1096,7 @@ void us_sethighlight(HIGHLIGHT *high, INTSML on)
 	/* handle text outlines */
 	if ((high->status&HIGHTYPE) == HIGHTEXT)
 	{
-		descript = us_gethighdescript(high);
+		us_gethighdescript(high, descript);
 		str = us_gethighstring(high);
 
 		/* determine center of text */
@@ -1123,7 +1130,7 @@ void us_sethighlight(HIGHLIGHT *high, INTSML on)
 			{
 				/* determine size from text */
 				tech = us_hightech(high);
-				screensettextsize(w, truefontsize((descript&VTSIZE)>>VTSIZESH, w, tech));
+				screensettextinfo(w, tech, descript);
 				screengettextsize(w, str, &tsx, &tsy);
 				xw = muldiv(tsx, w->screenhx-w->screenlx, w->usehx-w->uselx);
 				yw = muldiv(tsy, w->screenhy-w->screenly, w->usehy-w->usely);
@@ -1276,7 +1283,7 @@ void us_highlighteverywhere(GEOM *look, PORTPROTO *port, INTSML point, INTSML ve
 	INTBIG lx, hx, ly, hy;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* sensibility check to prevent null highlighting */
 	if (look->entrytype == OBJNODEINST)
@@ -1432,7 +1439,7 @@ void us_highlightverbose(GEOM *look, PORTPROTO *pp, INTSML color, NODEPROTO *par
 	REGISTER INTSML i, thisend;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 	poly->desc = &us_hbox;
 	poly->desc->col = color;
 
@@ -1563,7 +1570,8 @@ void us_highlightverbose(GEOM *look, PORTPROTO *pp, INTSML color, NODEPROTO *par
 						poly->style = TEXTBOTLEFT;
 	}
 	poly->count = 1;
-	poly->font = TXT1L;
+	TDCLEAR(poly->textdescript);
+	TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(4));
 	poly->tech = ai->parent->tech;
 	for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 	{
@@ -1585,7 +1593,7 @@ void us_pushhighlight(void)
 
 	/* get what is highlighted */
 	(void)initinfstr();
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 	if (var != NOVARIABLE)
 	{
 		len = getlength(var);
@@ -1597,11 +1605,11 @@ void us_pushhighlight(void)
 	}
 
 	/* now add this to the stack variable */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlightstack);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightstack);
 	if (var == NOVARIABLE)
 	{
 		one[0] = returninfstr();
-		(void)setvalkey((INTBIG)us_aid, VAID, us_highlightstack, (INTBIG)one,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlightstack, (INTBIG)one,
 			VSTRING|VISARRAY|(1<<VLENGTHSH)|VDONTSAVE);
 		return;
 	}
@@ -1612,7 +1620,7 @@ void us_pushhighlight(void)
 	for(i=0; i<len; i++)
 		(void)allocstring(&list[i], ((char **)var->addr)[i], el_tempcluster);
 	list[len] = returninfstr();
-	(void)setvalkey((INTBIG)us_aid, VAID, us_highlightstack, (INTBIG)list,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlightstack, (INTBIG)list,
 		VSTRING|VISARRAY|((len+1)<<VLENGTHSH)|VDONTSAVE);
 	for(i=0; i<len; i++) efree(list[i]);
 	efree((char *)list);
@@ -1630,7 +1638,7 @@ INTSML us_pophighlight(INTSML clearsnap)
 	REGISTER char **list;
 
 	/* get the stack variable */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlightstack);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightstack);
 	if (var == NOVARIABLE) return(1);
 	len = (INTSML)getlength(var);
 	vaddr = (char **)var->addr;
@@ -1639,14 +1647,14 @@ INTSML us_pophighlight(INTSML clearsnap)
 	us_setmultiplehighlight(vaddr[len-1], clearsnap);
 
 	/* shorten the stack */
-	if (len == 1) (void)delvalkey((INTBIG)us_aid, VAID, us_highlightstack); else
+	if (len == 1) (void)delvalkey((INTBIG)us_tool, VTOOL, us_highlightstack); else
 	{
 		len--;
 		list = (char **)emalloc((len * (sizeof (char *))), el_tempcluster);
 		if (list == 0) return(0);
 		for(i=0; i<len; i++)
 			(void)allocstring(&list[i], vaddr[i], el_tempcluster);
-		(void)setvalkey((INTBIG)us_aid, VAID, us_highlightstack, (INTBIG)list,
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlightstack, (INTBIG)list,
 			VSTRING|VISARRAY|(len<<VLENGTHSH)|VDONTSAVE);
 		for(i=0; i<len; i++) efree(list[i]);
 		efree((char *)list);
@@ -1706,7 +1714,7 @@ void us_setmultiplehighlight(char *str, INTSML clearsnap)
 
 	/* set the multiple list */
 	if (total == 0) return;
-	(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlighted, (INTBIG)list,
 		VSTRING|VISARRAY|(total<<VLENGTHSH)|VDONTSAVE);
 
 	for(i=0; i<total; i++) efree(list[i]);
@@ -1719,13 +1727,13 @@ void us_setmultiplehighlight(char *str, INTSML clearsnap)
  */
 void us_makecurrentobject(void)
 {
-	REGISTER NODEPROTO *np, *onp;
+	REGISTER NODEPROTO *np;
 	REGISTER GEOM *from;
 	HIGHLIGHT high;
 	REGISTER VARIABLE *var;
 
 	/* see what is highlighted */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 
 	/* there must be exactly 1 object highlighted */
 	if (var == NOVARIABLE || getlength(var) != 1)
@@ -1759,12 +1767,14 @@ void us_makecurrentobject(void)
 	/* a node is selected */
 	np = from->entryaddr.ni->proto;
 
+#if 0
 	/* for icon facets, see if the contents should be used */
 	if (np->cellview == el_iconview)
 	{
 		onp = contentsview(np);
 		if (onp != NONODEPROTO) np = onp;
 	}
+#endif
 	us_setnodeproto(np);
 }
 
@@ -1962,16 +1972,17 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 	XARRAY trans;
 	INTBIG newxc, newyc;
 	REGISTER INTSML saverot, savetrn;
-	REGISTER INTBIG descript, lambda;
+	REGISTER INTBIG lambda;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(1, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(1, us_tool->cluster);
 
 	poly->count = 1;
 	poly->style = FILLED;
 	if (high->fromvar != NOVARIABLE)
 	{
-		descript = high->fromvar->textdescript;
+		TDCOPY(descript, high->fromvar->textdescript);
 		if (high->fromport != NOPORTPROTO)
 		{
 			ni = high->fromport->subnodeinst;
@@ -2011,22 +2022,20 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 		*style = poly->style;
 	} else if (high->fromport != NOPORTPROTO)
 	{
-		descript = high->fromport->textdescript;
+		TDCOPY(descript, high->fromport->textdescript);
 		ni = high->fromgeom->entryaddr.ni;
 		portposition(high->fromport->subnodeinst, high->fromport->subportproto,
 			&poly->xv[0], &poly->yv[0]);
 		makeangle(ni->rotation, ni->transpose, trans);
 		facet = ni->parent;
 		lambda = facet->cell->lib->lambda[facet->tech->techindex];
-		newxc = (descript&VTXOFF)>>VTXOFFSH;
-		if ((descript&VTXOFFNEG) != 0) newxc = -newxc;
+		newxc = TDGETXOFF(descript);
 		newxc = newxc * lambda / 4;
-		newyc = (descript&VTYOFF)>>VTYOFFSH;
-		if ((descript&VTYOFFNEG) != 0) newyc = -newyc;
+		newyc = TDGETYOFF(descript);
 		newyc = newyc * lambda / 4;
 		xform(newxc, newyc, &newxc, &newyc, trans);
 		poly->xv[0] += newxc;   poly->yv[0] += newyc;
-		switch (descript&VTPOSITION)
+		switch (TDGETPOS(descript))
 		{
 			case VTPOSCENT:      *style = TEXTCENT;      break;
 			case VTPOSBOXED:     *style = TEXTBOX;       break;
@@ -2043,7 +2052,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 	} else if (high->fromgeom->entrytype == OBJNODEINST)
 	{
 		ni = high->fromgeom->entryaddr.ni;
-		descript = ni->textdescript;
+		TDCOPY(descript, ni->textdescript);
 		poly->xv[0] = (ni->lowx + ni->highx) / 2;
 		poly->yv[0] = (ni->lowy + ni->highy) / 2;
 		adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, poly, descript);
@@ -2055,29 +2064,26 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 }
 
 /*
- * Routine to determine whether highlight "high" resides on a node, and return
- * that node if so (NONODEINST if not).
+ * Routine to return the text descriptor on highlight "high" in "descript".
  */
-NODEINST *us_gethighnodeinst(HIGHLIGHT *high)
-{
-	if (high->fromport != NOPORTPROTO) return(high->fromport->subnodeinst);
-	if (high->fromgeom != NOGEOM && high->fromgeom->entrytype == OBJNODEINST)
-		return(high->fromgeom->entryaddr.ni);
-	return(NONODEINST);
-}
-
-/*
- * Routine to return the text descriptor on highlight "high".
- */
-INTBIG us_gethighdescript(HIGHLIGHT *high)
+void us_gethighdescript(HIGHLIGHT *high, UINTBIG *descript)
 {
 	if (high->fromvar != NOVARIABLE)
-		return(high->fromvar->textdescript);
+	{
+		TDCOPY(descript, high->fromvar->textdescript);
+		return;
+	}
 	if (high->fromport != NOPORTPROTO)
-		return(high->fromport->textdescript);
+	{
+		TDCOPY(descript, high->fromport->textdescript);
+		return;
+	}
 	if (high->fromgeom->entrytype == OBJNODEINST)
-		return(high->fromgeom->entryaddr.ni->textdescript);
-	return(0);
+	{
+		TDCOPY(descript, high->fromgeom->entryaddr.ni->textdescript);
+		return;
+	}
+	TDCLEAR(descript);
 }
 
 /*
@@ -2091,7 +2097,7 @@ char *us_gethighstring(HIGHLIGHT *high)
 	var = high->fromvar;
 	if (var != NOVARIABLE)
 	{
-		switch (var->textdescript&VTDISPLAYPART)
+		switch (TDGETDISPPART(var->textdescript))
 		{
 			case VTDISPLAYNAME:
 				str = describedisplayedvariable(var, -1, -1);
@@ -2242,17 +2248,16 @@ TECHNOLOGY *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, I
 void us_drawfacetvariable(VARIABLE *var, NODEPROTO *np)
 {
 	REGISTER INTBIG i, displaytotal;
-	REGISTER VARIABLE *thisvar;
 	REGISTER WINDOWPART *w;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	displaytotal = tech_displayablefacetvars(np, NOWINDOWPART);
 	for(i = 0; i < displaytotal; i++)
 	{
-		thisvar = tech_filldisplayablefacetvar(np, poly, NOWINDOWPART, 0);
+		(void)tech_filldisplayablefacetvar(np, poly, NOWINDOWPART, 0);
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 		{
 			if (w->curnodeproto != np) continue;
@@ -2265,8 +2270,7 @@ void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
 {
 	INTBIG x, y;
 	INTSML tsx, tsy;
-	REGISTER INTSML font;
-	REGISTER INTBIG tf, objwid, objhei, sea, slx, shx, sly, shy, nudge;
+	REGISTER INTBIG objwid, objhei, sea, slx, shx, sly, shy, nudge;
 	INTBIG lx, hx, ly, hy;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NODEINST *ni;
@@ -2278,14 +2282,12 @@ void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
 
 	if ((var->type&VDISPLAY) == 0) return;
 	tech = np->tech;
-	font = (INTSML)((var->textdescript & VTSIZE) >> VTSIZESH);
 	str = describevariable(var, -1, -1);
 	for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 	{
 		if ((w->state&WINDOWTYPE) != DISPWINDOW) continue;
 		if (w->curnodeproto != np) continue;
-		tf = truefontsize(font, w, tech);
-		screensettextsize(w, tf);
+		screensettextinfo(w, tech, var->textdescript);
 
 		getdisparrayvarlinepos((INTBIG)np, VNODEPROTO, tech,
 			w, var, 0, &x, &y, 1);
