@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrmenu.c
- * User interface aid: menu display control
+ * User interface tool: menu display control
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -42,7 +42,7 @@ GRAPHICS us_menufigs = {LAYERA, MENGLY, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* for drawing menu shadows */
-GRAPHICS us_shadowdesc = {LAYERA, MENGLY, PATTERNED, PATTERNED,
+static GRAPHICS us_shadowdesc = {LAYERA, MENGLY, PATTERNED, PATTERNED,
 	{0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA}, NOVARIABLE, 0};
 
 /* for drawing menu text (nothing changes) */
@@ -53,14 +53,12 @@ GRAPHICS us_menutext = {LAYERA, MENTXT, SOLIDC, SOLIDC,
 #define MENUSHADOW      2	/* size of shadow around popup menus */
 
 /* prototypes for local routines */
-INTSML us_groupfunction(NODEPROTO*);
-void us_pmfirst(void);
-void us_pmdone(void);
-INTSML us_pmeachchar(INTBIG, INTBIG, INTSML);
-INTSML us_pmeachdown(INTBIG, INTBIG);
-void us_pminvertline(void);
-INTSML us_makepulldownhash(POPUPMENU*);
-void us_recordmenudescription(POPUPMENU*);
+static INTSML us_groupfunction(NODEPROTO*);
+static void us_pmfirst(void);
+static void us_pmdone(void);
+static INTSML us_pmeachchar(INTBIG, INTBIG, INTSML);
+static INTSML us_pmeachdown(INTBIG, INTBIG);
+static void us_pminvertline(void);
 
 /****************************** MENU DISPLAY ******************************/
 
@@ -95,7 +93,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 	if (us_menubarsize != 0 && el_curwindowpart != NOWINDOWPART)
 	{
 		/* get polygon */
-		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 		/* get size of current window */
 		getwindowframesize(el_curwindowpart->frame, &swid, &shei);
@@ -121,7 +119,8 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 		poly->desc = &us_menutext;
 		us_menutext.col = el_colmentxt;
 		poly->style = TEXTBOX;
-		poly->font = TXTMENU;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, TXTMENU);
 		poly->tech = el_curtech;
 		for(i=0; i<us_pulldownmenucount; i++)
 		{
@@ -133,13 +132,13 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 	}
 
 	/* draw menus if requested */
-	if ((us_aid->aidstate&MENUON) != 0)
+	if ((us_tool->toolstate&MENUON) != 0)
 	{
 		if (mw != NOWINDOWFRAME && us_menuframe != NOWINDOWFRAME &&
 			us_menuframe != mw) return;
 
 		/* draw the menu entries */
-		var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 		if (var == NOVARIABLE) return;
 
 		if (us_menupos <= 1)
@@ -181,7 +180,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	COMMANDBINDING commandbinding;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* setup the fake variable for coloring artwork objects in the menu */
 	colorvar[0].key = art_colorkey;
@@ -189,7 +188,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	colorvar[0].addr = el_colmengly;
 
 	if (stopping(STOPREASONDISPLAY)) return;
-	if ((us_aid->aidstate&MENUON) == 0) return;
+	if ((us_tool->toolstate&MENUON) == 0) return;
 
 	/* parse the menu entry string */
 	us_parsebinding(str, &commandbinding);
@@ -412,7 +411,8 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		poly->desc = &us_menutext;
 		us_menutext.col = el_colmentxt;
 		poly->style = TEXTBOX;
-		poly->font = commandbinding.menumessagesize;
+		TDCLEAR(poly->textdescript);
+		TDSETSIZE(poly->textdescript, commandbinding.menumessagesize);
 		poly->tech = el_curtech;
 		if (commandbinding.menumessage != 0) poly->string = commandbinding.menumessage; else
 		{
@@ -505,23 +505,26 @@ void us_setmenunodearcs(void)
 {
 	REGISTER ARCPROTO *ap;
 	REGISTER NODEPROTO *np, *pinnp;
-	REGISTER INTSML i;
+	REGISTER INTBIG didinst, i;
 	REGISTER VARIABLE *var;
 	char si[20], sj[20], *par[MAXPARS+6];
 	COMMANDBINDING commandbinding;
+	extern COMCOMP us_userp;
 
 	/* bind menu entries for arcs */
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 	if (var == NOVARIABLE) return;
 	ap = el_curtech->firstarcproto;
 	np = el_curtech->firstnodeproto;
+	didinst = 0;
 	for(i=0; i<us_menuy*us_menux; i++)
 	{
 		us_parsebinding(((char **)var->addr)[i], &commandbinding);
 
 		/* make sure the menu item is a "getproto" command */
 		if (commandbinding.command != 0 &&
-			namesamen(commandbinding.command, "getproto", 8) == 0)
+			(namesamen(commandbinding.command, "getproto", 8) == 0 ||
+			namesamen(commandbinding.command, "pmgetproto", 10) == 0))
 		{
 			/* make sure the command is getting a primitive in a technology */
 			if (commandbinding.nodeglyph == NONODEPROTO ||
@@ -530,12 +533,12 @@ void us_setmenunodearcs(void)
 				/* load up the strings for the menu indices */
 				if (us_menupos <= 1)
 				{
-					(void)sprintf(si, "%d", i%us_menux);
-					(void)sprintf(sj, "%d", i/us_menux);
+					(void)sprintf(si, "%ld", i%us_menux);
+					(void)sprintf(sj, "%ld", i/us_menux);
 				} else
 				{
-					(void)sprintf(si, "%d", i/us_menuy);
-					(void)sprintf(sj, "%d", i%us_menuy);
+					(void)sprintf(si, "%ld", i/us_menuy);
+					(void)sprintf(sj, "%ld", i%us_menuy);
 				}
 				par[0] = "set";          par[1] = "menu";
 				par[2] = "background";   par[3] = "blue";
@@ -548,9 +551,12 @@ void us_setmenunodearcs(void)
 					for(;;)
 					{
 						if (ap == NOARCPROTO) break;
-						pinnp = getpinproto(ap);
-						if (pinnp == NONODEPROTO) break;
-						if ((pinnp->userbits & NNOTUSED) == 0) break;
+						if ((ap->userbits&ANOTUSED) == 0)
+						{
+							pinnp = getpinproto(ap);
+							if (pinnp == NONODEPROTO) break;
+							if ((pinnp->userbits & NNOTUSED) == 0) break;
+						}
 						ap = ap->nextarcproto;
 					}
 					if (ap != NOARCPROTO)
@@ -564,6 +570,22 @@ void us_setmenunodearcs(void)
 					}
 				}
 
+				/* insert the instance popup between the arcs and the nodes */
+				if (didinst == 0)
+				{
+					didinst = 1;
+					if (parse("pmgetproto", &us_userp, 0) >= 0)
+					{
+						par[2] = "message";
+						par[3] = _("Inst.");
+						par[6] = "pmgetproto";
+						par[7] = "instance";
+						us_bind(8, par);
+						us_freebindingparse(&commandbinding);
+						continue;
+					}
+				}
+
 				/* done with arcs, do the nodes */
 				if (np != NONODEPROTO)
 				{
@@ -615,9 +637,9 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 		return(0);
 
 	/* set new size, position */
-	(void)setvalkey((INTBIG)us_aid, VAID, us_menu_x, x, VINTEGER|VDONTSAVE);
-	(void)setvalkey((INTBIG)us_aid, VAID, us_menu_y, y, VINTEGER|VDONTSAVE);
-	(void)setvalkey((INTBIG)us_aid, VAID, us_menu_position, position, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_x, x, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_y, y, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_position, position, VINTEGER|VDONTSAVE);
 
 	/* rebuild the binding array size */
 	temp = (char **)emalloc(x*y * (sizeof (char *)), el_tempcluster);
@@ -630,7 +652,7 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 	} else
 	{
 		for(i=0; i<x*y; i++) temp[i] = "";
-		oldvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+		oldvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 		if (oldvar == NOVARIABLE) oldlen = 0; else oldlen = (INTSML)getlength(oldvar);
 		last = NOSTRING;
 		for(i=0; i<mini(oldlen, x*y); i++)
@@ -651,7 +673,7 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 			us_freebindingparse(&commandbinding);
 		}
 	}
-	(void)setvalkey((INTBIG)us_aid, VAID, us_binding_menu, (INTBIG)temp,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_binding_menu, (INTBIG)temp,
 		VSTRING|VISARRAY|VDONTSAVE|((x*y)<<VLENGTHSH));
 	for(i=0; i<mini(oldlen, x*y); i++) efree(temp[i]);
 	efree((char *)temp);
@@ -682,7 +704,7 @@ typedef struct
 	POPUPMENU     *current;			/* current popup menu structure */
 } POPUPINST;
 
-POPUPINST us_pmcur;
+static POPUPINST us_pmcur;
 
 /*
  * routine to display the popup menu "menu" and allow picking.  The menu
@@ -690,7 +712,7 @@ POPUPINST us_pmcur;
  * is nonzero).  If "header" is nonzero, display a header.  If "top" and "left" are not
  * negative, they are used as the coordinates of the upper-left of the menu.  If
  * "quitline" is nonzero, then exit the menu when the cursor moves over that line
- * (1: left side, 2: right side, 3: menu extent).
+ * (1: left side, 2: right side, 3: pulldown menu extent, 4: popup menu extent).
  * Returns the address of the item in the menu that is selected and sets "menu" to
  * the menu (if a submenu in a hierarchy was used).  Returns NOPOPUPMENUITEM
  * if no entry was selected.  Returns zero if this function cannot be done.  If the
@@ -703,8 +725,10 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 	REGISTER INTSML i, yp, waitdown, startfont;
 	REGISTER char *savepos, *pt;
 	REGISTER INTBIG textscale, save_pix;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTSML x, y, chwid, swid, shei;
 	REGISTER POPUPMENU *menu;
+	POPUPMENU *whichmenu;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER WINDOWFRAME *frame;
 
@@ -713,16 +737,19 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 	for(i=0; i<menu->total; i++)
 	{
 		mi = &menu->list[i];
+		if (mi->response != NOUSERCOM && mi->response->menu != NOPOPUPMENU)
+			continue;
 		if (mi->value != 0) break;
 	}
 	if (i >= menu->total)
 	{
-		/* no type-in entries: simple popup menu */
+		/* no type-in entries: see if OS can draw this simple popup menu */
 		if (graphicshas(CANSHOWPOPUP) != 0)
 		{
-			i = nativepopupmenu(menu, header, left, top);
+			whichmenu = menu;
+			i = nativepopupmenu(&whichmenu, header, left, top);
 			if (i < 0) return(NOPOPUPMENUITEM);
-			return(&menu->list[i]);
+			return(&whichmenu->list[i]);
 		}
 	}
 
@@ -760,8 +787,10 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 	for(textscale = startfont; textscale >= 4; textscale--)
 	{
 		us_pmcur.attlen = us_pmcur.vallen = 0;
-		if (textscale == 14) screensettextsize(&us_pmcur.popupwindow, TXTMENU); else
-			screensettextsize(&us_pmcur.popupwindow, textscale);
+		TDCLEAR(descript);
+		if (textscale == startfont) TDSETSIZE(descript, TXTMENU); else
+			TDSETSIZE(descript, textscale);
+		screensettextinfo(&us_pmcur.popupwindow, NOTECHNOLOGY, descript);
 		screengettextsize(&us_pmcur.popupwindow, "0", &chwid, &y);
 		us_pmcur.txthei = y+2;
 		for(i=0; i<us_pmcur.current->total; i++)
@@ -1080,31 +1109,33 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 
 				/* new menu entry: see if it is hierarchical */
 				uc = us_pmcur.retval->response;
-				if (uc != NOUSERCOM && uc->active > 0)
+				if (uc != NOUSERCOM && uc->menu != NOPOPUPMENU)
 				{
-					if (uc->menu != NOPOPUPMENU)
+					savepmcur = us_pmcur;
+					but = 0;
+					i = 1;
+					lx = us_pmcur.posx+us_pmcur.sizex;
+					if (us_pmcur.posx > us_pmcur.popupwindow.usehx-lx)
 					{
-						savepmcur = us_pmcur;
-						but = 0;
-						i = 1;
-						lx = us_pmcur.posx+us_pmcur.sizex;
-						if (us_pmcur.posx > swid-lx)
+						i = 2;
+						lx = us_pmcur.posx;
+						if (us_pmcur.posx < us_pmcur.sizex)
 						{
-							i = 2;
-							lx = us_pmcur.posx;
+							i = us_pmcur.quitline;
+							lx = (INTSML)(x-2);
 						}
-						cmenu = uc->menu;
-						pm = us_popupmenu(&cmenu, &but, 0, lx,
-							(INTSML)(us_pmcur.posy+(us_pmcur.current->total-line)*
-								us_pmcur.txthei), i);
-						us_pmcur = savepmcur;
-						us_pmcur.retval = pm;
-						us_pmcur.retmenu = cmenu;
-						if (but == 0) return(1);
-						readtablet(&sx, &sy);
-						x = sx;   y = sy;
-						continue;
 					}
+					cmenu = uc->menu;
+					pm = us_popupmenu(&cmenu, &but, 0, lx,
+						(INTSML)(us_pmcur.posy+(us_pmcur.current->total-line)*
+							us_pmcur.txthei), i);
+					us_pmcur = savepmcur;
+					us_pmcur.retval = pm;
+					us_pmcur.retmenu = cmenu;
+					if (but == 0) return(1);
+					readtablet(&sx, &sy);
+					x = sx;   y = sy;
+					continue;
 				}
 			}
 		}
@@ -1132,7 +1163,7 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 			}
 			us_pmcur.inarea = -1;
 			return(1);
-		case 3:			/* quit if out of this menu's menubar location */
+		case 3:			/* quit if out of this pulldown menu's menubar location */
 			if (y <= maxy) break;
 			lx = (INTSML)x;
 			for(i=0; i<us_pulldownmenucount; i++)
@@ -1144,6 +1175,11 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 				break;
 			us_pmcur.inarea = -1;
 			return(1);
+		case 4:			/* quit if out of this popup menu's location */
+			if (x >= us_pmcur.posx && x <= us_pmcur.posx+us_pmcur.sizex &&
+				y >= us_pmcur.posy && y <= us_pmcur.posy+us_pmcur.sizey) break;
+			us_pmcur.inarea = -1;
+			return(1);
 	}
 	return(0);
 }
@@ -1215,19 +1251,19 @@ void us_setkeyequiv(POPUPMENU *pm, INTSML i)
 	if (mi->response->active < 0) return;
 	if (mi->response->menu != NOPOPUPMENU) return;
 
-	/* see if it has a "/" in it */
-	for(pt = mi->attribute; *pt != 0 && *pt != '/'; pt++) ;
+	/* see if it has a "/" or "\" in it */
+	for(pt = mi->attribute; *pt != 0 && *pt != '/' && *pt != '\\'; pt++) ;
 	if (*pt == 0) return;
 
 	/* make it the Meta key */
 	key = pt[1];
 	if (isupper(key)) key = tolower(key);
-	key |= 0200;
+	if (*pt == '/') key |= 0200;
 	(void)initinfstr();
 	(void)addstringtoinfstr("command=");
 	(void)addstringtoinfstr(mi->response->comname);
 	(void)us_appendargs(mi->response);
-	(void)setindkey((INTBIG)us_aid, VAID, us_binding_keys, key, (INTBIG)returninfstr());
+	(void)setindkey((INTBIG)us_tool, VTOOL, us_binding_keys, key, (INTBIG)returninfstr());
 }
 
 /*
@@ -1236,7 +1272,7 @@ void us_setkeyequiv(POPUPMENU *pm, INTSML i)
  */
 void us_initpulldownmenu(POPUPMENU *pm)
 {
-	REGISTER INTSML i;
+	REGISTER INTSML i, slash;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER char *pt;
 	char keybuf[10], *acceleratorstring, *acceleratorprefix;
@@ -1255,11 +1291,14 @@ void us_initpulldownmenu(POPUPMENU *pm)
 			us_initpulldownmenu(mi->response->menu);
 			continue;
 		}
-		for(pt = mi->attribute; *pt != 0 && *pt != '/'; pt++) ;
+		for(pt = mi->attribute; *pt != 0 && *pt != '/' && *pt != '\\'; pt++) ;
 		if (*pt == 0) continue;
+		slash = *pt;
 		*pt++ = 0;
-		sprintf(keybuf, "%s%s", acceleratorprefix, pt);
-		allocstring(&mi->value, keybuf, us_aid->cluster);
+		keybuf[0] = 0;
+		if (slash == '/') strcat(keybuf, acceleratorprefix);
+		strcat(keybuf, pt);
+		allocstring(&mi->value, keybuf, us_tool->cluster);
 		mi->maxlen = -1;
 	}
 }
@@ -1270,10 +1309,13 @@ void us_initpulldownmenu(POPUPMENU *pm)
  */
 void us_termpulldownmenu(POPUPMENU *pm)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i, len;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER char *pt;
+	char *acceleratorstring, *acceleratorprefix;
 
+	getacceleratorstrings(&acceleratorstring, &acceleratorprefix);
+	len = strlen(acceleratorprefix);
 	for(i=0; i<pm->total; i++)
 	{
 		mi = &pm->list[i];
@@ -1285,8 +1327,9 @@ void us_termpulldownmenu(POPUPMENU *pm)
 			continue;
 		}
 		if (mi->value == 0) continue;
-		efree(mi->value);
 		pt = mi->attribute;
-		pt[strlen(pt)] = '/';
+		if (namesamen(mi->value, acceleratorprefix, len) == 0) pt[strlen(pt)] = '/'; else
+			pt[strlen(pt)] = '\\';
+		efree(mi->value);
 	}
 }
