@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrparse.c
- * User interface aid: command parsing and execution
+ * User interface tool: command parsing and execution
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -38,60 +38,60 @@
 #define MAXLINE 400		/* maximum length of command file input lines */
 
 /* working memory for "us_parsecommand()" */
-char *us_parseownbuild[MAXPARS];
-INTSML us_parsemaxownbuild = -1;
+static char *us_parseownbuild[MAXPARS];
+static INTSML us_parsemaxownbuild = -1;
 
 /* working memory for "us_evaluatevariable()" */
 static INTBIG *us_evaluatevarlist;
 static INTBIG  us_evaluatevarlimit = 0;
 
-DIALOGHOOK *us_firstdialoghook = NODIALOGHOOK;
+static DIALOGHOOK *us_firstdialoghook = NODIALOGHOOK;
 
 /* global variables for parsing */
-KEYWORD *us_pathiskey;					/* the current keyword list */
+       KEYWORD *us_pathiskey;					/* the current keyword list */
+static INTSML   us_pacurchar;					/* current character on current line */
+static char    *us_pattyline = 0;				/* current line image */
+static INTSML   us_patruelength;				/* size of above two buffers */
+static char    *us_paambiguous = 0;			/* used by "us_pagetword" for "?" message */
 
 /* local variables for parsing */
-INTSML   us_pacurchar;					/* current character on current line */
-char    *us_pattyline = 0;				/* current line image */
-INTSML   us_patruelength;				/* size of above two buffers */
-INTSML   us_paparamcount;				/* number of parameters read in */
-char    *us_palinestart;				/* first character position on line */
-COMCOMP *us_paparamtype[MAXKEYWORD];	/* expected type of each parameter */
-INTSML   us_pakeycount;					/* number of keywords allowed in parse */
-char   **us_paparamstart;				/* character position of each parameter */
-INTBIG	 us_ttypamyItemHit;				/* item hit during parsing */
-char    *us_paambiguous = 0;			/* used by "us_pagetword" for "?" message */
-INTSML   us_paparamadded[MAXKEYWORD];	/* number of parameters added here */
-INTSML   us_pathisind;					/* pointer into the current keyword list */
+static INTSML   us_paparamcount;			/* number of parameters read in */
+static char    *us_palinestart;				/* first character position on line */
+static COMCOMP *us_paparamtype[MAXKEYWORD];	/* expected type of each parameter */
+static INTSML   us_pakeycount;				/* number of keywords allowed in parse */
+static char   **us_paparamstart;			/* character position of each parameter */
+static INTBIG   us_ttypamyItemHit;			/* item hit during parsing */
+static INTSML   us_paparamadded[MAXKEYWORD];/* number of parameters added here */
+static INTSML   us_pathisind;				/* pointer into the current keyword list */
 
 /* prototypes for local routines */
-INTSML   us_addusercom(USERCOM*, char*);
-USERCOM *us_fleshcommand(USERCOM*);
-void     us_dopopupmenu(POPUPMENU*);
-void     us_domacro(char*, INTSML, char*[]);
-INTSML   us_expandvarlist(INTBIG **varlist, INTBIG *varlimit);
-INTSML   us_pagetword(INTSML(*)(COMCOMP**, INTSML*), void(*)(char*), void(*)(void), void(*)(void), INTSML);
-INTSML   us_ttyinttychar(COMCOMP**, INTSML*);
-void     us_ttyoutttychar(char*);
-void     us_ttyerasettychar(void);
-void     us_ttykillttychar(void);
-INTSML   us_specialparse(char*, COMCOMP*, INTSML, char *paramstart[]);
+static INTSML   us_addusercom(USERCOM*, char*);
+static USERCOM *us_fleshcommand(USERCOM*);
+static void     us_dopopupmenu(POPUPMENU*);
+static void     us_domacro(char*, INTSML, char*[]);
+static INTSML   us_expandvarlist(INTBIG **varlist, INTBIG *varlimit);
+static INTSML   us_pagetword(INTSML(*)(COMCOMP**, INTSML*), void(*)(char*), void(*)(void), void(*)(void), INTSML);
+static INTSML   us_ttyinttychar(COMCOMP**, INTSML*);
+static void     us_ttyoutttychar(char*);
+static void     us_ttyerasettychar(void);
+static void     us_ttykillttychar(void);
+static void     us_expandttybuffers(INTSML);
 
 /*
  * Routine to free all memory associated with this module.
  */
 void us_freeparsememory(void)
 {
-	REGISTER USERCOM *u;
+	REGISTER USERCOM *uc;
 	REGISTER INTBIG i;
 	REGISTER MACROPACK *p;
 	REGISTER DIALOGHOOK *dh;
 
 	while (us_usercomfree != NOUSERCOM)
 	{
-		u = us_usercomfree;
+		uc = us_usercomfree;
 		us_usercomfree = us_usercomfree->nextcom;
-		efree((char *)u);
+		efree((char *)uc);
 	}
 
 	for(i=0; i<=us_parsemaxownbuild; i++)
@@ -125,39 +125,41 @@ void us_freeparsememory(void)
  */
 USERCOM *us_allocusercom(void)
 {
-	REGISTER USERCOM *u;
+	REGISTER USERCOM *uc;
 
 	if (us_usercomfree == NOUSERCOM)
 	{
-		u = (USERCOM *)emalloc((sizeof (USERCOM)), us_aid->cluster);
-		if (u == 0) return(NOUSERCOM);
+		uc = (USERCOM *)emalloc((sizeof (USERCOM)), us_tool->cluster);
+		if (uc == 0) return(NOUSERCOM);
 	} else
 	{
 		/* take usercom from free list */
-		u = us_usercomfree;
-		us_usercomfree = (USERCOM *)u->nextcom;
+		uc = us_usercomfree;
+		us_usercomfree = (USERCOM *)uc->nextcom;
 	}
-	u->count = 0;
-	u->comname = 0;
-	u->nodeglyph = NONODEPROTO;
-	u->arcglyph = NOARCPROTO;
-	u->message = 0;
-	u->nextcom = NOUSERCOM;
-	return(u);
+	uc->active = -1;
+	uc->comname = 0;
+	uc->menu = NOPOPUPMENU;
+	uc->message = 0;
+	uc->nodeglyph = NONODEPROTO;
+	uc->arcglyph = NOARCPROTO;
+	uc->count = 0;
+	uc->nextcom = NOUSERCOM;
+	return(uc);
 }
 
 /*
- * routine to return user command "u" to the pool of free commands
+ * routine to return user command "uc" to the pool of free commands
  */
-void us_freeusercom(USERCOM *u)
+void us_freeusercom(USERCOM *uc)
 {
 	REGISTER INTSML i;
 
-	u->nextcom = us_usercomfree;
-	for(i=0; i<u->count; i++) efree(u->word[i]);
-	if (u->comname != 0) efree(u->comname);
-	if (u->message != 0) efree(u->message);
-	us_usercomfree = u;
+	uc->nextcom = us_usercomfree;
+	for(i=0; i<uc->count; i++) efree(uc->word[i]);
+	if (uc->comname != 0) efree(uc->comname);
+	if (uc->message != 0) efree(uc->message);
+	us_usercomfree = uc;
 }
 
 /*
@@ -167,18 +169,18 @@ MACROPACK *us_newmacropack(char *name)
 {
 	REGISTER MACROPACK *p;
 
-	p = (MACROPACK *)emalloc((sizeof (MACROPACK)), us_aid->cluster);
+	p = (MACROPACK *)emalloc((sizeof (MACROPACK)), us_tool->cluster);
 	if (p == 0) return(NOMACROPACK);
-	if (allocstring(&p->packname, name, us_aid->cluster) != 0) return(NOMACROPACK);
+	if (allocstring(&p->packname, name, us_tool->cluster) != 0) return(NOMACROPACK);
 	p->nextmacropack = us_macropacktop;
 	us_macropacktop = p;
 	return(p);
 }
 
 /*
- * routine to add user command "us" to macro "mac".  Returns nonzero upon error
+ * routine to add user command "uc" to macro "mac".  Returns nonzero upon error
  */
-INTSML us_addusercom(USERCOM *us, char *mac)
+INTSML us_addusercom(USERCOM *uc, char *mac)
 {
 	REGISTER INTSML i, parnumber, parsed, len, count, total, j, tot, hasspace;
 	REGISTER char *pt, **manystrings;
@@ -202,13 +204,13 @@ INTSML us_addusercom(USERCOM *us, char *mac)
 	/* build the new command */
 	parsed = 0;
 	(void)initinfstr();
-	(void)addstringtoinfstr(us->comname);
+	(void)addstringtoinfstr(uc->comname);
 	(void)addtoinfstr(' ');
-	for(i=0; i<us->count; i++)
+	for(i=0; i<uc->count; i++)
 	{
 		/* look for parameter substitution */
 		hasspace = 0;
-		for(pt = us->word[i]; *pt != 0; pt++)
+		for(pt = uc->word[i]; *pt != 0; pt++)
 		{
 
 			if (*pt == ' ' || *pt == '\t') hasspace++;
@@ -219,7 +221,7 @@ INTSML us_addusercom(USERCOM *us, char *mac)
 			parnumber = pt[1] - '0';
 			if (parsed == 0)
 			{
-				tot = us_fillcomcomp(us, comarray);
+				tot = us_fillcomcomp(uc, comarray);
 				parsed++;
 			}
 			count = us_parsecommand(manystrings[2], build);
@@ -241,11 +243,11 @@ INTSML us_addusercom(USERCOM *us, char *mac)
 			(void)reallocstring(&manystrings[2], returninfstr(), el_tempcluster);
 		}
 
-		if (hasspace == 0) (void)addstringtoinfstr(us->word[i]); else
+		if (hasspace == 0) (void)addstringtoinfstr(uc->word[i]); else
 		{
 			/* must quote this parameter: it has spaces */
 			(void)addtoinfstr('"');
-			for(pt = us->word[i]; *pt != 0; pt++)
+			for(pt = uc->word[i]; *pt != 0; pt++)
 			{
 				if (*pt == '"') (void)addtoinfstr('"');
 				(void)addtoinfstr(*pt);
@@ -256,7 +258,7 @@ INTSML us_addusercom(USERCOM *us, char *mac)
 	}
 
 	manystrings[len] = returninfstr();
-	(void)setvalkey((INTBIG)us_aid, VAID, var->key, (INTBIG)manystrings,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, var->key, (INTBIG)manystrings,
 		VSTRING|VISARRAY|((len+1)<<VLENGTHSH)|VDONTSAVE);
 	for(i=0; i<len; i++) efree(manystrings[i]);
 	efree((char *)manystrings);
@@ -364,11 +366,11 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 	if (uc != NOUSERCOM)
 	{
 		uc->active = act;
-		(void)allocstring(&uc->comname, item->comname, us_aid->cluster);
+		(void)allocstring(&uc->comname, item->comname, us_tool->cluster);
 		uc->menu = item->menu;
 		uc->count = item->count;
 		for(j=0; j<item->count; j++)
-			if (allocstring(&uc->word[j], item->word[j], us_aid->cluster) != 0)
+			if (allocstring(&uc->word[j], item->word[j], us_tool->cluster) != 0)
 		{
 			uc = NOUSERCOM;
 			break;
@@ -391,7 +393,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 	wasmacro = 0;
 	if (macro != 0)
 	{
-		var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 		if (var != NOVARIABLE)
 		{
 			/* see if macro was begun with the "no-execute" option */
@@ -457,7 +459,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 	/* save the command in a macro if requested */
 	if (wasmacro != 0 && (us_state&COMMANDFAILED) == 0 && ismacend == 0)
 	{
-		var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 		if (var != NOVARIABLE)
 			if (us_addusercom(uc, (char *)var->addr) != 0)
 				ttyputnomemory();
@@ -508,7 +510,7 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 	ucnew = us_allocusercom();
 	if (ucnew == NOUSERCOM) return(uc);
 	ucnew->active = uc->active;
-	(void)allocstring(&ucnew->comname, uc->comname, us_aid->cluster);
+	(void)allocstring(&ucnew->comname, uc->comname, us_tool->cluster);
 	ucnew->menu = uc->menu;
 	ucnew->count = uc->count;
 
@@ -547,7 +549,7 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 					break;
 				}
 
-				var = getval((INTBIG)us_aid, VAID, -1, us_commandvarname(*pp));
+				var = getval((INTBIG)us_tool, VTOOL, -1, us_commandvarname(*pp));
 				if (var != NOVARIABLE) i += addstringtoinfstr(describevariable(var, aindex, -1));
 				if (aindex >= 0)
 				{
@@ -561,8 +563,8 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 			if (isdigit(*pp))
 			{
 				/* substitute macro parameter */
-				varrunning = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrorunning);
-				varbuilding = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+				varrunning = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrorunning);
+				varbuilding = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 				if (varrunning != NOVARIABLE && (varbuilding == NOVARIABLE ||
 					namesame((char *)varrunning->addr, (char *)varbuilding->addr) != 0))
 				{
@@ -688,7 +690,7 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 				i += addtoinfstr((char)chr);
 			}
 		}
-		if (allocstring(&ucnew->word[j], returninfstr(), us_aid->cluster) != 0) i++;
+		if (allocstring(&ucnew->word[j], returninfstr(), us_tool->cluster) != 0) i++;
 		efree(tmpstring);
 	}
 	if (i != 0) ttyputnomemory();
@@ -751,15 +753,15 @@ INTSML us_evaluatevariable(char *name, INTBIG *objaddr, INTBIG *objtype, char **
 			*name = save;
 			if (lib == NOLIBRARY) return(1);
 			*objaddr = (INTBIG)lib;
-		} else if (namesamen(type, "aid", i) == 0 && i >= 2)
+		} else if (namesamen(type, "tool", i) == 0 && i >= 2)
 		{
-			*objtype = VAID;
-			if (strcmp(pp, "~") == 0) i = us_aid->aidindex; else
-				for(i=0; i<el_maxaid; i++)
-					if (namesame(el_aids[i].aidname, pp) == 0) break;
+			*objtype = VTOOL;
+			if (strcmp(pp, "~") == 0) i = us_tool->toolindex; else
+				for(i=0; i<el_maxtools; i++)
+					if (namesame(el_tools[i].toolname, pp) == 0) break;
 			*name = save;
-			if (i >= el_maxaid) return(1);
-			*objaddr = (INTBIG)&el_aids[i];
+			if (i >= el_maxtools) return(1);
+			*objaddr = (INTBIG)&el_tools[i];
 		} else if (namesamen(type, "arc", i) == 0 && i >= 2)
 		{
 			*objtype = VARCPROTO;
@@ -999,7 +1001,7 @@ INTSML us_evaluatevariable(char *name, INTBIG *objaddr, INTBIG *objtype, char **
 				/* if there are no objects selected, stop now */
 				if (list[1] == 0) return(1);
 
-				highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
+				highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
 				if (highvar == NOVARIABLE) return(1);
 				if (us_makehighlight(((char **)highvar->addr)[0], &thishigh) != 0) return(1);
 				high = &thishigh;
@@ -1093,7 +1095,7 @@ INTSML us_expandvarlist(INTBIG **varlist, INTBIG *varlimit)
 
 	newlimit = *varlimit * 2;
 	if (newlimit <= 0) newlimit = *varlimit + 10;
-	newlist = (INTBIG *)emalloc(newlimit * 2 * SIZEOFINTBIG, us_aid->cluster);
+	newlist = (INTBIG *)emalloc(newlimit * 2 * SIZEOFINTBIG, us_tool->cluster);
 	if (newlist == 0) return(1);
 	for(i=0; i < (*varlimit)*2; i++) newlist[i] = (*varlist)[i];
 	if (*varlimit != 0) efree((char *)*varlist);
@@ -1112,9 +1114,9 @@ INTSML us_expandaddrtypearray(INTBIG *limit, INTBIG **addr, INTBIG **type, INTBI
 
 	if (*limit > 0) { efree((char *)*addr);   efree((char *)*type); }
 	*limit = 0;
-	*addr = (INTBIG *)emalloc(len * SIZEOFINTBIG, us_aid->cluster);
+	*addr = (INTBIG *)emalloc(len * SIZEOFINTBIG, us_tool->cluster);
 	if (*addr == 0) return(1);
-	*type = (INTBIG *)emalloc(len * SIZEOFINTBIG, us_aid->cluster);
+	*type = (INTBIG *)emalloc(len * SIZEOFINTBIG, us_tool->cluster);
 	if (*type == 0) return(1);
 	*limit = len;
 	return(0);
@@ -1200,7 +1202,7 @@ void us_domacro(char *mac, INTSML count, char *pp[])
 	REGISTER VARIABLE *varmacro, *varbuilding, *varrunning;
 
 	/* make sure the macro being executed is not currently being defined */
-	varbuilding = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+	varbuilding = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 	if (varbuilding != NOVARIABLE && namesame((char *)varbuilding->addr, mac) == 0)
 	{
 		us_abortcommand(_("End macro definitions before executing them"));
@@ -1238,13 +1240,13 @@ void us_domacro(char *mac, INTSML count, char *pp[])
 		}
 		(void)addtoinfstr('"');
 	}
-	(void)setindkey((INTBIG)us_aid, VAID, varmacrokey, 1, (INTBIG)returninfstr());
+	(void)setindkey((INTBIG)us_tool, VTOOL, varmacrokey, 1, (INTBIG)returninfstr());
 
 	/* save currently running macro, set this as current */
-	varrunning = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrorunning);
+	varrunning = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrorunning);
 	if (varrunning == NOVARIABLE) runsave = 0; else
 		(void)allocstring(&runsave, (char *)varrunning->addr, el_tempcluster);
-	(void)setvalkey((INTBIG)us_aid, VAID, us_macrorunning, (INTBIG)mac, VSTRING|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_macrorunning, (INTBIG)mac, VSTRING|VDONTSAVE);
 
 	/* execute the macro */
 	us_state &= ~MACROTERMINATED;
@@ -1259,16 +1261,16 @@ void us_domacro(char *mac, INTSML count, char *pp[])
 	us_state &= ~MACROTERMINATED;
 
 	/* restore currently running macro */
-	if (runsave == 0) (void)delvalkey((INTBIG)us_aid, VAID, us_macrorunning); else
+	if (runsave == 0) (void)delvalkey((INTBIG)us_tool, VTOOL, us_macrorunning); else
 	{
-		(void)setvalkey((INTBIG)us_aid, VAID, us_macrorunning, (INTBIG)runsave, VSTRING|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_macrorunning, (INTBIG)runsave, VSTRING|VDONTSAVE);
 		efree(runsave);
 	}
 
 	/* restore the current macro parameters */
-	if (paramsave == 0) (void)setindkey((INTBIG)us_aid, VAID, varmacrokey, 1, (INTBIG)""); else
+	if (paramsave == 0) (void)setindkey((INTBIG)us_tool, VTOOL, varmacrokey, 1, (INTBIG)""); else
 	{
-		(void)setindkey((INTBIG)us_aid, VAID, varmacrokey, 1, (INTBIG)paramsave);
+		(void)setindkey((INTBIG)us_tool, VTOOL, varmacrokey, 1, (INTBIG)paramsave);
 		efree(paramsave);
 	}
 }
@@ -1295,11 +1297,11 @@ void us_docommands(FILE *infile, INTSML verbose, char *headerstring)
 
 	/* save iteration and macro state */
 	savelastc = us_lastcom;      us_lastcom = NOUSERCOM;
-	varbuilding = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
+	varbuilding = getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding);
 	if (varbuilding != NOVARIABLE)
 	{
 		(void)allocstring(&savemacro, (char *)varbuilding->addr, el_tempcluster);
-		(void)delvalkey((INTBIG)us_aid, VAID, us_macrobuilding);
+		(void)delvalkey((INTBIG)us_tool, VTOOL, us_macrobuilding);
 	} else savemacro = 0;
 
 	/* loop through the command file */
@@ -1329,7 +1331,7 @@ void us_docommands(FILE *infile, INTSML verbose, char *headerstring)
 	us_lastcom = savelastc;
 	if (savemacro != 0)
 	{
-		(void)setvalkey((INTBIG)us_aid, VAID, us_macrobuilding, (INTBIG)savemacro, VSTRING|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_macrobuilding, (INTBIG)savemacro, VSTRING|VDONTSAVE);
 		efree(savemacro);
 	}
 	if (verbose == 0) (void)ttyquiet(lastquiet);
@@ -1412,9 +1414,9 @@ INTSML us_parsecommand(char *pp, char *build[])
 		}
 		if (count > us_parsemaxownbuild)
 		{
-			(void)allocstring(&us_parseownbuild[count], ppsave, us_aid->cluster);
+			(void)allocstring(&us_parseownbuild[count], ppsave, us_tool->cluster);
 			us_parsemaxownbuild = count;
-		} else (void)reallocstring(&us_parseownbuild[count], ppsave, us_aid->cluster);
+		} else (void)reallocstring(&us_parseownbuild[count], ppsave, us_tool->cluster);
 		build[count] = us_parseownbuild[count];
 		*pp = c;
 	}
@@ -1439,11 +1441,11 @@ USERCOM *us_buildcommand(INTSML count, char *par[])
 	if (uc == NOUSERCOM) return(NOUSERCOM);
 	uc->active = i;
 	uc->menu = us_getpopupmenu(par[0]);
-	(void)allocstring(&uc->comname, par[0], us_aid->cluster);
+	(void)allocstring(&uc->comname, par[0], us_tool->cluster);
 	uc->count = count-1;
 	for(i=1; i<count; i++)
 	{
-		if (allocstring(&uc->word[i-1], par[i], us_aid->cluster) != 0) return(NOUSERCOM);
+		if (allocstring(&uc->word[i-1], par[i], us_tool->cluster) != 0) return(NOUSERCOM);
 
 		/* remove quotes from the keyword */
 		inquote = 0;
@@ -1500,7 +1502,7 @@ VARIABLE *us_getmacro(char *name)
 	(void)initinfstr();
 	(void)addstringtoinfstr("USER_macro_");
 	(void)addstringtoinfstr(name);
-	return(getval((INTBIG)us_aid, VAID, VSTRING|VISARRAY, returninfstr()));
+	return(getval((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, returninfstr()));
 }
 
 /*
@@ -1568,10 +1570,10 @@ void DiaDeclareHook(char *terminputkeyword, COMCOMP *getlinecomp, void (*routine
 {
 	DIALOGHOOK *dh;
 
-	dh = (DIALOGHOOK *)emalloc(sizeof (DIALOGHOOK), us_aid->cluster);
+	dh = (DIALOGHOOK *)emalloc(sizeof (DIALOGHOOK), us_tool->cluster);
 	if (dh == 0) return;
 	if (terminputkeyword == 0) dh->terminputkeyword = 0; else
-		(void)allocstring(&dh->terminputkeyword, terminputkeyword, us_aid->cluster);
+		(void)allocstring(&dh->terminputkeyword, terminputkeyword, us_tool->cluster);
 	dh->getlinecomp = getlinecomp;
 	dh->routine = routine;
 	dh->nextdialoghook = us_firstdialoghook;
@@ -1595,7 +1597,7 @@ COMCOMP *us_getcomcompfromkeyword(char *keyword)
 }
 
 /* List Dialog */
-DIALOGITEM us_listdialogitems[] =
+static DIALOGITEM us_listdialogitems[] =
 {
  /*  1 */ {0, {160,216,184,280}, BUTTON, N_("OK")},
  /*  2 */ {0, {96,216,120,280}, BUTTON, N_("Cancel")},
@@ -1625,12 +1627,12 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 		us_windowrnamep, us_technologyup, us_technologyedlp, us_librarydp, us_helpp,
 		us_technologyctdp, us_textdsp, us_librarywriteformatp, us_colorhighp,
 		us_technologyclsrp, us_technologyclscp, us_technologyclsecp, us_technologyclip,
-		us_technologycnsp, us_technologyclgp, us_technologyclsp, us_showdp, us_createxp,
+		us_technologycnsp, us_technologyclsp, us_showdp, us_createxp, sim_spiceformp,
 		us_nodetcaip, us_bindgkeyp, us_sizep, us_sizewp, us_defnodep, us_showup,
 		us_librarykp, us_findobjap, us_window3dp, us_gridp, us_technologytp, us_textfp,
 		us_renamecp, us_findnnamep, us_findexportp, us_noyesalwaysp, us_varop,
 		us_copyfacetdp, us_findnodep, us_technologycnnp, us_showep, us_purelayerp,
-		us_textsp, us_viewdp;
+		us_textsp, us_viewdp, us_interpretcp;
 
 	/* is this necessary?  if not, us_pathiskey does not need to be global */
 	us_pathiskey = parameter->ifmatch;
@@ -1669,6 +1671,7 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 	if (parameter == &us_colorhighp)          return(us_highlayerlog());
 	if (parameter == &us_copyfacetdp)         return(us_iconstyledlog());
 	if (parameter == &us_technologyclsecp)    return(us_inductancedlog(paramstart, 0));
+	if (parameter == &us_interpretcp)         return(us_javaoptionsdlog());
 	if (parameter == &us_lambdachp)           return(us_lambdadlog());
 	if (parameter == &us_librarydp)           return(us_librarypathdlog());
 	if (parameter == &us_technologycnnp)      return(us_libtotechnologydlog());
@@ -1696,6 +1699,7 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 	if (parameter == &us_findnodep)           return(us_selectportnodenetdlog(2));
 	if (parameter == &us_showp)               return(us_showdlog(0));
 	if (parameter == &us_showop)              return(us_showdlog(1));
+	if (parameter == &sim_spiceformp)         return(us_spicedlog());
 	if (parameter == &us_spreaddp)            return(us_spreaddlog());
 	if (parameter == &us_technologyup)        return(us_technologydlog(prompt, paramstart));
 	if (parameter == &us_technologytp)        return(us_techoptdlog());
@@ -1706,7 +1710,6 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 	if (parameter == &us_technologyclip)      return(us_vccsdlog(paramstart, 0));
 	if (parameter == &us_viewdp)              return(us_viewdlog(1));
 	if (parameter == &us_visiblelayersp)      return(us_visiblelayersdlog(prompt));
-	if (parameter == &us_technologyclgp)      return(us_widlendlog(paramstart, 0));
 	if (parameter == &us_windowrnamep)        return(us_windowviewdlog());
 	if (parameter == &us_yesnop)              return(us_yesnodlog(prompt, paramstart));
 	if (parameter == &us_colorwritep || parameter == &us_colorreadp)
@@ -1791,7 +1794,7 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 /***************************** GET FULL COMMAND *****************************/
 
 /* Full Input Dialog */
-DIALOGITEM us_ttyfulldialogitems[] =
+static DIALOGITEM us_ttyfulldialogitems[] =
 {
  /*  1 */ {0, {160,328,184,392}, BUTTON, N_("OK")},
  /*  2 */ {0, {104,328,128,392}, BUTTON, N_("Cancel")},
@@ -1800,7 +1803,7 @@ DIALOGITEM us_ttyfulldialogitems[] =
  /*  5 */ {0, {88,8,212,294}, SCROLL, ""},
  /*  6 */ {0, {72,56,88,270}, MESSAGE, N_("Type '?' for a list of options")}
 };
-DIALOG us_ttyfulldialog = {{50,75,271,493}, N_("Command Completion"), 0, 6, us_ttyfulldialogitems};
+static DIALOG us_ttyfulldialog = {{50,75,271,493}, N_("Command Completion"), 0, 6, us_ttyfulldialogitems};
 
 /* special items for the "ttygetline" dialog: */
 #define DGTF_LINE     3		/* line (edit text) */
@@ -2227,9 +2230,9 @@ void us_expandttybuffers(INTSML amt)
 	if (amt <= us_patruelength) return;
 
 	/* allocate new buffers */
-	newline = (char *)emalloc(((amt+1) * (sizeof (char))), us_aid->cluster);
+	newline = (char *)emalloc(((amt+1) * (sizeof (char))), us_tool->cluster);
 	if (newline == 0) return;
-	newamb = (char *)emalloc(((amt+1) * (sizeof (char))), us_aid->cluster);
+	newamb = (char *)emalloc(((amt+1) * (sizeof (char))), us_tool->cluster);
 	if (newamb == 0) return;
 
 	/* preserve any old buffers */
