@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrstatus.c
- * User interface aid: status display routines
+ * User interface tool: status display routines
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -51,13 +51,13 @@ struct explanation
 };
 
 /* prototypes for local routines */
-void us_addobjects(NODEPROTO*);
-INTSML us_wildmatch(char*, char*);
-void us_explainaid(INTBIG, struct explanation[]);
-void us_saveoptions(void);
-void us_drawarcmenu(ARCPROTO *ap);
+static void us_addobjects(NODEPROTO*);
+static INTSML us_wildmatch(char*, char*);
+static void us_explaintool(INTBIG, struct explanation[]);
+static void us_drawarcmenu(ARCPROTO *ap);
+static INTSML us_isuniquename(char *name, NODEPROTO *facet, INTBIG type, void *exclude);
 
-STATUSFIELD *us_clearstatuslines[3] = {0, 0, 0};
+static STATUSFIELD *us_clearstatuslines[3] = {0, 0, 0};
 
 /*
  * Routine to free all memory associated with this module.
@@ -136,14 +136,14 @@ STATUSFIELD *ttydeclarestatusfield(INTSML line, INTSML startper, INTSML endper,
 {
 	STATUSFIELD *sf;
 
-	sf = (STATUSFIELD *)emalloc((sizeof (STATUSFIELD)), us_aid->cluster);
+	sf = (STATUSFIELD *)emalloc((sizeof (STATUSFIELD)), us_tool->cluster);
 	if (sf == 0) return(0);
 	if (line < 0 || line > ttynumstatuslines()) return(0);
 	if (line > 0 && (startper < 0 || endper > 100 || startper >= endper)) return(0);
 	sf->line = line;
 	sf->startper = startper;
 	sf->endper = endper;
-	(void)allocstring(&sf->label, label, us_aid->cluster);
+	(void)allocstring(&sf->label, label, us_tool->cluster);
 	return(sf);
 }
 
@@ -169,7 +169,7 @@ void us_setlambda(WINDOWFRAME *frame)
 	char hold[50];
 
 	/* show nothing in X/Y mode */
-	if ((us_aid->aidstate&SHOWXY) != 0) return;
+	if ((us_tool->toolstate&SHOWXY) != 0) return;
 
 	lambdainmicrons = scaletodispunit(el_curlib->lambda[el_curtech->techindex], DISPUNITMIC);
 	(void)sprintf(hold, "%g", lambdainmicrons);
@@ -188,7 +188,7 @@ void us_setlambda(WINDOWFRAME *frame)
 void us_settechname(WINDOWFRAME *frame)
 {
 	/* show nothing in XY mode */
-	if ((us_aid->aidstate&SHOWXY) != 0) return;
+	if ((us_tool->toolstate&SHOWXY) != 0) return;
 
 	ttysetstatusfield(NOWINDOWFRAME, us_statustechnology, el_curtech->techname, 1);
 }
@@ -199,7 +199,7 @@ void us_setcursorpos(WINDOWFRAME *frame, INTBIG x, INTBIG y)
 	static INTBIG lastx=0, lasty=0;
 
 	/* show nothing in non XY mode */
-	if ((us_aid->aidstate&SHOWXY) == 0) return;
+	if ((us_tool->toolstate&SHOWXY) == 0) return;
 
 	if (lastx != x)
 	{
@@ -217,7 +217,7 @@ void us_setcursorpos(WINDOWFRAME *frame, INTBIG x, INTBIG y)
 /* set the current nodeproto */
 void us_setnodeproto(NODEPROTO *np)
 {
-	(void)setvalkey((INTBIG)us_aid, VAID, us_current_node, (INTBIG)np, VNODEPROTO|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_node, (INTBIG)np, VNODEPROTO|VDONTSAVE);
 }
 
 /*
@@ -230,7 +230,7 @@ void us_setarcproto(ARCPROTO *ap, INTSML always)
 	{
 		if (ap == gen_universalarc) return;
 	}
-	(void)setvalkey((INTBIG)us_aid, VAID, us_current_arc, (INTBIG)ap, VARCPROTO|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_arc, (INTBIG)ap, VARCPROTO|VDONTSAVE);
 }
 
 /* shadow changes to the current nodeproto */
@@ -262,11 +262,11 @@ void us_showcurrentnodeproto(void)
 	COMMANDBINDING commandbinding;
 
 	if (us_curnodeproto == NONODEPROTO) return;
-	if ((us_aid->aidstate&MENUON) == 0) return;
-	if ((us_aid->aidstate&ONESHOTMENU) != 0) return;
+	if ((us_tool->toolstate&MENUON) == 0) return;
+	if ((us_tool->toolstate&ONESHOTMENU) != 0) return;
 	if (us_menuhnx >= 0) us_highlightmenu(us_menuhnx, us_menuhny, el_colmenbor);
 	us_menuhnx = -1;
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 	if (var != NOVARIABLE) for(x=0; x<us_menux; x++) for(y=0; y<us_menuy; y++)
 	{
 		if (us_menupos <= 1) str = ((char **)var->addr)[y * us_menux + x]; else
@@ -313,7 +313,7 @@ void us_drawarcmenu(ARCPROTO *ap)
 	REGISTER ARCPROTO *pap;
 	COMMANDBINDING commandbinding;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 	if (var == NOVARIABLE) return;
 	for(x=0; x<us_menux; x++)
 		for(y=0; y<us_menuy; y++)
@@ -345,10 +345,10 @@ void us_showcurrentarcproto(void)
 
 	/* highlight the menu entry */
 	if (us_curarcproto == NOARCPROTO) return;
-	if ((us_aid->aidstate&MENUON) == 0) return;
-	if ((us_aid->aidstate&ONESHOTMENU) != 0) return;
+	if ((us_tool->toolstate&MENUON) == 0) return;
+	if ((us_tool->toolstate&ONESHOTMENU) != 0) return;
 	if (us_menuhax >= 0) us_highlightmenu(us_menuhax, us_menuhay, el_colmenbor);
-	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
 	if (var != NOVARIABLE) for(x=0; x<us_menux; x++) for(y=0; y<us_menuy; y++)
 	{
 		if (us_menupos <= 1) str = ((char **)var->addr)[y * us_menux + x]; else
@@ -377,14 +377,14 @@ void us_shownetworkname(WINDOWFRAME *frame)
 	ttysetstatusfield(frame, us_statusnetwork, hold, 0);
 }
 
-/* write the default placement angle from "aid:user.USER_placement_angle" */
+/* write the default placement angle from "tool:user.USER_placement_angle" */
 void us_setnodeangle(WINDOWFRAME *frame)
 {
 	char hold[5];
 	REGISTER VARIABLE *var;
 	REGISTER INTSML pangle;
 
-	var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_placement_angle);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_placement_angle);
 	if (var == NOVARIABLE) pangle = 0; else pangle = (INTSML)var->addr;
 	(void)strcpy(hold, frtoa(pangle%3600*WHOLE/10));
 	if (pangle >= 3600) (void)strcat(hold, "T");
@@ -419,6 +419,7 @@ void us_setfacetname(WINDOWPART *w)
 					break;
 				}
 			}
+			/* FALLTHROUGH */ 
 		case DISPWINDOW:
 		case DISP3DWINDOW:
 			if (w->curnodeproto != NONODEPROTO)
@@ -552,11 +553,11 @@ void us_printmacros(void)
 	for(pack=us_macropacktop; pack!=NOMACROPACK; pack=pack->nextmacropack)
 		pack->total = 0;
 	keyboard = gotany = 0;
-	for(i=0; i<us_aid->numvar; i++)
+	for(i=0; i<us_tool->numvar; i++)
 	{
-		if (namesamen(makename(us_aid->firstvar[i].key), "USER_macro_", 11) == 0)
+		if (namesamen(makename(us_tool->firstvar[i].key), "USER_macro_", 11) == 0)
 		{
-			var = &us_aid->firstvar[i];
+			var = &us_tool->firstvar[i];
 			if (getlength(var) <= 3) continue;
 			count = us_parsecommand(((char **)var->addr)[0], build);
 			for(j=0; j<count; j++)
@@ -594,10 +595,10 @@ void us_printmacros(void)
 		(void)strcat(line, M_(" macros:"));
 		len = strlen(line);
 		inter = "";
-		for(i=0; i<us_aid->numvar; i++)
-			if (namesamen(makename(us_aid->firstvar[i].key), "USER_macro_", 11) == 0)
+		for(i=0; i<us_tool->numvar; i++)
+			if (namesamen(makename(us_tool->firstvar[i].key), "USER_macro_", 11) == 0)
 		{
-			var = &us_aid->firstvar[i];
+			var = &us_tool->firstvar[i];
 			if (getlength(var) <= 3) continue;
 			count = us_parsecommand(((char **)var->addr)[0], build);
 			thispack = NOMACROPACK;
@@ -645,7 +646,7 @@ void us_printmacro(VARIABLE *mac)
 	for(j=3; j<len; j++) ttyputmsg("   %s", ((char **)mac->addr)[j]);
 }
 
-struct
+static struct
 {
 	char *typestring;
 	INTBIG typecode;
@@ -668,7 +669,7 @@ struct
 	{"Geometry",     VGEOM},
 	{"Library",      VLIBRARY},
 	{"Technology",   VTECHNOLOGY},
-	{"Aid",          VAID},
+	{"Tool",         VTOOL},
 	{"R-tree",       VRTNODE},
 	{"Fixed-Point",  VFRACT},
 	{"Network",      VNETWORK},
@@ -745,14 +746,14 @@ char *us_variableattributes(VARIABLE *var, INTSML aindex)
 	return(returninfstr());
 }
 
-/* routine to recursively count and print the nodes in nodeinst "ni" */
-void us_describecontents(NODEINST *ni)
+/* routine to recursively count and print the nodes in facet "facet" */
+void us_describecontents(NODEPROTO *facet)
 {
 	REGISTER INTSML i;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *lib;
 	REGISTER TECHNOLOGY *curtech, *printtech, *tech;
-	REGISTER NODEPROTO **sorted;
+	REGISTER NODEPROTO **sortedfacets;
 
 	/* first zero the count of each nodeproto */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -763,10 +764,10 @@ void us_describecontents(NODEINST *ni)
 			np->temp1 = 0;
 
 	/* now look at every object recursively in this facet */
-	us_addobjects(ni->proto);
+	us_addobjects(facet);
 
 	/* print the totals */
-	ttyputmsg(_("Contents of facet %s:"), describenodeproto(ni->proto));
+	ttyputmsg(_("Contents of facet %s:"), describenodeproto(facet));
 	printtech = el_curtech;
 	for(curtech = el_technologies; curtech != NOTECHNOLOGY; curtech = curtech->nexttechnology)
 	{
@@ -778,23 +779,44 @@ void us_describecontents(NODEINST *ni)
 				ttyputmsg(_("%s technology:"), curtech->techname);
 				printtech = curtech;
 			}
-			ttyputmsg(_("%6d nodes of prototype %s"), np->temp1, describenodeproto(np));
+			ttyputmsg(_("%6d %s %s"), np->temp1, describenodeproto(np),
+				makeplural(_("node"), np->temp1));
 		}
 	}
-	sorted = us_sortlib(el_curlib, (char *)0, 0);
-	if (sorted == 0) ttyputnomemory(); else
+	sortedfacets = us_sortlib(el_curlib, (char *)0, 0);
+	if (sortedfacets == 0) ttyputnomemory(); else
 	{
-		for(i = 0; sorted[i] != NONODEPROTO; i++)
+		for(i = 0; sortedfacets[i] != NONODEPROTO; i++)
 		{
-			np = sorted[i];
+			np = sortedfacets[i];
 			if (np->temp1 == 0) continue;
-			ttyputmsg(_("%6d facets of prototype %s"), np->temp1, describenodeproto(np));
+			ttyputmsg(_("%6d %s %s"), np->temp1, describenodeproto(np),
+				makeplural(_("node"), np->temp1));
 		}
-		efree((char *)sorted);
+		efree((char *)sortedfacets);
 	}
 }
 
-struct
+/*
+ * routine to recursively examine facet "np" and update the number of
+ * instantiated primitive nodeprotos in the "temp1" field of the nodeprotos.
+ */
+void us_addobjects(NODEPROTO *np)
+{
+	REGISTER NODEINST *ni;
+
+	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	{
+		ni->proto->temp1++;
+		if (ni->proto->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
+		us_addobjects(ni->proto);
+	}
+}
+
+static struct
 {
 	NODEPROTO **prim;
 	INTBIG      bits;
@@ -856,21 +878,6 @@ char *us_describemenunode(COMMANDBINDING *commandbinding)
 	return(returninfstr());
 }
 
-/*
- * routine to recursively examine facet "np" and update the number of
- * instantiated primitive nodeprotos in the "temp1" field of the nodeprotos.
- */
-void us_addobjects(NODEPROTO *np)
-{
-	REGISTER NODEINST *ni;
-
-	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-	{
-		ni->proto->temp1++;
-		if (ni->proto->primindex == 0) us_addobjects(ni->proto);
-	}
-}
-
 /*
  * routine to sort the facets in library "lib" by facet name and return an
  * array of NODEPROTO pointers (terminating with NONODEPROTO).  If "matchspec"
@@ -880,9 +887,9 @@ void us_addobjects(NODEPROTO *np)
  */
 NODEPROTO **us_sortlib(LIBRARY *lib, char *matchspec, INTSML shortlist)
 {
-	REGISTER NODEPROTO **sortindex, *np, *tempnt;
+	REGISTER NODEPROTO **sortindex, *np;
 	REGISTER CELL *c;
-	REGISTER INTSML total, i, j;
+	REGISTER INTSML total, i;
 	REGISTER char *pt;
 
 	/* remove library name if it is part of spec */
@@ -920,20 +927,8 @@ NODEPROTO **us_sortlib(LIBRARY *lib, char *matchspec, INTSML shortlist)
 	}
 	sortindex[i] = NONODEPROTO;
 
-	/* sort the facet names (this could be more efficient) */
-	i = 1;
-	while (i)
-	{
-		i = 0;
-		for(j=1; j<total; j++)
-		{
-			if (strcmp(nldescribenodeproto(sortindex[j-1]), nldescribenodeproto(sortindex[j])) <= 0)
-				continue;
-			tempnt = sortindex[j-1];   sortindex[j-1] = sortindex[j];
-			sortindex[j] = tempnt;
-			i++;
-		}
-	}
+	/* sort the facet names */
+	esort(sortindex, total, sizeof (NODEPROTO *), sort_facetnameascending);
 	return(sortindex);
 }
 
@@ -978,8 +973,8 @@ INTSML us_wildmatch(char *name, char *spec)
 	return(1);
 }
 
-/* routine to print the aid information about nodeinst "ni" */
-void us_printnodeaidinfo(NODEINST *ni)
+/* routine to print the tool information about nodeinst "ni" */
+void us_printnodetoolinfo(NODEINST *ni)
 {
 	static struct explanation explain[] =
 	{
@@ -989,11 +984,11 @@ void us_printnodeaidinfo(NODEINST *ni)
 		{NSHORT,      -1,      N_("short")},
 		{0, -1, NULL}
 	};
-	us_explainaid(ni->userbits, explain);
+	us_explaintool(ni->userbits, explain);
 }
 
-/* routine to print the aid information about arcinst "ai" */
-void us_printarcaidinfo(ARCINST *ai)
+/* routine to print the tool information about arcinst "ai" */
+void us_printarctoolinfo(ARCINST *ai)
 {
 	static struct explanation explain[] =
 	{
@@ -1012,16 +1007,16 @@ void us_printarcaidinfo(ARCINST *ai)
 		{REVERSEEND,    -1,                 N_("direction-reversed")},
 		{0, -1, NULL}
 	};
-	us_explainaid(ai->userbits, explain);
+	us_explaintool(ai->userbits, explain);
 }
 
-/* helper routine for "us_printnodeaidinfo" and "us_printarcaidinfo" */
-void us_explainaid(INTBIG bits, struct explanation explain[])
+/* helper routine for "us_printnodetoolinfo" and "us_printarctoolinfo" */
+void us_explaintool(INTBIG bits, struct explanation explain[])
 {
 	REGISTER INTSML j, k;
 	char partial[40];
 
-	/* print the aid bit information */
+	/* print the tool bit information */
 	(void)initinfstr();
 	(void)sprintf(partial, _("User state = %ld"), bits);
 	(void)addstringtoinfstr(partial);
@@ -1065,7 +1060,7 @@ void us_chatportproto(NODEINST *ni, PORTPROTO *pp)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* if this port has already been discussed, quit now */
 	if (pp->temp1 != 0) return;
@@ -1145,24 +1140,22 @@ void us_chatportproto(NODEINST *ni, PORTPROTO *pp)
  * in "descript".  The string has the form "POSITION+(DX,DY),SIZE" if there
  * is an offset, or "POSITION,SIZE" if there is not.  The string is returned.
  */
-char *us_describetextdescript(INTBIG descript)
+char *us_describetextdescript(UINTBIG *descript)
 {
 	REGISTER INTBIG xdist, ydist;
 	char offset[50];
 
 	(void)initinfstr();
-	(void)addstringtoinfstr(us_describestyle(descript&VTPOSITION));
-	if ((descript&(VTXOFF|VTYOFF)) != 0)
+	(void)addstringtoinfstr(us_describestyle(TDGETPOS(descript)));
+	if (TDGETXOFF(descript) != 0 || TDGETYOFF(descript) != 0)
 	{
-		xdist = (descript&VTXOFF) >> VTXOFFSH;
-		if ((descript&VTXOFFNEG) != 0) xdist = -xdist;
-		ydist = (descript&VTYOFF) >> VTYOFFSH;
-		if ((descript&VTYOFFNEG) != 0) ydist = -ydist;
+		xdist = TDGETXOFF(descript);
+		ydist = TDGETYOFF(descript);
 		(void)sprintf(offset, "+(%s,%s)", frtoa(xdist*WHOLE/4), frtoa(ydist*WHOLE/4));
 		(void)addstringtoinfstr(offset);
 	}
 	(void)addtoinfstr(',');
-	(void)addstringtoinfstr(us_describefont((descript&VTSIZE) >> VTSIZESH));
+	(void)addstringtoinfstr(us_describefont(TDGETSIZE(descript)));
 	return(returninfstr());
 }
 
@@ -1192,24 +1185,16 @@ char *us_describestyle(INTBIG style)
  */
 char *us_describefont(INTBIG font)
 {
-	switch (font)
+	static char description[60];
+	if (TXTGETPOINTS(font) != 0)
 	{
-		case TXT4P:     return(_("4-point"));
-		case TXT6P:     return(_("6-point"));
-		case TXT8P:     return(_("8-point"));
-		case TXT10P:    return(_("10-point"));
-		case TXT12P:    return(_("12-point"));
-		case TXT14P:    return(_("14-point"));
-		case TXT16P:    return(_("16-point"));
-		case TXT18P:    return(_("18-point"));
-		case TXT20P:    return(_("20-point"));
-		case TXTHL:     return(_("Half-lambda"));
-		case TXT1L:     return(_("1-lambda"));
-		case TXT2L:     return(_("2-lambda"));
-		case TXT3L:     return(_("3-lambda"));
-		case TXT4L:     return(_("4-lambda"));
-		case TXT5L:     return(_("5-lambda"));
-		case TXT6L:     return(_("6-lambda"));
+		sprintf(description, _("%ld-points"), TXTGETPOINTS(font));
+		return(description);
+	}
+	if (TXTGETQLAMBDA(font) != 0)
+	{
+		sprintf(description, _("%s-lambda"), frtoa(TXTGETQLAMBDA(font) * WHOLE / 4));
+		return(description);
 	}
 	return("?");
 }
@@ -1229,7 +1214,7 @@ char *us_keyname(INTSML key)
 	{
 		if (key >= FUNCTIONF1 && key <= FUNCTIONF12)
 		{
-			sprintf(pt, "F%ld", key - FUNCTIONF1 + 1);
+			sprintf(pt, "F%d", key - FUNCTIONF1 + 1);
 			return(line);
 		}
 
@@ -1262,9 +1247,9 @@ void us_printcolorvalue(INTSML ind)
 	REGISTER VARIABLE *varred, *vargreen, *varblue;
 
 	/* get color arrays */
-	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
 	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 	{
 		ttyputerr(_("Cannot get current color map"));
@@ -1307,19 +1292,18 @@ void us_printcolorvalue(INTSML ind)
  * amount of space to leave for the facet name is "maxlen" characters
  * (which is negative if dumping to a file).
  */
-char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
+char *us_makefacetline(NODEPROTO *np, INTBIG maxlen)
 {
 	char line[40];
-	REGISTER INTSML l, i, gooddrc, goodncc;
+	REGISTER INTBIG l, i, gooddrc, goodncc, len, total;
 	INTSML year, month, mday, hour, minute, second;
-	REGISTER INTBIG len, total;
 	REGISTER char *pt;
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 	REGISTER UINTBIG lastgooddate;
 
 	(void)initinfstr();
-	pt = nldescribenodeproto(np);
+	pt = describenodeproto(np);
 	(void)addstringtoinfstr(pt);
 	if (maxlen < 0) (void)addtoinfstr('\t'); else
 	{
@@ -1476,12 +1460,11 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
  */
 INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 {
-	REGISTER INTBIG i, count;
+	REGISTER INTBIG count;
 	char *par[10];
 	REGISTER LIBRARY *l;
 	extern COMCOMP us_quitp, us_yesnop;
 
-	i = 0;
 	for(l = el_curlib; l != NOLIBRARY; l = l->nextlibrary)
 	{
 		if ((l->userbits&HIDDENLIBRARY) != 0) continue;
@@ -1499,10 +1482,11 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
 				/* do nothing: ignoring the library changes */
+				/* EMPTY */ 
 			} else if (count > 0 && namesamen(par[0], "save", strlen(par[0])) == 0)
 			{
 				/* save the library */
-				(void)askaid(io_aid, "write", (INTBIG)l, (INTBIG)"binary");
+				(void)asktool(io_tool, "write", (INTBIG)l, (INTBIG)"binary");
 			} else
 			{
 				ttyputverbose(M_("Keep working"));
@@ -1515,7 +1499,7 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
 				/* save the library */
-				(void)askaid(io_aid, "write", (INTBIG)l, (INTBIG)"binary");
+				(void)asktool(io_tool, "write", (INTBIG)l, (INTBIG)"binary");
 			}
 		}
 	}
@@ -1529,6 +1513,7 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
 				/* do nothing: ignoring the option changes */
+				/* EMPTY */ 
 			} else if (count > 0 && namesamen(par[0], "save", strlen(par[0])) == 0)
 			{
 				/* save the options */
@@ -1551,6 +1536,10 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 	return(0);
 }
 
+/*
+ * Routine to save all options by creating a dummy library and saving it (without
+ * making options temporary first).
+ */
 void us_saveoptions(void)
 {
 	REGISTER INTBIG retval;
@@ -1565,11 +1554,12 @@ void us_saveoptions(void)
 		ttyputerr(_("Cannot create options library %s"), libfile);
 		return;
 	}
-	l->userbits |= READFROMDISK;
-	retval = askaid(io_aid, "write", (INTBIG)l, (INTBIG)"nobackupbinary");
+	l->userbits |= READFROMDISK | HIDDENLIBRARY;
+	retval = asktool(io_tool, "write", (INTBIG)l, (INTBIG)"nobackupbinary");
 	killlibrary(l);
 	if (retval != 0)
 		ttyputerr(_("Could not save options library"));
+	us_optionschanged = 0;
 }
 
 /*
@@ -1664,23 +1654,72 @@ INTSML us_getcolormapentry(char *pp, INTSML purpose)
  * for the string that is returned so this must be freed when done.
  */
 char *us_uniqueportname(char *name, NODEPROTO *facet)
+{
+	char *str;
+
+	str = us_uniqueobjectname(name, facet, VPORTPROTO, 0);
+
+	if (us_uniqueretstr != NOSTRING) efree(us_uniqueretstr);
+	(void)allocstring(&us_uniqueretstr, str, us_tool->cluster);
+	return(us_uniqueretstr);
+}
+
+/*
+ * Routine to determine whether the name "name" is unique in facet "facet"
+ * (given that it is on objects of type "type").  Does not consider object
+ * "exclude" (if nonzero).
+ */
+INTSML us_isuniquename(char *name, NODEPROTO *facet, INTBIG type, void *exclude)
 {
 	REGISTER PORTPROTO *pp;
+	REGISTER ARCINST *ai;
+	REGISTER NODEINST *ni;
+	REGISTER VARIABLE *var;
+
+	switch (type)
+	{
+		case VPORTPROTO:
+			for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			{
+				if (exclude != 0 && (PORTPROTO *)exclude == pp) continue;
+				if (namesame(name, pp->protoname) == 0) return(0);
+			}
+			break;
+		case VNODEINST:
+			for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			{
+				if (exclude != 0 && (NODEINST *)exclude == ni) continue;
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				if (var == NOVARIABLE) continue;
+				if (namesame(name, (char *)var->addr) == 0) return(0);
+			}
+			break;
+		case VARCINST:
+			for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			{
+				if (exclude != 0 && (ARCINST *)exclude == ai) continue;
+				var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+				if (var == NOVARIABLE) continue;
+				if (namesame(name, (char *)var->addr) == 0) return(0);
+			}
+			break;
+	}
+	return(1);
+}
+
+/*
+ * routine to return a unique object name in facet "facet" starting with the
+ * name "name".
+ */
+char *us_uniqueobjectname(char *name, NODEPROTO *facet, INTBIG type, void *exclude)
+{
 	char addon[10], *newname, *trailingpart;
 	REGISTER INTSML baselen, nextindex, i, adddash;
 
-	if (us_uniqueretstr != NOSTRING) efree(us_uniqueretstr);
-
 	/* first see if the name is unique */
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-		if (namesame(name, pp->protoname) == 0) break;
-	if (pp == NOPORTPROTO)
-	{
-		(void)allocstring(&us_uniqueretstr, name, us_aid->cluster);
-		return(us_uniqueretstr);
-	}
+	if (us_isuniquename(name, facet, type, exclude) != 0) return(name);
 
-	/* see if there is a number in the port name which can be incremented */
+	/* see if there is a number in the name which can be incremented */
 	baselen = strlen(name);
 	nextindex = 1;
 	trailingpart = 0;
@@ -1730,12 +1769,9 @@ char *us_uniqueportname(char *name, NODEPROTO *facet)
 		(void)addstringtoinfstr(addon);
 		if (trailingpart != 0) (void)addstringtoinfstr(trailingpart);
 		newname = returninfstr();
-		for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-			if (namesame(newname, pp->protoname) == 0) break;
-		if (pp == NOPORTPROTO) break;
+		if (us_isuniquename(newname, facet, type, 0) != 0) break;
 	}
-	(void)allocstring(&us_uniqueretstr, newname, us_aid->cluster);
-	return(us_uniqueretstr);
+	return(newname);
 }
 
 /*
@@ -1748,7 +1784,7 @@ void us_initlayerletters(void)
 	REGISTER TECHNOLOGY *t;
 
 	if (us_layer_letter_data != 0) efree((char *)us_layer_letter_data);
-	us_layer_letter_data = emalloc((el_maxtech * SIZEOFINTBIG), us_aid->cluster);
+	us_layer_letter_data = emalloc((el_maxtech * SIZEOFINTBIG), us_tool->cluster);
 	if (us_layer_letter_data == 0) return;
 	for(t = el_technologies; t != NOTECHNOLOGY; t = t->nexttechnology)
 	{
@@ -1779,63 +1815,63 @@ char *us_layerletters(TECHNOLOGY *tech, INTSML layer)
 }
 
 /*
- * routine to change an aid state.  The name of the aid is in "pt" (if "pt" is
- * null then an aid name is prompted).  The state of the aid is set to "state"
+ * routine to change an tool state.  The name of the tool is in "pt" (if "pt" is
+ * null then an tool name is prompted).  The state of the tool is set to "state"
  * (0 for off, 1 for permanently off, 2 for on, 3 for on without catchup).
  */
-void us_setaid(INTSML count, char *par[], INTSML state)
+void us_settool(INTSML count, char *par[], INTSML state)
 {
 	REGISTER INTSML i;
 	REGISTER char *pt;
-	extern COMCOMP us_onoffaidp;
-	REGISTER AIDENTRY *aid;
+	extern COMCOMP us_onofftoolp;
+	REGISTER TOOL *tool;
 
 	if (count == 0)
 	{
-		count = ttygetparam(M_("Which aid: "), &us_onoffaidp, MAXPARS, par);
+		count = ttygetparam(M_("Which tool: "), &us_onofftoolp, MAXPARS, par);
 		if (count == 0)
 		{
-			us_abortcommand(M_("Specify an aid to control"));
+			us_abortcommand(M_("Specify an tool to control"));
 			return;
 		}
 	}
 	pt = par[0];
 
-	for(i=0; i<el_maxaid; i++)
-		if (namesame(el_aids[i].aidname, pt) == 0) break;
-	if (i >= el_maxaid)
+	for(i=0; i<el_maxtools; i++)
+		if (namesame(el_tools[i].toolname, pt) == 0) break;
+	if (i >= el_maxtools)
 	{
-		us_abortcommand(_("No aid called %s"), pt);
+		us_abortcommand(_("No tool called %s"), pt);
 		return;
 	}
-	aid = &el_aids[i];
+	tool = &el_tools[i];
 
-	if (aid == us_aid && state <= 1)
+	if (tool == us_tool && state <= 1)
 	{
 		us_abortcommand(M_("No! I won't go!"));
 		return;
 	}
-	if ((aid->aidstate&AIDON) == 0 && state <= 1)
+	if ((tool->toolstate&TOOLON) == 0 && state <= 1)
 	{
 		ttyputverbose(M_("%s already off"), pt);
 		return;
 	}
-	if ((aid->aidstate&AIDON) != 0 && state > 1)
+	if ((tool->toolstate&TOOLON) != 0 && state > 1)
 	{
 		ttyputverbose(M_("%s already on"), pt);
 		return;
 	}
-	if (state <= 1) ttyputverbose(M_("%s turned off"), aid->aidname); else
+	if (state <= 1) ttyputverbose(M_("%s turned off"), tool->toolname); else
 	{
-		if ((aid->aidstate&AIDINCREMENTAL) == 0 || state == 3)
-			ttyputverbose(M_("%s turned on"), aid->aidname); else
-				ttyputmsg(_("%s turned on, catching up on changes..."), aid->aidname);
+		if ((tool->toolstate&TOOLINCREMENTAL) == 0 || state == 3)
+			ttyputverbose(M_("%s turned on"), tool->toolname); else
+				ttyputmsg(_("%s turned on, catching up on changes..."), tool->toolname);
 	}
 
-	if (state <= 1) aidturnoff(aid, state); else
+	if (state <= 1) toolturnoff(tool, state); else
 	{
-		if (state == 2) aidturnon(aid, 0); else aidturnon(aid, 1);
-		if ((aid->aidstate&AIDINCREMENTAL) != 0 && state != 3)
-			ttyputmsg(_("...%s caught up"), aid->aidname);
+		if (state == 2) toolturnon(tool, 0); else toolturnon(tool, 1);
+		if ((tool->toolstate&TOOLINCREMENTAL) != 0 && state != 3)
+			ttyputmsg(_("...%s caught up"), tool->toolname);
 	}
 }
