@@ -32,8 +32,8 @@
 #include "usr.h"
 #include "edialogs.h"
 
-INTBIG   us_ttymute = 0;				/* nonzero to supress unimportant messages */
-INTBIG	 us_ttyttywriteseparator = 0;	/* nonzero to write separator before next text */
+static INTBIG   us_ttymute = 0;				/* nonzero to supress unimportant messages */
+static INTBIG	 us_ttyttywriteseparator = 0;	/* nonzero to write separator before next text */
 
 /***************************** TERMINAL OUTPUT *****************************/
 
@@ -84,7 +84,7 @@ void ttyputverbose(char *msg, ...)
 	va_list ap;
 
 	/* ignore this message if facts are turned off */
-	if ((us_aid->aidstate&JUSTTHEFACTS) != 0) return;
+	if ((us_tool->toolstate&JUSTTHEFACTS) != 0) return;
 
 	/* don't print or save this message if muted */
 	if (us_ttymute != 0) return;
@@ -156,7 +156,7 @@ void us_abortcommand(char *msg, ...)
 	us_ttyprint(1, msg, ap);
 	va_end(ap);
 	us_state |= COMMANDFAILED;
-	if (getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding) != NOVARIABLE)
+	if (getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding) != NOVARIABLE)
 		ttyputmsg(_("Command ignored from macro definition"));
 	us_unknowncommand();
 }
@@ -169,7 +169,7 @@ void us_unknowncommand(void)
 {
 	REGISTER INTBIG i;
 
-	if ((us_aid->aidstate&NOKEYLOCK) != 0) return;
+	if ((us_tool->toolstate&NOKEYLOCK) != 0) return;
 	i = ttyquiet(0);
 	ttyputmsg(_("Single-key commands will be ignored until the next RETURN"));
 	(void)ttyquiet(i);
@@ -178,10 +178,10 @@ void us_unknowncommand(void)
 
 void us_abortedmsg(void)
 {
-	if ((us_aid->aidstate & JUSTTHEFACTS) == 0) us_abortcommand(_("Aborted")); else
+	if ((us_tool->toolstate & JUSTTHEFACTS) == 0) us_abortcommand(_("Aborted")); else
 	{
 		us_state |= COMMANDFAILED;
-		if (getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding) != NOVARIABLE)
+		if (getvalkey((INTBIG)us_tool, VTOOL, VSTRING, us_macrobuilding) != NOVARIABLE)
 			ttyputmsg(_("Command ignored from macro definition"));
 		us_unknowncommand();
 	}
@@ -199,14 +199,14 @@ INTSML ttygetchar(void)
 }
 
 /* ttygetline() Dialog */
-DIALOGITEM us_ttyinputdialogitems[] =
+static DIALOGITEM us_ttyinputdialogitems[] =
 {
  /*  1 */ {0, {96,200,120,264}, BUTTON, N_("OK")},
  /*  2 */ {0, {96,24,120,88}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {58,38,74,246}, EDITTEXT, ""},
  /*  4 */ {0, {3,9,51,281}, MESSAGE, ""}
 };
-DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 0, 4, us_ttyinputdialogitems};
+static DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 0, 4, us_ttyinputdialogitems};
 
 /* special items for the "ttygetline" dialog: */
 #define DGTL_LINE     3		/* line (edit text) */
@@ -289,7 +289,7 @@ void us_ttyprint(INTSML important, char *msg, va_list ap)
 	}
 
 	/* build the output line */
-	(void)vsprintf(line, msg, ap);
+	evsnprintf(line, 8192, msg, ap);
 
 	/* remove excessive trailing space */
 	i = strlen(line);
