@@ -2,7 +2,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: usrwindow.c
- * User interface aid: public graphics routines
+ * User interface tool: public graphics routines
  * Written by: Steven M. Rubin, Static Free Software
  *
  * Copyright (c) 2000 Static Free Software.
@@ -51,13 +51,13 @@ typedef struct Iredraw
 	struct Iredraw *nextredraw;			/* next in list */
 } REDRAW;
 
-REDRAW    *us_redrawfree = NOREDRAW;	/* free list of re-draw modules */
-REDRAW    *us_firstredraw = NOREDRAW;	/* first in list of active re-draw modules */
-REDRAW    *us_firstopaque = NOREDRAW;	/* first in list of active opaque re-draws */
-REDRAW    *us_usedredraw = NOREDRAW;	/* first in list of used re-draw modules */
+static REDRAW    *us_redrawfree = NOREDRAW;	/* free list of re-draw modules */
+static REDRAW    *us_firstredraw = NOREDRAW;	/* first in list of active re-draw modules */
+static REDRAW    *us_firstopaque = NOREDRAW;	/* first in list of active opaque re-draws */
+static REDRAW    *us_usedredraw = NOREDRAW;	/* first in list of used re-draw modules */
 
-REDRAW *us_allocredraw(void);
-void us_freeredraw(REDRAW*);
+static REDRAW *us_allocredraw(void);
+static void us_freeredraw(REDRAW*);
 
 /***** 3D DISPLAY *****/
 
@@ -75,27 +75,28 @@ typedef struct
 	float    *x, *y, *z;
 } POLY3D;
 
-INTSML      us_3dgatheringpolys = 0;
-INTBIG      us_3dpolycount;
-INTBIG      us_3dpolytotal = 0;
-POLY3D    **us_3dpolylist;
-WINDOWPART *us_3dwindowpart;
+static INTSML      us_3dgatheringpolys = 0;
+static INTBIG      us_3dpolycount;
+static INTBIG      us_3dpolytotal = 0;
+static POLY3D    **us_3dpolylist;
+static WINDOWPART *us_3dwindowpart;
 
 /* interaction information */
-INTSML      us_3dinteraction = ROTATEVIEW;
-INTBIG      us_3dinitialbutx, us_3dinitialbuty;
-INTBIG      us_3dlastbutx, us_3dlastbuty;
-float       us_3dinitialfov;
-float       us_3dcenterx, us_3dcentery, us_3dcenterz;
-float       us_3dlowx, us_3dhighx, us_3dlowy, us_3dhighy, us_3dlowz, us_3dhighz;
+static INTSML      us_3dinteraction = ROTATEVIEW;
+static INTBIG      us_3dinitialbuty;
+static INTBIG      us_3dlastbutx, us_3dlastbuty;
+static float       us_3dinitialfov;
+static float       us_3dcenterx, us_3dcentery, us_3dcenterz;
+static float       us_3dlowx, us_3dhighx, us_3dlowy, us_3dhighy, us_3dlowz, us_3dhighz;
 
-INTSML us_3deachdown(INTBIG x, INTBIG y);
 INTSML us_nullup(INTBIG, INTBIG);
 void us_nullvoid(void);
 INTSML us_nullchar(INTBIG, INTBIG, INTSML);
-void us_3dbuildtransform(XFORM3D *xf3);
-void us_3drender(WINDOWPART *w);
-POLY3D *us_3dgetnextpoly(INTBIG count);
+static INTSML us_3deachdown(INTBIG x, INTBIG y);
+static void us_3dbuildtransform(XFORM3D *xf3);
+static void us_3drender(WINDOWPART *w);
+static POLY3D *us_3dgetnextpoly(INTBIG count);
+static int us_3dpolydepthascending(const void *e1, const void *e2);
 
 /***** MISCELLANEOUS *****/
 
@@ -110,14 +111,15 @@ POLY3D *us_3dgetnextpoly(INTBIG count);
 extern GRAPHICS us_ebox;
 
 /* prototypes for local routines */
-INTSML us_showin(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTSML, INTSML);
-void us_queuevicinity(GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-INTSML us_showthispoly(POLYGON*, WINDOWPART*);
+static INTSML us_showin(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTSML, INTSML);
+static void us_queuevicinity(GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void us_wanttodrawo(INTBIG, INTSML, INTBIG, INTSML, INTBIG, INTSML, INTBIG, INTSML, WINDOWPART*, GRAPHICS*, INTSML);
+static void us_drawextendedpolyline(POLYGON*, WINDOWPART*);
+static INTSML us_writetext(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*, char*, UINTBIG*, WINDOWPART*, TECHNOLOGY*);
+static void us_reverse(POLYGON*);
+
+/* external prototypes */
 void us_wanttodraw(INTBIG, INTBIG, INTBIG, INTBIG, WINDOWPART*, GRAPHICS*, INTSML);
-void us_wanttodrawo(INTBIG, INTSML, INTBIG, INTSML, INTBIG, INTSML, INTBIG, INTSML, WINDOWPART*, GRAPHICS*, INTSML);
-void us_drawextendedpolyline(POLYGON*, WINDOWPART*);
-INTSML us_writetext(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*, char*, INTBIG, WINDOWPART*);
-void us_reverse(POLYGON*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -175,7 +177,7 @@ void us_erasewindow(WINDOWPART *w)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	maketruerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 	poly->desc = &us_ebox;
@@ -223,7 +225,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		oldstate = oldw->state;
 		location = oldw->location;
 	}
-	startobjectchange((INTBIG)us_aid, VAID);
+	startobjectchange((INTBIG)us_tool, VTOOL);
 
 	if (newframe == 0)
 	{
@@ -273,7 +275,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 
 		/* load the text into the window */
 		us_suspendgraphics(neww);
-		l = (INTSML)getlength(var);
+		l = getlength(var);
 		for(i=0; i<l; i++)
 		{
 			thisline = ((char **)var->addr)[i];
@@ -363,8 +365,8 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 	}
 
 	(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)cur, VNODEPROTO);
-	endobjectchange((INTBIG)us_aid, VAID);
-	(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
+	endobjectchange((INTBIG)us_tool, VTOOL);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
 }
 
 /*
@@ -386,6 +388,7 @@ void us_ensurepropertechnology(NODEPROTO *facet, char *forcedtechnology, INTSML
 	if ((facet->cellview->viewstate&TEXTVIEW) != 0) return;
 	tech = facet->tech;
 	if (tech == gen_tech) return;
+	if ((tech->userbits&NOPRIMTECHNOLOGY) != 0) return;
 
 	/* switch technologies */
 	lastframe = getwindowframe(1);
@@ -805,7 +808,7 @@ REDRAW *us_allocredraw(void)
 
 	if (us_redrawfree == NOREDRAW)
 	{
-		r = (REDRAW *)emalloc(sizeof (REDRAW), us_aid->cluster);
+		r = (REDRAW *)emalloc(sizeof (REDRAW), us_tool->cluster);
 		if (r == 0) return(NOREDRAW);
 	} else
 	{
@@ -951,7 +954,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 			}
 
 			/* copy the polygon since it will be mangled when clipped */
-			if (objc == NOPOLYGON) objc = allocstaticpolygon(obj->count, us_aid->cluster); else
+			if (objc == NOPOLYGON) objc = allocstaticpolygon(obj->count, us_tool->cluster); else
 				if (objc->limit < obj->count) (void)extendpolygon(objc, obj->count);
 			objc->count = obj->count;
 			objc->style = obj->style;
@@ -995,7 +998,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 		case CROSSED:		/* polygon outline with cross */
 			us_wanttodraw(obj->xv[0], obj->yv[0], obj->xv[2], obj->yv[2], w, gra, 0);
 			us_wanttodraw(obj->xv[1], obj->yv[1], obj->xv[3], obj->yv[3], w, gra, 0);
-			/* fall into the next case */
+			/* FALLTHROUGH */ 
 
 		case CLOSED:		/* closed polygon outline */
 			for(i=0; i<obj->count; i++)
@@ -1060,8 +1063,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 			ly = applyyscale(w, ly-w->screenly) + w->usely;
 			ux = applyxscale(w, ux-w->screenlx) + w->uselx;
 			uy = applyyscale(w, uy-w->screenly) + w->usely;
-			i = truefontsize(obj->font, w, obj->tech);
-			screensettextsize(w, i);
+			screensettextinfo(w, obj->tech, obj->textdescript);
 			screengettextsize(w, obj->string, &tsx, &tsy);
 			switch (obj->style)
 			{
@@ -1110,8 +1112,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 		case TEXTBOX:		/* text centered and contained in box */
 			getbbox(obj, &lx, &ux, &ly, &uy);
 			if (us_makescreen(&lx, &ly, &ux, &uy, w)) return(1);
-			return(us_writetext(lx,ux, ly,uy, gra, obj->string,
-				truefontsize(obj->font, w, obj->tech), w));
+			return(us_writetext(lx, ux, ly, uy, gra, obj->string, obj->textdescript, w, obj->tech));
 
 		case CIRCLE:   case DISC:   case CIRCLEARC:
 			/* must scale the window for best precision when drawing curves */
@@ -1126,7 +1127,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 			computewindowscale(&wsc);
 
 			/* get copy polygon */
-			if (objc == NOPOLYGON) objc = allocstaticpolygon(obj->count, us_aid->cluster); else
+			if (objc == NOPOLYGON) objc = allocstaticpolygon(obj->count, us_tool->cluster); else
 				if (objc->limit < obj->count) (void)extendpolygon(objc, obj->count);
 
 			/* transform and copy the polygon */
@@ -1303,26 +1304,38 @@ void us_drawextendedpolyline(POLYGON *obj, WINDOWPART *w)
  * will fit.
  */
 INTSML us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc, char *txt,
-	INTBIG initialfont, WINDOWPART *win)
+	UINTBIG *initdescript, WINDOWPART *win, TECHNOLOGY *tech)
 {
-	REGISTER INTBIG stop, save, font, xfont, yfont;
+	REGISTER INTBIG stop, save, xabssize, yabssize, abssize, newsize, oldsize;
 	INTSML six, siy;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/* scan for a font that fits */
-	if (initialfont < 4) initialfont = 4;
-	for(font = initialfont; font >= 4; font--)
+	TDCOPY(descript, initdescript);
+	for(;;)
 	{
-		screensettextsize(win, font);
+		screensettextinfo(win, tech, descript);
 		screengettextsize(win, txt, &six, &siy);
 		if (six <= ux-lx && siy <= uy-ly) break;
 
-		/* jump quickly to the proper font size */
-		if (six <= ux-lx) xfont = font; else
-			xfont = font * (ux-lx) / six;
-		if (siy <= uy-ly) yfont = font; else
-			yfont = font * (uy-ly) / siy;
-		font = mini(xfont, yfont);
-		if (font < 4) font = 4;
+		oldsize = TDGETSIZE(descript);
+		abssize = TXTGETPOINTS(oldsize);
+		if (abssize != 0)
+		{
+			/* jump quickly to the proper font size */
+			if (six <= ux-lx) xabssize = abssize; else
+				xabssize = abssize * (ux-lx) / six;
+			if (siy <= uy-ly) yabssize = abssize; else
+				yabssize = abssize * (uy-ly) / siy;
+			newsize = mini(xabssize, yabssize);
+			if (newsize < 4) return(0);
+			TDSETSIZE(descript, TXTSETPOINTS(newsize));
+		} else
+		{
+			newsize = TXTGETQLAMBDA(TDGETSIZE(descript)) - 1;
+			if (newsize <= 0) return(0);
+			TDSETSIZE(descript, TXTSETQLAMBDA(newsize));
+		}
 	}
 
 	/* if the text doesn't fit in Y, quit */
@@ -1617,35 +1630,32 @@ void us_3dstartdrawing(WINDOWPART *win)
 	us_3dwindowpart = win;
 }
 
+/*
+ * Helper routine for "us_3denddrawing()" that makes polygon depth go in ascending order
+ */
+int us_3dpolydepthascending(const void *e1, const void *e2)
+{
+	REGISTER POLY3D *c1, *c2;
+
+	c1 = *((POLY3D **)e1);
+	c2 = *((POLY3D **)e2);
+	return(c1->depth - c2->depth);
+}
+
 /*
  * Routine called at the end of drawing.
  */
 void us_3denddrawing(void)
 {
-	REGISTER POLY3D *poly1, *poly2;
-	REGISTER INTBIG sorted, i, j;
+	REGISTER POLY3D *poly1;
+	REGISTER INTBIG i, j;
 
 	/* flush the opaque graphics out */
 	us_endchanges(NOWINDOWPART);
 	us_3dgatheringpolys = 0;
 
 	/* sort the polygons */
-	sorted = 0;
-	while (sorted == 0)
-	{
-		sorted = 1;
-		for(i=1; i<us_3dpolycount; i++)
-		{
-			poly1 = us_3dpolylist[i-1];
-			poly2 = us_3dpolylist[i];
-			if (poly1->depth > poly2->depth)
-			{
-				us_3dpolylist[i-1] = poly2;
-				us_3dpolylist[i] = poly1;
-				sorted = 0;
-			}
-		}
-	}
+	esort(us_3dpolylist, us_3dpolycount, sizeof (POLY3D *), us_3dpolydepthascending);
 
 	/* determine bounding volume */
 	for(i=0; i<us_3dpolycount; i++)
@@ -1693,7 +1703,7 @@ void us_3drender(WINDOWPART *w)
 	REGISTER XFORM3D *xf3;
 
 	xf3 = &w->xf3;
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_tool->cluster);
 
 	/* clear the screen */
 	us_erasewindow(w);
@@ -1794,7 +1804,7 @@ void us_3dbuttonhandler(WINDOWPART *w, INTSML but, INTSML x, INTSML y)
 		return;
 	}
 	xf3 = &w->xf3;
-	us_3dlastbutx = us_3dinitialbutx = x;
+	us_3dlastbutx = x;
 	us_3dlastbuty = us_3dinitialbuty = y;
 	switch (us_3dinteraction)
 	{
@@ -2099,13 +2109,13 @@ POLY3D *us_3dgetnextpoly(INTBIG count)
 		newtotal = us_3dpolytotal * 2;
 		if (newtotal <= 0) newtotal = 50;
 		if (us_3dpolycount > newtotal) newtotal = us_3dpolycount;
-		newlist = (POLY3D **)emalloc(newtotal * (sizeof (POLY3D *)), us_aid->cluster);
+		newlist = (POLY3D **)emalloc(newtotal * (sizeof (POLY3D *)), us_tool->cluster);
 		if (newlist == 0) return(0);
 		for(i=0; i<us_3dpolytotal; i++)
 			newlist[i] = us_3dpolylist[i];
 		for(i=us_3dpolytotal; i<newtotal; i++)
 		{
-			newlist[i] = (POLY3D *)emalloc(sizeof (POLY3D), us_aid->cluster);
+			newlist[i] = (POLY3D *)emalloc(sizeof (POLY3D), us_tool->cluster);
 			if (newlist[i] == 0) return(0);
 			newlist[i]->total = 0;
 		}
@@ -2123,11 +2133,11 @@ POLY3D *us_3dgetnextpoly(INTBIG count)
 			efree((char *)poly3d->z);
 		}
 		poly3d->total = 0;
-		poly3d->x = (float *)emalloc(count * (sizeof (float)), us_aid->cluster);
+		poly3d->x = (float *)emalloc(count * (sizeof (float)), us_tool->cluster);
 		if (poly3d->x == 0) return(0);
-		poly3d->y = (float *)emalloc(count * (sizeof (float)), us_aid->cluster);
+		poly3d->y = (float *)emalloc(count * (sizeof (float)), us_tool->cluster);
 		if (poly3d->y == 0) return(0);
-		poly3d->z = (float *)emalloc(count * (sizeof (float)), us_aid->cluster);
+		poly3d->z = (float *)emalloc(count * (sizeof (float)), us_tool->cluster);
 		if (poly3d->z == 0) return(0);
 		poly3d->total = count;
 	}
