@@ -31,7 +31,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "efunction.h"
@@ -59,7 +59,7 @@
 #define BLOCKFLOPTR  11		/* a resettable T flip-flop */
 #define BLOCKFLOP    12		/* a general flip-flop */
 
-/* the VHDL compiler aid table */
+/* the VHDL compiler tool table */
 static KEYWORD vhdloutputopt[] =
 {
 	{"netlisp",     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -188,64 +188,64 @@ static VKEYWORD vhdl_keywords[] =
 	{"xor",				KEY_XOR}
 };
 
-IDENTTABLE        *vhdl_identtable = 0;
-TOKENLIST         *vhdl_tliststart, *vhdl_tlistend;
-INTBIG             vhdl_externentities;		/* enternal entities flag */
-INTBIG             vhdl_warnflag;			/* warning flag, TRUE warn */
-INTSML             vhdl_genequations;		/* nonzero to generate VHDL equations */
-INTBIG             vhdl_vhdlondisk;			/* cached key for "VHDL_vhdl_on_disk" */
-INTBIG             vhdl_netlistondisk;		/* cached key for "VHDL_netlist_on_disk" */
-INTBIG             vhdl_target;				/* Current simulator */
-LIBRARY           *vhdl_lib;				/* behavioral library */
-FILE              *vhdl_fp;					/* current file */
-VARIABLE          *vhdl_var;				/* current variable */
-INTBIG             vhdl_linecount;			/* current line number */
-NODEPROTO         *vhdl_facet;				/* current output facet */
+static IDENTTABLE *vhdl_identtable = 0;
+static TOKENLIST  *vhdl_tliststart;
+static TOKENLIST  *vhdl_tlistend;
+       INTBIG      vhdl_externentities;		/* enternal entities flag */
+       INTBIG      vhdl_warnflag;			/* warning flag, TRUE warn */
+static INTSML      vhdl_genequations;		/* nonzero to generate VHDL equations */
+static INTBIG      vhdl_vhdlondisk;			/* cached key for "VHDL_vhdl_on_disk" */
+static INTBIG      vhdl_netlistondisk;		/* cached key for "VHDL_netlist_on_disk" */
+       INTBIG      vhdl_target;				/* Current simulator */
+static LIBRARY    *vhdl_lib;				/* behavioral library */
+static FILE       *vhdl_fp;					/* current file */
+static VARIABLE   *vhdl_var;				/* current variable */
+static INTBIG      vhdl_linecount;			/* current line number */
+static NODEPROTO  *vhdl_facet;				/* current output facet */
 extern INTBIG      vhdl_errorcount;
 extern SYMBOLLIST *vhdl_gsymbols;
-AIDENTRY          *vhdl_aid;
-void              *vhdl_componentarray = 0;
-void              *vhdl_stringarray;
-UNRESLIST         *vhdl_unresolved_list = 0;
+       TOOL       *vhdl_tool;
+static void       *vhdl_componentarray = 0;
+static void       *vhdl_stringarray;
+       UNRESLIST  *vhdl_unresolved_list = 0;
 
 /* prototypes for local routines */
-void      vhdl_addportlist(NODEINST*, NODEPROTO*, INTSML);
-void      vhdl_addrealports(NODEINST *ni, INTSML special);
-void      vhdl_addstring(char*);
-void      vhdl_addtheseports(NODEINST*, NODEPROTO*, INTBIG, char*);
-void      vhdl_compile(NODEPROTO*);
-void      vhdl_convertfacet(NODEPROTO*, INTSML);
-INTBIG    vhdl_endinput(void);
-INTBIG    vhdl_endoutput(void);
-void      vhdl_freescannermemory(void);
-INTSML    vhdl_generatevhdl(NODEPROTO *np);
-UINTBIG   vhdl_getfacetdate(NODEPROTO *np);
-void      vhdl_getnetlistfactors(char**, char**);
-INTBIG    vhdl_getnextline(char*);
-INTBIG    vhdl_identfirsthash(char*);
-INTBIG    vhdl_identsecondhash(char*, INTBIG);
-VKEYWORD *vhdl_iskeyword(char*, INTBIG);
-void      vhdl_makechartoken(char, INTBIG, INTBIG);
-void      vhdl_makedecimaltoken(char*, INTBIG, INTBIG, INTBIG);
-void      vhdl_makeidenttoken(char*, INTBIG, INTBIG, INTBIG);
-void      vhdl_makekeytoken(VKEYWORD*, INTBIG, INTBIG);
-INTSML    vhdl_morerecentcontents(NODEPROTO*, UINTBIG);
-void      vhdl_makestrtoken(char*, INTBIG, INTBIG, INTBIG);
-void      vhdl_maketoken(INTBIG, INTBIG, INTBIG);
-void      vhdl_optionsdlog(void);
-char     *vhdl_primname(NODEINST*, INTSML*);
-INTSML    vhdl_propernetlist(NODEPROTO*, char*);
-void      vhdl_scanner(void);
-INTBIG    vhdl_startinput(NODEPROTO*, INTBIG, INTSML, char**, UINTBIG*);
-INTSML    vhdl_startoutput(NODEPROTO*, INTBIG, INTSML, char**);
-char      vhdl_toupper(char);
+static void      vhdl_addportlist(NODEINST*, NODEPROTO*, INTSML);
+static void      vhdl_addrealports(NODEINST *ni, INTSML special);
+static void      vhdl_addstring(char*, NODEPROTO*);
+static void      vhdl_addtheseports(NODEINST*, NODEPROTO*, INTBIG, char*);
+static void      vhdl_compile(NODEPROTO*);
+static void      vhdl_convertfacet(NODEPROTO*, INTSML);
+static INTBIG    vhdl_endinput(void);
+static INTBIG    vhdl_endoutput(void);
+static void      vhdl_freescannermemory(void);
+static INTSML    vhdl_generatevhdl(NODEPROTO *np);
+static UINTBIG   vhdl_getfacetdate(NODEPROTO *np);
+static INTBIG    vhdl_getnextline(char*);
+static INTBIG    vhdl_identfirsthash(char*);
+static INTBIG    vhdl_identsecondhash(char*, INTBIG);
+static VKEYWORD *vhdl_iskeyword(char*, INTBIG);
+static void      vhdl_makechartoken(char, INTBIG, INTBIG);
+static void      vhdl_makedecimaltoken(char*, INTBIG, INTBIG, INTBIG);
+static void      vhdl_makeidenttoken(char*, INTBIG, INTBIG, INTBIG);
+static void      vhdl_makekeytoken(VKEYWORD*, INTBIG, INTBIG);
+static INTSML    vhdl_morerecentcontents(NODEPROTO*, UINTBIG);
+static void      vhdl_makestrtoken(char*, INTBIG, INTBIG, INTBIG);
+static void      vhdl_maketoken(INTBIG, INTBIG, INTBIG);
+static INTBIG    vhdl_netexported(NETWORK *net);
+static void      vhdl_optionsdlog(void);
+static char     *vhdl_primname(NODEINST*, INTSML*);
+static void      vhdl_scanner(void);
+static INTBIG    vhdl_startinput(NODEPROTO*, INTBIG, INTSML, char**, UINTBIG*);
+static INTSML    vhdl_startoutput(NODEPROTO*, INTBIG, INTSML, char**);
+static char      vhdl_toupper(char);
 
-void vhdl_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
+void vhdl_init(INTBIG *argc, char *argv[], TOOL *thistool)
 {
 	/* only initialize during pass 1 */
-	if (thisaid == NOAID || thisaid == 0) return;
+	if (thistool == NOTOOL || thistool == 0) return;
 
-	vhdl_aid = thisaid;
+	vhdl_tool = thistool;
 	vhdl_target = TARGET_QUISC;
 	vhdl_externentities = TRUE;
 	vhdl_warnflag = FALSE;
@@ -258,12 +258,14 @@ void vhdl_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 
 void vhdl_done(void)
 {
+#ifdef DEBUGMEMORY
 	if (vhdl_componentarray != 0) killstringarray(vhdl_componentarray);
 	vhdl_freescannermemory();
 	if (vhdl_identtable != 0) efree((char *)vhdl_identtable);
 	vhdl_freeparsermemory();
 	vhdl_freesemantic();
 	vhdl_freeunresolvedlist(&vhdl_unresolved_list);
+#endif
 }
 
 INTSML vhdl_set(INTSML count, char *par[])
@@ -322,7 +324,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputusage("tellaid vhdl-compiler library LIBRARY");
+			ttyputusage("telltool vhdl-compiler library LIBRARY");
 			return(0);
 		}
 		vhdl_lib = getlibrary(par[1]);
@@ -337,14 +339,14 @@ INTSML vhdl_set(INTSML count, char *par[])
 
 	if (namesamen(pp, "vhdl-on-disk", l) == 0)
 	{
-		setvalkey((INTBIG)vhdl_aid, VAID, vhdl_vhdlondisk, 1, VINTEGER);
+		setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_vhdlondisk, 1, VINTEGER);
 		ttyputverbose(M_("VHDL will be kept in separate disk files"));
 		return(0);
 	}
 
 	if (namesamen(pp, "netlist-on-disk", l) == 0)
 	{
-		setvalkey((INTBIG)vhdl_aid, VAID, vhdl_netlistondisk, 1, VINTEGER);
+		setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_netlistondisk, 1, VINTEGER);
 		ttyputverbose(M_("Netlists will be kept in separate disk files"));
 		return(0);
 	}
@@ -374,7 +376,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputusage("tellaid vhdl-compiler not OPTION");
+			ttyputusage("telltool vhdl-compiler not OPTION");
 			return(0);
 		}
 		l = strlen(pp = par[1]);
@@ -392,13 +394,13 @@ INTSML vhdl_set(INTSML count, char *par[])
 		}
 		if (namesamen(pp, "vhdl-on-disk", l) == 0)
 		{
-			setvalkey((INTBIG)vhdl_aid, VAID, vhdl_vhdlondisk, 0, VINTEGER);
+			setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_vhdlondisk, 0, VINTEGER);
 			ttyputverbose(M_("VHDL will be kept in facets"));
 			return(0);
 		}
 		if (namesamen(pp, "netlist-on-disk", l) == 0)
 		{
-			setvalkey((INTBIG)vhdl_aid, VAID, vhdl_netlistondisk, 0, VINTEGER);
+			setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_netlistondisk, 0, VINTEGER);
 			ttyputverbose(M_("Netlists will be kept in facets"));
 			return(0);
 		}
@@ -408,7 +410,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 			ttyputverbose(M_("VHDL generation will use logic block calls instead of equations"));
 			return(0);
 		}
-		ttyputbadusage("tellaid vhdl-compiler not");
+		ttyputbadusage("telltool vhdl-compiler not");
 		return(0);
 	}
 
@@ -416,7 +418,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputusage("tellaid vhdl-compiler output-format FORMAT");
+			ttyputusage("telltool vhdl-compiler output-format FORMAT");
 			return(0);
 		}
 		l = strlen(pp = par[1]);
@@ -450,11 +452,11 @@ INTSML vhdl_set(INTSML count, char *par[])
 			ttyputverbose(M_("VHDL compiles to RSIM simulation"));
 			return(0);
 		}
-		ttyputbadusage("tellaid vhdl-compiler output-format");
+		ttyputbadusage("telltool vhdl-compiler output-format");
 		return(0);
 	}
 
-	ttyputbadusage("tellaid vhdl-compiler");
+	ttyputbadusage("telltool vhdl-compiler");
 	return(0);
 }
 
@@ -466,18 +468,18 @@ void vhdl_slice(void)
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a cell"));
-		aidturnoff(vhdl_aid, 0);
+		toolturnoff(vhdl_tool, 0);
 		return;
 	}
 
 	vhdl_compile(np);
 
-	aidturnoff(vhdl_aid, 0);
+	toolturnoff(vhdl_tool, 0);
 	ttyputmsg(_("VHDL compiler turned off"));
 }
 
 /*
- * make requests of the VHDL aid:
+ * make requests of the VHDL tool:
  *  "begin-vhdl-input" TAKES: facet, string for source  RETURNS: nonzero on error
  *  "begin-netlist-input" TAKES: facet, filetype, string for source
  *                        RETURNS: nonzero on error
@@ -502,10 +504,10 @@ INTBIG vhdl_request(char *command, va_list ap)
 	REGISTER NODEPROTO *np, *orignp;
 	REGISTER VIEW *view;
 
-	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_vhdlondisk);
+	var = getvalkey((INTBIG)vhdl_tool, VTOOL, VINTEGER, vhdl_vhdlondisk);
 	if (var == NOVARIABLE) vhdlondisk = 0; else
 		vhdlondisk = (INTSML)var->addr;
-	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_netlistondisk);
+	var = getvalkey((INTBIG)vhdl_tool, VTOOL, VINTEGER, vhdl_netlistondisk);
 	if (var == NOVARIABLE) netlistondisk = 0; else
 		netlistondisk = (INTSML)var->addr;
 
@@ -701,6 +703,9 @@ INTSML vhdl_morerecentcontents(NODEPROTO *np, UINTBIG dateoffile)
 	{
 		subnp = ni->proto;
 		if (subnp->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (subnp->cell == np->cell) continue;
 		if (subnp->cellview == el_iconview)
 		{
 			subnp = contentsview(subnp);
@@ -806,6 +811,7 @@ INTBIG vhdl_endinput(void)
 INTBIG vhdl_getnextline(char *addr)
 {
 	INTSML ret;
+	REGISTER char *line;
 
 	if (vhdl_fp != 0)
 	{
@@ -814,7 +820,17 @@ INTBIG vhdl_getnextline(char *addr)
 	} else if (vhdl_var != NOVARIABLE)
 	{
 		if (vhdl_linecount >= getlength(vhdl_var)) return(0);
-		(void)strcpy(addr, ((char **)vhdl_var->addr)[vhdl_linecount]);
+		line = ((char **)vhdl_var->addr)[vhdl_linecount];
+		if (strlen(line) >= MAXVHDLLINE)
+		{
+			ttyputerr(_("Error: line %ld longer than limit of %d characters"),
+				vhdl_linecount+1, MAXVHDLLINE);
+			strncpy(addr, line, MAXVHDLLINE-1);
+			addr[MAXVHDLLINE] = 0;
+		} else
+		{
+			(void)strcpy(addr, line);
+		}
 	} else return(0);
 	vhdl_linecount++;
 	return(vhdl_linecount);
@@ -884,7 +900,7 @@ INTSML vhdl_startoutput(NODEPROTO *np, INTBIG filetype, INTSML diskflag, char **
 		*intended = returninfstr();
 		vhdl_facet = newnodeproto(&(*intended)[6], np->cell->lib);
 		if (vhdl_facet == NONODEPROTO) return(1);
-		vhdl_stringarray = newstringarray(vhdl_aid->cluster);
+		vhdl_stringarray = newstringarray(vhdl_tool->cluster);
 	}
 	return(0);
 }
@@ -914,7 +930,7 @@ void vhdl_printoneline(char *fstring, ...)
 	va_list ap;
 
 	var_start(ap, fstring);
-	(void)vsprintf(buff, fstring, ap);
+	evsnprintf(buff, 4000, fstring, ap);
 	va_end(ap);
 	if (vhdl_fp == 0) addtostringarray(vhdl_stringarray, buff); else
 		xprintf(vhdl_fp, "%s\n", buff);
@@ -930,7 +946,7 @@ void vhdl_print(char *fstring, ...)
 	va_list ap;
 
 	var_start(ap, fstring);
-	(void)vsprintf(buff, fstring, ap);
+	evsnprintf(buff, 4000, fstring, ap);
 	va_end(ap);
 	sptr = buff;
 	while (strlen(sptr) > 70)
@@ -964,6 +980,9 @@ UINTBIG vhdl_getfacetdate(NODEPROTO *np)
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
 		subfacetdate = vhdl_getfacetdate(ni->proto);
 		if (subfacetdate > mostrecent) mostrecent = subfacetdate;
 	}
@@ -994,7 +1013,7 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 		return;
 	}
 
-	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_vhdlondisk);
+	var = getvalkey((INTBIG)vhdl_tool, VTOOL, VINTEGER, vhdl_vhdlondisk);
 	if (var == NOVARIABLE) vhdlondisk = 0; else
 		vhdlondisk = (INTSML)var->addr;
 
@@ -1076,8 +1095,8 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 
 	/* make sure that all nodes have names on them */
 	backannotate = 0;
-	if (askaid(net_aid, "name-nodes", (INTBIG)np) != 0) backannotate++;
-	if (askaid(net_aid, "name-nets", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, "name-nets", (INTBIG)np) != 0) backannotate++;
 
 	/* indicate the source of this VHDL */
 	(void)initinfstr();
@@ -1088,7 +1107,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	/* build the "entity" line */
 	(void)initinfstr();
 	(void)addstringtoinfstr("entity ");
-	vhdl_addstring(np->cell->cellname);
+	vhdl_addstring(np->cell->cellname, NONODEPROTO);
 	(void)addstringtoinfstr(" is port(");
 	vhdl_addportlist(NONODEINST, np, 0);
 	(void)addstringtoinfstr(");");
@@ -1097,16 +1116,16 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	/* add the "end" line */
 	(void)initinfstr();
 	(void)addstringtoinfstr("  end ");
-	vhdl_addstring(np->cell->cellname);
+	vhdl_addstring(np->cell->cellname, NONODEPROTO);
 	(void)addstringtoinfstr(";");
 	vhdl_print(returninfstr());
 
 	/* now write the "architecture" line */
 	(void)initinfstr();
 	(void)addstringtoinfstr("architecture ");
-	vhdl_addstring(np->cell->cellname);
+	vhdl_addstring(np->cell->cellname, NONODEPROTO);
 	(void)addstringtoinfstr("_BODY of ");
-	vhdl_addstring(np->cell->cellname);
+	vhdl_addstring(np->cell->cellname, NONODEPROTO);
 	(void)addstringtoinfstr(" is");
 	vhdl_print(returninfstr());
 
@@ -1123,7 +1142,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	for(i=0; i<=MAXINPUTS; i++) gotnand[i] = gotnor[i] = gotxnor[i] = 0;
 	if (vhdl_componentarray == 0)
 	{
-		vhdl_componentarray = newstringarray(vhdl_aid->cluster);
+		vhdl_componentarray = newstringarray(vhdl_tool->cluster);
 		if (vhdl_componentarray == 0) return(backannotate);
 	}
 	clearstrings(vhdl_componentarray);
@@ -1132,6 +1151,11 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	gotinverters = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
+		if (ni->proto->primindex == 0)
+		{
+			/* ignore recursive references (showing icon in contents) */
+			if (ni->proto->cell == np->cell) continue;
+		}
 		pt = vhdl_primname(ni, &special);
 		if (pt[0] == 0) continue;
 
@@ -1181,7 +1205,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 
 		(void)initinfstr();
 		(void)addstringtoinfstr("  component ");
-		vhdl_addstring(pt);
+		vhdl_addstring(pt, NONODEPROTO);
 		(void)addstringtoinfstr(" port(");
 		vhdl_addportlist(ni, ni->proto, special);
 		(void)addstringtoinfstr(");");
@@ -1207,13 +1231,13 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 		{
 			(void)initinfstr();
 			(void)addstringtoinfstr("  component nand");
-			(void)sprintf(line, "%d", i);
+			(void)sprintf(line, "%ld", i);
 			(void)addstringtoinfstr(line);
 			(void)addstringtoinfstr(" port(");
 			for(j=1; j<=i; j++)
 			{
 				if (j > 1) (void)addstringtoinfstr(", ");
-				(void)sprintf(line, "a%d", j);
+				(void)sprintf(line, "a%ld", j);
 				(void)addstringtoinfstr(line);
 			}
 			(void)addstringtoinfstr(": in BIT; y: out BIT);");
@@ -1224,13 +1248,13 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 		{
 			(void)initinfstr();
 			(void)addstringtoinfstr("  component nor");
-			(void)sprintf(line, "%d", i);
+			(void)sprintf(line, "%ld", i);
 			(void)addstringtoinfstr(line);
 			(void)addstringtoinfstr(" port(");
 			for(j=1; j<=i; j++)
 			{
 				if (j > 1) (void)addstringtoinfstr(", ");
-				(void)sprintf(line, "a%d", j);
+				(void)sprintf(line, "a%ld", j);
 				(void)addstringtoinfstr(line);
 			}
 			(void)addstringtoinfstr(": in BIT; y: out BIT);");
@@ -1241,13 +1265,13 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 		{
 			(void)initinfstr();
 			(void)addstringtoinfstr("  component xnor");
-			(void)sprintf(line, "%d", i);
+			(void)sprintf(line, "%ld", i);
 			(void)addstringtoinfstr(line);
 			(void)addstringtoinfstr(" port(");
 			for(j=1; j<=i; j++)
 			{
 				if (j > 1) (void)addstringtoinfstr(", ");
-				(void)sprintf(line, "a%d", j);
+				(void)sprintf(line, "a%ld", j);
 				(void)addstringtoinfstr(line);
 			}
 			(void)addstringtoinfstr(": in BIT; y: out BIT);");
@@ -1261,6 +1285,18 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
 		if (net->portcount != 0 || net->buslinkcount != 0) continue;
+
+		/* disallow if part of a bus export */
+		if (net->signals > 1)
+		{
+			for(i=0; i<net->signals; i++)
+				if (vhdl_netexported(net->networklist[i]) != 0) break;
+			if (i < net->signals) continue;
+		} else
+		{
+			if (vhdl_netexported(net) != 0) continue;
+		}
+
 		if (net->namecount > 0) pt = net->netname; else
 			pt = describenetwork(net);
 		count = net_evalbusname(APBUS, pt, &strings, NOARCINST, np, 0);
@@ -1284,7 +1320,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 				(void)addstringtoinfstr("    ");
 				linelen = 4;
 			}
-			vhdl_addstring(strings[i]);
+			vhdl_addstring(strings[i], np);
 			linelen += strlen(strings[i]);
 		}
 	}
@@ -1321,20 +1357,26 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 		/* ignore component with no ports */
 		if (ni->proto->firstportproto == NOPORTPROTO) continue;
 
+		if (ni->proto->primindex == 0)
+		{
+			/* ignore recursive references (showing icon in contents) */
+			if (ni->proto->cell == np->cell) continue;
+		}
+
 		pt = vhdl_primname(ni, &special);
 		if (pt[0] == 0) continue;
 
 		(void)initinfstr();
 		(void)addstringtoinfstr("  ");
 		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
-		if (var != NOVARIABLE) vhdl_addstring((char *)var->addr); else
+		if (var != NOVARIABLE) vhdl_addstring((char *)var->addr, NONODEPROTO); else
 		{
 			ttyputerr("VHDL conversion warning: no name on node %s", describenodeinst(ni));
 			(void)sprintf(line, "NODE%ld", (INTBIG)ni);
 			(void)addstringtoinfstr(line);
 		}
 		(void)addstringtoinfstr(": ");
-		vhdl_addstring(pt);
+		vhdl_addstring(pt, NONODEPROTO);
 
 		(void)addstringtoinfstr(" port map(");
 		vhdl_addrealports(ni, special);
@@ -1358,12 +1400,12 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 			(void)addstringtoinfstr(line);
 			(void)addstringtoinfstr(", ");
 			net = ai->network;
-			if (net->namecount > 0) vhdl_addstring(net->netname); else
+			if (net->namecount > 0) vhdl_addstring(net->netname, np); else
 				(void)addstringtoinfstr(describenetwork(net));
 		} else
 		{
 			net = ai->network;
-			if (net->namecount > 0) vhdl_addstring(net->netname); else
+			if (net->namecount > 0) vhdl_addstring(net->netname, np); else
 				(void)addstringtoinfstr(describenetwork(net));
 			(void)addstringtoinfstr(", ");
 			(void)sprintf(line, "PINV%ld", ai->temp1);
@@ -1376,7 +1418,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	/* write the end of the body */
 	(void)initinfstr();
 	(void)addstringtoinfstr("end ");
-	vhdl_addstring(np->cell->cellname);
+	vhdl_addstring(np->cell->cellname, NONODEPROTO);
 	(void)addstringtoinfstr("_BODY;");
 	vhdl_print(returninfstr());
 	vhdl_print("");
@@ -1386,6 +1428,9 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
+
+		/* ignore recursive references (showing icon in contents) */
+		if (ni->proto->cell == np->cell) continue;
 		if (ni->proto->temp1 != 0) continue;
 		cnp = contentsview(ni->proto);
 		if (cnp == NONODEPROTO) cnp = ni->proto;
@@ -1412,13 +1457,13 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 
 void vhdl_addrealports(NODEINST *ni, INTSML special)
 {
-	REGISTER INTSML first, pass;
+	REGISTER INTBIG first, pass, i;
 	REGISTER PORTPROTO *pp, *opp, *cpp;
 	REGISTER NODEPROTO *np, *cnp;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
-	REGISTER NETWORK *net;
+	REGISTER NETWORK *net, *subnet;
 	char line[50];
 
 	np = ni->proto;
@@ -1517,7 +1562,7 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 						}
 					}
 					net = ai->network;
-					if (net->namecount > 0) vhdl_addstring(net->netname); else
+					if (net->namecount > 0) vhdl_addstring(net->netname, ni->parent); else
 						(void)addstringtoinfstr(describenetwork(net));
 				}
 				continue;
@@ -1544,8 +1589,20 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 					}
 
 					net = ai->network;
-					if (net->namecount > 0) vhdl_addstring(net->netname); else
-						(void)addstringtoinfstr(describenetwork(net));
+					if (net->signals > 1)
+					{
+						for(i=0; i<net->signals; i++)
+						{
+							if (i != 0) (void)addstringtoinfstr(", ");
+							subnet = net->networklist[i];
+							if (subnet->namecount > 0) vhdl_addstring(subnet->netname, ni->parent); else
+								(void)addstringtoinfstr(describenetwork(subnet));
+						}
+					} else
+					{
+						if (net->namecount > 0) vhdl_addstring(net->netname, ni->parent); else
+							(void)addstringtoinfstr(describenetwork(net));
+					}
 					continue;
 				}
 			}
@@ -1556,7 +1613,7 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 			if (pe != NOPORTEXPINST)
 			{
 				if (first != 0) (void)addstringtoinfstr(", ");   first = 1;
-				vhdl_addstring(pe->exportproto->protoname);
+				vhdl_addstring(pe->exportproto->protoname, ni->parent);
 				continue;
 			}
 
@@ -1606,7 +1663,7 @@ char *vhdl_primname(NODEINST *ni, INTSML *special)
 	if (ni->proto->primindex == 0) return(ni->proto->cell->cellname);
 
 	/* get the primitive function */
-	k = nodefunction(ni, 0);
+	k = nodefunction(ni);
 	pt[0] = 0;
 	switch (k)
 	{
@@ -1841,10 +1898,16 @@ char *vhdl_primname(NODEINST *ni, INTSML *special)
 	return(pt);
 }
 
-void vhdl_addstring(char *orig)
+/*
+ * Routine to add the string "orig" to the infinite string.
+ * If "environment" is not NONODEPROTO, it is the facet in which this signal is
+ * to reside, and if that facet has nodes with this name, the signal must be renamed.
+ */
+void vhdl_addstring(char *orig, NODEPROTO *environment)
 {
-	char *pt;
-	INTSML len, nonalnum;
+	REGISTER char *pt;
+	REGISTER INTBIG len, nonalnum;
+	REGISTER NODEINST *ni;
 
 	/* remove all nonVHDL characters while adding to current string */
 	nonalnum = 0;
@@ -1856,14 +1919,38 @@ void vhdl_addstring(char *orig)
 	}
 
 	/* if there were nonalphanumeric characters, this cannot be a VHDL keyword */
-	if (nonalnum != 0) return;
+	if (nonalnum == 0)
+	{
+		/* check for VHDL keyword clashes */
+		len = strlen(orig);
+		if (vhdl_iskeyword(orig, len) != NOVKEYWORD)
+		{
+			(void)addstringtoinfstr("NV");
+			return;
+		}
 
-	/* check for VHDL keyword clashes */
-	len = strlen(orig);
-	if (vhdl_iskeyword(orig, len) != NOVKEYWORD) (void)addstringtoinfstr("NV");
+		/* "bit" isn't a keyword, but the compiler can't handle it */
+		if (namesame(orig, "bit") == 0)
+		{
+			(void)addstringtoinfstr("NV");
+			return;
+		}
+	}
 
-	/* "bit" isn't a keyword, but the compiler can't handle it */
-	if (namesame(orig, "bit") == 0) (void)addstringtoinfstr("NV");
+	/* see if there is a name clash */
+	if (environment != NONODEPROTO)
+	{
+		for(ni = environment->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		{
+			if (ni->proto->primindex != 0) continue;
+			if (namesame(orig, ni->proto->cell->cellname) == 0) break;
+		}
+		if (ni != NONODEINST)
+		{
+			(void)addstringtoinfstr("NV");
+			return;
+		}
+	}
 }
 
 /*
@@ -1972,7 +2059,7 @@ void vhdl_addtheseports(NODEINST *ni, NODEPROTO *np, INTBIG bits, char *before)
 				{
 					(void)addstringtoinfstr(before);
 					(void)strcpy(before, ", ");
-					vhdl_addstring(strings[i]);
+					vhdl_addstring(strings[i], np);
 					(void)sprintf(instname, "%d", inst);
 					(void)addstringtoinfstr(instname);
 					didsome++;
@@ -1986,7 +2073,7 @@ void vhdl_addtheseports(NODEINST *ni, NODEPROTO *np, INTBIG bits, char *before)
 			{
 				(void)addstringtoinfstr(before);
 				(void)strcpy(before, ", ");
-				vhdl_addstring(strings[i]);
+				vhdl_addstring(strings[i], np);
 				didsome++;
 			}
 		}
@@ -2007,6 +2094,28 @@ void vhdl_addtheseports(NODEINST *ni, NODEPROTO *np, INTBIG bits, char *before)
 	}
 }
 
+/*
+ * Routine to return nonzero if network "net" is exported.
+ */
+INTBIG vhdl_netexported(NETWORK *net)
+{
+	REGISTER PORTPROTO *pp;
+	REGISTER INTBIG i;
+
+	for(pp = net->parent->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	{
+		if (pp->network->signals <= 1)
+		{
+			if (pp->network == net) return(1);
+		} else
+		{
+			for(i=0; i<pp->network->signals; i++)
+				if (pp->network->networklist[i] == net) return(1);
+		}
+	}
+	return(0);
+}
+
 /****************************** COMPILATION ******************************/
 
 /*
@@ -2032,10 +2141,10 @@ void vhdl_compile(NODEPROTO *basefacet)
 		case TARGET_QUISC:   filetype = sim_filetypequisc;   break;
 	}
 
-	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_vhdlondisk);
+	var = getvalkey((INTBIG)vhdl_tool, VTOOL, VINTEGER, vhdl_vhdlondisk);
 	if (var == NOVARIABLE) vhdlondisk = 0; else
 		vhdlondisk = (INTSML)var->addr;
-	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_netlistondisk);
+	var = getvalkey((INTBIG)vhdl_tool, VTOOL, VINTEGER, vhdl_netlistondisk);
 	if (var == NOVARIABLE) netlistondisk = 0; else
 		netlistondisk = (INTSML)var->addr;
 
@@ -2067,7 +2176,7 @@ void vhdl_compile(NODEPROTO *basefacet)
 	if (vhdl_identtable == 0)
 	{
 		vhdl_identtable = (IDENTTABLE *)emalloc((INTBIG)IDENT_TABLE_SIZE *
-			(INTBIG)(sizeof (IDENTTABLE)), vhdl_aid->cluster);
+			(INTBIG)(sizeof (IDENTTABLE)), vhdl_tool->cluster);
 		if (vhdl_identtable == 0) return;
 		for (i = 0; i < IDENT_TABLE_SIZE; i++)
 			vhdl_identtable[i].string = (char *)0;
@@ -2129,7 +2238,7 @@ void vhdl_scanner(void)
 	vhdl_freescannermemory();
 
 	c = "";
-	while (TRUE)
+	for(;;)
 	{
 		if (*c == 0)
 		{
@@ -2148,10 +2257,13 @@ void vhdl_scanner(void)
 			{
 				if ((tchar = vhdl_toupper(*c)) == 'B')
 				{
+					/* EMPTY */ 
 				} else if (tchar == '0')
 				{
+					/* EMPTY */ 
 				} else if (tchar == 'X')
 				{
+					/* EMPTY */ 
 				}
 			}
 			end = c + 1;
@@ -2363,7 +2475,7 @@ void vhdl_makekeytoken(VKEYWORD *key, INTBIG line_num, INTBIG space)
 {
 	TOKENLIST *newtoken;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = TOKEN_KEYWORD;
 	newtoken->pointer = (char *)key;
 	newtoken->line_num = line_num;
@@ -2403,9 +2515,9 @@ void vhdl_makeidenttoken(char *str, INTBIG length, INTBIG line_num, INTBIG space
 	char *newstring;
 	IDENTTABLE *ikey;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = TOKEN_IDENTIFIER;
-	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_aid->cluster);
+	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_tool->cluster);
 	strncpy(newstring, str, length);
 	newstring[length] = 0;
 
@@ -2453,9 +2565,9 @@ void vhdl_makestrtoken(char *string, INTBIG length, INTBIG line_num, INTBIG spac
 	TOKENLIST *newtoken;
 	char *newstring, *str, *str2;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = TOKEN_STRING;
-	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_aid->cluster);
+	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_tool->cluster);
 	strncpy(newstring, string, length);
 	newstring[length] = 0;
 
@@ -2515,9 +2627,9 @@ void vhdl_makedecimaltoken(char *string, INTBIG length, INTBIG line_num,
 	TOKENLIST *newtoken;
 	char *newstring;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = TOKEN_DECIMAL;
-	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_aid->cluster);
+	newstring = (char *)emalloc((INTBIG)length + 1, vhdl_tool->cluster);
 	strncpy(newstring, string, length);
 	newstring[length] = 0;
 	newtoken->pointer = newstring;
@@ -2555,7 +2667,7 @@ void vhdl_maketoken(INTBIG token, INTBIG line_num, INTBIG space)
 {
 	TOKENLIST *newtoken;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = token;
 	newtoken->pointer = (char *)0;
 	newtoken->line_num = line_num;
@@ -2592,7 +2704,7 @@ void vhdl_makechartoken(char c, INTBIG line_num, INTBIG space)
 {
 	TOKENLIST *newtoken;
 
-	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_aid->cluster);
+	newtoken = (TOKENLIST *)emalloc((INTBIG)sizeof(TOKENLIST), vhdl_tool->cluster);
 	newtoken->token = TOKEN_CHAR;
 	newtoken->pointer = (char *)((INTBIG)c);
 	newtoken->line_num = line_num;
@@ -2613,7 +2725,7 @@ void vhdl_makechartoken(char c, INTBIG line_num, INTBIG space)
 void vhdl_freescannermemory(void)
 {
 	TOKENLIST *tok, *nexttok;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* free parsed tokens */
 	for(tok = vhdl_tliststart; tok != NOTOKENLIST; tok = nexttok)
@@ -2707,8 +2819,10 @@ IDENTTABLE *vhdl_findidentkey(char *string)
 	char *ident;
 
 	attempt = vhdl_identfirsthash(string);
-	while ((ident = vhdl_identtable[attempt].string))
+	for(;;)
 	{
+		ident = vhdl_identtable[attempt].string;
+		if (ident == 0) break;
 		if (namesame(string, ident) == 0) return(&(vhdl_identtable[attempt]));
 		attempt = vhdl_identsecondhash(string, attempt);
 	}
@@ -2918,7 +3032,7 @@ void vhdl_unresolved(IDENTTABLE *iname, UNRESLIST **lstart)
 	}
 	if (ulist) ulist->numref++; else
 	{
-		ulist = (UNRESLIST *)emalloc((INTBIG)sizeof(UNRESLIST), vhdl_aid->cluster);
+		ulist = (UNRESLIST *)emalloc((INTBIG)sizeof(UNRESLIST), vhdl_tool->cluster);
 		ulist->interfacef = iname;
 		ulist->numref = 1;
 		ulist->next = *lstart;
@@ -2929,7 +3043,7 @@ void vhdl_unresolved(IDENTTABLE *iname, UNRESLIST **lstart)
 /****************************** VHDL OPTIONS DIALOG ******************************/
 
 /* VHDL Options */
-DIALOGITEM vhdl_optionsdialogitems[] =
+static DIALOGITEM vhdl_optionsdialogitems[] =
 {
  /*  1 */ {0, {336,228,360,292}, BUTTON, N_("OK")},
  /*  2 */ {0, {300,228,324,292}, BUTTON, N_("Cancel")},
@@ -2943,7 +3057,7 @@ DIALOGITEM vhdl_optionsdialogitems[] =
  /* 10 */ {0, {8,8,24,183}, MESSAGE, N_("Schematics primitives:")},
  /* 11 */ {0, {292,8,293,295}, DIVIDELINE, ""}
 };
-DIALOG vhdl_optionsdialog = {{50,75,419,379}, N_("VHDL Options"), 0, 11, vhdl_optionsdialogitems};
+static DIALOG vhdl_optionsdialog = {{50,75,419,379}, N_("VHDL Options"), 0, 11, vhdl_optionsdialogitems};
 
 /* special items for the "VHDL Options" dialog: */
 #define DVHO_VHDLINFACET   3		/* VHDL stored in facet (check) */
@@ -2962,10 +3076,10 @@ void vhdl_optionsdlog(void)
 	REGISTER INTBIG i, len, vhdlondisk, netlistondisk, technameschanged;
 
 	if (DiaInitDialog(&vhdl_optionsdialog) != 0) return;
-	var = getval((INTBIG)vhdl_aid, VAID, VINTEGER, "VHDL_vhdl_on_disk");
+	var = getval((INTBIG)vhdl_tool, VTOOL, VINTEGER, "VHDL_vhdl_on_disk");
 	if (var == NOVARIABLE) vhdlondisk = 0; else
 		vhdlondisk = var->addr;
-	var = getval((INTBIG)vhdl_aid, VAID, VINTEGER, "VHDL_netlist_on_disk");
+	var = getval((INTBIG)vhdl_tool, VTOOL, VINTEGER, "VHDL_netlist_on_disk");
 	if (var == NOVARIABLE) netlistondisk = 0; else
 		netlistondisk = var->addr;
 
@@ -3075,10 +3189,10 @@ void vhdl_optionsdlog(void)
 	{
 		if (DiaGetControl(DVHO_VHDLINFACET) != 0) i = 0; else i = 1;
 		if (i != vhdlondisk)
-			setval((INTBIG)vhdl_aid, VAID, "VHDL_vhdl_on_disk", i, VINTEGER);
+			setval((INTBIG)vhdl_tool, VTOOL, "VHDL_vhdl_on_disk", i, VINTEGER);
 		if (DiaGetControl(DVHO_NETINFACET) != 0) i = 0; else i = 1;
 		if (i != netlistondisk)
-			setval((INTBIG)vhdl_aid, VAID, "VHDL_netlist_on_disk", i, VINTEGER);
+			setval((INTBIG)vhdl_tool, VTOOL, "VHDL_netlist_on_disk", i, VINTEGER);
 		if (technameschanged != 0)
 			setval((INTBIG)tech, VTECHNOLOGY, "TECH_vhdl_names", (INTBIG)varnames,
 				VSTRING|VISARRAY|(len<<VLENGTHSH));
@@ -3089,4 +3203,4 @@ void vhdl_optionsdlog(void)
 	efree((char *)nplist);
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
