@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -41,11 +41,11 @@ extern SYMBOLLIST	*vhdl_gsymbols;
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 
 /* prototypes for local routines */
-INTSML vhdl_addnetlist(LIBRARY*, char*);
-void vhdl_genfunction(char*, INTSML, INTSML, INTSML);
-void vhdl_dumpfunction(char*, char**);
-void vhdl_genals_interface(DBINTERFACE*, char*);
-void vhdl_genals_aport(INTBIG*, DBNAME*);
+static INTSML vhdl_addnetlist(LIBRARY*, char*);
+static void vhdl_genfunction(char*, INTSML, INTSML, INTSML);
+static void vhdl_dumpfunction(char*, char**);
+static void vhdl_genals_interface(DBINTERFACE*, char*);
+static void vhdl_genals_aport(INTBIG*, DBNAME*);
 
 /*
 Module:  vhdl_genals
@@ -558,6 +558,7 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 			{
 				/* Should have gate entity */
 				/* should be automatically added at end of .net file */
+				/* EMPTY */ 
 			} else
 			{
 				vhdl_genals_interface((DBINTERFACE *)symbol->pointer, inst->compo->name->string);
@@ -761,4 +762,4 @@ void vhdl_genals_aport(INTBIG *first, DBNAME *name)
 	}
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
