@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -40,26 +40,26 @@ extern TOKENLIST	*vhdl_nexttoken;
 extern SYMBOLLIST	*vhdl_symbols;
 
 /* prototypes for local routines */
-MRELATIONS *vhdl_parsemorerelations(INTBIG, INTBIG);
-RELATION *vhdl_parserelation(void);
-TERM *vhdl_parseterm(void);
-MTERMS *vhdl_parsemoreterms(void);
-FACTOR *vhdl_parsefactor(void);
-MFACTORS *vhdl_parsemorefactors(void);
-PRIMARY *vhdl_parseprimary(void);
-LITERAL *vhdl_parseliteral(void);
-INTBIG vhdl_parsedecimal(void);
-INTBIG vhdl_evalrelation(RELATION*);
-INTBIG vhdl_evalterm(TERM*);
-INTBIG vhdl_evalfactor(FACTOR*);
-INTBIG vhdl_evalprimary(PRIMARY*);
-INTBIG vhdl_evalname(NAME*);
-INTSML vhdl_indiscreterange(INTBIG, DBDISCRETERANGE*);
-SINGLENAME *vhdl_parsesinglename(void);
-INDEXEDNAME *vhdl_parseindexedname(INTBIG, char*);
-DBNAME *vhdl_semsinglename(SINGLENAME*);
-DBNAME *vhdl_semconcatenatedname(CONCATENATEDNAME*);
-DBNAME *vhdl_semindexedname(INDEXEDNAME*);
+static MRELATIONS *vhdl_parsemorerelations(INTBIG, INTBIG);
+static RELATION *vhdl_parserelation(void);
+static TERM *vhdl_parseterm(void);
+static MTERMS *vhdl_parsemoreterms(void);
+static FACTOR *vhdl_parsefactor(void);
+static MFACTORS *vhdl_parsemorefactors(void);
+static PRIMARY *vhdl_parseprimary(void);
+static LITERAL *vhdl_parseliteral(void);
+static INTBIG vhdl_parsedecimal(void);
+static INTBIG vhdl_evalrelation(RELATION*);
+static INTBIG vhdl_evalterm(TERM*);
+static INTBIG vhdl_evalfactor(FACTOR*);
+static INTBIG vhdl_evalprimary(PRIMARY*);
+static INTBIG vhdl_evalname(NAME*);
+static INTSML vhdl_indiscreterange(INTBIG, DBDISCRETERANGE*);
+static SINGLENAME *vhdl_parsesinglename(void);
+static INDEXEDNAME *vhdl_parseindexedname(INTBIG, char*);
+static DBNAME *vhdl_semsinglename(SINGLENAME*);
+static DBNAME *vhdl_semconcatenatedname(CONCATENATEDNAME*);
+static DBNAME *vhdl_semindexedname(INDEXEDNAME*);
 
 /*
 Module:  vhdl_parseexpression
@@ -86,7 +86,7 @@ EXPRESSION  *vhdl_parseexpression(void)
 	EXPRESSION *exp;
 	INTBIG key, logop;
 
-	exp = (EXPRESSION *)emalloc((INTBIG)sizeof(EXPRESSION), vhdl_aid->cluster);
+	exp = (EXPRESSION *)emalloc((INTBIG)sizeof(EXPRESSION), vhdl_tool->cluster);
 	exp->relation = vhdl_parserelation();
 	exp->next = 0;
 
@@ -154,7 +154,7 @@ MRELATIONS  *vhdl_parsemorerelations(INTBIG key, INTBIG logop)
 	if (vhdl_keysame(vhdl_nexttoken, key))
 	{
 		vhdl_getnexttoken();
-		more = (MRELATIONS *)emalloc((INTBIG)sizeof(MRELATIONS), vhdl_aid->cluster);
+		more = (MRELATIONS *)emalloc((INTBIG)sizeof(MRELATIONS), vhdl_tool->cluster);
 		more->log_operator = logop;
 		more->relation = vhdl_parserelation();
 		more->next = vhdl_parsemorerelations(key, logop);
@@ -187,7 +187,7 @@ RELATION  *vhdl_parserelation(void)
 	INTBIG relop;
 
 	relop = NORELOP;
-	relation = (RELATION *)emalloc((INTBIG)sizeof(RELATION), vhdl_aid->cluster);
+	relation = (RELATION *)emalloc((INTBIG)sizeof(RELATION), vhdl_tool->cluster);
 	relation->simple_expr = vhdl_parsesimpleexpression();
 	relation->rel_operator = NORELOP;
 	relation->simple_expr2 = 0;
@@ -246,7 +246,7 @@ SIMPLEEXPR  *vhdl_parsesimpleexpression(void)
 {
 	SIMPLEEXPR *exp;
 
-	exp = (SIMPLEEXPR *)emalloc((INTBIG)sizeof(SIMPLEEXPR), vhdl_aid->cluster);
+	exp = (SIMPLEEXPR *)emalloc((INTBIG)sizeof(SIMPLEEXPR), vhdl_tool->cluster);
 
 	/* check for optional sign */
 	if (vhdl_nexttoken->token == TOKEN_PLUS)
@@ -291,7 +291,7 @@ TERM  *vhdl_parseterm(void)
 {
 	TERM *term;
 
-	term = (TERM *)emalloc((INTBIG)sizeof(TERM), vhdl_aid->cluster);
+	term = (TERM *)emalloc((INTBIG)sizeof(TERM), vhdl_tool->cluster);
 	term->factor = vhdl_parsefactor();
 	term->next = vhdl_parsemorefactors();
 	return(term);
@@ -330,7 +330,7 @@ MTERMS  *vhdl_parsemoreterms(void)
 	if (addop != NOADDOP)
 	{
 		vhdl_getnexttoken();
-		more = (MTERMS *)emalloc((INTBIG)sizeof(MTERMS), vhdl_aid->cluster);
+		more = (MTERMS *)emalloc((INTBIG)sizeof(MTERMS), vhdl_tool->cluster);
 		more->add_operator = addop;
 		more->term = vhdl_parseterm();
 		more->next = vhdl_parsemoreterms();
@@ -385,7 +385,7 @@ FACTOR  *vhdl_parsefactor(void)
 			primary2 = vhdl_parseprimary();
 		}
 	}
-	factor = (FACTOR *)emalloc((INTBIG)sizeof(FACTOR), vhdl_aid->cluster);
+	factor = (FACTOR *)emalloc((INTBIG)sizeof(FACTOR), vhdl_tool->cluster);
 	factor->primary = primary;
 	factor->misc_operator = miscop;
 	factor->primary2 = primary2;
@@ -431,7 +431,7 @@ MFACTORS  *vhdl_parsemorefactors(void)
 	if (mulop != NOMULOP)
 	{
 		vhdl_getnexttoken();
-		more = (MFACTORS *)emalloc((INTBIG)sizeof(MFACTORS), vhdl_aid->cluster);
+		more = (MFACTORS *)emalloc((INTBIG)sizeof(MFACTORS), vhdl_tool->cluster);
 		more->mul_operator = mulop;
 		more->factor = vhdl_parsefactor();
 		more->next = vhdl_parsemorefactors();
@@ -501,7 +501,7 @@ PRIMARY  *vhdl_parseprimary(void)
 	}
 	if (type != NOPRIMARY)
 	{
-		primary = (PRIMARY *)emalloc((INTBIG)sizeof(PRIMARY), vhdl_aid->cluster);
+		primary = (PRIMARY *)emalloc((INTBIG)sizeof(PRIMARY), vhdl_tool->cluster);
 		primary->type = type;
 		primary->pointer = pointer;
 	}
@@ -554,7 +554,7 @@ LITERAL  *vhdl_parseliteral(void)
 	}
 	if (type != NOLITERAL)
 	{
-		literal = (LITERAL *)emalloc((INTBIG)sizeof(LITERAL), vhdl_aid->cluster);
+		literal = (LITERAL *)emalloc((INTBIG)sizeof(LITERAL), vhdl_tool->cluster);
 		literal->type = type;
 		literal->pointer = pointer;
 	}
@@ -993,7 +993,7 @@ NAME  *vhdl_parsename(void)
 	{
 		case TOKEN_AMPERSAND:
 			type = NAME_CONCATENATE;
-			concat = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_aid->cluster);
+			concat = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_tool->cluster);
 			concat->name = (SINGLENAME *)pointer;
 			concat->next = NULL;
 			pointer = (char *)concat;
@@ -1001,7 +1001,7 @@ NAME  *vhdl_parsename(void)
 			{
 				vhdl_getnexttoken();
 				pointer2 = (char *)vhdl_parsesinglename();
-				concat2 = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_aid->cluster);
+				concat2 = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_tool->cluster);
 				concat->next = concat2;
 				concat2->name = (SINGLENAME *)pointer2;
 				concat2->next = NULL;
@@ -1017,7 +1017,7 @@ NAME  *vhdl_parsename(void)
 
 	if (type != NONAME)
 	{
-		name = (NAME *)emalloc((INTBIG)sizeof(NAME), vhdl_aid->cluster);
+		name = (NAME *)emalloc((INTBIG)sizeof(NAME), vhdl_tool->cluster);
 		name->type = type;
 		name->pointer = pointer;
 	} else
@@ -1071,9 +1071,9 @@ SINGLENAME  *vhdl_parsesinglename(void)
 				/* but support only indexed names */
 				vhdl_getnexttoken();
 				type = SINGLENAME_INDEXED;
-				nptr = (NAME *)emalloc((INTBIG)sizeof(NAME), vhdl_aid->cluster);
+				nptr = (NAME *)emalloc((INTBIG)sizeof(NAME), vhdl_tool->cluster);
 				nptr->type = NAME_SINGLE;
-				sname2 = (SINGLENAME *)emalloc((INTBIG)sizeof(SINGLENAME), vhdl_aid->cluster);
+				sname2 = (SINGLENAME *)emalloc((INTBIG)sizeof(SINGLENAME), vhdl_tool->cluster);
 				nptr->pointer = (char *)sname2;
 				sname2->type = SINGLENAME_SIMPLE;
 				sname2->pointer = pointer;
@@ -1093,7 +1093,7 @@ SINGLENAME  *vhdl_parsesinglename(void)
 
 	if (type != NOSINGLENAME)
 	{
-		sname = (SINGLENAME *)emalloc((INTBIG)sizeof(SINGLENAME), vhdl_aid->cluster);
+		sname = (SINGLENAME *)emalloc((INTBIG)sizeof(SINGLENAME), vhdl_tool->cluster);
 		sname->type = type;
 		sname->pointer = pointer;
 	} else
@@ -1129,7 +1129,7 @@ SIMPLENAME  *vhdl_parsesimplename(void)
 		vhdl_getnexttoken();
 		return(sname);
 	}
-	sname = (SIMPLENAME *)emalloc((INTBIG)sizeof(SIMPLENAME), vhdl_aid->cluster);
+	sname = (SIMPLENAME *)emalloc((INTBIG)sizeof(SIMPLENAME), vhdl_tool->cluster);
 	sname->identifier = vhdl_nexttoken;
 	vhdl_getnexttoken();
 	return(sname);
@@ -1159,12 +1159,12 @@ INDEXEDNAME  *vhdl_parseindexedname(INTBIG pre_type, char *pre_ptr)
 	INDEXEDNAME *ind;
 	EXPRLIST *elist, *newelist;
 
-	prefix = (PREFIX *)emalloc((INTBIG)sizeof(PREFIX), vhdl_aid->cluster);
+	prefix = (PREFIX *)emalloc((INTBIG)sizeof(PREFIX), vhdl_tool->cluster);
 	prefix->type = pre_type;
 	prefix->pointer = pre_ptr;
-	ind = (INDEXEDNAME *)emalloc((INTBIG)sizeof(INDEXEDNAME), vhdl_aid->cluster);
+	ind = (INDEXEDNAME *)emalloc((INTBIG)sizeof(INDEXEDNAME), vhdl_tool->cluster);
 	ind->prefix = prefix;
-	ind->expr_list = (EXPRLIST *)emalloc((INTBIG)sizeof(EXPRLIST), vhdl_aid->cluster);
+	ind->expr_list = (EXPRLIST *)emalloc((INTBIG)sizeof(EXPRLIST), vhdl_tool->cluster);
 	ind->expr_list->expression = vhdl_parseexpression();
 	ind->expr_list->next = NULL;
 	elist = ind->expr_list;
@@ -1173,7 +1173,7 @@ INDEXEDNAME  *vhdl_parseindexedname(INTBIG pre_type, char *pre_ptr)
 	while (vhdl_nexttoken->token == TOKEN_COMMA)
 	{
 		vhdl_getnexttoken();
-		newelist = (EXPRLIST *)emalloc((INTBIG)sizeof(EXPRLIST), vhdl_aid->cluster);
+		newelist = (EXPRLIST *)emalloc((INTBIG)sizeof(EXPRLIST), vhdl_tool->cluster);
 		newelist->expression = vhdl_parseexpression();
 		newelist->next = NULL;
 		elist->next = newelist;
@@ -1406,7 +1406,7 @@ DBNAME *vhdl_semsinglename(SINGLENAME *name)
 	switch (name->type)
 	{
 		case SINGLENAME_SIMPLE:
-			dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_aid->cluster);
+			dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_tool->cluster);
 			dbname->name = (IDENTTABLE *)((SIMPLENAME *)(name->pointer))->identifier->pointer;
 			dbname->type = DBNAME_IDENTIFIER;
 			dbname->pointer = NULL;
@@ -1445,7 +1445,7 @@ DBNAME  *vhdl_semconcatenatedname(CONCATENATEDNAME *name)
 
 	dbname = NULL;
 	if (name == NULL) return(dbname);
-	dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_aid->cluster);
+	dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_tool->cluster);
 	dbname->name = NULL;
 	dbname->type = DBNAME_CONCATENATED;
 	dbname->pointer = NULL;
@@ -1453,7 +1453,7 @@ DBNAME  *vhdl_semconcatenatedname(CONCATENATEDNAME *name)
 	end = NULL;
 	for (cat = name; cat != NULL; cat = cat->next)
 	{
-		newnl = (DBNAMELIST *)emalloc((INTBIG)sizeof(DBNAMELIST), vhdl_aid->cluster);
+		newnl = (DBNAMELIST *)emalloc((INTBIG)sizeof(DBNAMELIST), vhdl_tool->cluster);
 		newnl->name = vhdl_semsinglename(cat->name);
 		newnl->next = NULL;
 		if (end)
@@ -1490,7 +1490,7 @@ DBNAME  *vhdl_semindexedname(INDEXEDNAME *name)
 	DBINDEXRANGE *indexr;
 	DBEXPRLIST *dbexpr, *nexpr, *endexpr;
 	INTBIG value;
-	DBTYPE *type;
+	DBLTYPE *type;
 
 	dbname = NULL;
 	if (name == NULL) return(dbname);
@@ -1507,7 +1507,7 @@ DBNAME  *vhdl_semindexedname(INDEXEDNAME *name)
 		vhdl_reporterrormsg(vhdl_getprefixtoken(name->prefix), _("Must be of constrained array type"));
 		return(dbname);
 	}
-	dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_aid->cluster);
+	dbname = (DBNAME *)emalloc((INTBIG)sizeof(DBNAME), vhdl_tool->cluster);
 	dbname->name = vhdl_getprefixident(name->prefix);
 	dbname->type = DBNAME_INDEXED;
 	dbname->pointer = NULL;
@@ -1524,7 +1524,7 @@ DBNAME  *vhdl_semindexedname(INDEXEDNAME *name)
 			vhdl_reporterrormsg(vhdl_getprefixtoken(name->prefix), _("Index is out of range"));
 			return(dbname);
 		}
-		nexpr = (DBEXPRLIST *)emalloc((INTBIG)sizeof(DBEXPRLIST), vhdl_aid->cluster);
+		nexpr = (DBEXPRLIST *)emalloc((INTBIG)sizeof(DBEXPRLIST), vhdl_tool->cluster);
 		nexpr->value = value;
 		nexpr->next = NULL;
 		if (endexpr == NULL)
@@ -1541,4 +1541,4 @@ DBNAME  *vhdl_semindexedname(INDEXEDNAME *name)
 	return(dbname);
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
