@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -42,8 +42,8 @@ static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 static DBINTERFACE	*vhdl_top_interface;
 
 /* prototypes for local routines */
-void vhdl_gennet_interface(DBINTERFACE*, char*);
-void vhdl_gennet_aport(DBNAME*);
+static void vhdl_gennet_interface(DBINTERFACE*, char*);
+static void vhdl_gennet_aport(DBNAME*);
 
 /*
 Module:  vhdl_gennet
@@ -171,6 +171,7 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 			{
 				/* Should have gate entity */
 				/* should be automatically added at end of .net file */
+				/* EMPTY */ 
 			} else
 			{
 				vhdl_gennet_interface((DBINTERFACE *)symbol->pointer, inst->compo->name->string);
@@ -413,4 +414,4 @@ void vhdl_gennet_aport(DBNAME *name)
 	}
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
