@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -47,45 +47,44 @@ static jmp_buf	vhdl_notoken_err;
 INTBIG			vhdl_errorcount;
 
 /* prototypes for local routines */
-VINTERFACE *vhdl_parseinterface(void);
-BODY *vhdl_parsebody(INTBIG);
-BODYDECLARE *vhdl_parsebody_declare(void);
-COMPONENT *vhdl_parsecomponent(void);
-BASICDECLARE *vhdl_parsebasic_declare(void);
-OBJECTDECLARE *vhdl_parseobject_declare(void);
-SIGNALDECLARE *vhdl_parsesignal_declare(void);
-CONSTANTDECLARE *vhdl_parseconstant_declare(void);
-IDENTLIST *vhdl_parseident_list(void);
-STATEMENTS *vhdl_parseset_of_statements(void);
-char *vhdl_parseif(void);
-GENERATE *vhdl_parsegenerate(TOKENLIST*, INTBIG);
-RANGE *vhdl_parserange(void);
-RANGESIMPLE *vhdl_parserange_simple(void);
-INSTANCE *vhdl_parseinstance(void);
-FPORTLIST *vhdl_parseformal_port_list(void);
-INTBIG vhdl_parseport_mode(void);
-APORTLIST *vhdl_parseactual_port_list(void);
-PACKAGE *vhdl_parsepackage(void);
-PACKAGEDPART *vhdl_parsepackage_declare_part(void);
-void vhdl_parsetosemicolon(void);
+static VINTERFACE *vhdl_parseinterface(void);
+static BODY *vhdl_parsebody(INTBIG);
+static BODYDECLARE *vhdl_parsebody_declare(void);
+static COMPONENT *vhdl_parsecomponent(void);
+static BASICDECLARE *vhdl_parsebasic_declare(void);
+static OBJECTDECLARE *vhdl_parseobject_declare(void);
+static SIGNALDECLARE *vhdl_parsesignal_declare(void);
+static CONSTANTDECLARE *vhdl_parseconstant_declare(void);
+static IDENTLIST *vhdl_parseident_list(void);
+static STATEMENTS *vhdl_parseset_of_statements(void);
+static GENERATE *vhdl_parsegenerate(TOKENLIST*, INTBIG);
+static RANGE *vhdl_parserange(void);
+static RANGESIMPLE *vhdl_parserange_simple(void);
+static INSTANCE *vhdl_parseinstance(void);
+static FPORTLIST *vhdl_parseformal_port_list(void);
+static INTBIG vhdl_parseport_mode(void);
+static APORTLIST *vhdl_parseactual_port_list(void);
+static PACKAGE *vhdl_parsepackage(void);
+static PACKAGEDPART *vhdl_parsepackage_declare_part(void);
+static void vhdl_parsetosemicolon(void);
 #ifdef VHDL50
-  WITH *vhdl_parsewith(void);
+  static WITH *vhdl_parsewith(void);
 #endif
-USE *vhdl_parseuse(void);
-void vhdl_freeports(FPORTLIST*);
-void vhdl_freeidentlist(IDENTLIST*);
-void vhdl_freesimpleexpr(SIMPLEEXPR*);
-void vhdl_freeterm(TERM*);
-void vhdl_freefactor(FACTOR*);
-void vhdl_freeprimary(PRIMARY*);
-void vhdl_freename(NAME*);
-void vhdl_freesinglename(SINGLENAME*);
-void vhdl_freeindexedname(INDEXEDNAME*);
-void vhdl_freesubtypeind(SUBTYPEIND*);
-void vhdl_freeexpression(EXPRESSION*);
-void vhdl_freerelation(RELATION*);
-void vhdl_freebasicdeclare(BASICDECLARE*);
-void vhdl_freesetofstatements(STATEMENTS*);
+static USE *vhdl_parseuse(void);
+static void vhdl_freeports(FPORTLIST*);
+static void vhdl_freeidentlist(IDENTLIST*);
+static void vhdl_freesimpleexpr(SIMPLEEXPR*);
+static void vhdl_freeterm(TERM*);
+static void vhdl_freefactor(FACTOR*);
+static void vhdl_freeprimary(PRIMARY*);
+static void vhdl_freename(NAME*);
+static void vhdl_freesinglename(SINGLENAME*);
+static void vhdl_freeindexedname(INDEXEDNAME*);
+static void vhdl_freesubtypeind(SUBTYPEIND*);
+static void vhdl_freeexpression(EXPRESSION*);
+static void vhdl_freerelation(RELATION*);
+static void vhdl_freebasicdeclare(BASICDECLARE*);
+static void vhdl_freesetofstatements(STATEMENTS*);
 
 /*
 Module:  vhdl_parser
@@ -161,7 +160,7 @@ INTSML vhdl_parser(TOKENLIST *tlist)
 			}
 			if (type != NOUNIT)
 			{
-				newunit = (PTREE *)emalloc((INTBIG)sizeof(PTREE), vhdl_aid->cluster);
+				newunit = (PTREE *)emalloc((INTBIG)sizeof(PTREE), vhdl_tool->cluster);
 				newunit->type = type;
 				newunit->pointer = pointer;
 				newunit->next = NULL;
@@ -212,7 +211,9 @@ void vhdl_reporterrormsg(TOKENLIST *tlist, char *err_msg)
 	for ( ; tstart != NOTOKENLIST && tstart->line_num == tlist->line_num;
 		tstart = tstart->next)
 	{
-		if (tstart == tlist) pointer = (INTBIG)strlen(buffer);
+		i = strlen(buffer);
+		if (i > MAXVHDLLINE/2) break;
+		if (tstart == tlist) pointer = i;
 		if (tstart->token < TOKEN_ARROW)
 		{
 			sprintf(stemp, "%c", vhdl_delimiterstr[tstart->token]);
@@ -242,7 +243,7 @@ void vhdl_reporterrormsg(TOKENLIST *tlist, char *err_msg)
 			default:
 				if (tstart->pointer != 0)
 				{
-					sprintf(stemp, "%ld", tstart->pointer);
+					sprintf(stemp, "%ld", (INTBIG)tstart->pointer);
 					strcat(buffer, stemp);
 				}
 				break;
@@ -365,7 +366,7 @@ VINTERFACE  *vhdl_parseinterface(void)
 	vhdl_nexttoken = vhdl_nexttoken->next;
 
 	/* allocate an entity parse tree */
-	interfacef = (VINTERFACE *)emalloc((INTBIG)sizeof(VINTERFACE), vhdl_aid->cluster);
+	interfacef = (VINTERFACE *)emalloc((INTBIG)sizeof(VINTERFACE), vhdl_tool->cluster);
 	interfacef->name = name;
 	interfacef->ports = ports;
 	interfacef->interfacef = NULL;
@@ -432,6 +433,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* next is design entity reference for this body (simple_name) */
 	if ((entity_name = vhdl_parsesimplename()) == (SIMPLENAME *)PARSE_ERR)
 	{
+		/* EMPTY */ 
 	}
 
 	/* check for keyword IS */
@@ -444,6 +446,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* body declaration part */
 	if ((body_declare = vhdl_parsebody_declare()) == (BODYDECLARE *)PARSE_ERR)
 	{
+		/* EMPTY */ 
 	}
 
 	/* should be at keyword BEGIN */
@@ -456,6 +459,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* statements of body */
 	if ((statements = vhdl_parseset_of_statements()) == (STATEMENTS *)PARSE_ERR)
 	{
+		/* EMPTY */ 
 	}
 
 	/* should be at keyword END */
@@ -483,7 +487,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	vhdl_nexttoken = vhdl_nexttoken->next;
 
 	/* create body parse tree */
-	body = (BODY *)emalloc((INTBIG)sizeof(BODY), vhdl_aid->cluster);
+	body = (BODY *)emalloc((INTBIG)sizeof(BODY), vhdl_tool->cluster);
 	body->classnew = vclass;
 	body->name = body_name;
 	body->entity = entity_name;
@@ -530,6 +534,7 @@ BODYDECLARE	*vhdl_parsebody_declare(void)
 			type = BODYDECLARE_COMPONENT;
 			if ((pointer = (char *)vhdl_parsecomponent()) == (char *)PARSE_ERR)
 			{
+				/* EMPTY */ 
 			}
 		}
 		/* check for resolution declaration */
@@ -552,9 +557,10 @@ BODYDECLARE	*vhdl_parsebody_declare(void)
 			type = BODYDECLARE_BASIC;
 			if ((pointer = (char *)vhdl_parsebasic_declare()) == (char *)PARSE_ERR)
 			{
+				/* EMPTY */ 
 			}
 		}
-		newbody = (BODYDECLARE *)emalloc((INTBIG)sizeof(BODYDECLARE), vhdl_aid->cluster);
+		newbody = (BODYDECLARE *)emalloc((INTBIG)sizeof(BODYDECLARE), vhdl_tool->cluster);
 		newbody->type = type;
 		newbody->pointer = pointer;
 		newbody->next = NULL;
@@ -629,6 +635,7 @@ COMPONENT  *vhdl_parsecomponent(void)
 	/* go through port list */
 	if ((ports = vhdl_parseformal_port_list()) == (FPORTLIST *)PARSE_ERR)
 	{
+		/* EMPTY */ 
 	}
 
 	/* should be pointing to RIGHTBRACKET */
@@ -662,7 +669,7 @@ COMPONENT  *vhdl_parsecomponent(void)
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
-	compo = (COMPONENT *)emalloc((INTBIG)sizeof(COMPONENT), vhdl_aid->cluster);
+	compo = (COMPONENT *)emalloc((INTBIG)sizeof(COMPONENT), vhdl_tool->cluster);
 	compo->name = entity;
 	compo->ports = ports;
 	return(compo);
@@ -706,12 +713,16 @@ BASICDECLARE  *vhdl_parsebasic_declare(void)
 	}
 	else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_SUBTYPE))
 	{
+		/* EMPTY */ 
 	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_CONVERT))
 	{
+		/* EMPTY */ 
 	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ATTRIBUTE))
 	{
+		/* EMPTY */ 
 	} else if (vhdl_nexttoken->token == TOKEN_IDENTIFIER)
 	{
+		/* EMPTY */ 
 	} else
 	{
 		type = BASICDECLARE_OBJECT;
@@ -719,7 +730,7 @@ BASICDECLARE  *vhdl_parsebasic_declare(void)
 	}
 	if (type != NOBASICDECLARE)
 	{
-		basic = (BASICDECLARE *)emalloc((INTBIG)sizeof(BASICDECLARE), vhdl_aid->cluster);
+		basic = (BASICDECLARE *)emalloc((INTBIG)sizeof(BASICDECLARE), vhdl_tool->cluster);
 		basic->type = type;
 		basic->pointer = pointer;
 	} else vhdl_getnexttoken();	/* Bug fix , D.J.Yurach, June, 1988 */
@@ -764,15 +775,17 @@ OBJECTDECLARE  *vhdl_parseobject_declare(void)
 		pointer = (char *)vhdl_parsesignal_declare();
 	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_VARIABLE))
 	{
+		/* EMPTY */ 
 	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ALIAS))
 	{
+		/* EMPTY */ 
 	} else
 	{
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Invalid object declaration"));
 	}
 	if (type != NOOBJECTDECLARE)
 	{
-		object = (OBJECTDECLARE *)emalloc((INTBIG)sizeof(OBJECTDECLARE), vhdl_aid->cluster);
+		object = (OBJECTDECLARE *)emalloc((INTBIG)sizeof(OBJECTDECLARE), vhdl_tool->cluster);
 		object->type = type;
 		object->pointer = pointer;
 	} else
@@ -827,7 +840,7 @@ SIGNALDECLARE  *vhdl_parsesignal_declare(void)
 	}
 	vhdl_getnexttoken();
 
-	signal = (SIGNALDECLARE *)emalloc((INTBIG)sizeof(SIGNALDECLARE), vhdl_aid->cluster);
+	signal = (SIGNALDECLARE *)emalloc((INTBIG)sizeof(SIGNALDECLARE), vhdl_tool->cluster);
 	signal->names = signal_list;
 	signal->subtype = ind;
 	return(signal);
@@ -901,7 +914,7 @@ CONSTANTDECLARE  *vhdl_parseconstant_declare(void)
 	}
 	vhdl_getnexttoken();
 
-	constant = (CONSTANTDECLARE *)emalloc((INTBIG)sizeof(CONSTANTDECLARE), vhdl_aid->cluster);
+	constant = (CONSTANTDECLARE *)emalloc((INTBIG)sizeof(CONSTANTDECLARE), vhdl_tool->cluster);
 	constant->identifier = ident;
 	constant->subtype = ind;
 	constant->expression = expr;
@@ -937,7 +950,7 @@ IDENTLIST  *vhdl_parseident_list(void)
 		vhdl_getnexttoken();
 		return(NULL);
 	}
-	newilist = (IDENTLIST *)emalloc((INTBIG)sizeof(IDENTLIST), vhdl_aid->cluster);
+	newilist = (IDENTLIST *)emalloc((INTBIG)sizeof(IDENTLIST), vhdl_tool->cluster);
 	newilist->identifier = vhdl_nexttoken;
 	newilist->next = NULL;
 	ilist = ilistend = newilist;
@@ -954,7 +967,7 @@ IDENTLIST  *vhdl_parseident_list(void)
 			vhdl_getnexttoken();
 			return(NULL);
 		}
-		newilist = (IDENTLIST *)emalloc((INTBIG)sizeof(IDENTLIST), vhdl_aid->cluster);
+		newilist = (IDENTLIST *)emalloc((INTBIG)sizeof(IDENTLIST), vhdl_tool->cluster);
 		newilist->identifier = vhdl_nexttoken;
 		newilist->next = NULL;
 		ilistend->next = newilist;
@@ -986,7 +999,7 @@ SUBTYPEIND  *vhdl_parsesubtype_indication(void)
 	NAME *type;
 
 	type = vhdl_parsename();
-	ind = (SUBTYPEIND *)emalloc((INTBIG)sizeof(SUBTYPEIND), vhdl_aid->cluster);
+	ind = (SUBTYPEIND *)emalloc((INTBIG)sizeof(SUBTYPEIND), vhdl_tool->cluster);
 	ind->type = type;
 	ind->constraint = NULL;
 	return(ind);
@@ -1051,6 +1064,7 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 		/* check for case statement */
 		if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_CASE))
 		{
+			/* EMPTY */ 
 		}
 
 		/* check for null statement */
@@ -1086,7 +1100,8 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 				pointer = (char *)vhdl_parsegenerate(label, (INTBIG)GENSCHEME_FOR);
 			}
 			/* should be component_instantiation_declaration */
-			else {
+			else
+			{
 				vhdl_nexttoken = label;
 				type = ARCHSTATE_INSTANCE;
 				pointer = (char *)vhdl_parseinstance();
@@ -1107,12 +1122,13 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 		/* should have signal assignment */
 		else
 		{
+			/* EMPTY */ 
 		}
 
 		/* add statement if found */
 		if (type != NOARCHSTATE)
 		{
-			newstate = (STATEMENTS *)emalloc((INTBIG)sizeof(STATEMENTS), vhdl_aid->cluster);
+			newstate = (STATEMENTS *)emalloc((INTBIG)sizeof(STATEMENTS), vhdl_tool->cluster);
 			newstate->type = type;
 			newstate->pointer = pointer;
 			newstate->next = NULL;
@@ -1135,8 +1151,6 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 	return(statements);
 }
 
-char  *vhdl_parseif(void) { return(""); }
-
 /*
 Module:  vhdl_parsegenerate
 ------------------------------------------------------------------------
@@ -1188,7 +1202,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IF"));
 		}
 	}
-	scheme = (GENSCHEME *)emalloc((INTBIG)sizeof(GENSCHEME), vhdl_aid->cluster);
+	scheme = (GENSCHEME *)emalloc((INTBIG)sizeof(GENSCHEME), vhdl_tool->cluster);
 	if (gscheme == GENSCHEME_FOR)
 	{
 		scheme->scheme = GENSCHEME_FOR;
@@ -1282,7 +1296,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 	vhdl_getnexttoken();
 
 	/* create generate statement structure */
-	gen = (GENERATE *)emalloc((INTBIG)sizeof(GENERATE), vhdl_aid->cluster);
+	gen = (GENERATE *)emalloc((INTBIG)sizeof(GENERATE), vhdl_tool->cluster);
 	gen->label = label;
 	gen->gen_scheme = scheme;
 	gen->statements = states;
@@ -1308,7 +1322,7 @@ DISCRETERANGE  *vhdl_parsediscrete_range(void)
 {
 	DISCRETERANGE *drange;
 
-	drange = (DISCRETERANGE *)emalloc((INTBIG)sizeof(DISCRETERANGE), vhdl_aid->cluster);
+	drange = (DISCRETERANGE *)emalloc((INTBIG)sizeof(DISCRETERANGE), vhdl_tool->cluster);
 	/* currently only support ranege option */
 	drange->type = DISCRETERANGE_RANGE;
 	drange->pointer = (char *)vhdl_parserange();
@@ -1338,7 +1352,7 @@ RANGE  *vhdl_parserange(void)
 {
 	RANGE *range;
 
-	range = (RANGE *)emalloc((INTBIG)sizeof(RANGE), vhdl_aid->cluster);
+	range = (RANGE *)emalloc((INTBIG)sizeof(RANGE), vhdl_tool->cluster);
 	/* currently support only simple expression range option */
 	range->type = RANGE_SIMPLE_EXPR;
 	range->pointer = (char *)vhdl_parserange_simple();
@@ -1364,7 +1378,7 @@ RANGESIMPLE  *vhdl_parserange_simple(void)
 {
 	RANGESIMPLE *srange;
 
-	srange = (RANGESIMPLE *)emalloc((INTBIG)sizeof(RANGESIMPLE), vhdl_aid->cluster);
+	srange = (RANGESIMPLE *)emalloc((INTBIG)sizeof(RANGESIMPLE), vhdl_tool->cluster);
 	srange->start = vhdl_parsesimpleexpression();
 
 #ifdef VHDL50
@@ -1470,7 +1484,7 @@ INSTANCE  *vhdl_parseinstance(void)
 	}
 	vhdl_getnexttoken();
 
-	inst = (INSTANCE *)emalloc((INTBIG)sizeof(INSTANCE), vhdl_aid->cluster);
+	inst = (INSTANCE *)emalloc((INTBIG)sizeof(INSTANCE), vhdl_tool->cluster);
 	inst->name = name;
 	inst->entity = entity;
 	inst->ports = ports;
@@ -1528,7 +1542,7 @@ FPORTLIST  *vhdl_parseformal_port_list(void)
 	type = vhdl_parsename();
 
 	/* create port declaration */
-	ports = (FPORTLIST *)emalloc((INTBIG)sizeof(FPORTLIST), vhdl_aid->cluster);
+	ports = (FPORTLIST *)emalloc((INTBIG)sizeof(FPORTLIST), vhdl_tool->cluster);
 	if (ports == 0) return((FPORTLIST *)PARSE_ERR);
 	ports->names = ilist;
 	ports->mode = mode;
@@ -1553,7 +1567,7 @@ FPORTLIST  *vhdl_parseformal_port_list(void)
 		mode = vhdl_parseport_mode();
 		/* should be at type_mark */
 		type = vhdl_parsename();
-		newport = (FPORTLIST *)emalloc((INTBIG)sizeof(FPORTLIST), vhdl_aid->cluster);
+		newport = (FPORTLIST *)emalloc((INTBIG)sizeof(FPORTLIST), vhdl_tool->cluster);
 		if (newport == 0) return((FPORTLIST *)PARSE_ERR);
 		newport->names = ilist;
 		newport->mode = mode;
@@ -1649,7 +1663,7 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 	aplist = lastport = NULL;
 
 	/* should be at least one port association */
-	aplist = (APORTLIST *)emalloc((INTBIG)sizeof(APORTLIST), vhdl_aid->cluster);
+	aplist = (APORTLIST *)emalloc((INTBIG)sizeof(APORTLIST), vhdl_tool->cluster);
 	aplist->type = APORTLIST_NAME;
 	if (vhdl_nexttoken->token != TOKEN_COMMA &&
 		vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
@@ -1685,7 +1699,7 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 	while (vhdl_nexttoken->token == TOKEN_COMMA)
 	{
 		vhdl_getnexttoken();
-		newport = (APORTLIST *)emalloc((INTBIG)sizeof(APORTLIST), vhdl_aid->cluster);
+		newport = (APORTLIST *)emalloc((INTBIG)sizeof(APORTLIST), vhdl_tool->cluster);
 		newport->type = APORTLIST_NAME;
 		if (vhdl_nexttoken->token != TOKEN_COMMA &&
 			vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
@@ -1826,7 +1840,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	vhdl_getnexttoken();
 
 	/* create package structure */
-	package = (PACKAGE *)emalloc((INTBIG)sizeof(PACKAGE), vhdl_aid->cluster);
+	package = (PACKAGE *)emalloc((INTBIG)sizeof(PACKAGE), vhdl_tool->cluster);
 	package->name = identifier;
 	package->declare = declare_part;
 
@@ -1869,7 +1883,7 @@ PACKAGEDPART *vhdl_parsepackage_declare_part(void)
 		return(dpart);
 	}
 	ditem = vhdl_parsebasic_declare();
-	dpart = (PACKAGEDPART *)emalloc((INTBIG)sizeof(PACKAGEDPART), vhdl_aid->cluster);
+	dpart = (PACKAGEDPART *)emalloc((INTBIG)sizeof(PACKAGEDPART), vhdl_tool->cluster);
 	dpart->item = ditem;
 	dpart->next = NULL;
 	endpart = dpart;
@@ -1877,7 +1891,7 @@ PACKAGEDPART *vhdl_parsepackage_declare_part(void)
 	while (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
 		ditem = vhdl_parsebasic_declare();
-		newpart = (PACKAGEDPART *)emalloc((INTBIG)sizeof(PACKAGEDPART), vhdl_aid->cluster);
+		newpart = (PACKAGEDPART *)emalloc((INTBIG)sizeof(PACKAGEDPART), vhdl_tool->cluster);
 		newpart->item = ditem;
 		newpart->next = NULL;
 		endpart->next = newpart;
@@ -1928,7 +1942,7 @@ WITH *vhdl_parsewith(void)
 		vhdl_getnexttoken();
 		return(with);
 	}
-	with = (WITH *)emalloc((INTBIG)sizeof(WITH), vhdl_aid->cluster);
+	with = (WITH *)emalloc((INTBIG)sizeof(WITH), vhdl_tool->cluster);
 	with->unit = vhdl_nexttoken;
 	with->next = NULL;
 	endwith = with;
@@ -1944,7 +1958,7 @@ WITH *vhdl_parsewith(void)
 			vhdl_getnexttoken();
 			return(with);
 		}
-		newwith = (WITH *)emalloc((INTBIG)sizeof(WITH), vhdl_aid->cluster);
+		newwith = (WITH *)emalloc((INTBIG)sizeof(WITH), vhdl_tool->cluster);
 		newwith->unit = vhdl_nexttoken;
 		newwith->next = NULL;
 		endwith->next = newwith;
@@ -2003,7 +2017,7 @@ USE *vhdl_parseuse(void)
 		vhdl_getnexttoken();
 		return(use);
 	}
-	use = (USE *)emalloc((INTBIG)sizeof(USE), vhdl_aid->cluster);
+	use = (USE *)emalloc((INTBIG)sizeof(USE), vhdl_tool->cluster);
 	use->unit = vhdl_nexttoken;
 	use->next = NULL;
 	enduse = use;
@@ -2042,7 +2056,7 @@ USE *vhdl_parseuse(void)
 			vhdl_getnexttoken();
 			return(use);
 		}
-		newuse = (USE *)emalloc((INTBIG)sizeof(USE), vhdl_aid->cluster);
+		newuse = (USE *)emalloc((INTBIG)sizeof(USE), vhdl_tool->cluster);
 		newuse->unit = vhdl_nexttoken;
 		newuse->next = NULL;
 		enduse->next = newuse;
@@ -2520,4 +2534,4 @@ void vhdl_freesetofstatements(STATEMENTS *statements)
 	}
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
