@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -70,12 +70,12 @@ typedef struct Iqport
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 
 /* prototypes for local routines */
-void vhdl_genquisc_interface(DBINTERFACE*);
-INTBIG vhdl_querysize(DBNAME*);
-void vhdl_addidentaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
-void vhdl_addindexedaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
-QPORT *vhdl_createqport(char*, DBPORTLIST*, INTBIG);
-void vhdl_addporttonode(QPORT*, IDENTTABLE*, INTBIG, INTBIG, QNODE**);
+static void vhdl_genquisc_interface(DBINTERFACE*);
+static INTBIG vhdl_querysize(DBNAME*);
+static void vhdl_addidentaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
+static void vhdl_addindexedaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
+static QPORT *vhdl_createqport(char*, DBPORTLIST*, INTBIG);
+static void vhdl_addporttonode(QPORT*, IDENTTABLE*, INTBIG, INTBIG, QNODE**);
 
 /*
 Module:  vhdl_genquisc
@@ -126,7 +126,7 @@ void vhdl_genquisc(void)
 	vhdl_printoneline("!********* End of command file *******************");
 
 	/* scan unresolved references for reality inside of Electric */
-	celllib = (LIBRARY *)askaid(sc_aid, "cell-lib");
+	celllib = (LIBRARY *)asktool(sc_tool, "cell-lib");
 	if (celllib == 0) celllib = NOLIBRARY;
 	total = 0;
 	for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
@@ -250,7 +250,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	{
 		if (fport->type == NULL || fport->type->type == DBTYPE_SINGLE)
 		{
-			newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_aid->cluster);
+			newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_tool->cluster);
 			newnode->name = fport->name;
 			newnode->name_type = QNODE_SNAME;
 			newnode->size = 0;
@@ -268,7 +268,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 			}
 		} else
 		{
-			newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_aid->cluster);
+			newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_tool->cluster);
 			newnode->name = fport->name;
 			newnode->name_type = QNODE_INAME;
 			newnode->flags = QNODE_EXPORT;
@@ -295,7 +295,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				size = 1;
 			}
 			newnode->size = size;
-			newnode->table = (QPORT **)emalloc(sizeof(QNODE *) * size, vhdl_aid->cluster);
+			newnode->table = (QPORT **)emalloc(sizeof(QNODE *) * size, vhdl_tool->cluster);
 			itable = newnode->table;
 			for (i = 0; i < size; i++) itable[i] = NULL;
 		}
@@ -308,7 +308,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		{
 			if (signal->type == NULL || signal->type->type == DBTYPE_SINGLE)
 			{
-				newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_aid->cluster);
+				newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_tool->cluster);
 				newnode->name = signal->name;
 				newnode->name_type = QNODE_SNAME;
 				newnode->size = 0;
@@ -338,7 +338,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				}
 			} else
 			{
-				newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_aid->cluster);
+				newnode = (QNODE *)emalloc(sizeof(QNODE), vhdl_tool->cluster);
 				newnode->name = signal->name;
 				newnode->name_type = QNODE_INAME;
 				newnode->flags = 0;
@@ -368,7 +368,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					size = 1;
 				}
 				newnode->size = size;
-				newnode->table = (QPORT **)emalloc(sizeof(QPORT *) * size, vhdl_aid->cluster);
+				newnode->table = (QPORT **)emalloc(sizeof(QPORT *) * size, vhdl_tool->cluster);
 				itable = newnode->table;
 				for (i = 0; i < size; i++)
 				{
@@ -426,7 +426,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	{
 		if (newnode->name_type == QNODE_SNAME)
 		{
-			if ((qport = newnode->ports))
+			qport = newnode->ports;
+			if (qport)
 			{
 				for (qport2 = qport->next; qport2; qport2 = qport2->next)
 				{
@@ -448,7 +449,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		{
 			for (i = 0; i < newnode->size; i++)
 			{
-				if ((qport = newnode->table[i]))
+				qport = newnode->table[i];
+				if (qport)
 				{
 					for (qport2 = qport->next; qport2; qport2 = qport2->next)
 					{
@@ -468,7 +470,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		{
 			if (newnode->name_type == QNODE_SNAME)
 			{
-				if ((qport = newnode->ports))
+				qport = newnode->ports;
+				if (qport)
 				{
 					switch (newnode->mode)
 					{
@@ -494,7 +497,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					{
 						indexc = newnode->start + i;
 					}
-					if ((qport = newnode->table[i]))
+					qport = newnode->table[i];
+					if (qport)
 					{
 						switch (newnode->mode)
 						{
@@ -525,7 +529,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		{
 			if (newnode->name_type == QNODE_SNAME)
 			{
-				if ((qport = newnode->ports))
+				qport = newnode->ports;
+				if (qport)
 				{
 					vhdl_print("set node-name %s %s %s", (INTBIG)qport->instname,
 						(INTBIG)qport->portname, (INTBIG)newnode->name->string);
@@ -541,7 +546,8 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					{
 						indexc = newnode->start + i;
 					}
-					if ((qport = newnode->table[i]))
+					qport = newnode->table[i];
+					if (qport)
 					{
 						vhdl_print("set node-name %s %s %s[%ld]",
 							(INTBIG)qport->instname, (INTBIG)qport->portname,
@@ -616,9 +622,11 @@ INTBIG vhdl_querysize(DBNAME *name)
 							size = 1;
 							break;
 						case DBTYPE_ARRAY:
-							if ((irange = (DBINDEXRANGE *)name->dbtype->pointer))
+							irange = (DBINDEXRANGE *)name->dbtype->pointer;
+							if (irange)
 							{
-								if ((drange = irange->drange))
+								drange = irange->drange;
+								if (drange)
 								{
 									if (drange->start > drange->end)
 									{
@@ -676,9 +684,11 @@ void vhdl_addidentaport(DBNAME *name, DBPORTLIST *port, INTBIG offset, DBINSTANC
 
 	if (name->dbtype && name->dbtype->type == DBTYPE_ARRAY)
 	{
-		if ((irange = (DBINDEXRANGE *)name->dbtype->pointer))
+		irange = (DBINDEXRANGE *)name->dbtype->pointer;
+		if (irange)
 		{
-			if ((drange = irange->drange))
+			drange = irange->drange;
+			if (drange)
 			{
 				if (drange->start > drange->end)
 				{
@@ -757,13 +767,13 @@ QPORT *vhdl_createqport(char *iname, DBPORTLIST *port, INTBIG offset)
 	QPORT *newport;
 	char buff[80];
 
-	newport = (QPORT *)emalloc(sizeof(QPORT), vhdl_aid->cluster);
+	newport = (QPORT *)emalloc(sizeof(QPORT), vhdl_tool->cluster);
 	newport->instname = iname;
 	newport->next = NULL;
 	if (port->type && port->type->type == DBTYPE_ARRAY)
 	{
 		sprintf(buff, "%s[%ld]", port->name->string, (INTBIG)offset);
-		allocstring(&(newport->portname), buff, vhdl_aid->cluster);
+		allocstring(&(newport->portname), buff, vhdl_tool->cluster);
 		newport->namealloc = 1;
 	} else
 	{
@@ -832,4 +842,4 @@ void vhdl_addporttonode(QPORT *port, IDENTTABLE *ident, INTBIG type, INTBIG inde
 	}
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
