@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -51,49 +51,48 @@ static char		vhdl_default_name[80];
 #endif
 
 /* prototypes for local routines */
-void             vhdl_createdefaulttype(SYMBOLLIST*);
-void             vhdl_sempackage(PACKAGE*);
-DBINTERFACE     *vhdl_seminterface(VINTERFACE*);
-DBBODY          *vhdl_sembody(BODY*);
-DBPORTLIST      *vhdl_semformal_port_list(FPORTLIST*);
-DBBODYDECLARE   *vhdl_sembody_declare(BODYDECLARE*);
-DBCOMPONENTS    *vhdl_semcomponent(COMPONENT*);
-DBSIGNALS       *vhdl_sembasic_declare(BASICDECLARE*);
-DBSIGNALS       *vhdl_semobject_declare(OBJECTDECLARE*);
-DBSIGNALS       *vhdl_semsignal_declare(SIGNALDECLARE*);
-void             vhdl_semconstant_declare(CONSTANTDECLARE*);
-DBSTATEMENTS    *vhdl_semset_of_statements(STATEMENTS*);
-DBINSTANCE      *vhdl_seminstance(INSTANCE*);
-DBSTATEMENTS    *vhdl_semgenerate(GENERATE*);
+static void             vhdl_createdefaulttype(SYMBOLLIST*);
+static void             vhdl_sempackage(PACKAGE*);
+static DBINTERFACE     *vhdl_seminterface(VINTERFACE*);
+static DBBODY          *vhdl_sembody(BODY*);
+static DBPORTLIST      *vhdl_semformal_port_list(FPORTLIST*);
+static DBBODYDECLARE   *vhdl_sembody_declare(BODYDECLARE*);
+static DBCOMPONENTS    *vhdl_semcomponent(COMPONENT*);
+static DBSIGNALS       *vhdl_sembasic_declare(BASICDECLARE*);
+static DBSIGNALS       *vhdl_semobject_declare(OBJECTDECLARE*);
+static DBSIGNALS       *vhdl_semsignal_declare(SIGNALDECLARE*);
+static void             vhdl_semconstant_declare(CONSTANTDECLARE*);
+static DBSTATEMENTS    *vhdl_semset_of_statements(STATEMENTS*);
+static DBINSTANCE      *vhdl_seminstance(INSTANCE*);
+static DBSTATEMENTS    *vhdl_semgenerate(GENERATE*);
 #ifdef VHDL50
-  void           vhdl_semwith(WITH*);
+  static void           vhdl_semwith(WITH*);
 #endif
-void             vhdl_semuse(USE*);
-SYMBOLTREE      *vhdl_searchfsymbol(IDENTTABLE*, SYMBOLLIST*);
-SYMBOLTREE      *vhdl_searchsymboltree(IDENTTABLE*, SYMBOLTREE*);
-SYMBOLTREE      *vhdl_addsymbol(IDENTTABLE*, INTBIG, char*, SYMBOLLIST*);
-SYMBOLTREE      *vhdl_addsymboltree(IDENTTABLE*, INTBIG, char*, SYMBOLTREE*);
-SYMBOLLIST      *vhdl_pushsymbols(SYMBOLLIST*);
-SYMBOLLIST      *vhdl_popsymbols(SYMBOLLIST*);
-void             vhdl_addprimitiveentities(FILE*);
-void             vhdl_semaport_check(NAME*);
-void             vhdl_semaport_check_single_name(SINGLENAME*);
-char            *vhdl_parsescalar_type(void);
-COMPOSITE       *vhdl_parsecomposite_type(void);
-char            *vhdl_parserecord_type(void);
-ARRAY           *vhdl_parsearray_type(void);
-void             vhdl_semtype_declare(TYPE*);
-DBTYPE          *vhdl_semcomposite_type(COMPOSITE*);
-DBTYPE          *vhdl_semarray_type(ARRAY*);
-DBTYPE          *vhdl_semconstrained_array(CONSTRAINED*);
-DBDISCRETERANGE *vhdl_semdiscrete_range(DISCRETERANGE*);
-DBDISCRETERANGE *vhdl_semrange(RANGE*);
-DBTYPE          *vhdl_semsubtype_indication(SUBTYPEIND*);
-DBTYPE          *vhdl_semtype_mark(NAME*);
-DBTYPE          *vhdl_getsymboltype(SYMBOLTREE*);
-void             vhdl_freesymboltree(SYMBOLTREE *tree);
+static void             vhdl_semuse(USE*);
+static SYMBOLTREE      *vhdl_searchfsymbol(IDENTTABLE*, SYMBOLLIST*);
+static SYMBOLTREE      *vhdl_searchsymboltree(IDENTTABLE*, SYMBOLTREE*);
+static SYMBOLTREE      *vhdl_addsymbol(IDENTTABLE*, INTBIG, char*, SYMBOLLIST*);
+static SYMBOLTREE      *vhdl_addsymboltree(IDENTTABLE*, INTBIG, char*, SYMBOLTREE*);
+static SYMBOLLIST      *vhdl_pushsymbols(SYMBOLLIST*);
+static SYMBOLLIST      *vhdl_popsymbols(SYMBOLLIST*);
+static void             vhdl_semaport_check(NAME*);
+static void             vhdl_semaport_check_single_name(SINGLENAME*);
+static char            *vhdl_parsescalar_type(void);
+static COMPOSITE       *vhdl_parsecomposite_type(void);
+static char            *vhdl_parserecord_type(void);
+static ARRAY           *vhdl_parsearray_type(void);
+static void             vhdl_semtype_declare(TYPE*);
+static DBLTYPE         *vhdl_semcomposite_type(COMPOSITE*);
+static DBLTYPE         *vhdl_semarray_type(ARRAY*);
+static DBLTYPE         *vhdl_semconstrained_array(CONSTRAINED*);
+static DBDISCRETERANGE *vhdl_semdiscrete_range(DISCRETERANGE*);
+static DBDISCRETERANGE *vhdl_semrange(RANGE*);
+static DBLTYPE         *vhdl_semsubtype_indication(SUBTYPEIND*);
+static DBLTYPE         *vhdl_semtype_mark(NAME*);
+static DBLTYPE         *vhdl_getsymboltype(SYMBOLTREE*);
+static void             vhdl_freesymboltree(SYMBOLTREE *tree);
 
-int vhdl_freeinggsymbols;
+static int vhdl_freeinggsymbols;
 
 void vhdl_freesemantic(void)
 {
@@ -216,7 +215,7 @@ void vhdl_freesemantic(void)
 
 void vhdl_freesymboltree(SYMBOLTREE *tree)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 	DBINDEXRANGE *range;
 
 	if (tree->pointer != 0)
@@ -228,7 +227,7 @@ void vhdl_freesymboltree(SYMBOLTREE *tree)
 					efree((char *)tree->pointer);
 				break;
 			case SYMBOL_TYPE:
-				dbtype = (DBTYPE *)tree->pointer;
+				dbtype = (DBLTYPE *)tree->pointer;
 				while (dbtype->pointer != 0)
 				{
 					range = (DBINDEXRANGE *)dbtype->pointer;
@@ -271,7 +270,7 @@ INTSML vhdl_semantic(void)
 	/* first free previous semantic memory */
 	vhdl_freesemantic();
 
-	vhdl_units = (DBUNITS *)emalloc((INTBIG)sizeof(DBUNITS), vhdl_aid->cluster);
+	vhdl_units = (DBUNITS *)emalloc((INTBIG)sizeof(DBUNITS), vhdl_tool->cluster);
 	vhdl_units->interfaces = endinterface = 0;
 	vhdl_units->bodies = endbody = 0;
 
@@ -352,7 +351,7 @@ void vhdl_createdefaulttype(SYMBOLLIST *symbols)
 	char *bitname;
 
 	/* type BIT */
-	bitname = (char *)emalloc(4, vhdl_aid->cluster);
+	bitname = (char *)emalloc(4, vhdl_tool->cluster);
 	(void)strcpy(bitname, "BIT");
 	if ((ikey = vhdl_findidentkey(bitname)) == 0)
 	{
@@ -362,7 +361,7 @@ void vhdl_createdefaulttype(SYMBOLLIST *symbols)
 	vhdl_addsymbol(ikey, (INTBIG)SYMBOL_TYPE, (char *)0, symbols);
 
 	/* type "std_logic" */
-	bitname = (char *)emalloc(10, vhdl_aid->cluster);
+	bitname = (char *)emalloc(10, vhdl_tool->cluster);
 	(void)strcpy(bitname, "std_logic");
 	if ((ikey = vhdl_findidentkey(bitname)) == 0)
 	{
@@ -399,7 +398,7 @@ void vhdl_sempackage(PACKAGE *package)
 		vhdl_reporterrormsg(package->name, _("Symbol previously defined"));
 	} else
 	{
-		dbpackage = (DBPACKAGE *)emalloc((INTBIG)sizeof(DBPACKAGE), vhdl_aid->cluster);
+		dbpackage = (DBPACKAGE *)emalloc((INTBIG)sizeof(DBPACKAGE), vhdl_tool->cluster);
 		dbpackage->name = (IDENTTABLE *)package->name->pointer;
 		dbpackage->root = 0;
 		vhdl_addsymbol(dbpackage->name, (INTBIG)SYMBOL_PACKAGE, (char *)dbpackage, vhdl_gsymbols);
@@ -444,7 +443,7 @@ DBINTERFACE  *vhdl_seminterface(VINTERFACE *interfacef)
 		vhdl_reporterrormsg(interfacef->name, _("Entity previously defined"));
 	} else
 	{
-		dbinter = (DBINTERFACE *)emalloc((INTBIG)sizeof(DBINTERFACE), vhdl_aid->cluster);
+		dbinter = (DBINTERFACE *)emalloc((INTBIG)sizeof(DBINTERFACE), vhdl_tool->cluster);
 		dbinter->name = (IDENTTABLE *)interfacef->name->pointer;
 		dbinter->ports = 0;
 		dbinter->flags = 0;
@@ -496,7 +495,7 @@ DBBODY *vhdl_sembody(BODY *body)
 	}
 
 	/* create dbbody */
-	dbbody = (DBBODY *)emalloc((INTBIG)sizeof(DBBODY), vhdl_aid->cluster);
+	dbbody = (DBBODY *)emalloc((INTBIG)sizeof(DBBODY), vhdl_tool->cluster);
 	dbbody->classnew = body->classnew;
 	dbbody->name = (IDENTTABLE *)body->name->pointer;
 	dbbody->entity = 0;
@@ -609,12 +608,12 @@ DBPORTLIST *vhdl_semformal_port_list(FPORTLIST *port)
 			} else
 			{
 				/* add to port list */
-				newport = (DBPORTLIST *)emalloc((INTBIG)sizeof(DBPORTLIST), vhdl_aid->cluster);
+				newport = (DBPORTLIST *)emalloc((INTBIG)sizeof(DBPORTLIST), vhdl_tool->cluster);
 				newport->name = (IDENTTABLE *)names->identifier->pointer;
 				newport->mode = port->mode;
 				if (symbol)
 				{
-					newport->type = (DBTYPE *)symbol->pointer;
+					newport->type = (DBLTYPE *)symbol->pointer;
 				} else
 				{
 					newport->type = 0;
@@ -659,7 +658,7 @@ DBBODYDECLARE *vhdl_sembody_declare(BODYDECLARE *declare)
 
 	dbdeclare = 0;
 	if (declare == 0) return(dbdeclare);
-	dbdeclare = (DBBODYDECLARE *)emalloc((INTBIG)sizeof(DBBODYDECLARE), vhdl_aid->cluster);
+	dbdeclare = (DBBODYDECLARE *)emalloc((INTBIG)sizeof(DBBODYDECLARE), vhdl_tool->cluster);
 	dbdeclare->components = endcomponent = 0;
 	dbdeclare->signals = endsignal = 0;
 
@@ -734,7 +733,7 @@ DBCOMPONENTS *vhdl_semcomponent(COMPONENT *compo)
 		vhdl_reporterrormsg(compo->name, _("Identifier previously defined"));
 		return(dbcomp);
 	}
-	dbcomp = (DBCOMPONENTS *)emalloc((INTBIG)sizeof(DBCOMPONENTS), vhdl_aid->cluster);
+	dbcomp = (DBCOMPONENTS *)emalloc((INTBIG)sizeof(DBCOMPONENTS), vhdl_tool->cluster);
 	dbcomp->name = (IDENTTABLE *)compo->name->pointer;
 	dbcomp->ports = 0;
 	dbcomp->next = 0;
@@ -858,11 +857,11 @@ DBSIGNALS *vhdl_semsignal_declare(SIGNALDECLARE *signal)
 			vhdl_reporterrormsg(sig->identifier, _("Signal previously defined"));
 		} else
 		{
-			newsignal = (DBSIGNALS *)emalloc((INTBIG)sizeof(DBSIGNALS), vhdl_aid->cluster);
+			newsignal = (DBSIGNALS *)emalloc((INTBIG)sizeof(DBSIGNALS), vhdl_tool->cluster);
 			newsignal->name = (IDENTTABLE *)sig->identifier->pointer;
 			if (symbol)
 			{
-				newsignal->type = (DBTYPE *)symbol->pointer;
+				newsignal->type = (DBLTYPE *)symbol->pointer;
 			} else
 			{
 				newsignal->type = 0;
@@ -928,7 +927,7 @@ DBSTATEMENTS *vhdl_semset_of_statements(STATEMENTS *state)
 
 	dbstates = 0;
 	if (state == 0) return(dbstates);
-	dbstates = (DBSTATEMENTS *)emalloc((INTBIG)sizeof(DBSTATEMENTS), vhdl_aid->cluster);
+	dbstates = (DBSTATEMENTS *)emalloc((INTBIG)sizeof(DBSTATEMENTS), vhdl_tool->cluster);
 	dbstates->instances = endinstance = 0;
 	for (; state != 0; state = state->next)
 	{
@@ -1032,7 +1031,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 		/* add to global name space */
 		if ((ikey = vhdl_findidentkey(sbuffer)) == 0)
 		{
-			allocstring(&sptr, sbuffer, vhdl_aid->cluster);
+			allocstring(&sptr, sbuffer, vhdl_tool->cluster);
 			ikey = vhdl_makeidentkey(sptr);
 			if (ikey == 0) return((DBINSTANCE *)0);
 		}
@@ -1040,7 +1039,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	{
 		ikey = (IDENTTABLE *)inst->name->pointer;
 	}
-	dbinst = (DBINSTANCE *)emalloc((INTBIG)sizeof(DBINSTANCE), vhdl_aid->cluster);
+	dbinst = (DBINSTANCE *)emalloc((INTBIG)sizeof(DBINSTANCE), vhdl_tool->cluster);
 	dbinst->name = ikey;
 	dbinst->compo = 0;
 	dbinst->ports = enddbaport = 0;
@@ -1097,7 +1096,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	}
 	for (aplist = inst->ports; aplist != 0; aplist = aplist->next)
 	{
-		dbaport = (DBAPORTLIST *)emalloc((INTBIG)sizeof(DBAPORTLIST), vhdl_aid->cluster);
+		dbaport = (DBAPORTLIST *)emalloc((INTBIG)sizeof(DBAPORTLIST), vhdl_tool->cluster);
 		dbaport->name = 0;
 		dbaport->port = plist;
 		if (plist)
@@ -1475,7 +1474,7 @@ SYMBOLTREE *vhdl_addsymbol(IDENTTABLE *value, INTBIG type, char *pointer, SYMBOL
 		symbol = vhdl_addsymboltree(value, (INTBIG)type, pointer, sym_list->root);
 	} else
 	{
-		sym_list->root = (SYMBOLTREE *)emalloc((INTBIG)sizeof(SYMBOLTREE), vhdl_aid->cluster);
+		sym_list->root = (SYMBOLTREE *)emalloc((INTBIG)sizeof(SYMBOLTREE), vhdl_tool->cluster);
 		sym_list->root->value = value;
 		sym_list->root->type = type;
 		sym_list->root->pointer = pointer;
@@ -1531,7 +1530,7 @@ SYMBOLTREE *vhdl_addsymboltree(IDENTTABLE *value, INTBIG type, char *pointer, SY
 	}
 
 	/* create new node */
-	newnode = (SYMBOLTREE *)emalloc((INTBIG)sizeof(SYMBOLTREE), vhdl_aid->cluster);
+	newnode = (SYMBOLTREE *)emalloc((INTBIG)sizeof(SYMBOLTREE), vhdl_tool->cluster);
 	newnode->value = value;
 	newnode->type = type;
 	newnode->pointer = pointer;
@@ -1558,7 +1557,7 @@ SYMBOLLIST *vhdl_pushsymbols(SYMBOLLIST *old_sym_list)
 {
 	SYMBOLLIST *new_sym_list;
 
-	new_sym_list = (SYMBOLLIST *)emalloc((INTBIG)sizeof(SYMBOLLIST), vhdl_aid->cluster);
+	new_sym_list = (SYMBOLLIST *)emalloc((INTBIG)sizeof(SYMBOLLIST), vhdl_tool->cluster);
 	new_sym_list->root = 0;
 	new_sym_list->last = old_sym_list;
 
@@ -1766,7 +1765,7 @@ TYPE *vhdl_parsetype(void)
 	}
 	vhdl_getnexttoken();
 
-	type = (TYPE *)emalloc((INTBIG)sizeof(TYPE), vhdl_aid->cluster);
+	type = (TYPE *)emalloc((INTBIG)sizeof(TYPE), vhdl_tool->cluster);
 	type->identifier = ident;
 	type->type = type_define;
 	type->pointer = pointer;
@@ -1811,7 +1810,7 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 		return(compo);
 	}
 
-	compo = (COMPOSITE *)emalloc((INTBIG)sizeof(COMPOSITE), vhdl_aid->cluster);
+	compo = (COMPOSITE *)emalloc((INTBIG)sizeof(COMPOSITE), vhdl_tool->cluster);
 	compo->type = type;
 	compo->pointer = pointer;
 
@@ -1877,7 +1876,7 @@ ARRAY *vhdl_parsearray_type(void)
 	vhdl_getnexttoken();
 
 	/* should at least one discrete range */
-	iconstraint = (INDEXCONSTRAINT *)emalloc((INTBIG)sizeof(INDEXCONSTRAINT), vhdl_aid->cluster);
+	iconstraint = (INDEXCONSTRAINT *)emalloc((INTBIG)sizeof(INDEXCONSTRAINT), vhdl_tool->cluster);
 	iconstraint->discrete = vhdl_parsediscrete_range();
 	iconstraint->next = NULL;
 	endconstraint = iconstraint;
@@ -1886,7 +1885,7 @@ ARRAY *vhdl_parsearray_type(void)
 	while (vhdl_nexttoken->token == TOKEN_COMMA)
 	{
 		vhdl_getnexttoken();
-		newconstraint = (INDEXCONSTRAINT *)emalloc((INTBIG)sizeof(INDEXCONSTRAINT), vhdl_aid->cluster);
+		newconstraint = (INDEXCONSTRAINT *)emalloc((INTBIG)sizeof(INDEXCONSTRAINT), vhdl_tool->cluster);
 		newconstraint->discrete = vhdl_parsediscrete_range();
 		newconstraint->next = NULL;
 		endconstraint->next = newconstraint;
@@ -1915,9 +1914,9 @@ ARRAY *vhdl_parsearray_type(void)
 	subtype = vhdl_parsesubtype_indication();
 
 	/* create array type definition */
-	array = (ARRAY *)emalloc((INTBIG)sizeof(ARRAY), vhdl_aid->cluster);
+	array = (ARRAY *)emalloc((INTBIG)sizeof(ARRAY), vhdl_tool->cluster);
 	array->type = ARRAY_CONSTRAINED;
-	constr = (CONSTRAINED *)emalloc((INTBIG)sizeof(CONSTRAINED), vhdl_aid->cluster);
+	constr = (CONSTRAINED *)emalloc((INTBIG)sizeof(CONSTRAINED), vhdl_tool->cluster);
 	array->pointer = (char *)constr;
 	constr->constraint = iconstraint;
 	constr->subtype = subtype;
@@ -1940,7 +1939,7 @@ type		*TYPE		Pointer to type parse tree.
 */
 void vhdl_semtype_declare(TYPE *type)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 
 	dbtype = NULL;
 	if (type == NULL) return;
@@ -1983,12 +1982,12 @@ Calling Sequence:  dbtype = vhdl_semcomposite_type(composite);
 Name		Type		Description
 ----		----		-----------
 composite	*COMPOSITE	Pointer to composite type structure.
-dbtype		*DBTYPE		Generated db type.
+dbtype		*DBLTYPE	Generated db type.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_semcomposite_type(COMPOSITE *composite)
+DBLTYPE *vhdl_semcomposite_type(COMPOSITE *composite)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 
 	dbtype = NULL;
 	if (composite == NULL) return(dbtype);
@@ -2016,12 +2015,12 @@ Calling Sequence:  dbtype = vhdl_semarray_type(array);
 Name		Type		Description
 ----		----		-----------
 array		*ARRAY		Pointer to composite array type structure.
-dbtype		*DBTYPE		Pointer to generated type.
+dbtype		*DBLTYPE	Pointer to generated type.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_semarray_type(ARRAY *array)
+DBLTYPE *vhdl_semarray_type(ARRAY *array)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 
 	dbtype = NULL;
 	if (array == NULL) return(dbtype);
@@ -2049,18 +2048,18 @@ Calling Sequence:  dbtype = vhdl_semconstrained_array(constr);
 Name		Type			Description
 ----		----			-----------
 constr		*CONSTRAINED	Pointer to constrained array structure.
-dbtype		*DBTYPE			Pointer to generated type.
+dbtype		*DBLTYPE		Pointer to generated type.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_semconstrained_array(CONSTRAINED *constr)
+DBLTYPE *vhdl_semconstrained_array(CONSTRAINED *constr)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 	INDEXCONSTRAINT *indexc;
 	DBINDEXRANGE *newrange, *endrange;
 
 	dbtype = NULL;
 	if (constr == NULL) return(dbtype);
-	dbtype = (DBTYPE *)emalloc((INTBIG)sizeof(DBTYPE), vhdl_aid->cluster);
+	dbtype = (DBLTYPE *)emalloc((INTBIG)sizeof(DBLTYPE), vhdl_tool->cluster);
 	dbtype->name = NULL;
 	dbtype->type = DBTYPE_ARRAY;
 	endrange = NULL;
@@ -2070,7 +2069,7 @@ DBTYPE *vhdl_semconstrained_array(CONSTRAINED *constr)
 	/* check index constraint */
 	for (indexc = constr->constraint; indexc != NULL; indexc = indexc->next)
 	{
-		newrange = (DBINDEXRANGE *)emalloc((INTBIG)sizeof(DBINDEXRANGE), vhdl_aid->cluster);
+		newrange = (DBINDEXRANGE *)emalloc((INTBIG)sizeof(DBINDEXRANGE), vhdl_tool->cluster);
 		newrange->drange = vhdl_semdiscrete_range(indexc->discrete);
 		newrange->next = NULL;
 		if (endrange == NULL)
@@ -2148,9 +2147,10 @@ DBDISCRETERANGE *vhdl_semrange(RANGE *range)
 		case RANGE_ATTRIBUTE:
 			break;
 		case RANGE_SIMPLE_EXPR:
-			if ((rsimp = (RANGESIMPLE *)range->pointer))
+			rsimp = (RANGESIMPLE *)range->pointer;
+			if (rsimp)
 			{
-				dbrange = (DBDISCRETERANGE *)emalloc((INTBIG)sizeof(DBDISCRETERANGE), vhdl_aid->cluster);
+				dbrange = (DBDISCRETERANGE *)emalloc((INTBIG)sizeof(DBDISCRETERANGE), vhdl_tool->cluster);
 				dbrange->start = vhdl_evalsimpleexpr(rsimp->start);
 				dbrange->end = vhdl_evalsimpleexpr(rsimp->end);
 			}
@@ -2172,12 +2172,12 @@ Calling Sequence:  dbtype = vhdl_semsubtype_indication(subtype);
 Name		Type		Description
 ----		----		-----------
 subtype		*SUBTYPEIND	Pointer to subtype indication.
-dbtype		*DBTYPE		Pointer to db type;
+dbtype		*DBLTYPE	Pointer to db type;
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_semsubtype_indication(SUBTYPEIND *subtype)
+DBLTYPE *vhdl_semsubtype_indication(SUBTYPEIND *subtype)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 
 	dbtype = NULL;
 	if (subtype == NULL) return(dbtype);;
@@ -2196,12 +2196,12 @@ Calling Sequence:  dbtype = vhdl_semtype_mark(name);
 Name		Type		Description
 ----		----		-----------
 name		*NAME		Pointer to type name.
-dbtype		*DBTYPE		Pointer to db type.
+dbtype		*DBLTYPE	Pointer to db type.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_semtype_mark(NAME *name)
+DBLTYPE *vhdl_semtype_mark(NAME *name)
 {
-	DBTYPE *dbtype;
+	DBLTYPE *dbtype;
 	SYMBOLTREE *symbol;
 
 	dbtype = NULL;
@@ -2212,7 +2212,7 @@ DBTYPE *vhdl_semtype_mark(NAME *name)
 		vhdl_reporterrormsg(vhdl_getnametoken(name), _("Bad type"));
 	} else
 	{
-		dbtype = (DBTYPE *)symbol->pointer;
+		dbtype = (DBLTYPE *)symbol->pointer;
 	}
 	return(dbtype);
 }
@@ -2229,13 +2229,12 @@ Calling Sequence:  type = vhdl_getsymboltype(symbol);
 Name		Type		Description
 ----		----		-----------
 symbol		*SYMBOLTREE	Pointer to symbol.
-type		*DBTYPE		Pointer to returned type, NULL if no
-								type exists.
+type		*DBLTYPE	Pointer to returned type, NULL if no type exists.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_getsymboltype(SYMBOLTREE *symbol)
+DBLTYPE *vhdl_getsymboltype(SYMBOLTREE *symbol)
 {
-	DBTYPE *type;
+	DBLTYPE *type;
 	DBPORTLIST *fport;
 	DBSIGNALS *signal;
 
@@ -2252,7 +2251,7 @@ DBTYPE *vhdl_getsymboltype(SYMBOLTREE *symbol)
 			type = signal->type;
 			break;
 		case SYMBOL_TYPE:
-			type = (DBTYPE *)symbol->pointer;
+			type = (DBLTYPE *)symbol->pointer;
 			break;
 		default:
 			break;
@@ -2271,12 +2270,12 @@ Calling Sequence:  type = vhdl_gettype(ident);
 Name		Type		Description
 ----		----		-----------
 ident		*IDENTTABLE	Pointer to identifier.
-type		*DBTYPE		Returned type, NULL if no type.
+type		*DBLTYPE	Returned type, NULL if no type.
 ------------------------------------------------------------------------
 */
-DBTYPE *vhdl_gettype(IDENTTABLE *ident)
+DBLTYPE *vhdl_gettype(IDENTTABLE *ident)
 {
-	DBTYPE *type;
+	DBLTYPE *type;
 	SYMBOLTREE *symbol;
 
 	type = NULL;
@@ -2291,4 +2290,4 @@ DBTYPE *vhdl_gettype(IDENTTABLE *ident)
 	return(type);
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
