@@ -30,7 +30,7 @@
  */
 
 #include "config.h"
-#if VHDLAID
+#if VHDLTOOL
 
 #include "global.h"
 #include "vhdl.h"
@@ -41,9 +41,9 @@ extern SYMBOLLIST	*vhdl_gsymbols;
 static DBINTERFACE  *vhdl_top_interface;
 
 /* prototypes for local routines */
-void vhdl_gensilos_interface(DBINTERFACE*, char*);
-void vhdl_gensilos_aport(DBINTERFACE*, DBNAME*);
-INTSML vhdl_gensilos_isport(DBINTERFACE*, DBNAME*);
+static void vhdl_gensilos_interface(DBINTERFACE*, char*);
+static void vhdl_gensilos_aport(DBINTERFACE*, DBNAME*);
+static INTSML vhdl_gensilos_isport(DBINTERFACE*, DBNAME*);
 
 /*
 Module:  vhdl_gensilos
@@ -171,6 +171,7 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 			{
 				/* Should have gate entity */
 				/* should be automatically added at end of .net file */
+				/* EMPTY */ 
 			} else
 			{
 				vhdl_gensilos_interface((DBINTERFACE *)symbol->pointer, inst->compo->name->string);
@@ -373,4 +374,4 @@ INTSML vhdl_gensilos_isport(DBINTERFACE *interfacef, DBNAME *name)
 	return(0);
 }
 
-#endif  /* VHDLAID - at top */
+#endif  /* VHDLTOOL - at top */
